/*! confusionflow - v0.1.0 - 2018
* https://confusionflow.org
* Copyright (c) 2018 The ConfusionFlow Team; Licensed BSD-3-Clause*/
webpackJsonp([13,14],[function(t,e,n){"use strict";function r(t,e){function n(){this.constructor=t}a(t,e),t.prototype=null===e?Object.create(e):(n.prototype=e.prototype,new n)}function i(t,e,n,r){return new(n||(n=Promise))(function(i,o){function a(t){try{u(r.next(t))}catch(t){o(t)}}function s(t){try{u(r.throw(t))}catch(t){o(t)}}function u(t){t.done?i(t.value):new n(function(e){e(t.value)}).then(a,s)}u((r=r.apply(t,e||[])).next())})}function o(t,e){function n(t){return function(e){return r([t,e])}}function r(n){if(i)throw new TypeError("Generator is already executing.");for(;u;)try{if(i=1,o&&(a=o[2&n[0]?"return":n[0]?"throw":"next"])&&!(a=a.call(o,n[1])).done)return a;switch(o=0,a&&(n=[0,a.value]),n[0]){case 0:case 1:a=n;break;case 4:return u.label++,{value:n[1],done:!1};case 5:u.label++,o=n[1],n=[0];continue;case 7:n=u.ops.pop(),u.trys.pop();continue;default:if(a=u.trys,!(a=a.length>0&&a[a.length-1])&&(6===n[0]||2===n[0])){u=0;continue}if(3===n[0]&&(!a||n[1]>a[0]&&n[1]<a[3])){u.label=n[1];break}if(6===n[0]&&u.label<a[1]){u.label=a[1],a=n;break}if(a&&u.label<a[2]){u.label=a[2],u.ops.push(n);break}a[2]&&u.ops.pop(),u.trys.pop();continue}n=e.call(t,u)}catch(t){n=[6,t],o=0}finally{i=a=0}if(5&n[0])throw n[1];return{value:n[0]?n[1]:void 0,done:!0}}var i,o,a,s,u={label:0,sent:function(){if(1&a[0])throw a[1];return a[1]},trys:[],ops:[]};return s={next:n(0),throw:n(1),return:n(2)},"function"==typeof Symbol&&(s[Symbol.iterator]=function(){return this}),s}e.c=r,e.a=i,e.b=o;/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */
var a=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(t,e){t.__proto__=e}||function(t,e){for(var n in e)e.hasOwnProperty(n)&&(t[n]=e[n])};Object.assign},function(t,e,n){"use strict";function r(t){void 0===t&&(t={}),t=o({offline:v,server_url:y,server_json_suffix:m},t),v=t.offline,y=t.server_url,m=t.server_json_suffix}function i(){function t(t,e){void 0===e&&(e=t.slice(0,1).toUpperCase()+t.slice(1));var n=document.currentScript||document.querySelector("script[data-phovea-"+t+"]");if(n)return n.dataset["phovea"+e]}var e={};"true"===t("offline")&&(e.offline=!0);var n;void 0!==(n=t("server-url","ServerUrl"))&&(e.server_url=n),void 0!==(n=t("server-json-suffix","ServerJsonSuffix"))&&(e.server_json_suffix=n),r(e)}function o(t,e){function n(t,e){return Object.keys(e).forEach(function(r){var i=e[r];"[object Object]"===Object.prototype.toString.call(i)?t[r]=null!=t[r]?n(t[r],i):i:t[r]=i}),t}for(var r=[],i=2;i<arguments.length;i++)r[i-2]=arguments[i];return r.unshift(e),r.forEach(function(e){e&&(t=n(t,e))}),t}function a(t){void 0===t&&(t=8);for(var e="";e.length<t;)e+=Math.random().toString(36).slice(-8);return e.substr(0,t)}function s(t){return t.replace(/[\s!#$%&'()*+,.\/:;<=>?@\[\\\]\^`{|}~_-]/g," ").trim().split(/\s+/).map(function(t,e){return(0===e?t[0].toLowerCase():t[0].toUpperCase())+t.slice(1)}).join("")}function u(t,e){n.i(g.c)(t,e)}var l=n(23);n.d(e,"i",function(){return l.a}),n.d(e,"h",function(){return l.b});var c=(n(24),n(7));n.d(e,"k",function(){return c.c}),n.d(e,"l",function(){return c.b}),n.d(e,"a",function(){return c.a});var f=n(21);n.d(e,"f",function(){return f.a});var h=(n(19),n(6)),p=n(4),d=n(22),g=n(0);n.d(e,"c",function(){return v}),n.d(e,"d",function(){return y}),n.d(e,"e",function(){return m}),e.b=o,e.m=a,e.g=s,e.j=u;var v=!1,y="/api",m="";i();new d.a,new h.a,new p.a(location.search)},function(t,e,n){"use strict";function r(t,e){var n=e.trim();if("new"===n&&(n="new default"),"create"===n){if("function"==typeof t.create)return t.create;"function"==typeof t.default?n=void 0!==t.default.prototype?"new default":"default":console.error("neighter a default export nor the 'create' method exists in the module:",t)}if(n.startsWith("new ")){var r=n.substring("new ".length);return function(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];var i;return new((i=t[r]).bind.apply(i,[void 0].concat(e)))}}return t[n]}function i(t,e,i,o){var a=this,s="string"==typeof e?e:n.i(l.a)(t),f=i,h=n.i(l.b)({type:t,id:s,name:s,factory:"create",description:"",version:"1.0.0",load:function(){return u.a(a,void 0,void 0,function(){var t;return u.b(this,function(e){switch(e.label){case 0:return[4,Promise.resolve(f())];case 1:return t=e.sent(),[2,{desc:h,factory:r(t,h.factory)}]}})})}},"function"==typeof i?o:i);c.push(h)}function o(t,e){"function"==typeof e&&(f.has(t)||(f.add(t),e({push:i,flags:{}})))}function a(t){if(void 0===t&&(t=function(){return!0}),"string"==typeof t){var e=t;t=function(t){return t.type===e}}return c.filter(t)}function s(t,e){return c.find(function(n){return n.type===t&&n.id===e})}var u=n(0),l=n(1);e.b=o,e.c=a,e.a=s;var c=[],f=new Set},function(t,e,n){"use strict";function r(t,e,n){return new u(t,e,n,n)}function i(t,e){return new u(t.type,t.args,e,t.target)}function o(t,e){return f.on(t,e)}function a(t,e){return f.off(t,e)}function s(t){for(var e=[],n=1;n<arguments.length;n++)e[n-1]=arguments[n];return f.fire.apply(f,[t].concat(e))}n.d(e,"b",function(){return c}),e.c=o,e.d=a,e.a=s;var u=function(){function t(t,e,n,r){this.type=t,this.args=e,this.target=n,this.delegateTarget=r,this.timeStamp=new Date,this.stopped=!1,this.stopedPropagation=!1}return Object.defineProperty(t.prototype,"currentTarget",{get:function(){return this.target},enumerable:!0,configurable:!0}),t.prototype.isImmediatePropagationStopped=function(){return this.stopped},t.prototype.stopImmediatePropagation=function(){this.stopped=!0},t.prototype.isPropagationStopped=function(){return this.stopedPropagation},t.prototype.stopPropagation=function(){this.stopedPropagation=!0},t}(),l=function(){function t(t){this.type=t,this.listeners=[]}return t.prototype.push=function(t){this.listeners.push(t)},t.prototype.remove=function(t){var e=this.listeners.indexOf(t);return e>=0&&(this.listeners.splice(e,1),!0)},t.prototype.fire=function(t){if(0===this.listeners.length)return!1;var e=[t].concat(t.args);if(1===this.listeners.length)this.listeners[0].apply(t,e);else for(var n=this.listeners.slice(),r=n.length,i=0;i<r&&!t.isImmediatePropagationStopped();++i)n[i].apply(t,e);return!0},Object.defineProperty(t.prototype,"length",{get:function(){return this.listeners.length},enumerable:!0,configurable:!0}),t}(),c=function(){function t(){var t=this;this.handlers=new Map,this.propagationHandler=function(e){e.isPropagationStopped()||t.fireEvent(i(e,t))}}return t.prototype.on=function(e,n){var r=this;return"string"==typeof e?e.split(t.MULTI_EVENT_SEPARATOR).forEach(function(t){r.handlers.has(t)||r.handlers.set(t,new l(t)),r.handlers.get(t).push(n)}):Object.keys(e).forEach(function(t){var n=e[t];r.on(t,n)}),this},t.prototype.off=function(e,n){var r=this;return"string"==typeof e?e.split(t.MULTI_EVENT_SEPARATOR).forEach(function(t){if(r.handlers.has(t)){var e=r.handlers.get(t);e.remove(n),0===e.length&&r.handlers.delete(t)}}):Object.keys(e).forEach(function(t){var n=e[t];r.off(t,n)}),this},t.prototype.getRegisteredHandlerCount=function(){var t={};return this.handlers.forEach(function(e,n){t[n]=e.length}),t},t.prototype.fire=function(e){for(var n=this,i=[],o=1;o<arguments.length;o++)i[o-1]=arguments[o];return e.split(t.MULTI_EVENT_SEPARATOR).forEach(function(t){n.fireEvent(r(t,i,n))}),this},t.prototype.fireEvent=function(t){if(this.handlers.has(t.type)){return this.handlers.get(t.type).fire(t)}return!1},t.prototype.propagate=function(e){for(var n=[],r=1;r<arguments.length;r++)n[r-1]=arguments[r];e.on(n.join(t.MULTI_EVENT_SEPARATOR),this.propagationHandler)},t.prototype.stopPropagation=function(e){for(var n=[],r=1;r<arguments.length;r++)n[r-1]=arguments[r];e.off(n.join(t.MULTI_EVENT_SEPARATOR),this.propagationHandler)},t.MULTI_EVENT_SEPARATOR=",",t}(),f=new c},function(t,e,n){"use strict";var r=n(0),i=n(3),o=function(t){function e(e){var n=t.call(this)||this;return n.map=new Map,e&&n.parse(e),n}return r.c(e,t),e.prototype.keys=function(){return Array.from(this.map.keys())},e.prototype.forEach=function(t){this.map.forEach(function(e,n){return t(n,e)})},e.prototype.is=function(t){return this.has(t)},e.prototype.has=function(t){return null!=this.getProp(t,null)},e.prototype.getProp=function(t,e){if(void 0===e&&(e=null),this.map.has(t)){var n=this.map.get(t);return null===n?null:n.toString()}return e},e.prototype.getInt=function(t,e){void 0===e&&(e=NaN);var n=this.getProp(t,null);return null===n?e:parseInt(n,10)},e.prototype.removeProp=function(t){return!!this.map.has(t)&&(this.fire(e.EVENT_ENTRY_CHANGED+e.MULTI_EVENT_SEPARATOR+e.EVENT_CHANGED,t,this.map.get(t),null),this.map.delete(t),!0)},e.prototype.toString=function(){var t=[];return this.map.forEach(function(e,n){t.push(encodeURIComponent(n)+"="+encodeURIComponent(e))}),t.join("&")},e.prototype.parse=function(t){var n=this;void 0===t&&(t="");var r=this.map.size;if(this.map.clear(),t.length<=1)return void(0!==r&&this.fire(e.EVENT_CHANGED));t.substr(1).split("&").forEach(function(t){var e=t.split("="),r=decodeURIComponent(e[0]),i=e[1]&&decodeURIComponent(e[1]);if(n.map.has(r)){var o=n.map.get(r);Array.isArray(o)?n.map.get(r).push(i):n.map.set(r,[o,i])}else n.map.set(r,i)}),this.fire(e.EVENT_CHANGED)},e.EVENT_CHANGED="changed",e.EVENT_ENTRY_CHANGED="entryChanged",e}(i.b);e.a=o},function(t,e,n){var r,i;/*!
 * jQuery JavaScript Library v3.1.1
 * https://jquery.com/
 *
 * Includes Sizzle.js
 * https://sizzlejs.com/
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license
 * https://jquery.org/license
 *
 * Date: 2016-09-22T22:30Z
 */
!function(e,n){"use strict";"object"==typeof t&&"object"==typeof t.exports?t.exports=e.document?n(e,!0):function(t){if(!t.document)throw new Error("jQuery requires a window with a document");return n(t)}:n(e)}("undefined"!=typeof window?window:this,function(n,o){"use strict";function a(t,e){e=e||ot;var n=e.createElement("script");n.text=t,e.head.appendChild(n).parentNode.removeChild(n)}function s(t){var e=!!t&&"length"in t&&t.length,n=mt.type(t);return"function"!==n&&!mt.isWindow(t)&&("array"===n||0===e||"number"==typeof e&&e>0&&e-1 in t)}function u(t,e,n){return mt.isFunction(e)?mt.grep(t,function(t,r){return!!e.call(t,r,t)!==n}):e.nodeType?mt.grep(t,function(t){return t===e!==n}):"string"!=typeof e?mt.grep(t,function(t){return ct.call(e,t)>-1!==n}):kt.test(e)?mt.filter(e,t,n):(e=mt.filter(e,t),mt.grep(t,function(t){return ct.call(e,t)>-1!==n&&1===t.nodeType}))}function l(t,e){for(;(t=t[e])&&1!==t.nodeType;);return t}function c(t){var e={};return mt.each(t.match(Rt)||[],function(t,n){e[n]=!0}),e}function f(t){return t}function h(t){throw t}function p(t,e,n){var r;try{t&&mt.isFunction(r=t.promise)?r.call(t).done(e).fail(n):t&&mt.isFunction(r=t.then)?r.call(t,e,n):e.call(void 0,t)}catch(t){n.call(void 0,t)}}function d(){ot.removeEventListener("DOMContentLoaded",d),n.removeEventListener("load",d),mt.ready()}function g(){this.expando=mt.expando+g.uid++}function v(t){return"true"===t||"false"!==t&&("null"===t?null:t===+t+""?+t:Ht.test(t)?JSON.parse(t):t)}function y(t,e,n){var r;if(void 0===n&&1===t.nodeType)if(r="data-"+e.replace(Ft,"-$&").toLowerCase(),"string"==typeof(n=t.getAttribute(r))){try{n=v(n)}catch(t){}qt.set(t,e,n)}else n=void 0;return n}function m(t,e,n,r){var i,o=1,a=20,s=r?function(){return r.cur()}:function(){return mt.css(t,e,"")},u=s(),l=n&&n[3]||(mt.cssNumber[e]?"":"px"),c=(mt.cssNumber[e]||"px"!==l&&+u)&&Ut.exec(mt.css(t,e));if(c&&c[3]!==l){l=l||c[3],n=n||[],c=+u||1;do{o=o||".5",c/=o,mt.style(t,e,c+l)}while(o!==(o=s()/u)&&1!==o&&--a)}return n&&(c=+c||+u||0,i=n[1]?c+(n[1]+1)*n[2]:+n[2],r&&(r.unit=l,r.start=c,r.end=i)),i}function b(t){var e,n=t.ownerDocument,r=t.nodeName,i=Yt[r];return i||(e=n.body.appendChild(n.createElement(r)),i=mt.css(e,"display"),e.parentNode.removeChild(e),"none"===i&&(i="block"),Yt[r]=i,i)}function x(t,e){for(var n,r,i=[],o=0,a=t.length;o<a;o++)r=t[o],r.style&&(n=r.style.display,e?("none"===n&&(i[o]=$t.get(r,"display")||null,i[o]||(r.style.display="")),""===r.style.display&&Bt(r)&&(i[o]=b(r))):"none"!==n&&(i[o]="none",$t.set(r,"display",n)));for(o=0;o<a;o++)null!=i[o]&&(t[o].style.display=i[o]);return t}function w(t,e){var n;return n=void 0!==t.getElementsByTagName?t.getElementsByTagName(e||"*"):void 0!==t.querySelectorAll?t.querySelectorAll(e||"*"):[],void 0===e||e&&mt.nodeName(t,e)?mt.merge([t],n):n}function M(t,e){for(var n=0,r=t.length;n<r;n++)$t.set(t[n],"globalEval",!e||$t.get(e[n],"globalEval"))}function E(t,e,n,r,i){for(var o,a,s,u,l,c,f=e.createDocumentFragment(),h=[],p=0,d=t.length;p<d;p++)if((o=t[p])||0===o)if("object"===mt.type(o))mt.merge(h,o.nodeType?[o]:o);else if(Qt.test(o)){for(a=a||f.appendChild(e.createElement("div")),s=(Zt.exec(o)||["",""])[1].toLowerCase(),u=Jt[s]||Jt._default,a.innerHTML=u[1]+mt.htmlPrefilter(o)+u[2],c=u[0];c--;)a=a.lastChild;mt.merge(h,a.childNodes),a=f.firstChild,a.textContent=""}else h.push(e.createTextNode(o));for(f.textContent="",p=0;o=h[p++];)if(r&&mt.inArray(o,r)>-1)i&&i.push(o);else if(l=mt.contains(o.ownerDocument,o),a=w(f.appendChild(o),"script"),l&&M(a),n)for(c=0;o=a[c++];)Xt.test(o.type||"")&&n.push(o);return f}function T(){return!0}function C(){return!1}function S(){try{return ot.activeElement}catch(t){}}function N(t,e,n,r,i,o){var a,s;if("object"==typeof e){"string"!=typeof n&&(r=r||n,n=void 0);for(s in e)N(t,s,n,r,e[s],o);return t}if(null==r&&null==i?(i=n,r=n=void 0):null==i&&("string"==typeof n?(i=r,r=void 0):(i=r,r=n,n=void 0)),!1===i)i=C;else if(!i)return t;return 1===o&&(a=i,i=function(t){return mt().off(t),a.apply(this,arguments)},i.guid=a.guid||(a.guid=mt.guid++)),t.each(function(){mt.event.add(this,e,i,r,n)})}function k(t,e){return mt.nodeName(t,"table")&&mt.nodeName(11!==e.nodeType?e:e.firstChild,"tr")?t.getElementsByTagName("tbody")[0]||t:t}function _(t){return t.type=(null!==t.getAttribute("type"))+"/"+t.type,t}function A(t){var e=ae.exec(t.type);return e?t.type=e[1]:t.removeAttribute("type"),t}function L(t,e){var n,r,i,o,a,s,u,l;if(1===e.nodeType){if($t.hasData(t)&&(o=$t.access(t),a=$t.set(e,o),l=o.events)){delete a.handle,a.events={};for(i in l)for(n=0,r=l[i].length;n<r;n++)mt.event.add(e,i,l[i][n])}qt.hasData(t)&&(s=qt.access(t),u=mt.extend({},s),qt.set(e,u))}}function D(t,e){var n=e.nodeName.toLowerCase();"input"===n&&Gt.test(t.type)?e.checked=t.checked:"input"!==n&&"textarea"!==n||(e.defaultValue=t.defaultValue)}function R(t,e,n,r){e=ut.apply([],e);var i,o,s,u,l,c,f=0,h=t.length,p=h-1,d=e[0],g=mt.isFunction(d);if(g||h>1&&"string"==typeof d&&!vt.checkClone&&oe.test(d))return t.each(function(i){var o=t.eq(i);g&&(e[0]=d.call(this,i,o.html())),R(o,e,n,r)});if(h&&(i=E(e,t[0].ownerDocument,!1,t,r),o=i.firstChild,1===i.childNodes.length&&(i=o),o||r)){for(s=mt.map(w(i,"script"),_),u=s.length;f<h;f++)l=i,f!==p&&(l=mt.clone(l,!0,!0),u&&mt.merge(s,w(l,"script"))),n.call(t[f],l,f);if(u)for(c=s[s.length-1].ownerDocument,mt.map(s,A),f=0;f<u;f++)l=s[f],Xt.test(l.type||"")&&!$t.access(l,"globalEval")&&mt.contains(c,l)&&(l.src?mt._evalUrl&&mt._evalUrl(l.src):a(l.textContent.replace(se,""),c))}return t}function j(t,e,n){for(var r,i=e?mt.filter(e,t):t,o=0;null!=(r=i[o]);o++)n||1!==r.nodeType||mt.cleanData(w(r)),r.parentNode&&(n&&mt.contains(r.ownerDocument,r)&&M(w(r,"script")),r.parentNode.removeChild(r));return t}function O(t,e,n){var r,i,o,a,s=t.style;return n=n||ce(t),n&&(a=n.getPropertyValue(e)||n[e],""!==a||mt.contains(t.ownerDocument,t)||(a=mt.style(t,e)),!vt.pixelMarginRight()&&le.test(a)&&ue.test(e)&&(r=s.width,i=s.minWidth,o=s.maxWidth,s.minWidth=s.maxWidth=s.width=a,a=n.width,s.width=r,s.minWidth=i,s.maxWidth=o)),void 0!==a?a+"":a}function I(t,e){return{get:function(){return t()?void delete this.get:(this.get=e).apply(this,arguments)}}}function P(t){if(t in ge)return t;for(var e=t[0].toUpperCase()+t.slice(1),n=de.length;n--;)if((t=de[n]+e)in ge)return t}function $(t,e,n){var r=Ut.exec(e);return r?Math.max(0,r[2]-(n||0))+(r[3]||"px"):e}function q(t,e,n,r,i){var o,a=0;for(o=n===(r?"border":"content")?4:"width"===e?1:0;o<4;o+=2)"margin"===n&&(a+=mt.css(t,n+Vt[o],!0,i)),r?("content"===n&&(a-=mt.css(t,"padding"+Vt[o],!0,i)),"margin"!==n&&(a-=mt.css(t,"border"+Vt[o]+"Width",!0,i))):(a+=mt.css(t,"padding"+Vt[o],!0,i),"padding"!==n&&(a+=mt.css(t,"border"+Vt[o]+"Width",!0,i)));return a}function H(t,e,n){var r,i=!0,o=ce(t),a="border-box"===mt.css(t,"boxSizing",!1,o);if(t.getClientRects().length&&(r=t.getBoundingClientRect()[e]),r<=0||null==r){if(r=O(t,e,o),(r<0||null==r)&&(r=t.style[e]),le.test(r))return r;i=a&&(vt.boxSizingReliable()||r===t.style[e]),r=parseFloat(r)||0}return r+q(t,e,n||(a?"border":"content"),i,o)+"px"}function F(t,e,n,r,i){return new F.prototype.init(t,e,n,r,i)}function z(){ye&&(n.requestAnimationFrame(z),mt.fx.tick())}function U(){return n.setTimeout(function(){ve=void 0}),ve=mt.now()}function V(t,e){var n,r=0,i={height:t};for(e=e?1:0;r<4;r+=2-e)n=Vt[r],i["margin"+n]=i["padding"+n]=t;return e&&(i.opacity=i.width=t),i}function B(t,e,n){for(var r,i=(G.tweeners[e]||[]).concat(G.tweeners["*"]),o=0,a=i.length;o<a;o++)if(r=i[o].call(n,e,t))return r}function W(t,e,n){var r,i,o,a,s,u,l,c,f="width"in e||"height"in e,h=this,p={},d=t.style,g=t.nodeType&&Bt(t),v=$t.get(t,"fxshow");n.queue||(a=mt._queueHooks(t,"fx"),null==a.unqueued&&(a.unqueued=0,s=a.empty.fire,a.empty.fire=function(){a.unqueued||s()}),a.unqueued++,h.always(function(){h.always(function(){a.unqueued--,mt.queue(t,"fx").length||a.empty.fire()})}));for(r in e)if(i=e[r],me.test(i)){if(delete e[r],o=o||"toggle"===i,i===(g?"hide":"show")){if("show"!==i||!v||void 0===v[r])continue;g=!0}p[r]=v&&v[r]||mt.style(t,r)}if((u=!mt.isEmptyObject(e))||!mt.isEmptyObject(p)){f&&1===t.nodeType&&(n.overflow=[d.overflow,d.overflowX,d.overflowY],l=v&&v.display,null==l&&(l=$t.get(t,"display")),c=mt.css(t,"display"),"none"===c&&(l?c=l:(x([t],!0),l=t.style.display||l,c=mt.css(t,"display"),x([t]))),("inline"===c||"inline-block"===c&&null!=l)&&"none"===mt.css(t,"float")&&(u||(h.done(function(){d.display=l}),null==l&&(c=d.display,l="none"===c?"":c)),d.display="inline-block")),n.overflow&&(d.overflow="hidden",h.always(function(){d.overflow=n.overflow[0],d.overflowX=n.overflow[1],d.overflowY=n.overflow[2]})),u=!1;for(r in p)u||(v?"hidden"in v&&(g=v.hidden):v=$t.access(t,"fxshow",{display:l}),o&&(v.hidden=!g),g&&x([t],!0),h.done(function(){g||x([t]),$t.remove(t,"fxshow");for(r in p)mt.style(t,r,p[r])})),u=B(g?v[r]:0,r,h),r in v||(v[r]=u.start,g&&(u.end=u.start,u.start=0))}}function Y(t,e){var n,r,i,o,a;for(n in t)if(r=mt.camelCase(n),i=e[r],o=t[n],mt.isArray(o)&&(i=o[1],o=t[n]=o[0]),n!==r&&(t[r]=o,delete t[n]),(a=mt.cssHooks[r])&&"expand"in a){o=a.expand(o),delete t[r];for(n in o)n in t||(t[n]=o[n],e[n]=i)}else e[r]=i}function G(t,e,n){var r,i,o=0,a=G.prefilters.length,s=mt.Deferred().always(function(){delete u.elem}),u=function(){if(i)return!1;for(var e=ve||U(),n=Math.max(0,l.startTime+l.duration-e),r=n/l.duration||0,o=1-r,a=0,u=l.tweens.length;a<u;a++)l.tweens[a].run(o);return s.notifyWith(t,[l,o,n]),o<1&&u?n:(s.resolveWith(t,[l]),!1)},l=s.promise({elem:t,props:mt.extend({},e),opts:mt.extend(!0,{specialEasing:{},easing:mt.easing._default},n),originalProperties:e,originalOptions:n,startTime:ve||U(),duration:n.duration,tweens:[],createTween:function(e,n){var r=mt.Tween(t,l.opts,e,n,l.opts.specialEasing[e]||l.opts.easing);return l.tweens.push(r),r},stop:function(e){var n=0,r=e?l.tweens.length:0;if(i)return this;for(i=!0;n<r;n++)l.tweens[n].run(1);return e?(s.notifyWith(t,[l,1,0]),s.resolveWith(t,[l,e])):s.rejectWith(t,[l,e]),this}}),c=l.props;for(Y(c,l.opts.specialEasing);o<a;o++)if(r=G.prefilters[o].call(l,t,c,l.opts))return mt.isFunction(r.stop)&&(mt._queueHooks(l.elem,l.opts.queue).stop=mt.proxy(r.stop,r)),r;return mt.map(c,B,l),mt.isFunction(l.opts.start)&&l.opts.start.call(t,l),mt.fx.timer(mt.extend(u,{elem:t,anim:l,queue:l.opts.queue})),l.progress(l.opts.progress).done(l.opts.done,l.opts.complete).fail(l.opts.fail).always(l.opts.always)}function Z(t){return(t.match(Rt)||[]).join(" ")}function X(t){return t.getAttribute&&t.getAttribute("class")||""}function J(t,e,n,r){var i;if(mt.isArray(e))mt.each(e,function(e,i){n||_e.test(t)?r(t,i):J(t+"["+("object"==typeof i&&null!=i?e:"")+"]",i,n,r)});else if(n||"object"!==mt.type(e))r(t,e);else for(i in e)J(t+"["+i+"]",e[i],n,r)}function Q(t){return function(e,n){"string"!=typeof e&&(n=e,e="*");var r,i=0,o=e.toLowerCase().match(Rt)||[];if(mt.isFunction(n))for(;r=o[i++];)"+"===r[0]?(r=r.slice(1)||"*",(t[r]=t[r]||[]).unshift(n)):(t[r]=t[r]||[]).push(n)}}function K(t,e,n,r){function i(s){var u;return o[s]=!0,mt.each(t[s]||[],function(t,s){var l=s(e,n,r);return"string"!=typeof l||a||o[l]?a?!(u=l):void 0:(e.dataTypes.unshift(l),i(l),!1)}),u}var o={},a=t===Fe;return i(e.dataTypes[0])||!o["*"]&&i("*")}function tt(t,e){var n,r,i=mt.ajaxSettings.flatOptions||{};for(n in e)void 0!==e[n]&&((i[n]?t:r||(r={}))[n]=e[n]);return r&&mt.extend(!0,t,r),t}function et(t,e,n){for(var r,i,o,a,s=t.contents,u=t.dataTypes;"*"===u[0];)u.shift(),void 0===r&&(r=t.mimeType||e.getResponseHeader("Content-Type"));if(r)for(i in s)if(s[i]&&s[i].test(r)){u.unshift(i);break}if(u[0]in n)o=u[0];else{for(i in n){if(!u[0]||t.converters[i+" "+u[0]]){o=i;break}a||(a=i)}o=o||a}if(o)return o!==u[0]&&u.unshift(o),n[o]}function nt(t,e,n,r){var i,o,a,s,u,l={},c=t.dataTypes.slice();if(c[1])for(a in t.converters)l[a.toLowerCase()]=t.converters[a];for(o=c.shift();o;)if(t.responseFields[o]&&(n[t.responseFields[o]]=e),!u&&r&&t.dataFilter&&(e=t.dataFilter(e,t.dataType)),u=o,o=c.shift())if("*"===o)o=u;else if("*"!==u&&u!==o){if(!(a=l[u+" "+o]||l["* "+o]))for(i in l)if(s=i.split(" "),s[1]===o&&(a=l[u+" "+s[0]]||l["* "+s[0]])){!0===a?a=l[i]:!0!==l[i]&&(o=s[0],c.unshift(s[1]));break}if(!0!==a)if(a&&t.throws)e=a(e);else try{e=a(e)}catch(t){return{state:"parsererror",error:a?t:"No conversion from "+u+" to "+o}}}return{state:"success",data:e}}function rt(t){return mt.isWindow(t)?t:9===t.nodeType&&t.defaultView}var it=[],ot=n.document,at=Object.getPrototypeOf,st=it.slice,ut=it.concat,lt=it.push,ct=it.indexOf,ft={},ht=ft.toString,pt=ft.hasOwnProperty,dt=pt.toString,gt=dt.call(Object),vt={},yt="3.1.1",mt=function(t,e){return new mt.fn.init(t,e)},bt=/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,xt=/^-ms-/,wt=/-([a-z])/g,Mt=function(t,e){return e.toUpperCase()};mt.fn=mt.prototype={jquery:yt,constructor:mt,length:0,toArray:function(){return st.call(this)},get:function(t){return null==t?st.call(this):t<0?this[t+this.length]:this[t]},pushStack:function(t){var e=mt.merge(this.constructor(),t);return e.prevObject=this,e},each:function(t){return mt.each(this,t)},map:function(t){return this.pushStack(mt.map(this,function(e,n){return t.call(e,n,e)}))},slice:function(){return this.pushStack(st.apply(this,arguments))},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},eq:function(t){var e=this.length,n=+t+(t<0?e:0);return this.pushStack(n>=0&&n<e?[this[n]]:[])},end:function(){return this.prevObject||this.constructor()},push:lt,sort:it.sort,splice:it.splice},mt.extend=mt.fn.extend=function(){var t,e,n,r,i,o,a=arguments[0]||{},s=1,u=arguments.length,l=!1;for("boolean"==typeof a&&(l=a,a=arguments[s]||{},s++),"object"==typeof a||mt.isFunction(a)||(a={}),s===u&&(a=this,s--);s<u;s++)if(null!=(t=arguments[s]))for(e in t)n=a[e],r=t[e],a!==r&&(l&&r&&(mt.isPlainObject(r)||(i=mt.isArray(r)))?(i?(i=!1,o=n&&mt.isArray(n)?n:[]):o=n&&mt.isPlainObject(n)?n:{},a[e]=mt.extend(l,o,r)):void 0!==r&&(a[e]=r));return a},mt.extend({expando:"jQuery"+(yt+Math.random()).replace(/\D/g,""),isReady:!0,error:function(t){throw new Error(t)},noop:function(){},isFunction:function(t){return"function"===mt.type(t)},isArray:Array.isArray,isWindow:function(t){return null!=t&&t===t.window},isNumeric:function(t){var e=mt.type(t);return("number"===e||"string"===e)&&!isNaN(t-parseFloat(t))},isPlainObject:function(t){var e,n;return!(!t||"[object Object]"!==ht.call(t))&&(!(e=at(t))||"function"==typeof(n=pt.call(e,"constructor")&&e.constructor)&&dt.call(n)===gt)},isEmptyObject:function(t){var e;for(e in t)return!1;return!0},type:function(t){return null==t?t+"":"object"==typeof t||"function"==typeof t?ft[ht.call(t)]||"object":typeof t},globalEval:function(t){a(t)},camelCase:function(t){return t.replace(xt,"ms-").replace(wt,Mt)},nodeName:function(t,e){return t.nodeName&&t.nodeName.toLowerCase()===e.toLowerCase()},each:function(t,e){var n,r=0;if(s(t))for(n=t.length;r<n&&!1!==e.call(t[r],r,t[r]);r++);else for(r in t)if(!1===e.call(t[r],r,t[r]))break;return t},trim:function(t){return null==t?"":(t+"").replace(bt,"")},makeArray:function(t,e){var n=e||[];return null!=t&&(s(Object(t))?mt.merge(n,"string"==typeof t?[t]:t):lt.call(n,t)),n},inArray:function(t,e,n){return null==e?-1:ct.call(e,t,n)},merge:function(t,e){for(var n=+e.length,r=0,i=t.length;r<n;r++)t[i++]=e[r];return t.length=i,t},grep:function(t,e,n){for(var r=[],i=0,o=t.length,a=!n;i<o;i++)!e(t[i],i)!==a&&r.push(t[i]);return r},map:function(t,e,n){var r,i,o=0,a=[];if(s(t))for(r=t.length;o<r;o++)null!=(i=e(t[o],o,n))&&a.push(i);else for(o in t)null!=(i=e(t[o],o,n))&&a.push(i);return ut.apply([],a)},guid:1,proxy:function(t,e){var n,r,i;if("string"==typeof e&&(n=t[e],e=t,t=n),mt.isFunction(t))return r=st.call(arguments,2),i=function(){return t.apply(e||this,r.concat(st.call(arguments)))},i.guid=t.guid=t.guid||mt.guid++,i},now:Date.now,support:vt}),"function"==typeof Symbol&&(mt.fn[Symbol.iterator]=it[Symbol.iterator]),mt.each("Boolean Number String Function Array Date RegExp Object Error Symbol".split(" "),function(t,e){ft["[object "+e+"]"]=e.toLowerCase()});var Et=/*!
 * Sizzle CSS Selector Engine v2.3.3
 * https://sizzlejs.com/
 *
 * Copyright jQuery Foundation and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2016-08-08
 */
function(t){function e(t,e,n,r){var i,o,a,s,u,l,c,h=e&&e.ownerDocument,d=e?e.nodeType:9;if(n=n||[],"string"!=typeof t||!t||1!==d&&9!==d&&11!==d)return n;if(!r&&((e?e.ownerDocument||e:F)!==R&&D(e),e=e||R,O)){if(11!==d&&(u=yt.exec(t)))if(i=u[1]){if(9===d){if(!(a=e.getElementById(i)))return n;if(a.id===i)return n.push(a),n}else if(h&&(a=h.getElementById(i))&&q(e,a)&&a.id===i)return n.push(a),n}else{if(u[2])return Q.apply(n,e.getElementsByTagName(t)),n;if((i=u[3])&&M.getElementsByClassName&&e.getElementsByClassName)return Q.apply(n,e.getElementsByClassName(i)),n}if(M.qsa&&!W[t+" "]&&(!I||!I.test(t))){if(1!==d)h=e,c=t;else if("object"!==e.nodeName.toLowerCase()){for((s=e.getAttribute("id"))?s=s.replace(wt,Mt):e.setAttribute("id",s=H),l=S(t),o=l.length;o--;)l[o]="#"+s+" "+p(l[o]);c=l.join(","),h=mt.test(t)&&f(e.parentNode)||e}if(c)try{return Q.apply(n,h.querySelectorAll(c)),n}catch(t){}finally{s===H&&e.removeAttribute("id")}}}return k(t.replace(st,"$1"),e,n,r)}function n(){function t(n,r){return e.push(n+" ")>E.cacheLength&&delete t[e.shift()],t[n+" "]=r}var e=[];return t}function r(t){return t[H]=!0,t}function i(t){var e=R.createElement("fieldset");try{return!!t(e)}catch(t){return!1}finally{e.parentNode&&e.parentNode.removeChild(e),e=null}}function o(t,e){for(var n=t.split("|"),r=n.length;r--;)E.attrHandle[n[r]]=e}function a(t,e){var n=e&&t,r=n&&1===t.nodeType&&1===e.nodeType&&t.sourceIndex-e.sourceIndex;if(r)return r;if(n)for(;n=n.nextSibling;)if(n===e)return-1;return t?1:-1}function s(t){return function(e){return"input"===e.nodeName.toLowerCase()&&e.type===t}}function u(t){return function(e){var n=e.nodeName.toLowerCase();return("input"===n||"button"===n)&&e.type===t}}function l(t){return function(e){return"form"in e?e.parentNode&&!1===e.disabled?"label"in e?"label"in e.parentNode?e.parentNode.disabled===t:e.disabled===t:e.isDisabled===t||e.isDisabled!==!t&&Tt(e)===t:e.disabled===t:"label"in e&&e.disabled===t}}function c(t){return r(function(e){return e=+e,r(function(n,r){for(var i,o=t([],n.length,e),a=o.length;a--;)n[i=o[a]]&&(n[i]=!(r[i]=n[i]))})})}function f(t){return t&&void 0!==t.getElementsByTagName&&t}function h(){}function p(t){for(var e=0,n=t.length,r="";e<n;e++)r+=t[e].value;return r}function d(t,e,n){var r=e.dir,i=e.next,o=i||r,a=n&&"parentNode"===o,s=U++;return e.first?function(e,n,i){for(;e=e[r];)if(1===e.nodeType||a)return t(e,n,i);return!1}:function(e,n,u){var l,c,f,h=[z,s];if(u){for(;e=e[r];)if((1===e.nodeType||a)&&t(e,n,u))return!0}else for(;e=e[r];)if(1===e.nodeType||a)if(f=e[H]||(e[H]={}),c=f[e.uniqueID]||(f[e.uniqueID]={}),i&&i===e.nodeName.toLowerCase())e=e[r]||e;else{if((l=c[o])&&l[0]===z&&l[1]===s)return h[2]=l[2];if(c[o]=h,h[2]=t(e,n,u))return!0}return!1}}function g(t){return t.length>1?function(e,n,r){for(var i=t.length;i--;)if(!t[i](e,n,r))return!1;return!0}:t[0]}function v(t,n,r){for(var i=0,o=n.length;i<o;i++)e(t,n[i],r);return r}function y(t,e,n,r,i){for(var o,a=[],s=0,u=t.length,l=null!=e;s<u;s++)(o=t[s])&&(n&&!n(o,r,i)||(a.push(o),l&&e.push(s)));return a}function m(t,e,n,i,o,a){return i&&!i[H]&&(i=m(i)),o&&!o[H]&&(o=m(o,a)),r(function(r,a,s,u){var l,c,f,h=[],p=[],d=a.length,g=r||v(e||"*",s.nodeType?[s]:s,[]),m=!t||!r&&e?g:y(g,h,t,s,u),b=n?o||(r?t:d||i)?[]:a:m;if(n&&n(m,b,s,u),i)for(l=y(b,p),i(l,[],s,u),c=l.length;c--;)(f=l[c])&&(b[p[c]]=!(m[p[c]]=f));if(r){if(o||t){if(o){for(l=[],c=b.length;c--;)(f=b[c])&&l.push(m[c]=f);o(null,b=[],l,u)}for(c=b.length;c--;)(f=b[c])&&(l=o?tt(r,f):h[c])>-1&&(r[l]=!(a[l]=f))}}else b=y(b===a?b.splice(d,b.length):b),o?o(null,a,b,u):Q.apply(a,b)})}function b(t){for(var e,n,r,i=t.length,o=E.relative[t[0].type],a=o||E.relative[" "],s=o?1:0,u=d(function(t){return t===e},a,!0),l=d(function(t){return tt(e,t)>-1},a,!0),c=[function(t,n,r){var i=!o&&(r||n!==_)||((e=n).nodeType?u(t,n,r):l(t,n,r));return e=null,i}];s<i;s++)if(n=E.relative[t[s].type])c=[d(g(c),n)];else{if(n=E.filter[t[s].type].apply(null,t[s].matches),n[H]){for(r=++s;r<i&&!E.relative[t[r].type];r++);return m(s>1&&g(c),s>1&&p(t.slice(0,s-1).concat({value:" "===t[s-2].type?"*":""})).replace(st,"$1"),n,s<r&&b(t.slice(s,r)),r<i&&b(t=t.slice(r)),r<i&&p(t))}c.push(n)}return g(c)}function x(t,n){var i=n.length>0,o=t.length>0,a=function(r,a,s,u,l){var c,f,h,p=0,d="0",g=r&&[],v=[],m=_,b=r||o&&E.find.TAG("*",l),x=z+=null==m?1:Math.random()||.1,w=b.length;for(l&&(_=a===R||a||l);d!==w&&null!=(c=b[d]);d++){if(o&&c){for(f=0,a||c.ownerDocument===R||(D(c),s=!O);h=t[f++];)if(h(c,a||R,s)){u.push(c);break}l&&(z=x)}i&&((c=!h&&c)&&p--,r&&g.push(c))}if(p+=d,i&&d!==p){for(f=0;h=n[f++];)h(g,v,a,s);if(r){if(p>0)for(;d--;)g[d]||v[d]||(v[d]=X.call(u));v=y(v)}Q.apply(u,v),l&&!r&&v.length>0&&p+n.length>1&&e.uniqueSort(u)}return l&&(z=x,_=m),g};return i?r(a):a}var w,M,E,T,C,S,N,k,_,A,L,D,R,j,O,I,P,$,q,H="sizzle"+1*new Date,F=t.document,z=0,U=0,V=n(),B=n(),W=n(),Y=function(t,e){return t===e&&(L=!0),0},G={}.hasOwnProperty,Z=[],X=Z.pop,J=Z.push,Q=Z.push,K=Z.slice,tt=function(t,e){for(var n=0,r=t.length;n<r;n++)if(t[n]===e)return n;return-1},et="checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",nt="[\\x20\\t\\r\\n\\f]",rt="(?:\\\\.|[\\w-]|[^\0-\\xa0])+",it="\\["+nt+"*("+rt+")(?:"+nt+"*([*^$|!~]?=)"+nt+"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|("+rt+"))|)"+nt+"*\\]",ot=":("+rt+")(?:\\((('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|((?:\\\\.|[^\\\\()[\\]]|"+it+")*)|.*)\\)|)",at=new RegExp(nt+"+","g"),st=new RegExp("^"+nt+"+|((?:^|[^\\\\])(?:\\\\.)*)"+nt+"+$","g"),ut=new RegExp("^"+nt+"*,"+nt+"*"),lt=new RegExp("^"+nt+"*([>+~]|"+nt+")"+nt+"*"),ct=new RegExp("="+nt+"*([^\\]'\"]*?)"+nt+"*\\]","g"),ft=new RegExp(ot),ht=new RegExp("^"+rt+"$"),pt={ID:new RegExp("^#("+rt+")"),CLASS:new RegExp("^\\.("+rt+")"),TAG:new RegExp("^("+rt+"|[*])"),ATTR:new RegExp("^"+it),PSEUDO:new RegExp("^"+ot),CHILD:new RegExp("^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\("+nt+"*(even|odd|(([+-]|)(\\d*)n|)"+nt+"*(?:([+-]|)"+nt+"*(\\d+)|))"+nt+"*\\)|)","i"),bool:new RegExp("^(?:"+et+")$","i"),needsContext:new RegExp("^"+nt+"*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\("+nt+"*((?:-\\d)?\\d*)"+nt+"*\\)|)(?=[^-]|$)","i")},dt=/^(?:input|select|textarea|button)$/i,gt=/^h\d$/i,vt=/^[^{]+\{\s*\[native \w/,yt=/^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,mt=/[+~]/,bt=new RegExp("\\\\([\\da-f]{1,6}"+nt+"?|("+nt+")|.)","ig"),xt=function(t,e,n){var r="0x"+e-65536;return r!==r||n?e:r<0?String.fromCharCode(r+65536):String.fromCharCode(r>>10|55296,1023&r|56320)},wt=/([\0-\x1f\x7f]|^-?\d)|^-$|[^\0-\x1f\x7f-\uFFFF\w-]/g,Mt=function(t,e){return e?"\0"===t?"�":t.slice(0,-1)+"\\"+t.charCodeAt(t.length-1).toString(16)+" ":"\\"+t},Et=function(){D()},Tt=d(function(t){return!0===t.disabled&&("form"in t||"label"in t)},{dir:"parentNode",next:"legend"});try{Q.apply(Z=K.call(F.childNodes),F.childNodes),Z[F.childNodes.length].nodeType}catch(t){Q={apply:Z.length?function(t,e){J.apply(t,K.call(e))}:function(t,e){for(var n=t.length,r=0;t[n++]=e[r++];);t.length=n-1}}}M=e.support={},C=e.isXML=function(t){var e=t&&(t.ownerDocument||t).documentElement;return!!e&&"HTML"!==e.nodeName},D=e.setDocument=function(t){var e,n,r=t?t.ownerDocument||t:F;return r!==R&&9===r.nodeType&&r.documentElement?(R=r,j=R.documentElement,O=!C(R),F!==R&&(n=R.defaultView)&&n.top!==n&&(n.addEventListener?n.addEventListener("unload",Et,!1):n.attachEvent&&n.attachEvent("onunload",Et)),M.attributes=i(function(t){return t.className="i",!t.getAttribute("className")}),M.getElementsByTagName=i(function(t){return t.appendChild(R.createComment("")),!t.getElementsByTagName("*").length}),M.getElementsByClassName=vt.test(R.getElementsByClassName),M.getById=i(function(t){return j.appendChild(t).id=H,!R.getElementsByName||!R.getElementsByName(H).length}),M.getById?(E.filter.ID=function(t){var e=t.replace(bt,xt);return function(t){return t.getAttribute("id")===e}},E.find.ID=function(t,e){if(void 0!==e.getElementById&&O){var n=e.getElementById(t);return n?[n]:[]}}):(E.filter.ID=function(t){var e=t.replace(bt,xt);return function(t){var n=void 0!==t.getAttributeNode&&t.getAttributeNode("id");return n&&n.value===e}},E.find.ID=function(t,e){if(void 0!==e.getElementById&&O){var n,r,i,o=e.getElementById(t);if(o){if((n=o.getAttributeNode("id"))&&n.value===t)return[o];for(i=e.getElementsByName(t),r=0;o=i[r++];)if((n=o.getAttributeNode("id"))&&n.value===t)return[o]}return[]}}),E.find.TAG=M.getElementsByTagName?function(t,e){return void 0!==e.getElementsByTagName?e.getElementsByTagName(t):M.qsa?e.querySelectorAll(t):void 0}:function(t,e){var n,r=[],i=0,o=e.getElementsByTagName(t);if("*"===t){for(;n=o[i++];)1===n.nodeType&&r.push(n);return r}return o},E.find.CLASS=M.getElementsByClassName&&function(t,e){if(void 0!==e.getElementsByClassName&&O)return e.getElementsByClassName(t)},P=[],I=[],(M.qsa=vt.test(R.querySelectorAll))&&(i(function(t){j.appendChild(t).innerHTML="<a id='"+H+"'></a><select id='"+H+"-\r\\' msallowcapture=''><option selected=''></option></select>",t.querySelectorAll("[msallowcapture^='']").length&&I.push("[*^$]="+nt+"*(?:''|\"\")"),t.querySelectorAll("[selected]").length||I.push("\\["+nt+"*(?:value|"+et+")"),t.querySelectorAll("[id~="+H+"-]").length||I.push("~="),t.querySelectorAll(":checked").length||I.push(":checked"),t.querySelectorAll("a#"+H+"+*").length||I.push(".#.+[+~]")}),i(function(t){t.innerHTML="<a href='' disabled='disabled'></a><select disabled='disabled'><option/></select>";var e=R.createElement("input");e.setAttribute("type","hidden"),t.appendChild(e).setAttribute("name","D"),t.querySelectorAll("[name=d]").length&&I.push("name"+nt+"*[*^$|!~]?="),2!==t.querySelectorAll(":enabled").length&&I.push(":enabled",":disabled"),j.appendChild(t).disabled=!0,2!==t.querySelectorAll(":disabled").length&&I.push(":enabled",":disabled"),t.querySelectorAll("*,:x"),I.push(",.*:")})),(M.matchesSelector=vt.test($=j.matches||j.webkitMatchesSelector||j.mozMatchesSelector||j.oMatchesSelector||j.msMatchesSelector))&&i(function(t){M.disconnectedMatch=$.call(t,"*"),$.call(t,"[s!='']:x"),P.push("!=",ot)}),I=I.length&&new RegExp(I.join("|")),P=P.length&&new RegExp(P.join("|")),e=vt.test(j.compareDocumentPosition),q=e||vt.test(j.contains)?function(t,e){var n=9===t.nodeType?t.documentElement:t,r=e&&e.parentNode;return t===r||!(!r||1!==r.nodeType||!(n.contains?n.contains(r):t.compareDocumentPosition&&16&t.compareDocumentPosition(r)))}:function(t,e){if(e)for(;e=e.parentNode;)if(e===t)return!0;return!1},Y=e?function(t,e){if(t===e)return L=!0,0;var n=!t.compareDocumentPosition-!e.compareDocumentPosition;return n||(n=(t.ownerDocument||t)===(e.ownerDocument||e)?t.compareDocumentPosition(e):1,1&n||!M.sortDetached&&e.compareDocumentPosition(t)===n?t===R||t.ownerDocument===F&&q(F,t)?-1:e===R||e.ownerDocument===F&&q(F,e)?1:A?tt(A,t)-tt(A,e):0:4&n?-1:1)}:function(t,e){if(t===e)return L=!0,0;var n,r=0,i=t.parentNode,o=e.parentNode,s=[t],u=[e];if(!i||!o)return t===R?-1:e===R?1:i?-1:o?1:A?tt(A,t)-tt(A,e):0;if(i===o)return a(t,e);for(n=t;n=n.parentNode;)s.unshift(n);for(n=e;n=n.parentNode;)u.unshift(n);for(;s[r]===u[r];)r++;return r?a(s[r],u[r]):s[r]===F?-1:u[r]===F?1:0},R):R},e.matches=function(t,n){return e(t,null,null,n)},e.matchesSelector=function(t,n){if((t.ownerDocument||t)!==R&&D(t),n=n.replace(ct,"='$1']"),M.matchesSelector&&O&&!W[n+" "]&&(!P||!P.test(n))&&(!I||!I.test(n)))try{var r=$.call(t,n);if(r||M.disconnectedMatch||t.document&&11!==t.document.nodeType)return r}catch(t){}return e(n,R,null,[t]).length>0},e.contains=function(t,e){return(t.ownerDocument||t)!==R&&D(t),q(t,e)},e.attr=function(t,e){(t.ownerDocument||t)!==R&&D(t);var n=E.attrHandle[e.toLowerCase()],r=n&&G.call(E.attrHandle,e.toLowerCase())?n(t,e,!O):void 0;return void 0!==r?r:M.attributes||!O?t.getAttribute(e):(r=t.getAttributeNode(e))&&r.specified?r.value:null},e.escape=function(t){return(t+"").replace(wt,Mt)},e.error=function(t){throw new Error("Syntax error, unrecognized expression: "+t)},e.uniqueSort=function(t){var e,n=[],r=0,i=0;if(L=!M.detectDuplicates,A=!M.sortStable&&t.slice(0),t.sort(Y),L){for(;e=t[i++];)e===t[i]&&(r=n.push(i));for(;r--;)t.splice(n[r],1)}return A=null,t},T=e.getText=function(t){var e,n="",r=0,i=t.nodeType;if(i){if(1===i||9===i||11===i){if("string"==typeof t.textContent)return t.textContent;for(t=t.firstChild;t;t=t.nextSibling)n+=T(t)}else if(3===i||4===i)return t.nodeValue}else for(;e=t[r++];)n+=T(e);return n},E=e.selectors={cacheLength:50,createPseudo:r,match:pt,attrHandle:{},find:{},relative:{">":{dir:"parentNode",first:!0}," ":{dir:"parentNode"},"+":{dir:"previousSibling",first:!0},"~":{dir:"previousSibling"}},preFilter:{ATTR:function(t){return t[1]=t[1].replace(bt,xt),t[3]=(t[3]||t[4]||t[5]||"").replace(bt,xt),"~="===t[2]&&(t[3]=" "+t[3]+" "),t.slice(0,4)},CHILD:function(t){return t[1]=t[1].toLowerCase(),"nth"===t[1].slice(0,3)?(t[3]||e.error(t[0]),t[4]=+(t[4]?t[5]+(t[6]||1):2*("even"===t[3]||"odd"===t[3])),t[5]=+(t[7]+t[8]||"odd"===t[3])):t[3]&&e.error(t[0]),t},PSEUDO:function(t){var e,n=!t[6]&&t[2];return pt.CHILD.test(t[0])?null:(t[3]?t[2]=t[4]||t[5]||"":n&&ft.test(n)&&(e=S(n,!0))&&(e=n.indexOf(")",n.length-e)-n.length)&&(t[0]=t[0].slice(0,e),t[2]=n.slice(0,e)),t.slice(0,3))}},filter:{TAG:function(t){var e=t.replace(bt,xt).toLowerCase();return"*"===t?function(){return!0}:function(t){return t.nodeName&&t.nodeName.toLowerCase()===e}},CLASS:function(t){var e=V[t+" "];return e||(e=new RegExp("(^|"+nt+")"+t+"("+nt+"|$)"))&&V(t,function(t){return e.test("string"==typeof t.className&&t.className||void 0!==t.getAttribute&&t.getAttribute("class")||"")})},ATTR:function(t,n,r){return function(i){var o=e.attr(i,t);return null==o?"!="===n:!n||(o+="","="===n?o===r:"!="===n?o!==r:"^="===n?r&&0===o.indexOf(r):"*="===n?r&&o.indexOf(r)>-1:"$="===n?r&&o.slice(-r.length)===r:"~="===n?(" "+o.replace(at," ")+" ").indexOf(r)>-1:"|="===n&&(o===r||o.slice(0,r.length+1)===r+"-"))}},CHILD:function(t,e,n,r,i){var o="nth"!==t.slice(0,3),a="last"!==t.slice(-4),s="of-type"===e;return 1===r&&0===i?function(t){return!!t.parentNode}:function(e,n,u){var l,c,f,h,p,d,g=o!==a?"nextSibling":"previousSibling",v=e.parentNode,y=s&&e.nodeName.toLowerCase(),m=!u&&!s,b=!1;if(v){if(o){for(;g;){for(h=e;h=h[g];)if(s?h.nodeName.toLowerCase()===y:1===h.nodeType)return!1;d=g="only"===t&&!d&&"nextSibling"}return!0}if(d=[a?v.firstChild:v.lastChild],a&&m){for(h=v,f=h[H]||(h[H]={}),c=f[h.uniqueID]||(f[h.uniqueID]={}),l=c[t]||[],p=l[0]===z&&l[1],b=p&&l[2],h=p&&v.childNodes[p];h=++p&&h&&h[g]||(b=p=0)||d.pop();)if(1===h.nodeType&&++b&&h===e){c[t]=[z,p,b];break}}else if(m&&(h=e,f=h[H]||(h[H]={}),c=f[h.uniqueID]||(f[h.uniqueID]={}),l=c[t]||[],p=l[0]===z&&l[1],b=p),!1===b)for(;(h=++p&&h&&h[g]||(b=p=0)||d.pop())&&((s?h.nodeName.toLowerCase()!==y:1!==h.nodeType)||!++b||(m&&(f=h[H]||(h[H]={}),c=f[h.uniqueID]||(f[h.uniqueID]={}),c[t]=[z,b]),h!==e)););return(b-=i)===r||b%r==0&&b/r>=0}}},PSEUDO:function(t,n){var i,o=E.pseudos[t]||E.setFilters[t.toLowerCase()]||e.error("unsupported pseudo: "+t);return o[H]?o(n):o.length>1?(i=[t,t,"",n],E.setFilters.hasOwnProperty(t.toLowerCase())?r(function(t,e){for(var r,i=o(t,n),a=i.length;a--;)r=tt(t,i[a]),t[r]=!(e[r]=i[a])}):function(t){return o(t,0,i)}):o}},pseudos:{not:r(function(t){var e=[],n=[],i=N(t.replace(st,"$1"));return i[H]?r(function(t,e,n,r){for(var o,a=i(t,null,r,[]),s=t.length;s--;)(o=a[s])&&(t[s]=!(e[s]=o))}):function(t,r,o){return e[0]=t,i(e,null,o,n),e[0]=null,!n.pop()}}),has:r(function(t){return function(n){return e(t,n).length>0}}),contains:r(function(t){return t=t.replace(bt,xt),function(e){return(e.textContent||e.innerText||T(e)).indexOf(t)>-1}}),lang:r(function(t){return ht.test(t||"")||e.error("unsupported lang: "+t),t=t.replace(bt,xt).toLowerCase(),function(e){var n;do{if(n=O?e.lang:e.getAttribute("xml:lang")||e.getAttribute("lang"))return(n=n.toLowerCase())===t||0===n.indexOf(t+"-")}while((e=e.parentNode)&&1===e.nodeType);return!1}}),target:function(e){var n=t.location&&t.location.hash;return n&&n.slice(1)===e.id},root:function(t){return t===j},focus:function(t){return t===R.activeElement&&(!R.hasFocus||R.hasFocus())&&!!(t.type||t.href||~t.tabIndex)},enabled:l(!1),disabled:l(!0),checked:function(t){var e=t.nodeName.toLowerCase();return"input"===e&&!!t.checked||"option"===e&&!!t.selected},selected:function(t){return t.parentNode&&t.parentNode.selectedIndex,!0===t.selected},empty:function(t){for(t=t.firstChild;t;t=t.nextSibling)if(t.nodeType<6)return!1;return!0},parent:function(t){return!E.pseudos.empty(t)},header:function(t){return gt.test(t.nodeName)},input:function(t){return dt.test(t.nodeName)},button:function(t){var e=t.nodeName.toLowerCase();return"input"===e&&"button"===t.type||"button"===e},text:function(t){var e;return"input"===t.nodeName.toLowerCase()&&"text"===t.type&&(null==(e=t.getAttribute("type"))||"text"===e.toLowerCase())},first:c(function(){return[0]}),last:c(function(t,e){return[e-1]}),eq:c(function(t,e,n){return[n<0?n+e:n]}),even:c(function(t,e){for(var n=0;n<e;n+=2)t.push(n);return t}),odd:c(function(t,e){for(var n=1;n<e;n+=2)t.push(n);return t}),lt:c(function(t,e,n){for(var r=n<0?n+e:n;--r>=0;)t.push(r);return t}),gt:c(function(t,e,n){for(var r=n<0?n+e:n;++r<e;)t.push(r);return t})}},E.pseudos.nth=E.pseudos.eq;for(w in{radio:!0,checkbox:!0,file:!0,password:!0,image:!0})E.pseudos[w]=s(w);for(w in{submit:!0,reset:!0})E.pseudos[w]=u(w);return h.prototype=E.filters=E.pseudos,E.setFilters=new h,S=e.tokenize=function(t,n){var r,i,o,a,s,u,l,c=B[t+" "];if(c)return n?0:c.slice(0);for(s=t,u=[],l=E.preFilter;s;){r&&!(i=ut.exec(s))||(i&&(s=s.slice(i[0].length)||s),u.push(o=[])),r=!1,(i=lt.exec(s))&&(r=i.shift(),o.push({value:r,type:i[0].replace(st," ")}),s=s.slice(r.length));for(a in E.filter)!(i=pt[a].exec(s))||l[a]&&!(i=l[a](i))||(r=i.shift(),o.push({value:r,type:a,matches:i}),s=s.slice(r.length));if(!r)break}return n?s.length:s?e.error(t):B(t,u).slice(0)},N=e.compile=function(t,e){var n,r=[],i=[],o=W[t+" "];if(!o){for(e||(e=S(t)),n=e.length;n--;)o=b(e[n]),o[H]?r.push(o):i.push(o);o=W(t,x(i,r)),o.selector=t}return o},k=e.select=function(t,e,n,r){var i,o,a,s,u,l="function"==typeof t&&t,c=!r&&S(t=l.selector||t);if(n=n||[],1===c.length){if(o=c[0]=c[0].slice(0),o.length>2&&"ID"===(a=o[0]).type&&9===e.nodeType&&O&&E.relative[o[1].type]){if(!(e=(E.find.ID(a.matches[0].replace(bt,xt),e)||[])[0]))return n;l&&(e=e.parentNode),t=t.slice(o.shift().value.length)}for(i=pt.needsContext.test(t)?0:o.length;i--&&(a=o[i],!E.relative[s=a.type]);)if((u=E.find[s])&&(r=u(a.matches[0].replace(bt,xt),mt.test(o[0].type)&&f(e.parentNode)||e))){if(o.splice(i,1),!(t=r.length&&p(o)))return Q.apply(n,r),n;break}}return(l||N(t,c))(r,e,!O,n,!e||mt.test(t)&&f(e.parentNode)||e),n},M.sortStable=H.split("").sort(Y).join("")===H,M.detectDuplicates=!!L,D(),M.sortDetached=i(function(t){return 1&t.compareDocumentPosition(R.createElement("fieldset"))}),i(function(t){return t.innerHTML="<a href='#'></a>","#"===t.firstChild.getAttribute("href")})||o("type|href|height|width",function(t,e,n){if(!n)return t.getAttribute(e,"type"===e.toLowerCase()?1:2)}),M.attributes&&i(function(t){return t.innerHTML="<input/>",t.firstChild.setAttribute("value",""),""===t.firstChild.getAttribute("value")})||o("value",function(t,e,n){if(!n&&"input"===t.nodeName.toLowerCase())return t.defaultValue}),i(function(t){return null==t.getAttribute("disabled")})||o(et,function(t,e,n){var r;if(!n)return!0===t[e]?e.toLowerCase():(r=t.getAttributeNode(e))&&r.specified?r.value:null}),e}(n);mt.find=Et,mt.expr=Et.selectors,mt.expr[":"]=mt.expr.pseudos,mt.uniqueSort=mt.unique=Et.uniqueSort,mt.text=Et.getText,mt.isXMLDoc=Et.isXML,mt.contains=Et.contains,mt.escapeSelector=Et.escape;var Tt=function(t,e,n){for(var r=[],i=void 0!==n;(t=t[e])&&9!==t.nodeType;)if(1===t.nodeType){if(i&&mt(t).is(n))break;r.push(t)}return r},Ct=function(t,e){for(var n=[];t;t=t.nextSibling)1===t.nodeType&&t!==e&&n.push(t);return n},St=mt.expr.match.needsContext,Nt=/^<([a-z][^\/\0>:\x20\t\r\n\f]*)[\x20\t\r\n\f]*\/?>(?:<\/\1>|)$/i,kt=/^.[^:#\[\.,]*$/;mt.filter=function(t,e,n){var r=e[0];return n&&(t=":not("+t+")"),1===e.length&&1===r.nodeType?mt.find.matchesSelector(r,t)?[r]:[]:mt.find.matches(t,mt.grep(e,function(t){return 1===t.nodeType}))},mt.fn.extend({find:function(t){var e,n,r=this.length,i=this;if("string"!=typeof t)return this.pushStack(mt(t).filter(function(){for(e=0;e<r;e++)if(mt.contains(i[e],this))return!0}));for(n=this.pushStack([]),e=0;e<r;e++)mt.find(t,i[e],n);return r>1?mt.uniqueSort(n):n},filter:function(t){return this.pushStack(u(this,t||[],!1))},not:function(t){return this.pushStack(u(this,t||[],!0))},is:function(t){return!!u(this,"string"==typeof t&&St.test(t)?mt(t):t||[],!1).length}});var _t,At=/^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]+))$/;(mt.fn.init=function(t,e,n){var r,i;if(!t)return this;if(n=n||_t,"string"==typeof t){if(!(r="<"===t[0]&&">"===t[t.length-1]&&t.length>=3?[null,t,null]:At.exec(t))||!r[1]&&e)return!e||e.jquery?(e||n).find(t):this.constructor(e).find(t);if(r[1]){if(e=e instanceof mt?e[0]:e,mt.merge(this,mt.parseHTML(r[1],e&&e.nodeType?e.ownerDocument||e:ot,!0)),Nt.test(r[1])&&mt.isPlainObject(e))for(r in e)mt.isFunction(this[r])?this[r](e[r]):this.attr(r,e[r]);return this}return i=ot.getElementById(r[2]),i&&(this[0]=i,this.length=1),this}return t.nodeType?(this[0]=t,this.length=1,this):mt.isFunction(t)?void 0!==n.ready?n.ready(t):t(mt):mt.makeArray(t,this)}).prototype=mt.fn,_t=mt(ot);var Lt=/^(?:parents|prev(?:Until|All))/,Dt={children:!0,contents:!0,next:!0,prev:!0};mt.fn.extend({has:function(t){var e=mt(t,this),n=e.length;return this.filter(function(){for(var t=0;t<n;t++)if(mt.contains(this,e[t]))return!0})},closest:function(t,e){var n,r=0,i=this.length,o=[],a="string"!=typeof t&&mt(t);if(!St.test(t))for(;r<i;r++)for(n=this[r];n&&n!==e;n=n.parentNode)if(n.nodeType<11&&(a?a.index(n)>-1:1===n.nodeType&&mt.find.matchesSelector(n,t))){o.push(n);break}return this.pushStack(o.length>1?mt.uniqueSort(o):o)},index:function(t){return t?"string"==typeof t?ct.call(mt(t),this[0]):ct.call(this,t.jquery?t[0]:t):this[0]&&this[0].parentNode?this.first().prevAll().length:-1},add:function(t,e){return this.pushStack(mt.uniqueSort(mt.merge(this.get(),mt(t,e))))},addBack:function(t){return this.add(null==t?this.prevObject:this.prevObject.filter(t))}}),mt.each({parent:function(t){var e=t.parentNode;return e&&11!==e.nodeType?e:null},parents:function(t){return Tt(t,"parentNode")},parentsUntil:function(t,e,n){return Tt(t,"parentNode",n)},next:function(t){return l(t,"nextSibling")},prev:function(t){return l(t,"previousSibling")},nextAll:function(t){return Tt(t,"nextSibling")},prevAll:function(t){return Tt(t,"previousSibling")},nextUntil:function(t,e,n){return Tt(t,"nextSibling",n)},prevUntil:function(t,e,n){return Tt(t,"previousSibling",n)},siblings:function(t){return Ct((t.parentNode||{}).firstChild,t)},children:function(t){return Ct(t.firstChild)},contents:function(t){return t.contentDocument||mt.merge([],t.childNodes)}},function(t,e){mt.fn[t]=function(n,r){var i=mt.map(this,e,n);return"Until"!==t.slice(-5)&&(r=n),r&&"string"==typeof r&&(i=mt.filter(r,i)),this.length>1&&(Dt[t]||mt.uniqueSort(i),Lt.test(t)&&i.reverse()),this.pushStack(i)}});var Rt=/[^\x20\t\r\n\f]+/g;mt.Callbacks=function(t){t="string"==typeof t?c(t):mt.extend({},t);var e,n,r,i,o=[],a=[],s=-1,u=function(){for(i=t.once,r=e=!0;a.length;s=-1)for(n=a.shift();++s<o.length;)!1===o[s].apply(n[0],n[1])&&t.stopOnFalse&&(s=o.length,n=!1);t.memory||(n=!1),e=!1,i&&(o=n?[]:"")},l={add:function(){return o&&(n&&!e&&(s=o.length-1,a.push(n)),function e(n){mt.each(n,function(n,r){mt.isFunction(r)?t.unique&&l.has(r)||o.push(r):r&&r.length&&"string"!==mt.type(r)&&e(r)})}(arguments),n&&!e&&u()),this},remove:function(){return mt.each(arguments,function(t,e){for(var n;(n=mt.inArray(e,o,n))>-1;)o.splice(n,1),n<=s&&s--}),this},has:function(t){return t?mt.inArray(t,o)>-1:o.length>0},empty:function(){return o&&(o=[]),this},disable:function(){return i=a=[],o=n="",this},disabled:function(){return!o},lock:function(){return i=a=[],n||e||(o=n=""),this},locked:function(){return!!i},fireWith:function(t,n){return i||(n=n||[],n=[t,n.slice?n.slice():n],a.push(n),e||u()),this},fire:function(){return l.fireWith(this,arguments),this},fired:function(){return!!r}};return l},mt.extend({Deferred:function(t){var e=[["notify","progress",mt.Callbacks("memory"),mt.Callbacks("memory"),2],["resolve","done",mt.Callbacks("once memory"),mt.Callbacks("once memory"),0,"resolved"],["reject","fail",mt.Callbacks("once memory"),mt.Callbacks("once memory"),1,"rejected"]],r="pending",i={state:function(){return r},always:function(){return o.done(arguments).fail(arguments),this},catch:function(t){return i.then(null,t)},pipe:function(){var t=arguments;return mt.Deferred(function(n){mt.each(e,function(e,r){var i=mt.isFunction(t[r[4]])&&t[r[4]];o[r[1]](function(){var t=i&&i.apply(this,arguments);t&&mt.isFunction(t.promise)?t.promise().progress(n.notify).done(n.resolve).fail(n.reject):n[r[0]+"With"](this,i?[t]:arguments)})}),t=null}).promise()},then:function(t,r,i){function o(t,e,r,i){return function(){var s=this,u=arguments,l=function(){var n,l;if(!(t<a)){if((n=r.apply(s,u))===e.promise())throw new TypeError("Thenable self-resolution");l=n&&("object"==typeof n||"function"==typeof n)&&n.then,mt.isFunction(l)?i?l.call(n,o(a,e,f,i),o(a,e,h,i)):(a++,l.call(n,o(a,e,f,i),o(a,e,h,i),o(a,e,f,e.notifyWith))):(r!==f&&(s=void 0,u=[n]),(i||e.resolveWith)(s,u))}},c=i?l:function(){try{l()}catch(n){mt.Deferred.exceptionHook&&mt.Deferred.exceptionHook(n,c.stackTrace),t+1>=a&&(r!==h&&(s=void 0,u=[n]),e.rejectWith(s,u))}};t?c():(mt.Deferred.getStackHook&&(c.stackTrace=mt.Deferred.getStackHook()),n.setTimeout(c))}}var a=0;return mt.Deferred(function(n){e[0][3].add(o(0,n,mt.isFunction(i)?i:f,n.notifyWith)),e[1][3].add(o(0,n,mt.isFunction(t)?t:f)),e[2][3].add(o(0,n,mt.isFunction(r)?r:h))}).promise()},promise:function(t){return null!=t?mt.extend(t,i):i}},o={};return mt.each(e,function(t,n){var a=n[2],s=n[5];i[n[1]]=a.add,s&&a.add(function(){r=s},e[3-t][2].disable,e[0][2].lock),a.add(n[3].fire),o[n[0]]=function(){return o[n[0]+"With"](this===o?void 0:this,arguments),this},o[n[0]+"With"]=a.fireWith}),i.promise(o),t&&t.call(o,o),o},when:function(t){var e=arguments.length,n=e,r=Array(n),i=st.call(arguments),o=mt.Deferred(),a=function(t){return function(n){r[t]=this,i[t]=arguments.length>1?st.call(arguments):n,--e||o.resolveWith(r,i)}};if(e<=1&&(p(t,o.done(a(n)).resolve,o.reject),"pending"===o.state()||mt.isFunction(i[n]&&i[n].then)))return o.then();for(;n--;)p(i[n],a(n),o.reject);return o.promise()}});var jt=/^(Eval|Internal|Range|Reference|Syntax|Type|URI)Error$/;mt.Deferred.exceptionHook=function(t,e){n.console&&n.console.warn&&t&&jt.test(t.name)&&n.console.warn("jQuery.Deferred exception: "+t.message,t.stack,e)},mt.readyException=function(t){n.setTimeout(function(){throw t})};var Ot=mt.Deferred();mt.fn.ready=function(t){return Ot.then(t).catch(function(t){mt.readyException(t)}),this},mt.extend({isReady:!1,readyWait:1,holdReady:function(t){t?mt.readyWait++:mt.ready(!0)},ready:function(t){(!0===t?--mt.readyWait:mt.isReady)||(mt.isReady=!0,!0!==t&&--mt.readyWait>0||Ot.resolveWith(ot,[mt]))}}),mt.ready.then=Ot.then,"complete"===ot.readyState||"loading"!==ot.readyState&&!ot.documentElement.doScroll?n.setTimeout(mt.ready):(ot.addEventListener("DOMContentLoaded",d),n.addEventListener("load",d));var It=function(t,e,n,r,i,o,a){var s=0,u=t.length,l=null==n;if("object"===mt.type(n)){i=!0;for(s in n)It(t,e,s,n[s],!0,o,a)}else if(void 0!==r&&(i=!0,mt.isFunction(r)||(a=!0),l&&(a?(e.call(t,r),e=null):(l=e,e=function(t,e,n){return l.call(mt(t),n)})),e))for(;s<u;s++)e(t[s],n,a?r:r.call(t[s],s,e(t[s],n)));return i?t:l?e.call(t):u?e(t[0],n):o},Pt=function(t){return 1===t.nodeType||9===t.nodeType||!+t.nodeType};g.uid=1,g.prototype={cache:function(t){var e=t[this.expando];return e||(e={},Pt(t)&&(t.nodeType?t[this.expando]=e:Object.defineProperty(t,this.expando,{value:e,configurable:!0}))),e},set:function(t,e,n){var r,i=this.cache(t);if("string"==typeof e)i[mt.camelCase(e)]=n;else for(r in e)i[mt.camelCase(r)]=e[r];return i},get:function(t,e){return void 0===e?this.cache(t):t[this.expando]&&t[this.expando][mt.camelCase(e)]},access:function(t,e,n){return void 0===e||e&&"string"==typeof e&&void 0===n?this.get(t,e):(this.set(t,e,n),void 0!==n?n:e)},remove:function(t,e){var n,r=t[this.expando];if(void 0!==r){if(void 0!==e){mt.isArray(e)?e=e.map(mt.camelCase):(e=mt.camelCase(e),e=e in r?[e]:e.match(Rt)||[]),n=e.length;for(;n--;)delete r[e[n]]}(void 0===e||mt.isEmptyObject(r))&&(t.nodeType?t[this.expando]=void 0:delete t[this.expando])}},hasData:function(t){var e=t[this.expando];return void 0!==e&&!mt.isEmptyObject(e)}};var $t=new g,qt=new g,Ht=/^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,Ft=/[A-Z]/g;mt.extend({hasData:function(t){return qt.hasData(t)||$t.hasData(t)},data:function(t,e,n){return qt.access(t,e,n)},removeData:function(t,e){qt.remove(t,e)},_data:function(t,e,n){return $t.access(t,e,n)},_removeData:function(t,e){$t.remove(t,e)}}),mt.fn.extend({data:function(t,e){var n,r,i,o=this[0],a=o&&o.attributes;if(void 0===t){if(this.length&&(i=qt.get(o),1===o.nodeType&&!$t.get(o,"hasDataAttrs"))){for(n=a.length;n--;)a[n]&&(r=a[n].name,0===r.indexOf("data-")&&(r=mt.camelCase(r.slice(5)),y(o,r,i[r])));$t.set(o,"hasDataAttrs",!0)}return i}return"object"==typeof t?this.each(function(){qt.set(this,t)}):It(this,function(e){var n;if(o&&void 0===e){if(void 0!==(n=qt.get(o,t)))return n;if(void 0!==(n=y(o,t)))return n}else this.each(function(){qt.set(this,t,e)})},null,e,arguments.length>1,null,!0)},removeData:function(t){return this.each(function(){qt.remove(this,t)})}}),mt.extend({queue:function(t,e,n){var r;if(t)return e=(e||"fx")+"queue",r=$t.get(t,e),n&&(!r||mt.isArray(n)?r=$t.access(t,e,mt.makeArray(n)):r.push(n)),r||[]},dequeue:function(t,e){e=e||"fx";var n=mt.queue(t,e),r=n.length,i=n.shift(),o=mt._queueHooks(t,e),a=function(){mt.dequeue(t,e)};"inprogress"===i&&(i=n.shift(),r--),i&&("fx"===e&&n.unshift("inprogress"),delete o.stop,i.call(t,a,o)),!r&&o&&o.empty.fire()},_queueHooks:function(t,e){var n=e+"queueHooks";return $t.get(t,n)||$t.access(t,n,{empty:mt.Callbacks("once memory").add(function(){$t.remove(t,[e+"queue",n])})})}}),mt.fn.extend({queue:function(t,e){var n=2;return"string"!=typeof t&&(e=t,t="fx",n--),arguments.length<n?mt.queue(this[0],t):void 0===e?this:this.each(function(){var n=mt.queue(this,t,e);mt._queueHooks(this,t),"fx"===t&&"inprogress"!==n[0]&&mt.dequeue(this,t)})},dequeue:function(t){return this.each(function(){mt.dequeue(this,t)})},clearQueue:function(t){return this.queue(t||"fx",[])},promise:function(t,e){var n,r=1,i=mt.Deferred(),o=this,a=this.length,s=function(){--r||i.resolveWith(o,[o])};for("string"!=typeof t&&(e=t,t=void 0),t=t||"fx";a--;)(n=$t.get(o[a],t+"queueHooks"))&&n.empty&&(r++,n.empty.add(s));return s(),i.promise(e)}});var zt=/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/.source,Ut=new RegExp("^(?:([+-])=|)("+zt+")([a-z%]*)$","i"),Vt=["Top","Right","Bottom","Left"],Bt=function(t,e){return t=e||t,"none"===t.style.display||""===t.style.display&&mt.contains(t.ownerDocument,t)&&"none"===mt.css(t,"display")},Wt=function(t,e,n,r){var i,o,a={};for(o in e)a[o]=t.style[o],t.style[o]=e[o];i=n.apply(t,r||[]);for(o in e)t.style[o]=a[o];return i},Yt={};mt.fn.extend({show:function(){return x(this,!0)},hide:function(){return x(this)},toggle:function(t){return"boolean"==typeof t?t?this.show():this.hide():this.each(function(){Bt(this)?mt(this).show():mt(this).hide()})}});var Gt=/^(?:checkbox|radio)$/i,Zt=/<([a-z][^\/\0>\x20\t\r\n\f]+)/i,Xt=/^$|\/(?:java|ecma)script/i,Jt={option:[1,"<select multiple='multiple'>","</select>"],thead:[1,"<table>","</table>"],col:[2,"<table><colgroup>","</colgroup></table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],_default:[0,"",""]};Jt.optgroup=Jt.option,Jt.tbody=Jt.tfoot=Jt.colgroup=Jt.caption=Jt.thead,Jt.th=Jt.td;var Qt=/<|&#?\w+;/;!function(){var t=ot.createDocumentFragment(),e=t.appendChild(ot.createElement("div")),n=ot.createElement("input");n.setAttribute("type","radio"),n.setAttribute("checked","checked"),n.setAttribute("name","t"),e.appendChild(n),vt.checkClone=e.cloneNode(!0).cloneNode(!0).lastChild.checked,e.innerHTML="<textarea>x</textarea>",vt.noCloneChecked=!!e.cloneNode(!0).lastChild.defaultValue}();var Kt=ot.documentElement,te=/^key/,ee=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,ne=/^([^.]*)(?:\.(.+)|)/;mt.event={global:{},add:function(t,e,n,r,i){var o,a,s,u,l,c,f,h,p,d,g,v=$t.get(t);if(v)for(n.handler&&(o=n,n=o.handler,i=o.selector),i&&mt.find.matchesSelector(Kt,i),n.guid||(n.guid=mt.guid++),(u=v.events)||(u=v.events={}),(a=v.handle)||(a=v.handle=function(e){return void 0!==mt&&mt.event.triggered!==e.type?mt.event.dispatch.apply(t,arguments):void 0}),e=(e||"").match(Rt)||[""],l=e.length;l--;)s=ne.exec(e[l])||[],p=g=s[1],d=(s[2]||"").split(".").sort(),p&&(f=mt.event.special[p]||{},p=(i?f.delegateType:f.bindType)||p,f=mt.event.special[p]||{},c=mt.extend({type:p,origType:g,data:r,handler:n,guid:n.guid,selector:i,needsContext:i&&mt.expr.match.needsContext.test(i),namespace:d.join(".")},o),(h=u[p])||(h=u[p]=[],h.delegateCount=0,f.setup&&!1!==f.setup.call(t,r,d,a)||t.addEventListener&&t.addEventListener(p,a)),f.add&&(f.add.call(t,c),c.handler.guid||(c.handler.guid=n.guid)),i?h.splice(h.delegateCount++,0,c):h.push(c),mt.event.global[p]=!0)},remove:function(t,e,n,r,i){var o,a,s,u,l,c,f,h,p,d,g,v=$t.hasData(t)&&$t.get(t);if(v&&(u=v.events)){for(e=(e||"").match(Rt)||[""],l=e.length;l--;)if(s=ne.exec(e[l])||[],p=g=s[1],d=(s[2]||"").split(".").sort(),p){for(f=mt.event.special[p]||{},p=(r?f.delegateType:f.bindType)||p,h=u[p]||[],s=s[2]&&new RegExp("(^|\\.)"+d.join("\\.(?:.*\\.|)")+"(\\.|$)"),a=o=h.length;o--;)c=h[o],!i&&g!==c.origType||n&&n.guid!==c.guid||s&&!s.test(c.namespace)||r&&r!==c.selector&&("**"!==r||!c.selector)||(h.splice(o,1),c.selector&&h.delegateCount--,f.remove&&f.remove.call(t,c));a&&!h.length&&(f.teardown&&!1!==f.teardown.call(t,d,v.handle)||mt.removeEvent(t,p,v.handle),delete u[p])}else for(p in u)mt.event.remove(t,p+e[l],n,r,!0);mt.isEmptyObject(u)&&$t.remove(t,"handle events")}},dispatch:function(t){var e,n,r,i,o,a,s=mt.event.fix(t),u=new Array(arguments.length),l=($t.get(this,"events")||{})[s.type]||[],c=mt.event.special[s.type]||{};for(u[0]=s,e=1;e<arguments.length;e++)u[e]=arguments[e];if(s.delegateTarget=this,!c.preDispatch||!1!==c.preDispatch.call(this,s)){for(a=mt.event.handlers.call(this,s,l),e=0;(i=a[e++])&&!s.isPropagationStopped();)for(s.currentTarget=i.elem,n=0;(o=i.handlers[n++])&&!s.isImmediatePropagationStopped();)s.rnamespace&&!s.rnamespace.test(o.namespace)||(s.handleObj=o,s.data=o.data,void 0!==(r=((mt.event.special[o.origType]||{}).handle||o.handler).apply(i.elem,u))&&!1===(s.result=r)&&(s.preventDefault(),s.stopPropagation()));return c.postDispatch&&c.postDispatch.call(this,s),s.result}},handlers:function(t,e){var n,r,i,o,a,s=[],u=e.delegateCount,l=t.target;if(u&&l.nodeType&&!("click"===t.type&&t.button>=1))for(;l!==this;l=l.parentNode||this)if(1===l.nodeType&&("click"!==t.type||!0!==l.disabled)){for(o=[],a={},n=0;n<u;n++)r=e[n],i=r.selector+" ",void 0===a[i]&&(a[i]=r.needsContext?mt(i,this).index(l)>-1:mt.find(i,this,null,[l]).length),a[i]&&o.push(r);o.length&&s.push({elem:l,handlers:o})}return l=this,u<e.length&&s.push({elem:l,handlers:e.slice(u)}),s},addProp:function(t,e){Object.defineProperty(mt.Event.prototype,t,{enumerable:!0,configurable:!0,get:mt.isFunction(e)?function(){if(this.originalEvent)return e(this.originalEvent)}:function(){if(this.originalEvent)return this.originalEvent[t]},set:function(e){Object.defineProperty(this,t,{enumerable:!0,configurable:!0,writable:!0,value:e})}})},fix:function(t){return t[mt.expando]?t:new mt.Event(t)},special:{load:{noBubble:!0},focus:{trigger:function(){if(this!==S()&&this.focus)return this.focus(),!1},delegateType:"focusin"},blur:{trigger:function(){if(this===S()&&this.blur)return this.blur(),!1},delegateType:"focusout"},click:{trigger:function(){if("checkbox"===this.type&&this.click&&mt.nodeName(this,"input"))return this.click(),!1},_default:function(t){return mt.nodeName(t.target,"a")}},beforeunload:{postDispatch:function(t){void 0!==t.result&&t.originalEvent&&(t.originalEvent.returnValue=t.result)}}}},mt.removeEvent=function(t,e,n){t.removeEventListener&&t.removeEventListener(e,n)},mt.Event=function(t,e){if(!(this instanceof mt.Event))return new mt.Event(t,e);t&&t.type?(this.originalEvent=t,this.type=t.type,this.isDefaultPrevented=t.defaultPrevented||void 0===t.defaultPrevented&&!1===t.returnValue?T:C,this.target=t.target&&3===t.target.nodeType?t.target.parentNode:t.target,this.currentTarget=t.currentTarget,this.relatedTarget=t.relatedTarget):this.type=t,e&&mt.extend(this,e),this.timeStamp=t&&t.timeStamp||mt.now(),this[mt.expando]=!0},mt.Event.prototype={constructor:mt.Event,isDefaultPrevented:C,isPropagationStopped:C,isImmediatePropagationStopped:C,isSimulated:!1,preventDefault:function(){var t=this.originalEvent;this.isDefaultPrevented=T,t&&!this.isSimulated&&t.preventDefault()},stopPropagation:function(){var t=this.originalEvent;this.isPropagationStopped=T,t&&!this.isSimulated&&t.stopPropagation()},stopImmediatePropagation:function(){var t=this.originalEvent;this.isImmediatePropagationStopped=T,t&&!this.isSimulated&&t.stopImmediatePropagation(),this.stopPropagation()}},mt.each({altKey:!0,bubbles:!0,cancelable:!0,changedTouches:!0,ctrlKey:!0,detail:!0,eventPhase:!0,metaKey:!0,pageX:!0,pageY:!0,shiftKey:!0,view:!0,char:!0,charCode:!0,key:!0,keyCode:!0,button:!0,buttons:!0,clientX:!0,clientY:!0,offsetX:!0,offsetY:!0,pointerId:!0,pointerType:!0,screenX:!0,screenY:!0,targetTouches:!0,toElement:!0,touches:!0,which:function(t){var e=t.button;return null==t.which&&te.test(t.type)?null!=t.charCode?t.charCode:t.keyCode:!t.which&&void 0!==e&&ee.test(t.type)?1&e?1:2&e?3:4&e?2:0:t.which}},mt.event.addProp),mt.each({mouseenter:"mouseover",mouseleave:"mouseout",pointerenter:"pointerover",pointerleave:"pointerout"},function(t,e){mt.event.special[t]={delegateType:e,bindType:e,handle:function(t){var n,r=this,i=t.relatedTarget,o=t.handleObj;return i&&(i===r||mt.contains(r,i))||(t.type=o.origType,n=o.handler.apply(this,arguments),t.type=e),n}}}),mt.fn.extend({on:function(t,e,n,r){return N(this,t,e,n,r)},one:function(t,e,n,r){return N(this,t,e,n,r,1)},off:function(t,e,n){var r,i;if(t&&t.preventDefault&&t.handleObj)return r=t.handleObj,mt(t.delegateTarget).off(r.namespace?r.origType+"."+r.namespace:r.origType,r.selector,r.handler),this;if("object"==typeof t){for(i in t)this.off(i,e,t[i]);return this}return!1!==e&&"function"!=typeof e||(n=e,e=void 0),!1===n&&(n=C),this.each(function(){mt.event.remove(this,t,n,e)})}});var re=/<(?!area|br|col|embed|hr|img|input|link|meta|param)(([a-z][^\/\0>\x20\t\r\n\f]*)[^>]*)\/>/gi,ie=/<script|<style|<link/i,oe=/checked\s*(?:[^=]|=\s*.checked.)/i,ae=/^true\/(.*)/,se=/^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g;mt.extend({htmlPrefilter:function(t){return t.replace(re,"<$1></$2>")},clone:function(t,e,n){var r,i,o,a,s=t.cloneNode(!0),u=mt.contains(t.ownerDocument,t);if(!(vt.noCloneChecked||1!==t.nodeType&&11!==t.nodeType||mt.isXMLDoc(t)))for(a=w(s),o=w(t),r=0,i=o.length;r<i;r++)D(o[r],a[r]);if(e)if(n)for(o=o||w(t),a=a||w(s),r=0,i=o.length;r<i;r++)L(o[r],a[r]);else L(t,s);return a=w(s,"script"),a.length>0&&M(a,!u&&w(t,"script")),s},cleanData:function(t){for(var e,n,r,i=mt.event.special,o=0;void 0!==(n=t[o]);o++)if(Pt(n)){if(e=n[$t.expando]){if(e.events)for(r in e.events)i[r]?mt.event.remove(n,r):mt.removeEvent(n,r,e.handle);n[$t.expando]=void 0}n[qt.expando]&&(n[qt.expando]=void 0)}}}),mt.fn.extend({detach:function(t){return j(this,t,!0)},remove:function(t){return j(this,t)},text:function(t){return It(this,function(t){return void 0===t?mt.text(this):this.empty().each(function(){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||(this.textContent=t)})},null,t,arguments.length)},append:function(){return R(this,arguments,function(t){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){k(this,t).appendChild(t)}})},prepend:function(){return R(this,arguments,function(t){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){var e=k(this,t);e.insertBefore(t,e.firstChild)}})},before:function(){return R(this,arguments,function(t){this.parentNode&&this.parentNode.insertBefore(t,this)})},after:function(){return R(this,arguments,function(t){this.parentNode&&this.parentNode.insertBefore(t,this.nextSibling)})},empty:function(){for(var t,e=0;null!=(t=this[e]);e++)1===t.nodeType&&(mt.cleanData(w(t,!1)),t.textContent="");return this},clone:function(t,e){return t=null!=t&&t,e=null==e?t:e,this.map(function(){return mt.clone(this,t,e)})},html:function(t){return It(this,function(t){var e=this[0]||{},n=0,r=this.length;if(void 0===t&&1===e.nodeType)return e.innerHTML;if("string"==typeof t&&!ie.test(t)&&!Jt[(Zt.exec(t)||["",""])[1].toLowerCase()]){t=mt.htmlPrefilter(t);try{for(;n<r;n++)e=this[n]||{},1===e.nodeType&&(mt.cleanData(w(e,!1)),e.innerHTML=t);e=0}catch(t){}}e&&this.empty().append(t)},null,t,arguments.length)},replaceWith:function(){var t=[];return R(this,arguments,function(e){var n=this.parentNode;mt.inArray(this,t)<0&&(mt.cleanData(w(this)),n&&n.replaceChild(e,this))},t)}}),mt.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},function(t,e){mt.fn[t]=function(t){for(var n,r=[],i=mt(t),o=i.length-1,a=0;a<=o;a++)n=a===o?this:this.clone(!0),mt(i[a])[e](n),lt.apply(r,n.get());return this.pushStack(r)}});var ue=/^margin/,le=new RegExp("^("+zt+")(?!px)[a-z%]+$","i"),ce=function(t){var e=t.ownerDocument.defaultView;return e&&e.opener||(e=n),e.getComputedStyle(t)};!function(){function t(){if(s){s.style.cssText="box-sizing:border-box;position:relative;display:block;margin:auto;border:1px;padding:1px;top:1%;width:50%",s.innerHTML="",Kt.appendChild(a);var t=n.getComputedStyle(s);e="1%"!==t.top,o="2px"===t.marginLeft,r="4px"===t.width,s.style.marginRight="50%",i="4px"===t.marginRight,Kt.removeChild(a),s=null}}var e,r,i,o,a=ot.createElement("div"),s=ot.createElement("div");s.style&&(s.style.backgroundClip="content-box",s.cloneNode(!0).style.backgroundClip="",vt.clearCloneStyle="content-box"===s.style.backgroundClip,a.style.cssText="border:0;width:8px;height:0;top:0;left:-9999px;padding:0;margin-top:1px;position:absolute",a.appendChild(s),mt.extend(vt,{pixelPosition:function(){return t(),e},boxSizingReliable:function(){return t(),r},pixelMarginRight:function(){return t(),i},reliableMarginLeft:function(){return t(),o}}))}();var fe=/^(none|table(?!-c[ea]).+)/,he={position:"absolute",visibility:"hidden",display:"block"},pe={letterSpacing:"0",fontWeight:"400"},de=["Webkit","Moz","ms"],ge=ot.createElement("div").style;mt.extend({cssHooks:{opacity:{get:function(t,e){if(e){var n=O(t,"opacity");return""===n?"1":n}}}},cssNumber:{animationIterationCount:!0,columnCount:!0,fillOpacity:!0,flexGrow:!0,flexShrink:!0,fontWeight:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,widows:!0,zIndex:!0,zoom:!0},cssProps:{float:"cssFloat"},style:function(t,e,n,r){if(t&&3!==t.nodeType&&8!==t.nodeType&&t.style){var i,o,a,s=mt.camelCase(e),u=t.style;if(e=mt.cssProps[s]||(mt.cssProps[s]=P(s)||s),a=mt.cssHooks[e]||mt.cssHooks[s],void 0===n)return a&&"get"in a&&void 0!==(i=a.get(t,!1,r))?i:u[e];o=typeof n,"string"===o&&(i=Ut.exec(n))&&i[1]&&(n=m(t,e,i),o="number"),null!=n&&n===n&&("number"===o&&(n+=i&&i[3]||(mt.cssNumber[s]?"":"px")),vt.clearCloneStyle||""!==n||0!==e.indexOf("background")||(u[e]="inherit"),a&&"set"in a&&void 0===(n=a.set(t,n,r))||(u[e]=n))}},css:function(t,e,n,r){var i,o,a,s=mt.camelCase(e);return e=mt.cssProps[s]||(mt.cssProps[s]=P(s)||s),a=mt.cssHooks[e]||mt.cssHooks[s],a&&"get"in a&&(i=a.get(t,!0,n)),void 0===i&&(i=O(t,e,r)),"normal"===i&&e in pe&&(i=pe[e]),""===n||n?(o=parseFloat(i),!0===n||isFinite(o)?o||0:i):i}}),mt.each(["height","width"],function(t,e){mt.cssHooks[e]={get:function(t,n,r){if(n)return!fe.test(mt.css(t,"display"))||t.getClientRects().length&&t.getBoundingClientRect().width?H(t,e,r):Wt(t,he,function(){return H(t,e,r)})},set:function(t,n,r){var i,o=r&&ce(t),a=r&&q(t,e,r,"border-box"===mt.css(t,"boxSizing",!1,o),o);return a&&(i=Ut.exec(n))&&"px"!==(i[3]||"px")&&(t.style[e]=n,n=mt.css(t,e)),$(t,n,a)}}}),mt.cssHooks.marginLeft=I(vt.reliableMarginLeft,function(t,e){if(e)return(parseFloat(O(t,"marginLeft"))||t.getBoundingClientRect().left-Wt(t,{marginLeft:0},function(){return t.getBoundingClientRect().left}))+"px"}),mt.each({margin:"",padding:"",border:"Width"},function(t,e){mt.cssHooks[t+e]={expand:function(n){for(var r=0,i={},o="string"==typeof n?n.split(" "):[n];r<4;r++)i[t+Vt[r]+e]=o[r]||o[r-2]||o[0];return i}},ue.test(t)||(mt.cssHooks[t+e].set=$)}),mt.fn.extend({css:function(t,e){return It(this,function(t,e,n){var r,i,o={},a=0;if(mt.isArray(e)){for(r=ce(t),i=e.length;a<i;a++)o[e[a]]=mt.css(t,e[a],!1,r);return o}return void 0!==n?mt.style(t,e,n):mt.css(t,e)},t,e,arguments.length>1)}}),mt.Tween=F,F.prototype={constructor:F,init:function(t,e,n,r,i,o){this.elem=t,this.prop=n,this.easing=i||mt.easing._default,this.options=e,this.start=this.now=this.cur(),this.end=r,this.unit=o||(mt.cssNumber[n]?"":"px")},cur:function(){var t=F.propHooks[this.prop];return t&&t.get?t.get(this):F.propHooks._default.get(this)},run:function(t){var e,n=F.propHooks[this.prop];return this.options.duration?this.pos=e=mt.easing[this.easing](t,this.options.duration*t,0,1,this.options.duration):this.pos=e=t,this.now=(this.end-this.start)*e+this.start,this.options.step&&this.options.step.call(this.elem,this.now,this),n&&n.set?n.set(this):F.propHooks._default.set(this),this}},F.prototype.init.prototype=F.prototype,F.propHooks={_default:{get:function(t){var e;return 1!==t.elem.nodeType||null!=t.elem[t.prop]&&null==t.elem.style[t.prop]?t.elem[t.prop]:(e=mt.css(t.elem,t.prop,""),e&&"auto"!==e?e:0)},set:function(t){mt.fx.step[t.prop]?mt.fx.step[t.prop](t):1!==t.elem.nodeType||null==t.elem.style[mt.cssProps[t.prop]]&&!mt.cssHooks[t.prop]?t.elem[t.prop]=t.now:mt.style(t.elem,t.prop,t.now+t.unit)}}},F.propHooks.scrollTop=F.propHooks.scrollLeft={set:function(t){t.elem.nodeType&&t.elem.parentNode&&(t.elem[t.prop]=t.now)}},mt.easing={linear:function(t){return t},swing:function(t){return.5-Math.cos(t*Math.PI)/2},_default:"swing"},mt.fx=F.prototype.init,mt.fx.step={};var ve,ye,me=/^(?:toggle|show|hide)$/,be=/queueHooks$/;mt.Animation=mt.extend(G,{tweeners:{"*":[function(t,e){var n=this.createTween(t,e);return m(n.elem,t,Ut.exec(e),n),n}]},tweener:function(t,e){mt.isFunction(t)?(e=t,t=["*"]):t=t.match(Rt);for(var n,r=0,i=t.length;r<i;r++)n=t[r],G.tweeners[n]=G.tweeners[n]||[],G.tweeners[n].unshift(e)},prefilters:[W],prefilter:function(t,e){e?G.prefilters.unshift(t):G.prefilters.push(t)}}),mt.speed=function(t,e,n){var r=t&&"object"==typeof t?mt.extend({},t):{complete:n||!n&&e||mt.isFunction(t)&&t,duration:t,easing:n&&e||e&&!mt.isFunction(e)&&e};return mt.fx.off||ot.hidden?r.duration=0:"number"!=typeof r.duration&&(r.duration in mt.fx.speeds?r.duration=mt.fx.speeds[r.duration]:r.duration=mt.fx.speeds._default),null!=r.queue&&!0!==r.queue||(r.queue="fx"),r.old=r.complete,r.complete=function(){mt.isFunction(r.old)&&r.old.call(this),r.queue&&mt.dequeue(this,r.queue)},r},mt.fn.extend({fadeTo:function(t,e,n,r){return this.filter(Bt).css("opacity",0).show().end().animate({opacity:e},t,n,r)},animate:function(t,e,n,r){var i=mt.isEmptyObject(t),o=mt.speed(e,n,r),a=function(){var e=G(this,mt.extend({},t),o);(i||$t.get(this,"finish"))&&e.stop(!0)};return a.finish=a,i||!1===o.queue?this.each(a):this.queue(o.queue,a)},stop:function(t,e,n){var r=function(t){var e=t.stop;delete t.stop,e(n)};return"string"!=typeof t&&(n=e,e=t,t=void 0),e&&!1!==t&&this.queue(t||"fx",[]),this.each(function(){var e=!0,i=null!=t&&t+"queueHooks",o=mt.timers,a=$t.get(this);if(i)a[i]&&a[i].stop&&r(a[i]);else for(i in a)a[i]&&a[i].stop&&be.test(i)&&r(a[i]);for(i=o.length;i--;)o[i].elem!==this||null!=t&&o[i].queue!==t||(o[i].anim.stop(n),e=!1,o.splice(i,1));!e&&n||mt.dequeue(this,t)})},finish:function(t){return!1!==t&&(t=t||"fx"),this.each(function(){var e,n=$t.get(this),r=n[t+"queue"],i=n[t+"queueHooks"],o=mt.timers,a=r?r.length:0;for(n.finish=!0,mt.queue(this,t,[]),i&&i.stop&&i.stop.call(this,!0),e=o.length;e--;)o[e].elem===this&&o[e].queue===t&&(o[e].anim.stop(!0),o.splice(e,1));for(e=0;e<a;e++)r[e]&&r[e].finish&&r[e].finish.call(this);delete n.finish})}}),mt.each(["toggle","show","hide"],function(t,e){var n=mt.fn[e];mt.fn[e]=function(t,r,i){return null==t||"boolean"==typeof t?n.apply(this,arguments):this.animate(V(e,!0),t,r,i)}}),mt.each({slideDown:V("show"),slideUp:V("hide"),slideToggle:V("toggle"),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},function(t,e){mt.fn[t]=function(t,n,r){return this.animate(e,t,n,r)}}),mt.timers=[],mt.fx.tick=function(){var t,e=0,n=mt.timers;for(ve=mt.now();e<n.length;e++)(t=n[e])()||n[e]!==t||n.splice(e--,1);n.length||mt.fx.stop(),ve=void 0},mt.fx.timer=function(t){mt.timers.push(t),t()?mt.fx.start():mt.timers.pop()},mt.fx.interval=13,mt.fx.start=function(){ye||(ye=n.requestAnimationFrame?n.requestAnimationFrame(z):n.setInterval(mt.fx.tick,mt.fx.interval))},mt.fx.stop=function(){n.cancelAnimationFrame?n.cancelAnimationFrame(ye):n.clearInterval(ye),ye=null},mt.fx.speeds={slow:600,fast:200,_default:400},mt.fn.delay=function(t,e){return t=mt.fx?mt.fx.speeds[t]||t:t,e=e||"fx",this.queue(e,function(e,r){var i=n.setTimeout(e,t);r.stop=function(){n.clearTimeout(i)}})},function(){var t=ot.createElement("input"),e=ot.createElement("select"),n=e.appendChild(ot.createElement("option"));t.type="checkbox",vt.checkOn=""!==t.value,vt.optSelected=n.selected,t=ot.createElement("input"),t.value="t",t.type="radio",vt.radioValue="t"===t.value}();var xe,we=mt.expr.attrHandle;mt.fn.extend({attr:function(t,e){return It(this,mt.attr,t,e,arguments.length>1)},removeAttr:function(t){return this.each(function(){mt.removeAttr(this,t)})}}),mt.extend({attr:function(t,e,n){var r,i,o=t.nodeType;if(3!==o&&8!==o&&2!==o)return void 0===t.getAttribute?mt.prop(t,e,n):(1===o&&mt.isXMLDoc(t)||(i=mt.attrHooks[e.toLowerCase()]||(mt.expr.match.bool.test(e)?xe:void 0)),void 0!==n?null===n?void mt.removeAttr(t,e):i&&"set"in i&&void 0!==(r=i.set(t,n,e))?r:(t.setAttribute(e,n+""),n):i&&"get"in i&&null!==(r=i.get(t,e))?r:(r=mt.find.attr(t,e),null==r?void 0:r))},attrHooks:{type:{set:function(t,e){if(!vt.radioValue&&"radio"===e&&mt.nodeName(t,"input")){var n=t.value;return t.setAttribute("type",e),n&&(t.value=n),e}}}},removeAttr:function(t,e){var n,r=0,i=e&&e.match(Rt);if(i&&1===t.nodeType)for(;n=i[r++];)t.removeAttribute(n)}}),xe={set:function(t,e,n){return!1===e?mt.removeAttr(t,n):t.setAttribute(n,n),n}},mt.each(mt.expr.match.bool.source.match(/\w+/g),function(t,e){var n=we[e]||mt.find.attr;we[e]=function(t,e,r){var i,o,a=e.toLowerCase();return r||(o=we[a],we[a]=i,i=null!=n(t,e,r)?a:null,we[a]=o),i}});var Me=/^(?:input|select|textarea|button)$/i,Ee=/^(?:a|area)$/i;mt.fn.extend({prop:function(t,e){return It(this,mt.prop,t,e,arguments.length>1)},removeProp:function(t){return this.each(function(){delete this[mt.propFix[t]||t]})}}),mt.extend({prop:function(t,e,n){var r,i,o=t.nodeType;if(3!==o&&8!==o&&2!==o)return 1===o&&mt.isXMLDoc(t)||(e=mt.propFix[e]||e,i=mt.propHooks[e]),void 0!==n?i&&"set"in i&&void 0!==(r=i.set(t,n,e))?r:t[e]=n:i&&"get"in i&&null!==(r=i.get(t,e))?r:t[e]},propHooks:{tabIndex:{get:function(t){var e=mt.find.attr(t,"tabindex");return e?parseInt(e,10):Me.test(t.nodeName)||Ee.test(t.nodeName)&&t.href?0:-1}}},propFix:{for:"htmlFor",class:"className"}}),vt.optSelected||(mt.propHooks.selected={get:function(t){var e=t.parentNode;return e&&e.parentNode&&e.parentNode.selectedIndex,null},set:function(t){var e=t.parentNode;e&&(e.selectedIndex,e.parentNode&&e.parentNode.selectedIndex)}}),mt.each(["tabIndex","readOnly","maxLength","cellSpacing","cellPadding","rowSpan","colSpan","useMap","frameBorder","contentEditable"],function(){mt.propFix[this.toLowerCase()]=this}),mt.fn.extend({addClass:function(t){var e,n,r,i,o,a,s,u=0;if(mt.isFunction(t))return this.each(function(e){mt(this).addClass(t.call(this,e,X(this)))});if("string"==typeof t&&t)for(e=t.match(Rt)||[];n=this[u++];)if(i=X(n),r=1===n.nodeType&&" "+Z(i)+" "){for(a=0;o=e[a++];)r.indexOf(" "+o+" ")<0&&(r+=o+" ");s=Z(r),i!==s&&n.setAttribute("class",s)}return this},removeClass:function(t){var e,n,r,i,o,a,s,u=0;if(mt.isFunction(t))return this.each(function(e){mt(this).removeClass(t.call(this,e,X(this)))});if(!arguments.length)return this.attr("class","");if("string"==typeof t&&t)for(e=t.match(Rt)||[];n=this[u++];)if(i=X(n),r=1===n.nodeType&&" "+Z(i)+" "){for(a=0;o=e[a++];)for(;r.indexOf(" "+o+" ")>-1;)r=r.replace(" "+o+" "," ");s=Z(r),i!==s&&n.setAttribute("class",s)}return this},toggleClass:function(t,e){var n=typeof t;return"boolean"==typeof e&&"string"===n?e?this.addClass(t):this.removeClass(t):mt.isFunction(t)?this.each(function(n){mt(this).toggleClass(t.call(this,n,X(this),e),e)}):this.each(function(){var e,r,i,o;if("string"===n)for(r=0,i=mt(this),o=t.match(Rt)||[];e=o[r++];)i.hasClass(e)?i.removeClass(e):i.addClass(e);else void 0!==t&&"boolean"!==n||(e=X(this),e&&$t.set(this,"__className__",e),this.setAttribute&&this.setAttribute("class",e||!1===t?"":$t.get(this,"__className__")||""))})},hasClass:function(t){var e,n,r=0;for(e=" "+t+" ";n=this[r++];)if(1===n.nodeType&&(" "+Z(X(n))+" ").indexOf(e)>-1)return!0;return!1}});var Te=/\r/g;mt.fn.extend({val:function(t){var e,n,r,i=this[0];{if(arguments.length)return r=mt.isFunction(t),this.each(function(n){var i;1===this.nodeType&&(i=r?t.call(this,n,mt(this).val()):t,null==i?i="":"number"==typeof i?i+="":mt.isArray(i)&&(i=mt.map(i,function(t){return null==t?"":t+""})),(e=mt.valHooks[this.type]||mt.valHooks[this.nodeName.toLowerCase()])&&"set"in e&&void 0!==e.set(this,i,"value")||(this.value=i))});if(i)return(e=mt.valHooks[i.type]||mt.valHooks[i.nodeName.toLowerCase()])&&"get"in e&&void 0!==(n=e.get(i,"value"))?n:(n=i.value,"string"==typeof n?n.replace(Te,""):null==n?"":n)}}}),mt.extend({valHooks:{option:{get:function(t){var e=mt.find.attr(t,"value");return null!=e?e:Z(mt.text(t))}},select:{get:function(t){var e,n,r,i=t.options,o=t.selectedIndex,a="select-one"===t.type,s=a?null:[],u=a?o+1:i.length;for(r=o<0?u:a?o:0;r<u;r++)if(n=i[r],(n.selected||r===o)&&!n.disabled&&(!n.parentNode.disabled||!mt.nodeName(n.parentNode,"optgroup"))){if(e=mt(n).val(),a)return e;s.push(e)}return s},set:function(t,e){for(var n,r,i=t.options,o=mt.makeArray(e),a=i.length;a--;)r=i[a],(r.selected=mt.inArray(mt.valHooks.option.get(r),o)>-1)&&(n=!0);return n||(t.selectedIndex=-1),o}}}}),mt.each(["radio","checkbox"],function(){mt.valHooks[this]={set:function(t,e){if(mt.isArray(e))return t.checked=mt.inArray(mt(t).val(),e)>-1}},vt.checkOn||(mt.valHooks[this].get=function(t){return null===t.getAttribute("value")?"on":t.value})});var Ce=/^(?:focusinfocus|focusoutblur)$/;mt.extend(mt.event,{trigger:function(t,e,r,i){var o,a,s,u,l,c,f,h=[r||ot],p=pt.call(t,"type")?t.type:t,d=pt.call(t,"namespace")?t.namespace.split("."):[];if(a=s=r=r||ot,3!==r.nodeType&&8!==r.nodeType&&!Ce.test(p+mt.event.triggered)&&(p.indexOf(".")>-1&&(d=p.split("."),p=d.shift(),d.sort()),l=p.indexOf(":")<0&&"on"+p,t=t[mt.expando]?t:new mt.Event(p,"object"==typeof t&&t),t.isTrigger=i?2:3,t.namespace=d.join("."),t.rnamespace=t.namespace?new RegExp("(^|\\.)"+d.join("\\.(?:.*\\.|)")+"(\\.|$)"):null,t.result=void 0,t.target||(t.target=r),e=null==e?[t]:mt.makeArray(e,[t]),f=mt.event.special[p]||{},i||!f.trigger||!1!==f.trigger.apply(r,e))){if(!i&&!f.noBubble&&!mt.isWindow(r)){for(u=f.delegateType||p,Ce.test(u+p)||(a=a.parentNode);a;a=a.parentNode)h.push(a),s=a;s===(r.ownerDocument||ot)&&h.push(s.defaultView||s.parentWindow||n)}for(o=0;(a=h[o++])&&!t.isPropagationStopped();)t.type=o>1?u:f.bindType||p,c=($t.get(a,"events")||{})[t.type]&&$t.get(a,"handle"),c&&c.apply(a,e),(c=l&&a[l])&&c.apply&&Pt(a)&&(t.result=c.apply(a,e),!1===t.result&&t.preventDefault());return t.type=p,i||t.isDefaultPrevented()||f._default&&!1!==f._default.apply(h.pop(),e)||!Pt(r)||l&&mt.isFunction(r[p])&&!mt.isWindow(r)&&(s=r[l],s&&(r[l]=null),mt.event.triggered=p,r[p](),mt.event.triggered=void 0,s&&(r[l]=s)),t.result}},simulate:function(t,e,n){var r=mt.extend(new mt.Event,n,{type:t,isSimulated:!0});mt.event.trigger(r,null,e)}}),mt.fn.extend({trigger:function(t,e){return this.each(function(){mt.event.trigger(t,e,this)})},triggerHandler:function(t,e){var n=this[0];if(n)return mt.event.trigger(t,e,n,!0)}}),mt.each("blur focus focusin focusout resize scroll click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup contextmenu".split(" "),function(t,e){mt.fn[e]=function(t,n){return arguments.length>0?this.on(e,null,t,n):this.trigger(e)}}),mt.fn.extend({hover:function(t,e){return this.mouseenter(t).mouseleave(e||t)}}),vt.focusin="onfocusin"in n,vt.focusin||mt.each({focus:"focusin",blur:"focusout"},function(t,e){var n=function(t){mt.event.simulate(e,t.target,mt.event.fix(t))};mt.event.special[e]={setup:function(){var r=this.ownerDocument||this,i=$t.access(r,e);i||r.addEventListener(t,n,!0),$t.access(r,e,(i||0)+1)},teardown:function(){var r=this.ownerDocument||this,i=$t.access(r,e)-1;i?$t.access(r,e,i):(r.removeEventListener(t,n,!0),$t.remove(r,e))}}});var Se=n.location,Ne=mt.now(),ke=/\?/;mt.parseXML=function(t){var e;if(!t||"string"!=typeof t)return null;try{e=(new n.DOMParser).parseFromString(t,"text/xml")}catch(t){e=void 0}return e&&!e.getElementsByTagName("parsererror").length||mt.error("Invalid XML: "+t),e};var _e=/\[\]$/,Ae=/\r?\n/g,Le=/^(?:submit|button|image|reset|file)$/i,De=/^(?:input|select|textarea|keygen)/i;mt.param=function(t,e){var n,r=[],i=function(t,e){var n=mt.isFunction(e)?e():e;r[r.length]=encodeURIComponent(t)+"="+encodeURIComponent(null==n?"":n)};if(mt.isArray(t)||t.jquery&&!mt.isPlainObject(t))mt.each(t,function(){i(this.name,this.value)});else for(n in t)J(n,t[n],e,i);return r.join("&")},mt.fn.extend({serialize:function(){return mt.param(this.serializeArray())},serializeArray:function(){return this.map(function(){var t=mt.prop(this,"elements");return t?mt.makeArray(t):this}).filter(function(){var t=this.type;return this.name&&!mt(this).is(":disabled")&&De.test(this.nodeName)&&!Le.test(t)&&(this.checked||!Gt.test(t))}).map(function(t,e){var n=mt(this).val();return null==n?null:mt.isArray(n)?mt.map(n,function(t){return{name:e.name,value:t.replace(Ae,"\r\n")}}):{name:e.name,value:n.replace(Ae,"\r\n")}}).get()}});var Re=/%20/g,je=/#.*$/,Oe=/([?&])_=[^&]*/,Ie=/^(.*?):[ \t]*([^\r\n]*)$/gm,Pe=/^(?:about|app|app-storage|.+-extension|file|res|widget):$/,$e=/^(?:GET|HEAD)$/,qe=/^\/\//,He={},Fe={},ze="*/".concat("*"),Ue=ot.createElement("a");Ue.href=Se.href,mt.extend({active:0,lastModified:{},etag:{},ajaxSettings:{url:Se.href,type:"GET",isLocal:Pe.test(Se.protocol),global:!0,processData:!0,async:!0,contentType:"application/x-www-form-urlencoded; charset=UTF-8",accepts:{"*":ze,text:"text/plain",html:"text/html",xml:"application/xml, text/xml",json:"application/json, text/javascript"},contents:{xml:/\bxml\b/,html:/\bhtml/,json:/\bjson\b/},responseFields:{xml:"responseXML",text:"responseText",json:"responseJSON"},converters:{"* text":String,"text html":!0,"text json":JSON.parse,"text xml":mt.parseXML},flatOptions:{url:!0,context:!0}},ajaxSetup:function(t,e){return e?tt(tt(t,mt.ajaxSettings),e):tt(mt.ajaxSettings,t)},ajaxPrefilter:Q(He),ajaxTransport:Q(Fe),ajax:function(t,e){function r(t,e,r,s){var l,h,p,x,w,M=e;c||(c=!0,u&&n.clearTimeout(u),i=void 0,a=s||"",E.readyState=t>0?4:0,l=t>=200&&t<300||304===t,r&&(x=et(d,E,r)),x=nt(d,x,E,l),l?(d.ifModified&&(w=E.getResponseHeader("Last-Modified"),w&&(mt.lastModified[o]=w),(w=E.getResponseHeader("etag"))&&(mt.etag[o]=w)),204===t||"HEAD"===d.type?M="nocontent":304===t?M="notmodified":(M=x.state,h=x.data,p=x.error,l=!p)):(p=M,!t&&M||(M="error",t<0&&(t=0))),E.status=t,E.statusText=(e||M)+"",l?y.resolveWith(g,[h,M,E]):y.rejectWith(g,[E,M,p]),E.statusCode(b),b=void 0,f&&v.trigger(l?"ajaxSuccess":"ajaxError",[E,d,l?h:p]),m.fireWith(g,[E,M]),f&&(v.trigger("ajaxComplete",[E,d]),--mt.active||mt.event.trigger("ajaxStop")))}"object"==typeof t&&(e=t,t=void 0),e=e||{};var i,o,a,s,u,l,c,f,h,p,d=mt.ajaxSetup({},e),g=d.context||d,v=d.context&&(g.nodeType||g.jquery)?mt(g):mt.event,y=mt.Deferred(),m=mt.Callbacks("once memory"),b=d.statusCode||{},x={},w={},M="canceled",E={readyState:0,getResponseHeader:function(t){var e;if(c){if(!s)for(s={};e=Ie.exec(a);)s[e[1].toLowerCase()]=e[2];e=s[t.toLowerCase()]}return null==e?null:e},getAllResponseHeaders:function(){return c?a:null},setRequestHeader:function(t,e){return null==c&&(t=w[t.toLowerCase()]=w[t.toLowerCase()]||t,x[t]=e),this},overrideMimeType:function(t){return null==c&&(d.mimeType=t),this},statusCode:function(t){var e;if(t)if(c)E.always(t[E.status]);else for(e in t)b[e]=[b[e],t[e]];return this},abort:function(t){var e=t||M;return i&&i.abort(e),r(0,e),this}};if(y.promise(E),d.url=((t||d.url||Se.href)+"").replace(qe,Se.protocol+"//"),d.type=e.method||e.type||d.method||d.type,d.dataTypes=(d.dataType||"*").toLowerCase().match(Rt)||[""],null==d.crossDomain){l=ot.createElement("a");try{l.href=d.url,l.href=l.href,d.crossDomain=Ue.protocol+"//"+Ue.host!=l.protocol+"//"+l.host}catch(t){d.crossDomain=!0}}if(d.data&&d.processData&&"string"!=typeof d.data&&(d.data=mt.param(d.data,d.traditional)),K(He,d,e,E),c)return E;f=mt.event&&d.global,f&&0==mt.active++&&mt.event.trigger("ajaxStart"),d.type=d.type.toUpperCase(),d.hasContent=!$e.test(d.type),o=d.url.replace(je,""),d.hasContent?d.data&&d.processData&&0===(d.contentType||"").indexOf("application/x-www-form-urlencoded")&&(d.data=d.data.replace(Re,"+")):(p=d.url.slice(o.length),d.data&&(o+=(ke.test(o)?"&":"?")+d.data,delete d.data),!1===d.cache&&(o=o.replace(Oe,"$1"),p=(ke.test(o)?"&":"?")+"_="+Ne+++p),d.url=o+p),d.ifModified&&(mt.lastModified[o]&&E.setRequestHeader("If-Modified-Since",mt.lastModified[o]),mt.etag[o]&&E.setRequestHeader("If-None-Match",mt.etag[o])),(d.data&&d.hasContent&&!1!==d.contentType||e.contentType)&&E.setRequestHeader("Content-Type",d.contentType),E.setRequestHeader("Accept",d.dataTypes[0]&&d.accepts[d.dataTypes[0]]?d.accepts[d.dataTypes[0]]+("*"!==d.dataTypes[0]?", "+ze+"; q=0.01":""):d.accepts["*"]);for(h in d.headers)E.setRequestHeader(h,d.headers[h]);if(d.beforeSend&&(!1===d.beforeSend.call(g,E,d)||c))return E.abort();if(M="abort",m.add(d.complete),E.done(d.success),E.fail(d.error),i=K(Fe,d,e,E)){if(E.readyState=1,f&&v.trigger("ajaxSend",[E,d]),c)return E;d.async&&d.timeout>0&&(u=n.setTimeout(function(){E.abort("timeout")},d.timeout));try{c=!1,i.send(x,r)}catch(t){if(c)throw t;r(-1,t)}}else r(-1,"No Transport");return E},getJSON:function(t,e,n){return mt.get(t,e,n,"json")},getScript:function(t,e){return mt.get(t,void 0,e,"script")}}),mt.each(["get","post"],function(t,e){mt[e]=function(t,n,r,i){return mt.isFunction(n)&&(i=i||r,r=n,n=void 0),mt.ajax(mt.extend({url:t,type:e,dataType:i,data:n,success:r},mt.isPlainObject(t)&&t))}}),mt._evalUrl=function(t){return mt.ajax({url:t,type:"GET",dataType:"script",cache:!0,async:!1,global:!1,throws:!0})},mt.fn.extend({wrapAll:function(t){var e;return this[0]&&(mt.isFunction(t)&&(t=t.call(this[0])),e=mt(t,this[0].ownerDocument).eq(0).clone(!0),this[0].parentNode&&e.insertBefore(this[0]),e.map(function(){for(var t=this;t.firstElementChild;)t=t.firstElementChild;return t}).append(this)),this},wrapInner:function(t){return mt.isFunction(t)?this.each(function(e){mt(this).wrapInner(t.call(this,e))}):this.each(function(){var e=mt(this),n=e.contents();n.length?n.wrapAll(t):e.append(t)})},wrap:function(t){var e=mt.isFunction(t);return this.each(function(n){mt(this).wrapAll(e?t.call(this,n):t)})},unwrap:function(t){return this.parent(t).not("body").each(function(){mt(this).replaceWith(this.childNodes)}),this}}),mt.expr.pseudos.hidden=function(t){return!mt.expr.pseudos.visible(t)},mt.expr.pseudos.visible=function(t){return!!(t.offsetWidth||t.offsetHeight||t.getClientRects().length)},mt.ajaxSettings.xhr=function(){try{return new n.XMLHttpRequest}catch(t){}};var Ve={0:200,1223:204},Be=mt.ajaxSettings.xhr();vt.cors=!!Be&&"withCredentials"in Be,vt.ajax=Be=!!Be,mt.ajaxTransport(function(t){var e,r;if(vt.cors||Be&&!t.crossDomain)return{send:function(i,o){var a,s=t.xhr();if(s.open(t.type,t.url,t.async,t.username,t.password),t.xhrFields)for(a in t.xhrFields)s[a]=t.xhrFields[a];t.mimeType&&s.overrideMimeType&&s.overrideMimeType(t.mimeType),t.crossDomain||i["X-Requested-With"]||(i["X-Requested-With"]="XMLHttpRequest");for(a in i)s.setRequestHeader(a,i[a]);e=function(t){return function(){e&&(e=r=s.onload=s.onerror=s.onabort=s.onreadystatechange=null,"abort"===t?s.abort():"error"===t?"number"!=typeof s.status?o(0,"error"):o(s.status,s.statusText):o(Ve[s.status]||s.status,s.statusText,"text"!==(s.responseType||"text")||"string"!=typeof s.responseText?{binary:s.response}:{text:s.responseText},s.getAllResponseHeaders()))}},s.onload=e(),r=s.onerror=e("error"),void 0!==s.onabort?s.onabort=r:s.onreadystatechange=function(){4===s.readyState&&n.setTimeout(function(){e&&r()})},e=e("abort");try{s.send(t.hasContent&&t.data||null)}catch(t){if(e)throw t}},abort:function(){e&&e()}}}),mt.ajaxPrefilter(function(t){t.crossDomain&&(t.contents.script=!1)}),mt.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/\b(?:java|ecma)script\b/},converters:{"text script":function(t){return mt.globalEval(t),t}}}),mt.ajaxPrefilter("script",function(t){void 0===t.cache&&(t.cache=!1),t.crossDomain&&(t.type="GET")}),mt.ajaxTransport("script",function(t){if(t.crossDomain){var e,n;return{send:function(r,i){e=mt("<script>").prop({charset:t.scriptCharset,src:t.url}).on("load error",n=function(t){e.remove(),n=null,t&&i("error"===t.type?404:200,t.type)}),ot.head.appendChild(e[0])},abort:function(){n&&n()}}}});var We=[],Ye=/(=)\?(?=&|$)|\?\?/;mt.ajaxSetup({jsonp:"callback",jsonpCallback:function(){var t=We.pop()||mt.expando+"_"+Ne++;return this[t]=!0,t}}),mt.ajaxPrefilter("json jsonp",function(t,e,r){var i,o,a,s=!1!==t.jsonp&&(Ye.test(t.url)?"url":"string"==typeof t.data&&0===(t.contentType||"").indexOf("application/x-www-form-urlencoded")&&Ye.test(t.data)&&"data");if(s||"jsonp"===t.dataTypes[0])return i=t.jsonpCallback=mt.isFunction(t.jsonpCallback)?t.jsonpCallback():t.jsonpCallback,s?t[s]=t[s].replace(Ye,"$1"+i):!1!==t.jsonp&&(t.url+=(ke.test(t.url)?"&":"?")+t.jsonp+"="+i),t.converters["script json"]=function(){return a||mt.error(i+" was not called"),a[0]},t.dataTypes[0]="json",o=n[i],n[i]=function(){a=arguments},r.always(function(){void 0===o?mt(n).removeProp(i):n[i]=o,t[i]&&(t.jsonpCallback=e.jsonpCallback,We.push(i)),a&&mt.isFunction(o)&&o(a[0]),a=o=void 0}),"script"}),vt.createHTMLDocument=function(){var t=ot.implementation.createHTMLDocument("").body;return t.innerHTML="<form></form><form></form>",2===t.childNodes.length}(),mt.parseHTML=function(t,e,n){if("string"!=typeof t)return[];"boolean"==typeof e&&(n=e,e=!1);var r,i,o;return e||(vt.createHTMLDocument?(e=ot.implementation.createHTMLDocument(""),r=e.createElement("base"),r.href=ot.location.href,e.head.appendChild(r)):e=ot),i=Nt.exec(t),o=!n&&[],i?[e.createElement(i[1])]:(i=E([t],e,o),o&&o.length&&mt(o).remove(),mt.merge([],i.childNodes))},mt.fn.load=function(t,e,n){var r,i,o,a=this,s=t.indexOf(" ");return s>-1&&(r=Z(t.slice(s)),t=t.slice(0,s)),mt.isFunction(e)?(n=e,e=void 0):e&&"object"==typeof e&&(i="POST"),a.length>0&&mt.ajax({url:t,type:i||"GET",dataType:"html",data:e}).done(function(t){o=arguments,a.html(r?mt("<div>").append(mt.parseHTML(t)).find(r):t)}).always(n&&function(t,e){a.each(function(){n.apply(this,o||[t.responseText,e,t])})}),this},mt.each(["ajaxStart","ajaxStop","ajaxComplete","ajaxError","ajaxSuccess","ajaxSend"],function(t,e){mt.fn[e]=function(t){return this.on(e,t)}}),mt.expr.pseudos.animated=function(t){return mt.grep(mt.timers,function(e){return t===e.elem}).length},mt.offset={setOffset:function(t,e,n){var r,i,o,a,s,u,l,c=mt.css(t,"position"),f=mt(t),h={};"static"===c&&(t.style.position="relative"),s=f.offset(),o=mt.css(t,"top"),u=mt.css(t,"left"),l=("absolute"===c||"fixed"===c)&&(o+u).indexOf("auto")>-1,l?(r=f.position(),a=r.top,i=r.left):(a=parseFloat(o)||0,i=parseFloat(u)||0),mt.isFunction(e)&&(e=e.call(t,n,mt.extend({},s))),null!=e.top&&(h.top=e.top-s.top+a),null!=e.left&&(h.left=e.left-s.left+i),"using"in e?e.using.call(t,h):f.css(h)}},mt.fn.extend({offset:function(t){if(arguments.length)return void 0===t?this:this.each(function(e){mt.offset.setOffset(this,t,e)});var e,n,r,i,o=this[0];if(o)return o.getClientRects().length?(r=o.getBoundingClientRect(),r.width||r.height?(i=o.ownerDocument,n=rt(i),e=i.documentElement,{top:r.top+n.pageYOffset-e.clientTop,left:r.left+n.pageXOffset-e.clientLeft}):r):{top:0,left:0}},position:function(){if(this[0]){var t,e,n=this[0],r={top:0,left:0};return"fixed"===mt.css(n,"position")?e=n.getBoundingClientRect():(t=this.offsetParent(),e=this.offset(),mt.nodeName(t[0],"html")||(r=t.offset()),r={top:r.top+mt.css(t[0],"borderTopWidth",!0),left:r.left+mt.css(t[0],"borderLeftWidth",!0)}),{top:e.top-r.top-mt.css(n,"marginTop",!0),left:e.left-r.left-mt.css(n,"marginLeft",!0)}}},offsetParent:function(){return this.map(function(){for(var t=this.offsetParent;t&&"static"===mt.css(t,"position");)t=t.offsetParent;return t||Kt})}}),mt.each({scrollLeft:"pageXOffset",scrollTop:"pageYOffset"},function(t,e){var n="pageYOffset"===e;mt.fn[t]=function(r){return It(this,function(t,r,i){var o=rt(t);if(void 0===i)return o?o[e]:t[r];o?o.scrollTo(n?o.pageXOffset:i,n?i:o.pageYOffset):t[r]=i},t,r,arguments.length)}}),mt.each(["top","left"],function(t,e){mt.cssHooks[e]=I(vt.pixelPosition,function(t,n){if(n)return n=O(t,e),le.test(n)?mt(t).position()[e]+"px":n})}),mt.each({Height:"height",Width:"width"},function(t,e){mt.each({padding:"inner"+t,content:e,"":"outer"+t},function(n,r){mt.fn[r]=function(i,o){var a=arguments.length&&(n||"boolean"!=typeof i),s=n||(!0===i||!0===o?"margin":"border");return It(this,function(e,n,i){var o;return mt.isWindow(e)?0===r.indexOf("outer")?e["inner"+t]:e.document.documentElement["client"+t]:9===e.nodeType?(o=e.documentElement,Math.max(e.body["scroll"+t],o["scroll"+t],e.body["offset"+t],o["offset"+t],o["client"+t])):void 0===i?mt.css(e,n,s):mt.style(e,n,i,s)},e,a?i:void 0,a)}})}),mt.fn.extend({bind:function(t,e,n){return this.on(t,null,e,n)},unbind:function(t,e){return this.off(t,null,e)},delegate:function(t,e,n,r){return this.on(e,t,n,r)},undelegate:function(t,e,n){return 1===arguments.length?this.off(t,"**"):this.off(e,t||"**",n)}}),mt.parseJSON=JSON.parse,r=[],void 0!==(i=function(){return mt}.apply(e,r))&&(t.exports=i);var Ge=n.jQuery,Ze=n.$;return mt.noConflict=function(t){return n.$===mt&&(n.$=Ze),t&&n.jQuery===mt&&(n.jQuery=Ge),mt},o||(n.jQuery=n.$=mt),mt})},function(t,e,n){"use strict";var r=n(0),i=n(4),o=function(t){function e(){var n=t.call(this)||this;n.updated=function(){n.parse(location.hash),n.fire(e.EVENT_HASH_CHANGED)},n.debounceTimer=-1;var r=history.state;return r?Object.keys(r).forEach(function(t){return n.map.set(t,r[t])}):n.parse(location.hash),window.addEventListener("hashchange",n.updated,!1),n}return r.c(e,t),e.prototype.setInt=function(t,e,n){void 0===n&&(n=!0),this.setProp(t,String(e),n)},e.prototype.setProp=function(t,e,n){void 0===n&&(n=!0),this.map.get(t)!==e&&(this.map.set(t,e),!1!==n&&this.update("number"==typeof n?n:0))},e.prototype.removeProp=function(t,e){return void 0===e&&(e=!0),!!this.map.has(t)&&(this.map.delete(t),!1!==e&&this.update("number"==typeof e?e:0),!0)},e.prototype.toObject=function(){var t={};return this.map.forEach(function(e,n){return t[n]=e}),t},e.prototype.update=function(t){var e=this;if(void 0===t&&(t=0),t<=0)return this.updateImpl();this.debounceTimer>=0&&(self.clearTimeout(this.debounceTimer),this.debounceTimer=-1),this.debounceTimer=self.setTimeout(function(){return e.updateImpl()},t)},e.prototype.updateImpl=function(){var t=this;if(this.debounceTimer>=0&&(self.clearTimeout(this.debounceTimer),this.debounceTimer=-1),history.state){var n=history.state,r=Object.keys(n);if(r.length===this.map.size&&r.every(function(e){return t.map.get(e)===n[e]}))return}window.removeEventListener("hashchange",this.updated,!1),history.pushState(this.toObject(),"State "+Date.now(),"#"+this.toString()),window.addEventListener("hashchange",this.updated,!1),this.fire(e.EVENT_STATE_PUSHED,"State "+Date.now(),"#"+this.toString())},e.EVENT_STATE_PUSHED="pushedState",e.EVENT_HASH_CHANGED="hashChanged",e}(i.a);e.a=o},function(t,e,n){"use strict";function r(t){void 0===t&&(t="_default"),a.has(t)||a.set(t,0);var e=a.get(t);return a.set(t,e+1),e}function i(t,e){return isNaN(e)||e<0?e:(a.has(t)?a.set(t,Math.max(a.get(t),e+1)):a.set(t,e+1),e)}function o(t){return void 0===t&&(t="_default"),t+r(t)}e.b=r,e.c=i,e.a=o;var a=new Map},function(t,e){},function(t,e,n){"use strict";var r=n(2);n.i(r.b)("phovea_core",n(50))},function(t,e,n){var r=n(5);/*!
 * Bootstrap v3.3.7 (http://getbootstrap.com)
 * Copyright 2011-2016 Twitter, Inc.
 * Licensed under the MIT license
 */
if(void 0===r)throw new Error("Bootstrap's JavaScript requires jQuery");+function(t){"use strict";var e=t.fn.jquery.split(" ")[0].split(".");if(e[0]<2&&e[1]<9||1==e[0]&&9==e[1]&&e[2]<1||e[0]>3)throw new Error("Bootstrap's JavaScript requires jQuery version 1.9.1 or higher, but lower than version 4")}(r),function(t){"use strict";function e(){var t=document.createElement("bootstrap"),e={WebkitTransition:"webkitTransitionEnd",MozTransition:"transitionend",OTransition:"oTransitionEnd otransitionend",transition:"transitionend"};for(var n in e)if(void 0!==t.style[n])return{end:e[n]};return!1}t.fn.emulateTransitionEnd=function(e){var n=!1,r=this;t(this).one("bsTransitionEnd",function(){n=!0});var i=function(){n||t(r).trigger(t.support.transition.end)};return setTimeout(i,e),this},t(function(){t.support.transition=e(),t.support.transition&&(t.event.special.bsTransitionEnd={bindType:t.support.transition.end,delegateType:t.support.transition.end,handle:function(e){if(t(e.target).is(this))return e.handleObj.handler.apply(this,arguments)}})})}(r),function(t){"use strict";function e(e){return this.each(function(){var n=t(this),i=n.data("bs.alert");i||n.data("bs.alert",i=new r(this)),"string"==typeof e&&i[e].call(n)})}var n='[data-dismiss="alert"]',r=function(e){t(e).on("click",n,this.close)};r.VERSION="3.3.7",r.TRANSITION_DURATION=150,r.prototype.close=function(e){function n(){a.detach().trigger("closed.bs.alert").remove()}var i=t(this),o=i.attr("data-target");o||(o=i.attr("href"),o=o&&o.replace(/.*(?=#[^\s]*$)/,""));var a=t("#"===o?[]:o);e&&e.preventDefault(),a.length||(a=i.closest(".alert")),a.trigger(e=t.Event("close.bs.alert")),e.isDefaultPrevented()||(a.removeClass("in"),t.support.transition&&a.hasClass("fade")?a.one("bsTransitionEnd",n).emulateTransitionEnd(r.TRANSITION_DURATION):n())};var i=t.fn.alert;t.fn.alert=e,t.fn.alert.Constructor=r,t.fn.alert.noConflict=function(){return t.fn.alert=i,this},t(document).on("click.bs.alert.data-api",n,r.prototype.close)}(r),function(t){"use strict";function e(e){return this.each(function(){var r=t(this),i=r.data("bs.button"),o="object"==typeof e&&e;i||r.data("bs.button",i=new n(this,o)),"toggle"==e?i.toggle():e&&i.setState(e)})}var n=function(e,r){this.$element=t(e),this.options=t.extend({},n.DEFAULTS,r),this.isLoading=!1};n.VERSION="3.3.7",n.DEFAULTS={loadingText:"loading..."},n.prototype.setState=function(e){var n="disabled",r=this.$element,i=r.is("input")?"val":"html",o=r.data();e+="Text",null==o.resetText&&r.data("resetText",r[i]()),setTimeout(t.proxy(function(){r[i](null==o[e]?this.options[e]:o[e]),"loadingText"==e?(this.isLoading=!0,r.addClass(n).attr(n,n).prop(n,!0)):this.isLoading&&(this.isLoading=!1,r.removeClass(n).removeAttr(n).prop(n,!1))},this),0)},n.prototype.toggle=function(){var t=!0,e=this.$element.closest('[data-toggle="buttons"]');if(e.length){var n=this.$element.find("input");"radio"==n.prop("type")?(n.prop("checked")&&(t=!1),e.find(".active").removeClass("active"),this.$element.addClass("active")):"checkbox"==n.prop("type")&&(n.prop("checked")!==this.$element.hasClass("active")&&(t=!1),this.$element.toggleClass("active")),n.prop("checked",this.$element.hasClass("active")),t&&n.trigger("change")}else this.$element.attr("aria-pressed",!this.$element.hasClass("active")),this.$element.toggleClass("active")};var r=t.fn.button;t.fn.button=e,t.fn.button.Constructor=n,t.fn.button.noConflict=function(){return t.fn.button=r,this},t(document).on("click.bs.button.data-api",'[data-toggle^="button"]',function(n){var r=t(n.target).closest(".btn");e.call(r,"toggle"),t(n.target).is('input[type="radio"], input[type="checkbox"]')||(n.preventDefault(),r.is("input,button")?r.trigger("focus"):r.find("input:visible,button:visible").first().trigger("focus"))}).on("focus.bs.button.data-api blur.bs.button.data-api",'[data-toggle^="button"]',function(e){t(e.target).closest(".btn").toggleClass("focus",/^focus(in)?$/.test(e.type))})}(r),function(t){"use strict";function e(e){return this.each(function(){var r=t(this),i=r.data("bs.carousel"),o=t.extend({},n.DEFAULTS,r.data(),"object"==typeof e&&e),a="string"==typeof e?e:o.slide;i||r.data("bs.carousel",i=new n(this,o)),"number"==typeof e?i.to(e):a?i[a]():o.interval&&i.pause().cycle()})}var n=function(e,n){this.$element=t(e),this.$indicators=this.$element.find(".carousel-indicators"),this.options=n,this.paused=null,this.sliding=null,this.interval=null,this.$active=null,this.$items=null,this.options.keyboard&&this.$element.on("keydown.bs.carousel",t.proxy(this.keydown,this)),"hover"==this.options.pause&&!("ontouchstart"in document.documentElement)&&this.$element.on("mouseenter.bs.carousel",t.proxy(this.pause,this)).on("mouseleave.bs.carousel",t.proxy(this.cycle,this))};n.VERSION="3.3.7",n.TRANSITION_DURATION=600,n.DEFAULTS={interval:5e3,pause:"hover",wrap:!0,keyboard:!0},n.prototype.keydown=function(t){if(!/input|textarea/i.test(t.target.tagName)){switch(t.which){case 37:this.prev();break;case 39:this.next();break;default:return}t.preventDefault()}},n.prototype.cycle=function(e){return e||(this.paused=!1),this.interval&&clearInterval(this.interval),this.options.interval&&!this.paused&&(this.interval=setInterval(t.proxy(this.next,this),this.options.interval)),this},n.prototype.getItemIndex=function(t){return this.$items=t.parent().children(".item"),this.$items.index(t||this.$active)},n.prototype.getItemForDirection=function(t,e){var n=this.getItemIndex(e);if(("prev"==t&&0===n||"next"==t&&n==this.$items.length-1)&&!this.options.wrap)return e;var r="prev"==t?-1:1,i=(n+r)%this.$items.length;return this.$items.eq(i)},n.prototype.to=function(t){var e=this,n=this.getItemIndex(this.$active=this.$element.find(".item.active"));if(!(t>this.$items.length-1||t<0))return this.sliding?this.$element.one("slid.bs.carousel",function(){e.to(t)}):n==t?this.pause().cycle():this.slide(t>n?"next":"prev",this.$items.eq(t))},n.prototype.pause=function(e){return e||(this.paused=!0),this.$element.find(".next, .prev").length&&t.support.transition&&(this.$element.trigger(t.support.transition.end),this.cycle(!0)),this.interval=clearInterval(this.interval),this},n.prototype.next=function(){if(!this.sliding)return this.slide("next")},n.prototype.prev=function(){if(!this.sliding)return this.slide("prev")},n.prototype.slide=function(e,r){var i=this.$element.find(".item.active"),o=r||this.getItemForDirection(e,i),a=this.interval,s="next"==e?"left":"right",u=this;if(o.hasClass("active"))return this.sliding=!1;var l=o[0],c=t.Event("slide.bs.carousel",{relatedTarget:l,direction:s});if(this.$element.trigger(c),!c.isDefaultPrevented()){if(this.sliding=!0,a&&this.pause(),this.$indicators.length){this.$indicators.find(".active").removeClass("active");var f=t(this.$indicators.children()[this.getItemIndex(o)]);f&&f.addClass("active")}var h=t.Event("slid.bs.carousel",{relatedTarget:l,direction:s});return t.support.transition&&this.$element.hasClass("slide")?(o.addClass(e),o[0].offsetWidth,i.addClass(s),o.addClass(s),i.one("bsTransitionEnd",function(){o.removeClass([e,s].join(" ")).addClass("active"),i.removeClass(["active",s].join(" ")),u.sliding=!1,setTimeout(function(){u.$element.trigger(h)},0)}).emulateTransitionEnd(n.TRANSITION_DURATION)):(i.removeClass("active"),o.addClass("active"),this.sliding=!1,this.$element.trigger(h)),a&&this.cycle(),this}};var r=t.fn.carousel;t.fn.carousel=e,t.fn.carousel.Constructor=n,t.fn.carousel.noConflict=function(){return t.fn.carousel=r,this};var i=function(n){var r,i=t(this),o=t(i.attr("data-target")||(r=i.attr("href"))&&r.replace(/.*(?=#[^\s]+$)/,""));if(o.hasClass("carousel")){var a=t.extend({},o.data(),i.data()),s=i.attr("data-slide-to");s&&(a.interval=!1),e.call(o,a),s&&o.data("bs.carousel").to(s),n.preventDefault()}};t(document).on("click.bs.carousel.data-api","[data-slide]",i).on("click.bs.carousel.data-api","[data-slide-to]",i),t(window).on("load",function(){t('[data-ride="carousel"]').each(function(){var n=t(this);e.call(n,n.data())})})}(r),function(t){"use strict";function e(e){var n,r=e.attr("data-target")||(n=e.attr("href"))&&n.replace(/.*(?=#[^\s]+$)/,"");return t(r)}function n(e){return this.each(function(){var n=t(this),i=n.data("bs.collapse"),o=t.extend({},r.DEFAULTS,n.data(),"object"==typeof e&&e);!i&&o.toggle&&/show|hide/.test(e)&&(o.toggle=!1),i||n.data("bs.collapse",i=new r(this,o)),"string"==typeof e&&i[e]()})}var r=function(e,n){this.$element=t(e),this.options=t.extend({},r.DEFAULTS,n),this.$trigger=t('[data-toggle="collapse"][href="#'+e.id+'"],[data-toggle="collapse"][data-target="#'+e.id+'"]'),this.transitioning=null,this.options.parent?this.$parent=this.getParent():this.addAriaAndCollapsedClass(this.$element,this.$trigger),this.options.toggle&&this.toggle()};r.VERSION="3.3.7",r.TRANSITION_DURATION=350,r.DEFAULTS={toggle:!0},r.prototype.dimension=function(){return this.$element.hasClass("width")?"width":"height"},r.prototype.show=function(){if(!this.transitioning&&!this.$element.hasClass("in")){var e,i=this.$parent&&this.$parent.children(".panel").children(".in, .collapsing");if(!(i&&i.length&&(e=i.data("bs.collapse"))&&e.transitioning)){var o=t.Event("show.bs.collapse");if(this.$element.trigger(o),!o.isDefaultPrevented()){i&&i.length&&(n.call(i,"hide"),e||i.data("bs.collapse",null));var a=this.dimension();this.$element.removeClass("collapse").addClass("collapsing")[a](0).attr("aria-expanded",!0),this.$trigger.removeClass("collapsed").attr("aria-expanded",!0),this.transitioning=1;var s=function(){this.$element.removeClass("collapsing").addClass("collapse in")[a](""),this.transitioning=0,this.$element.trigger("shown.bs.collapse")};if(!t.support.transition)return s.call(this);var u=t.camelCase(["scroll",a].join("-"));this.$element.one("bsTransitionEnd",t.proxy(s,this)).emulateTransitionEnd(r.TRANSITION_DURATION)[a](this.$element[0][u])}}}},r.prototype.hide=function(){if(!this.transitioning&&this.$element.hasClass("in")){var e=t.Event("hide.bs.collapse");if(this.$element.trigger(e),!e.isDefaultPrevented()){var n=this.dimension();this.$element[n](this.$element[n]())[0].offsetHeight,this.$element.addClass("collapsing").removeClass("collapse in").attr("aria-expanded",!1),this.$trigger.addClass("collapsed").attr("aria-expanded",!1),this.transitioning=1;var i=function(){this.transitioning=0,this.$element.removeClass("collapsing").addClass("collapse").trigger("hidden.bs.collapse")};if(!t.support.transition)return i.call(this);this.$element[n](0).one("bsTransitionEnd",t.proxy(i,this)).emulateTransitionEnd(r.TRANSITION_DURATION)}}},r.prototype.toggle=function(){this[this.$element.hasClass("in")?"hide":"show"]()},r.prototype.getParent=function(){return t(this.options.parent).find('[data-toggle="collapse"][data-parent="'+this.options.parent+'"]').each(t.proxy(function(n,r){var i=t(r);this.addAriaAndCollapsedClass(e(i),i)},this)).end()},r.prototype.addAriaAndCollapsedClass=function(t,e){var n=t.hasClass("in");t.attr("aria-expanded",n),e.toggleClass("collapsed",!n).attr("aria-expanded",n)};var i=t.fn.collapse;t.fn.collapse=n,t.fn.collapse.Constructor=r,t.fn.collapse.noConflict=function(){return t.fn.collapse=i,this},t(document).on("click.bs.collapse.data-api",'[data-toggle="collapse"]',function(r){var i=t(this);i.attr("data-target")||r.preventDefault();var o=e(i),a=o.data("bs.collapse"),s=a?"toggle":i.data();n.call(o,s)})}(r),function(t){"use strict";function e(e){var n=e.attr("data-target");n||(n=e.attr("href"),n=n&&/#[A-Za-z]/.test(n)&&n.replace(/.*(?=#[^\s]*$)/,""));var r=n&&t(n);return r&&r.length?r:e.parent()}function n(n){n&&3===n.which||(t(i).remove(),t(o).each(function(){var r=t(this),i=e(r),o={relatedTarget:this};i.hasClass("open")&&(n&&"click"==n.type&&/input|textarea/i.test(n.target.tagName)&&t.contains(i[0],n.target)||(i.trigger(n=t.Event("hide.bs.dropdown",o)),n.isDefaultPrevented()||(r.attr("aria-expanded","false"),i.removeClass("open").trigger(t.Event("hidden.bs.dropdown",o)))))}))}function r(e){return this.each(function(){var n=t(this),r=n.data("bs.dropdown");r||n.data("bs.dropdown",r=new a(this)),"string"==typeof e&&r[e].call(n)})}var i=".dropdown-backdrop",o='[data-toggle="dropdown"]',a=function(e){t(e).on("click.bs.dropdown",this.toggle)};a.VERSION="3.3.7",a.prototype.toggle=function(r){var i=t(this);if(!i.is(".disabled, :disabled")){var o=e(i),a=o.hasClass("open");if(n(),!a){"ontouchstart"in document.documentElement&&!o.closest(".navbar-nav").length&&t(document.createElement("div")).addClass("dropdown-backdrop").insertAfter(t(this)).on("click",n);var s={relatedTarget:this};if(o.trigger(r=t.Event("show.bs.dropdown",s)),r.isDefaultPrevented())return;i.trigger("focus").attr("aria-expanded","true"),o.toggleClass("open").trigger(t.Event("shown.bs.dropdown",s))}return!1}},a.prototype.keydown=function(n){if(/(38|40|27|32)/.test(n.which)&&!/input|textarea/i.test(n.target.tagName)){var r=t(this);if(n.preventDefault(),n.stopPropagation(),!r.is(".disabled, :disabled")){var i=e(r),a=i.hasClass("open");if(!a&&27!=n.which||a&&27==n.which)return 27==n.which&&i.find(o).trigger("focus"),r.trigger("click");var s=" li:not(.disabled):visible a",u=i.find(".dropdown-menu"+s);if(u.length){var l=u.index(n.target);38==n.which&&l>0&&l--,40==n.which&&l<u.length-1&&l++,~l||(l=0),u.eq(l).trigger("focus")}}}};var s=t.fn.dropdown;t.fn.dropdown=r,t.fn.dropdown.Constructor=a,t.fn.dropdown.noConflict=function(){return t.fn.dropdown=s,this},t(document).on("click.bs.dropdown.data-api",n).on("click.bs.dropdown.data-api",".dropdown form",function(t){t.stopPropagation()}).on("click.bs.dropdown.data-api",o,a.prototype.toggle).on("keydown.bs.dropdown.data-api",o,a.prototype.keydown).on("keydown.bs.dropdown.data-api",".dropdown-menu",a.prototype.keydown)}(r),function(t){"use strict";function e(e,r){return this.each(function(){var i=t(this),o=i.data("bs.modal"),a=t.extend({},n.DEFAULTS,i.data(),"object"==typeof e&&e);o||i.data("bs.modal",o=new n(this,a)),"string"==typeof e?o[e](r):a.show&&o.show(r)})}var n=function(e,n){this.options=n,this.$body=t(document.body),this.$element=t(e),this.$dialog=this.$element.find(".modal-dialog"),this.$backdrop=null,this.isShown=null,this.originalBodyPad=null,this.scrollbarWidth=0,this.ignoreBackdropClick=!1,this.options.remote&&this.$element.find(".modal-content").load(this.options.remote,t.proxy(function(){this.$element.trigger("loaded.bs.modal")},this))};n.VERSION="3.3.7",n.TRANSITION_DURATION=300,n.BACKDROP_TRANSITION_DURATION=150,n.DEFAULTS={backdrop:!0,keyboard:!0,show:!0},n.prototype.toggle=function(t){return this.isShown?this.hide():this.show(t)},n.prototype.show=function(e){var r=this,i=t.Event("show.bs.modal",{relatedTarget:e});this.$element.trigger(i),this.isShown||i.isDefaultPrevented()||(this.isShown=!0,this.checkScrollbar(),this.setScrollbar(),this.$body.addClass("modal-open"),this.escape(),this.resize(),this.$element.on("click.dismiss.bs.modal",'[data-dismiss="modal"]',t.proxy(this.hide,this)),this.$dialog.on("mousedown.dismiss.bs.modal",function(){r.$element.one("mouseup.dismiss.bs.modal",function(e){t(e.target).is(r.$element)&&(r.ignoreBackdropClick=!0)})}),this.backdrop(function(){var i=t.support.transition&&r.$element.hasClass("fade");r.$element.parent().length||r.$element.appendTo(r.$body),r.$element.show().scrollTop(0),r.adjustDialog(),i&&r.$element[0].offsetWidth,r.$element.addClass("in"),r.enforceFocus();var o=t.Event("shown.bs.modal",{relatedTarget:e});i?r.$dialog.one("bsTransitionEnd",function(){r.$element.trigger("focus").trigger(o)}).emulateTransitionEnd(n.TRANSITION_DURATION):r.$element.trigger("focus").trigger(o)}))},n.prototype.hide=function(e){e&&e.preventDefault(),e=t.Event("hide.bs.modal"),this.$element.trigger(e),this.isShown&&!e.isDefaultPrevented()&&(this.isShown=!1,this.escape(),this.resize(),t(document).off("focusin.bs.modal"),this.$element.removeClass("in").off("click.dismiss.bs.modal").off("mouseup.dismiss.bs.modal"),this.$dialog.off("mousedown.dismiss.bs.modal"),t.support.transition&&this.$element.hasClass("fade")?this.$element.one("bsTransitionEnd",t.proxy(this.hideModal,this)).emulateTransitionEnd(n.TRANSITION_DURATION):this.hideModal())},n.prototype.enforceFocus=function(){t(document).off("focusin.bs.modal").on("focusin.bs.modal",t.proxy(function(t){document===t.target||this.$element[0]===t.target||this.$element.has(t.target).length||this.$element.trigger("focus")},this))},n.prototype.escape=function(){this.isShown&&this.options.keyboard?this.$element.on("keydown.dismiss.bs.modal",t.proxy(function(t){27==t.which&&this.hide()},this)):this.isShown||this.$element.off("keydown.dismiss.bs.modal")},n.prototype.resize=function(){this.isShown?t(window).on("resize.bs.modal",t.proxy(this.handleUpdate,this)):t(window).off("resize.bs.modal")},n.prototype.hideModal=function(){var t=this;this.$element.hide(),this.backdrop(function(){t.$body.removeClass("modal-open"),t.resetAdjustments(),t.resetScrollbar(),t.$element.trigger("hidden.bs.modal")})},n.prototype.removeBackdrop=function(){this.$backdrop&&this.$backdrop.remove(),this.$backdrop=null},n.prototype.backdrop=function(e){var r=this,i=this.$element.hasClass("fade")?"fade":"";if(this.isShown&&this.options.backdrop){var o=t.support.transition&&i;if(this.$backdrop=t(document.createElement("div")).addClass("modal-backdrop "+i).appendTo(this.$body),this.$element.on("click.dismiss.bs.modal",t.proxy(function(t){if(this.ignoreBackdropClick)return void(this.ignoreBackdropClick=!1);t.target===t.currentTarget&&("static"==this.options.backdrop?this.$element[0].focus():this.hide())},this)),o&&this.$backdrop[0].offsetWidth,this.$backdrop.addClass("in"),!e)return;o?this.$backdrop.one("bsTransitionEnd",e).emulateTransitionEnd(n.BACKDROP_TRANSITION_DURATION):e()}else if(!this.isShown&&this.$backdrop){this.$backdrop.removeClass("in");var a=function(){r.removeBackdrop(),e&&e()};t.support.transition&&this.$element.hasClass("fade")?this.$backdrop.one("bsTransitionEnd",a).emulateTransitionEnd(n.BACKDROP_TRANSITION_DURATION):a()}else e&&e()},n.prototype.handleUpdate=function(){this.adjustDialog()},n.prototype.adjustDialog=function(){var t=this.$element[0].scrollHeight>document.documentElement.clientHeight;this.$element.css({paddingLeft:!this.bodyIsOverflowing&&t?this.scrollbarWidth:"",paddingRight:this.bodyIsOverflowing&&!t?this.scrollbarWidth:""})},n.prototype.resetAdjustments=function(){this.$element.css({paddingLeft:"",paddingRight:""})},n.prototype.checkScrollbar=function(){var t=window.innerWidth;if(!t){var e=document.documentElement.getBoundingClientRect();t=e.right-Math.abs(e.left)}this.bodyIsOverflowing=document.body.clientWidth<t,this.scrollbarWidth=this.measureScrollbar()},n.prototype.setScrollbar=function(){var t=parseInt(this.$body.css("padding-right")||0,10);this.originalBodyPad=document.body.style.paddingRight||"",this.bodyIsOverflowing&&this.$body.css("padding-right",t+this.scrollbarWidth)},n.prototype.resetScrollbar=function(){this.$body.css("padding-right",this.originalBodyPad)},n.prototype.measureScrollbar=function(){var t=document.createElement("div");t.className="modal-scrollbar-measure",this.$body.append(t);var e=t.offsetWidth-t.clientWidth;return this.$body[0].removeChild(t),e};var r=t.fn.modal;t.fn.modal=e,t.fn.modal.Constructor=n,t.fn.modal.noConflict=function(){return t.fn.modal=r,this},t(document).on("click.bs.modal.data-api",'[data-toggle="modal"]',function(n){var r=t(this),i=r.attr("href"),o=t(r.attr("data-target")||i&&i.replace(/.*(?=#[^\s]+$)/,"")),a=o.data("bs.modal")?"toggle":t.extend({remote:!/#/.test(i)&&i},o.data(),r.data());r.is("a")&&n.preventDefault(),o.one("show.bs.modal",function(t){t.isDefaultPrevented()||o.one("hidden.bs.modal",function(){r.is(":visible")&&r.trigger("focus")})}),e.call(o,a,this)})}(r),function(t){"use strict";function e(e){return this.each(function(){var r=t(this),i=r.data("bs.tooltip"),o="object"==typeof e&&e;!i&&/destroy|hide/.test(e)||(i||r.data("bs.tooltip",i=new n(this,o)),"string"==typeof e&&i[e]())})}var n=function(t,e){this.type=null,this.options=null,this.enabled=null,this.timeout=null,this.hoverState=null,this.$element=null,this.inState=null,this.init("tooltip",t,e)};n.VERSION="3.3.7",n.TRANSITION_DURATION=150,n.DEFAULTS={animation:!0,placement:"top",selector:!1,template:'<div class="tooltip" role="tooltip"><div class="tooltip-arrow"></div><div class="tooltip-inner"></div></div>',trigger:"hover focus",title:"",delay:0,html:!1,container:!1,viewport:{selector:"body",padding:0}},n.prototype.init=function(e,n,r){if(this.enabled=!0,this.type=e,this.$element=t(n),this.options=this.getOptions(r),this.$viewport=this.options.viewport&&t(t.isFunction(this.options.viewport)?this.options.viewport.call(this,this.$element):this.options.viewport.selector||this.options.viewport),this.inState={click:!1,hover:!1,focus:!1},this.$element[0]instanceof document.constructor&&!this.options.selector)throw new Error("`selector` option must be specified when initializing "+this.type+" on the window.document object!");for(var i=this.options.trigger.split(" "),o=i.length;o--;){var a=i[o];if("click"==a)this.$element.on("click."+this.type,this.options.selector,t.proxy(this.toggle,this));else if("manual"!=a){var s="hover"==a?"mouseenter":"focusin",u="hover"==a?"mouseleave":"focusout";this.$element.on(s+"."+this.type,this.options.selector,t.proxy(this.enter,this)),this.$element.on(u+"."+this.type,this.options.selector,t.proxy(this.leave,this))}}this.options.selector?this._options=t.extend({},this.options,{trigger:"manual",selector:""}):this.fixTitle()},n.prototype.getDefaults=function(){return n.DEFAULTS},n.prototype.getOptions=function(e){return e=t.extend({},this.getDefaults(),this.$element.data(),e),e.delay&&"number"==typeof e.delay&&(e.delay={show:e.delay,hide:e.delay}),e},n.prototype.getDelegateOptions=function(){var e={},n=this.getDefaults();return this._options&&t.each(this._options,function(t,r){n[t]!=r&&(e[t]=r)}),e},n.prototype.enter=function(e){var n=e instanceof this.constructor?e:t(e.currentTarget).data("bs."+this.type);return n||(n=new this.constructor(e.currentTarget,this.getDelegateOptions()),t(e.currentTarget).data("bs."+this.type,n)),e instanceof t.Event&&(n.inState["focusin"==e.type?"focus":"hover"]=!0),n.tip().hasClass("in")||"in"==n.hoverState?void(n.hoverState="in"):(clearTimeout(n.timeout),n.hoverState="in",n.options.delay&&n.options.delay.show?void(n.timeout=setTimeout(function(){"in"==n.hoverState&&n.show()},n.options.delay.show)):n.show())},n.prototype.isInStateTrue=function(){for(var t in this.inState)if(this.inState[t])return!0;return!1},n.prototype.leave=function(e){var n=e instanceof this.constructor?e:t(e.currentTarget).data("bs."+this.type);if(n||(n=new this.constructor(e.currentTarget,this.getDelegateOptions()),t(e.currentTarget).data("bs."+this.type,n)),e instanceof t.Event&&(n.inState["focusout"==e.type?"focus":"hover"]=!1),!n.isInStateTrue()){if(clearTimeout(n.timeout),n.hoverState="out",!n.options.delay||!n.options.delay.hide)return n.hide();n.timeout=setTimeout(function(){"out"==n.hoverState&&n.hide()},n.options.delay.hide)}},n.prototype.show=function(){var e=t.Event("show.bs."+this.type);if(this.hasContent()&&this.enabled){this.$element.trigger(e);var r=t.contains(this.$element[0].ownerDocument.documentElement,this.$element[0]);if(e.isDefaultPrevented()||!r)return;var i=this,o=this.tip(),a=this.getUID(this.type);this.setContent(),o.attr("id",a),this.$element.attr("aria-describedby",a),this.options.animation&&o.addClass("fade");var s="function"==typeof this.options.placement?this.options.placement.call(this,o[0],this.$element[0]):this.options.placement,u=/\s?auto?\s?/i,l=u.test(s);l&&(s=s.replace(u,"")||"top"),o.detach().css({top:0,left:0,display:"block"}).addClass(s).data("bs."+this.type,this),this.options.container?o.appendTo(this.options.container):o.insertAfter(this.$element),this.$element.trigger("inserted.bs."+this.type);var c=this.getPosition(),f=o[0].offsetWidth,h=o[0].offsetHeight;if(l){var p=s,d=this.getPosition(this.$viewport);s="bottom"==s&&c.bottom+h>d.bottom?"top":"top"==s&&c.top-h<d.top?"bottom":"right"==s&&c.right+f>d.width?"left":"left"==s&&c.left-f<d.left?"right":s,o.removeClass(p).addClass(s)}var g=this.getCalculatedOffset(s,c,f,h);this.applyPlacement(g,s);var v=function(){var t=i.hoverState;i.$element.trigger("shown.bs."+i.type),i.hoverState=null,"out"==t&&i.leave(i)};t.support.transition&&this.$tip.hasClass("fade")?o.one("bsTransitionEnd",v).emulateTransitionEnd(n.TRANSITION_DURATION):v()}},n.prototype.applyPlacement=function(e,n){var r=this.tip(),i=r[0].offsetWidth,o=r[0].offsetHeight,a=parseInt(r.css("margin-top"),10),s=parseInt(r.css("margin-left"),10);isNaN(a)&&(a=0),isNaN(s)&&(s=0),e.top+=a,e.left+=s,t.offset.setOffset(r[0],t.extend({using:function(t){r.css({top:Math.round(t.top),left:Math.round(t.left)})}},e),0),r.addClass("in");var u=r[0].offsetWidth,l=r[0].offsetHeight;"top"==n&&l!=o&&(e.top=e.top+o-l);var c=this.getViewportAdjustedDelta(n,e,u,l);c.left?e.left+=c.left:e.top+=c.top;var f=/top|bottom/.test(n),h=f?2*c.left-i+u:2*c.top-o+l,p=f?"offsetWidth":"offsetHeight";r.offset(e),this.replaceArrow(h,r[0][p],f)},n.prototype.replaceArrow=function(t,e,n){this.arrow().css(n?"left":"top",50*(1-t/e)+"%").css(n?"top":"left","")},n.prototype.setContent=function(){var t=this.tip(),e=this.getTitle();t.find(".tooltip-inner")[this.options.html?"html":"text"](e),t.removeClass("fade in top bottom left right")},n.prototype.hide=function(e){function r(){"in"!=i.hoverState&&o.detach(),i.$element&&i.$element.removeAttr("aria-describedby").trigger("hidden.bs."+i.type),e&&e()}var i=this,o=t(this.$tip),a=t.Event("hide.bs."+this.type);if(this.$element.trigger(a),!a.isDefaultPrevented())return o.removeClass("in"),t.support.transition&&o.hasClass("fade")?o.one("bsTransitionEnd",r).emulateTransitionEnd(n.TRANSITION_DURATION):r(),this.hoverState=null,this},n.prototype.fixTitle=function(){var t=this.$element;(t.attr("title")||"string"!=typeof t.attr("data-original-title"))&&t.attr("data-original-title",t.attr("title")||"").attr("title","")},n.prototype.hasContent=function(){return this.getTitle()},n.prototype.getPosition=function(e){e=e||this.$element;var n=e[0],r="BODY"==n.tagName,i=n.getBoundingClientRect();null==i.width&&(i=t.extend({},i,{width:i.right-i.left,height:i.bottom-i.top}));var o=window.SVGElement&&n instanceof window.SVGElement,a=r?{top:0,left:0}:o?null:e.offset(),s={scroll:r?document.documentElement.scrollTop||document.body.scrollTop:e.scrollTop()},u=r?{width:t(window).width(),height:t(window).height()}:null;return t.extend({},i,s,u,a)},n.prototype.getCalculatedOffset=function(t,e,n,r){return"bottom"==t?{top:e.top+e.height,left:e.left+e.width/2-n/2}:"top"==t?{top:e.top-r,left:e.left+e.width/2-n/2}:"left"==t?{top:e.top+e.height/2-r/2,left:e.left-n}:{top:e.top+e.height/2-r/2,left:e.left+e.width}},n.prototype.getViewportAdjustedDelta=function(t,e,n,r){var i={top:0,left:0};if(!this.$viewport)return i;var o=this.options.viewport&&this.options.viewport.padding||0,a=this.getPosition(this.$viewport);if(/right|left/.test(t)){var s=e.top-o-a.scroll,u=e.top+o-a.scroll+r;s<a.top?i.top=a.top-s:u>a.top+a.height&&(i.top=a.top+a.height-u)}else{var l=e.left-o,c=e.left+o+n;l<a.left?i.left=a.left-l:c>a.right&&(i.left=a.left+a.width-c)}return i},n.prototype.getTitle=function(){var t=this.$element,e=this.options;return t.attr("data-original-title")||("function"==typeof e.title?e.title.call(t[0]):e.title)},n.prototype.getUID=function(t){do{t+=~~(1e6*Math.random())}while(document.getElementById(t));return t},n.prototype.tip=function(){if(!this.$tip&&(this.$tip=t(this.options.template),1!=this.$tip.length))throw new Error(this.type+" `template` option must consist of exactly 1 top-level element!");return this.$tip},n.prototype.arrow=function(){return this.$arrow=this.$arrow||this.tip().find(".tooltip-arrow")},n.prototype.enable=function(){this.enabled=!0},n.prototype.disable=function(){this.enabled=!1},n.prototype.toggleEnabled=function(){this.enabled=!this.enabled},n.prototype.toggle=function(e){var n=this;e&&((n=t(e.currentTarget).data("bs."+this.type))||(n=new this.constructor(e.currentTarget,this.getDelegateOptions()),t(e.currentTarget).data("bs."+this.type,n))),e?(n.inState.click=!n.inState.click,n.isInStateTrue()?n.enter(n):n.leave(n)):n.tip().hasClass("in")?n.leave(n):n.enter(n)},n.prototype.destroy=function(){var t=this;clearTimeout(this.timeout),this.hide(function(){t.$element.off("."+t.type).removeData("bs."+t.type),t.$tip&&t.$tip.detach(),t.$tip=null,t.$arrow=null,t.$viewport=null,t.$element=null})};var r=t.fn.tooltip;t.fn.tooltip=e,t.fn.tooltip.Constructor=n,t.fn.tooltip.noConflict=function(){return t.fn.tooltip=r,this}}(r),function(t){"use strict";function e(e){return this.each(function(){var r=t(this),i=r.data("bs.popover"),o="object"==typeof e&&e;!i&&/destroy|hide/.test(e)||(i||r.data("bs.popover",i=new n(this,o)),"string"==typeof e&&i[e]())})}var n=function(t,e){this.init("popover",t,e)};if(!t.fn.tooltip)throw new Error("Popover requires tooltip.js");n.VERSION="3.3.7",n.DEFAULTS=t.extend({},t.fn.tooltip.Constructor.DEFAULTS,{placement:"right",trigger:"click",content:"",template:'<div class="popover" role="tooltip"><div class="arrow"></div><h3 class="popover-title"></h3><div class="popover-content"></div></div>'}),n.prototype=t.extend({},t.fn.tooltip.Constructor.prototype),n.prototype.constructor=n,n.prototype.getDefaults=function(){return n.DEFAULTS},n.prototype.setContent=function(){var t=this.tip(),e=this.getTitle(),n=this.getContent();t.find(".popover-title")[this.options.html?"html":"text"](e),t.find(".popover-content").children().detach().end()[this.options.html?"string"==typeof n?"html":"append":"text"](n),t.removeClass("fade top bottom left right in"),t.find(".popover-title").html()||t.find(".popover-title").hide()},n.prototype.hasContent=function(){return this.getTitle()||this.getContent()},n.prototype.getContent=function(){var t=this.$element,e=this.options;return t.attr("data-content")||("function"==typeof e.content?e.content.call(t[0]):e.content)},n.prototype.arrow=function(){return this.$arrow=this.$arrow||this.tip().find(".arrow")};var r=t.fn.popover;t.fn.popover=e,t.fn.popover.Constructor=n,t.fn.popover.noConflict=function(){return t.fn.popover=r,this}}(r),function(t){"use strict";function e(n,r){this.$body=t(document.body),this.$scrollElement=t(t(n).is(document.body)?window:n),this.options=t.extend({},e.DEFAULTS,r),this.selector=(this.options.target||"")+" .nav li > a",this.offsets=[],this.targets=[],this.activeTarget=null,this.scrollHeight=0,this.$scrollElement.on("scroll.bs.scrollspy",t.proxy(this.process,this)),this.refresh(),this.process()}function n(n){return this.each(function(){var r=t(this),i=r.data("bs.scrollspy"),o="object"==typeof n&&n;i||r.data("bs.scrollspy",i=new e(this,o)),"string"==typeof n&&i[n]()})}e.VERSION="3.3.7",e.DEFAULTS={offset:10},e.prototype.getScrollHeight=function(){return this.$scrollElement[0].scrollHeight||Math.max(this.$body[0].scrollHeight,document.documentElement.scrollHeight)},e.prototype.refresh=function(){var e=this,n="offset",r=0;this.offsets=[],this.targets=[],this.scrollHeight=this.getScrollHeight(),t.isWindow(this.$scrollElement[0])||(n="position",r=this.$scrollElement.scrollTop()),this.$body.find(this.selector).map(function(){var e=t(this),i=e.data("target")||e.attr("href"),o=/^#./.test(i)&&t(i);return o&&o.length&&o.is(":visible")&&[[o[n]().top+r,i]]||null}).sort(function(t,e){return t[0]-e[0]}).each(function(){e.offsets.push(this[0]),e.targets.push(this[1])})},e.prototype.process=function(){var t,e=this.$scrollElement.scrollTop()+this.options.offset,n=this.getScrollHeight(),r=this.options.offset+n-this.$scrollElement.height(),i=this.offsets,o=this.targets,a=this.activeTarget;if(this.scrollHeight!=n&&this.refresh(),e>=r)return a!=(t=o[o.length-1])&&this.activate(t);if(a&&e<i[0])return this.activeTarget=null,this.clear();for(t=i.length;t--;)a!=o[t]&&e>=i[t]&&(void 0===i[t+1]||e<i[t+1])&&this.activate(o[t])},e.prototype.activate=function(e){this.activeTarget=e,this.clear();var n=this.selector+'[data-target="'+e+'"],'+this.selector+'[href="'+e+'"]',r=t(n).parents("li").addClass("active");r.parent(".dropdown-menu").length&&(r=r.closest("li.dropdown").addClass("active")),r.trigger("activate.bs.scrollspy")},e.prototype.clear=function(){t(this.selector).parentsUntil(this.options.target,".active").removeClass("active")};var r=t.fn.scrollspy;t.fn.scrollspy=n,t.fn.scrollspy.Constructor=e,t.fn.scrollspy.noConflict=function(){return t.fn.scrollspy=r,this},t(window).on("load.bs.scrollspy.data-api",function(){t('[data-spy="scroll"]').each(function(){var e=t(this);n.call(e,e.data())})})}(r),function(t){"use strict";function e(e){return this.each(function(){var r=t(this),i=r.data("bs.tab");i||r.data("bs.tab",i=new n(this)),"string"==typeof e&&i[e]()})}var n=function(e){this.element=t(e)};n.VERSION="3.3.7",n.TRANSITION_DURATION=150,n.prototype.show=function(){var e=this.element,n=e.closest("ul:not(.dropdown-menu)"),r=e.data("target");if(r||(r=e.attr("href"),r=r&&r.replace(/.*(?=#[^\s]*$)/,"")),!e.parent("li").hasClass("active")){var i=n.find(".active:last a"),o=t.Event("hide.bs.tab",{relatedTarget:e[0]}),a=t.Event("show.bs.tab",{relatedTarget:i[0]});if(i.trigger(o),e.trigger(a),!a.isDefaultPrevented()&&!o.isDefaultPrevented()){var s=t(r);this.activate(e.closest("li"),n),this.activate(s,s.parent(),function(){i.trigger({type:"hidden.bs.tab",relatedTarget:e[0]}),e.trigger({type:"shown.bs.tab",relatedTarget:i[0]})})}}},n.prototype.activate=function(e,r,i){function o(){a.removeClass("active").find("> .dropdown-menu > .active").removeClass("active").end().find('[data-toggle="tab"]').attr("aria-expanded",!1),e.addClass("active").find('[data-toggle="tab"]').attr("aria-expanded",!0),s?(e[0].offsetWidth,e.addClass("in")):e.removeClass("fade"),e.parent(".dropdown-menu").length&&e.closest("li.dropdown").addClass("active").end().find('[data-toggle="tab"]').attr("aria-expanded",!0),i&&i()}var a=r.find("> .active"),s=i&&t.support.transition&&(a.length&&a.hasClass("fade")||!!r.find("> .fade").length);a.length&&s?a.one("bsTransitionEnd",o).emulateTransitionEnd(n.TRANSITION_DURATION):o(),a.removeClass("in")};var r=t.fn.tab;t.fn.tab=e,t.fn.tab.Constructor=n,t.fn.tab.noConflict=function(){return t.fn.tab=r,this};var i=function(n){n.preventDefault(),e.call(t(this),"show")};t(document).on("click.bs.tab.data-api",'[data-toggle="tab"]',i).on("click.bs.tab.data-api",'[data-toggle="pill"]',i)}(r),function(t){"use strict";function e(e){return this.each(function(){var r=t(this),i=r.data("bs.affix"),o="object"==typeof e&&e;i||r.data("bs.affix",i=new n(this,o)),"string"==typeof e&&i[e]()})}var n=function(e,r){this.options=t.extend({},n.DEFAULTS,r),this.$target=t(this.options.target).on("scroll.bs.affix.data-api",t.proxy(this.checkPosition,this)).on("click.bs.affix.data-api",t.proxy(this.checkPositionWithEventLoop,this)),this.$element=t(e),this.affixed=null,this.unpin=null,this.pinnedOffset=null,this.checkPosition()};n.VERSION="3.3.7",n.RESET="affix affix-top affix-bottom",n.DEFAULTS={offset:0,target:window},n.prototype.getState=function(t,e,n,r){var i=this.$target.scrollTop(),o=this.$element.offset(),a=this.$target.height();if(null!=n&&"top"==this.affixed)return i<n&&"top";if("bottom"==this.affixed)return null!=n?!(i+this.unpin<=o.top)&&"bottom":!(i+a<=t-r)&&"bottom";var s=null==this.affixed,u=s?i:o.top,l=s?a:e;return null!=n&&i<=n?"top":null!=r&&u+l>=t-r&&"bottom"},n.prototype.getPinnedOffset=function(){if(this.pinnedOffset)return this.pinnedOffset;this.$element.removeClass(n.RESET).addClass("affix");var t=this.$target.scrollTop(),e=this.$element.offset();return this.pinnedOffset=e.top-t},n.prototype.checkPositionWithEventLoop=function(){setTimeout(t.proxy(this.checkPosition,this),1)},n.prototype.checkPosition=function(){if(this.$element.is(":visible")){var e=this.$element.height(),r=this.options.offset,i=r.top,o=r.bottom,a=Math.max(t(document).height(),t(document.body).height());"object"!=typeof r&&(o=i=r),"function"==typeof i&&(i=r.top(this.$element)),"function"==typeof o&&(o=r.bottom(this.$element));var s=this.getState(a,e,i,o);if(this.affixed!=s){null!=this.unpin&&this.$element.css("top","");var u="affix"+(s?"-"+s:""),l=t.Event(u+".bs.affix");if(this.$element.trigger(l),l.isDefaultPrevented())return;this.affixed=s,this.unpin="bottom"==s?this.getPinnedOffset():null,this.$element.removeClass(n.RESET).addClass(u).trigger(u.replace("affix","affixed")+".bs.affix")}"bottom"==s&&this.$element.offset({top:a-e-o})}};var r=t.fn.affix;t.fn.affix=e,t.fn.affix.Constructor=n,t.fn.affix.noConflict=function(){return t.fn.affix=r,this},t(window).on("load",function(){t('[data-spy="affix"]').each(function(){var n=t(this),r=n.data();r.offset=r.offset||{},null!=r.offsetBottom&&(r.offset.bottom=r.offsetBottom),null!=r.offsetTop&&(r.offset.top=r.offsetTop),e.call(n,r)})})}(r)},function(t,e,n){"use strict";Object.defineProperty(e,"__esModule",{value:!0});var r=n(44),i=(n.n(r),n(32),n(36)),o=(n.n(i),n(46)),a=(n.n(o),n(25),n(35)),s=(n.n(a),n(31)),u=n(29),l=n(20);n.i(u.a)(document.querySelector("#caleydoHeader"),{appLink:new u.b(l.a.APP_NAME)});var c=document.querySelector('[data-header="bugLink"] > a');c.setAttribute("href","https://github.com/Caleydo/malevo/issues/new"),c.setAttribute("target","_blank"),c.removeAttribute("data-toggle"),c.removeAttribute("data-target");var f=document.querySelector("#app");n.i(s.a)(f).init()},function(t,e,n){t.exports=n.p+"buildInfo.json"},function(t,e,n){t.exports=n.p+"phoveaMetaData.json"},function(t,e,n){"use strict";Object.defineProperty(e,"__esModule",{value:!0});var r=n(2);n(9),n(52);n.i(r.b)("confusionflow-ui",n(53))},function(t,e,n){var r,i;!function(){function o(t){return t&&(t.ownerDocument||t.document||t).documentElement}function a(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}function s(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function u(t){return null===t?NaN:+t}function l(t){return!isNaN(t)}function c(t){return{left:function(e,n,r,i){for(arguments.length<3&&(r=0),arguments.length<4&&(i=e.length);r<i;){var o=r+i>>>1;t(e[o],n)<0?r=o+1:i=o}return r},right:function(e,n,r,i){for(arguments.length<3&&(r=0),arguments.length<4&&(i=e.length);r<i;){var o=r+i>>>1;t(e[o],n)>0?i=o:r=o+1}return r}}}function f(t){return t.length}function h(t){for(var e=1;t*e%1;)e*=10;return e}function p(t,e){for(var n in e)Object.defineProperty(t.prototype,n,{value:e[n],enumerable:!1})}function d(){this._=Object.create(null)}function g(t){return(t+="")===Ta||t[0]===Ca?Ca+t:t}function v(t){return(t+="")[0]===Ca?t.slice(1):t}function y(t){return g(t)in this._}function m(t){return(t=g(t))in this._&&delete this._[t]}function b(){var t=[];for(var e in this._)t.push(v(e));return t}function x(){var t=0;for(var e in this._)++t;return t}function w(){for(var t in this._)return!1;return!0}function M(){this._=Object.create(null)}function E(t){return t}function T(t,e,n){return function(){var r=n.apply(e,arguments);return r===e?t:r}}function C(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var n=0,r=Sa.length;n<r;++n){var i=Sa[n]+e;if(i in t)return i}}function S(){}function N(){}function k(t){function e(){for(var e,r=n,i=-1,o=r.length;++i<o;)(e=r[i].on)&&e.apply(this,arguments);return t}var n=[],r=new d;return e.on=function(e,i){var o,a=r.get(e);return arguments.length<2?a&&a.on:(a&&(a.on=null,n=n.slice(0,o=n.indexOf(a)).concat(n.slice(o+1)),r.remove(e)),i&&n.push(r.set(e,{on:i})),t)},e}function _(){pa.event.preventDefault()}function A(){for(var t,e=pa.event;t=e.sourceEvent;)e=t;return e}function L(t){for(var e=new N,n=0,r=arguments.length;++n<r;)e[arguments[n]]=k(e);return e.of=function(n,r){return function(i){try{var o=i.sourceEvent=pa.event;i.target=t,pa.event=i,e[i.type].apply(n,r)}finally{pa.event=o}}},e}function D(t){return ka(t,Da),t}function R(t){return"function"==typeof t?t:function(){return _a(t,this)}}function j(t){return"function"==typeof t?t:function(){return Aa(t,this)}}function O(t,e){function n(){this.removeAttribute(t)}function r(){this.removeAttributeNS(t.space,t.local)}function i(){this.setAttribute(t,e)}function o(){this.setAttributeNS(t.space,t.local,e)}function a(){var n=e.apply(this,arguments);null==n?this.removeAttribute(t):this.setAttribute(t,n)}function s(){var n=e.apply(this,arguments);null==n?this.removeAttributeNS(t.space,t.local):this.setAttributeNS(t.space,t.local,n)}return t=pa.ns.qualify(t),null==e?t.local?r:n:"function"==typeof e?t.local?s:a:t.local?o:i}function I(t){return t.trim().replace(/\s+/g," ")}function P(t){return new RegExp("(?:^|\\s+)"+pa.requote(t)+"(?:\\s+|$)","g")}function $(t){return(t+"").trim().split(/^|\s+/)}function q(t,e){function n(){for(var n=-1;++n<i;)t[n](this,e)}function r(){for(var n=-1,r=e.apply(this,arguments);++n<i;)t[n](this,r)}t=$(t).map(H);var i=t.length;return"function"==typeof e?r:n}function H(t){var e=P(t);return function(n,r){if(i=n.classList)return r?i.add(t):i.remove(t);var i=n.getAttribute("class")||"";r?(e.lastIndex=0,e.test(i)||n.setAttribute("class",I(i+" "+t))):n.setAttribute("class",I(i.replace(e," ")))}}function F(t,e,n){function r(){this.style.removeProperty(t)}function i(){this.style.setProperty(t,e,n)}function o(){var r=e.apply(this,arguments);null==r?this.style.removeProperty(t):this.style.setProperty(t,r,n)}return null==e?r:"function"==typeof e?o:i}function z(t,e){function n(){delete this[t]}function r(){this[t]=e}function i(){var n=e.apply(this,arguments);null==n?delete this[t]:this[t]=n}return null==e?n:"function"==typeof e?i:r}function U(t){function e(){var e=this.ownerDocument,n=this.namespaceURI;return n===Ra&&e.documentElement.namespaceURI===Ra?e.createElement(t):e.createElementNS(n,t)}function n(){return this.ownerDocument.createElementNS(t.space,t.local)}return"function"==typeof t?t:(t=pa.ns.qualify(t)).local?n:e}function V(){var t=this.parentNode;t&&t.removeChild(this)}function B(t){return{__data__:t}}function W(t){return function(){return La(this,t)}}function Y(t){return arguments.length||(t=s),function(e,n){return e&&n?t(e.__data__,n.__data__):!e-!n}}function G(t,e){for(var n=0,r=t.length;n<r;n++)for(var i,o=t[n],a=0,s=o.length;a<s;a++)(i=o[a])&&e(i,a,n);return t}function Z(t){return ka(t,Oa),t}function X(t){var e,n;return function(r,i,o){var a,s=t[o].update,u=s.length;for(o!=n&&(n=o,e=0),i>=e&&(e=i+1);!(a=s[e])&&++e<u;);return a}}function J(t,e,n){function r(){var e=this[a];e&&(this.removeEventListener(t,e,e.$),delete this[a])}function i(){var i=u(e,ga(arguments));r.call(this),this.addEventListener(t,this[a]=i,i.$=n),i._=e}function o(){var e,n=new RegExp("^__on([^.]+)"+pa.requote(t)+"$");for(var r in this)if(e=r.match(n)){var i=this[r];this.removeEventListener(e[1],i,i.$),delete this[r]}}var a="__on"+t,s=t.indexOf("."),u=Q;s>0&&(t=t.slice(0,s));var l=Ia.get(t);return l&&(t=l,u=K),s?e?i:r:e?S:o}function Q(t,e){return function(n){var r=pa.event;pa.event=n,e[0]=this.__data__;try{t.apply(this,e)}finally{pa.event=r}}}function K(t,e){var n=Q(t,e);return function(t){var e=this,r=t.relatedTarget;r&&(r===e||8&r.compareDocumentPosition(e))||n.call(e,t)}}function tt(t){var e=".dragsuppress-"+ ++$a,n="click"+e,r=pa.select(a(t)).on("touchmove"+e,_).on("dragstart"+e,_).on("selectstart"+e,_);if(null==Pa&&(Pa=!("onselectstart"in t)&&C(t.style,"userSelect")),Pa){var i=o(t).style,s=i[Pa];i[Pa]="none"}return function(t){if(r.on(e,null),Pa&&(i[Pa]=s),t){var o=function(){r.on(n,null)};r.on(n,function(){_(),o()},!0),setTimeout(o,0)}}}function et(t,e){e.changedTouches&&(e=e.changedTouches[0]);var n=t.ownerSVGElement||t;if(n.createSVGPoint){var r=n.createSVGPoint();if(qa<0){var i=a(t);if(i.scrollX||i.scrollY){n=pa.select("body").append("svg").style({position:"absolute",top:0,left:0,margin:0,padding:0,border:"none"},"important");var o=n[0][0].getScreenCTM();qa=!(o.f||o.e),n.remove()}}return qa?(r.x=e.pageX,r.y=e.pageY):(r.x=e.clientX,r.y=e.clientY),r=r.matrixTransform(t.getScreenCTM().inverse()),[r.x,r.y]}var s=t.getBoundingClientRect();return[e.clientX-s.left-t.clientLeft,e.clientY-s.top-t.clientTop]}function nt(){return pa.event.changedTouches[0].identifier}function rt(t){return t>0?1:t<0?-1:0}function it(t,e,n){return(e[0]-t[0])*(n[1]-t[1])-(e[1]-t[1])*(n[0]-t[0])}function ot(t){return t>1?0:t<-1?za:Math.acos(t)}function at(t){return t>1?Ba:t<-1?-Ba:Math.asin(t)}function st(t){return((t=Math.exp(t))-1/t)/2}function ut(t){return((t=Math.exp(t))+1/t)/2}function lt(t){return((t=Math.exp(2*t))-1)/(t+1)}function ct(t){return(t=Math.sin(t/2))*t}function ft(){}function ht(t,e,n){return this instanceof ht?(this.h=+t,this.s=+e,void(this.l=+n)):arguments.length<2?t instanceof ht?new ht(t.h,t.s,t.l):St(""+t,Nt,ht):new ht(t,e,n)}function pt(t,e,n){function r(t){return t>360?t-=360:t<0&&(t+=360),t<60?o+(a-o)*t/60:t<180?a:t<240?o+(a-o)*(240-t)/60:o}function i(t){return Math.round(255*r(t))}var o,a;return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)?0:e<0?0:e>1?1:e,n=n<0?0:n>1?1:n,a=n<=.5?n*(1+e):n+e-n*e,o=2*n-a,new Mt(i(t+120),i(t),i(t-120))}function dt(t,e,n){return this instanceof dt?(this.h=+t,this.c=+e,void(this.l=+n)):arguments.length<2?t instanceof dt?new dt(t.h,t.c,t.l):t instanceof vt?mt(t.l,t.a,t.b):mt((t=kt((t=pa.rgb(t)).r,t.g,t.b)).l,t.a,t.b):new dt(t,e,n)}function gt(t,e,n){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new vt(n,Math.cos(t*=Wa)*e,Math.sin(t)*e)}function vt(t,e,n){return this instanceof vt?(this.l=+t,this.a=+e,void(this.b=+n)):arguments.length<2?t instanceof vt?new vt(t.l,t.a,t.b):t instanceof dt?gt(t.h,t.c,t.l):kt((t=Mt(t)).r,t.g,t.b):new vt(t,e,n)}function yt(t,e,n){var r=(t+16)/116,i=r+e/500,o=r-n/200;return i=bt(i)*rs,r=bt(r)*is,o=bt(o)*os,new Mt(wt(3.2404542*i-1.5371385*r-.4985314*o),wt(-.969266*i+1.8760108*r+.041556*o),wt(.0556434*i-.2040259*r+1.0572252*o))}function mt(t,e,n){return t>0?new dt(Math.atan2(n,e)*Ya,Math.sqrt(e*e+n*n),t):new dt(NaN,NaN,t)}function bt(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function xt(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function wt(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function Mt(t,e,n){return this instanceof Mt?(this.r=~~t,this.g=~~e,void(this.b=~~n)):arguments.length<2?t instanceof Mt?new Mt(t.r,t.g,t.b):St(""+t,Mt,pt):new Mt(t,e,n)}function Et(t){return new Mt(t>>16,t>>8&255,255&t)}function Tt(t){return Et(t)+""}function Ct(t){return t<16?"0"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function St(t,e,n){var r,i,o,a=0,s=0,u=0;if(r=/([a-z]+)\((.*)\)/.exec(t=t.toLowerCase()))switch(i=r[2].split(","),r[1]){case"hsl":return n(parseFloat(i[0]),parseFloat(i[1])/100,parseFloat(i[2])/100);case"rgb":return e(At(i[0]),At(i[1]),At(i[2]))}return(o=us.get(t))?e(o.r,o.g,o.b):(null==t||"#"!==t.charAt(0)||isNaN(o=parseInt(t.slice(1),16))||(4===t.length?(a=(3840&o)>>4,a|=a>>4,s=240&o,s|=s>>4,u=15&o,u|=u<<4):7===t.length&&(a=(16711680&o)>>16,s=(65280&o)>>8,u=255&o)),e(a,s,u))}function Nt(t,e,n){var r,i,o=Math.min(t/=255,e/=255,n/=255),a=Math.max(t,e,n),s=a-o,u=(a+o)/2;return s?(i=u<.5?s/(a+o):s/(2-a-o),r=t==a?(e-n)/s+(e<n?6:0):e==a?(n-t)/s+2:(t-e)/s+4,r*=60):(r=NaN,i=u>0&&u<1?0:r),new ht(r,i,u)}function kt(t,e,n){t=_t(t),e=_t(e),n=_t(n);var r=xt((.4124564*t+.3575761*e+.1804375*n)/rs),i=xt((.2126729*t+.7151522*e+.072175*n)/is);return vt(116*i-16,500*(r-i),200*(i-xt((.0193339*t+.119192*e+.9503041*n)/os)))}function _t(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function At(t){var e=parseFloat(t);return"%"===t.charAt(t.length-1)?Math.round(2.55*e):e}function Lt(t){return"function"==typeof t?t:function(){return t}}function Dt(t){return function(e,n,r){return 2===arguments.length&&"function"==typeof n&&(r=n,n=null),Rt(e,n,t,r)}}function Rt(t,e,n,r){function i(){var t,e=u.status;if(!e&&Ot(u)||e>=200&&e<300||304===e){try{t=n.call(o,u)}catch(t){return void a.error.call(o,t)}a.load.call(o,t)}else a.error.call(o,u)}var o={},a=pa.dispatch("beforesend","progress","load","error"),s={},u=new XMLHttpRequest,l=null;return!this.XDomainRequest||"withCredentials"in u||!/^(http(s)?:)?\/\//.test(t)||(u=new XDomainRequest),"onload"in u?u.onload=u.onerror=i:u.onreadystatechange=function(){u.readyState>3&&i()},u.onprogress=function(t){var e=pa.event;pa.event=t;try{a.progress.call(o,u)}finally{pa.event=e}},o.header=function(t,e){return t=(t+"").toLowerCase(),arguments.length<2?s[t]:(null==e?delete s[t]:s[t]=e+"",o)},o.mimeType=function(t){return arguments.length?(e=null==t?null:t+"",o):e},o.responseType=function(t){return arguments.length?(l=t,o):l},o.response=function(t){return n=t,o},["get","post"].forEach(function(t){o[t]=function(){return o.send.apply(o,[t].concat(ga(arguments)))}}),o.send=function(n,r,i){if(2===arguments.length&&"function"==typeof r&&(i=r,r=null),u.open(n,t,!0),null==e||"accept"in s||(s.accept=e+",*/*"),u.setRequestHeader)for(var c in s)u.setRequestHeader(c,s[c]);return null!=e&&u.overrideMimeType&&u.overrideMimeType(e),null!=l&&(u.responseType=l),null!=i&&o.on("error",i).on("load",function(t){i(null,t)}),a.beforesend.call(o,u),u.send(null==r?null:r),o},o.abort=function(){return u.abort(),o},pa.rebind(o,a,"on"),null==r?o:o.get(jt(r))}function jt(t){return 1===t.length?function(e,n){t(null==e?n:null)}:t}function Ot(t){var e=t.responseType;return e&&"text"!==e?t.response:t.responseText}function It(t,e,n){var r=arguments.length;r<2&&(e=0),r<3&&(n=Date.now());var i=n+e,o={c:t,t:i,n:null};return cs?cs.n=o:ls=o,cs=o,fs||(hs=clearTimeout(hs),fs=1,ps(Pt)),o}function Pt(){var t=$t(),e=qt()-t;e>24?(isFinite(e)&&(clearTimeout(hs),hs=setTimeout(Pt,e)),fs=0):(fs=1,ps(Pt))}function $t(){for(var t=Date.now(),e=ls;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function qt(){for(var t,e=ls,n=1/0;e;)e.c?(e.t<n&&(n=e.t),e=(t=e).n):e=t?t.n=e.n:ls=e.n;return cs=t,n}function Ht(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}function Ft(t,e){var n=Math.pow(10,3*Ea(8-e));return{scale:e>8?function(t){return t/n}:function(t){return t*n},symbol:t}}function zt(t){var e=t.decimal,n=t.thousands,r=t.grouping,i=t.currency,o=r&&n?function(t,e){for(var i=t.length,o=[],a=0,s=r[0],u=0;i>0&&s>0&&(u+s+1>e&&(s=Math.max(1,e-u)),o.push(t.substring(i-=s,i+s)),!((u+=s+1)>e));)s=r[a=(a+1)%r.length];return o.reverse().join(n)}:E;return function(t){var n=gs.exec(t),r=n[1]||" ",a=n[2]||">",s=n[3]||"-",u=n[4]||"",l=n[5],c=+n[6],f=n[7],h=n[8],p=n[9],d=1,g="",v="",y=!1,m=!0;switch(h&&(h=+h.substring(1)),(l||"0"===r&&"="===a)&&(l=r="0",a="="),p){case"n":f=!0,p="g";break;case"%":d=100,v="%",p="f";break;case"p":d=100,v="%",p="r";break;case"b":case"o":case"x":case"X":"#"===u&&(g="0"+p.toLowerCase());case"c":m=!1;case"d":y=!0,h=0;break;case"s":d=-1,p="r"}"$"===u&&(g=i[0],v=i[1]),"r"!=p||h||(p="g"),null!=h&&("g"==p?h=Math.max(1,Math.min(21,h)):"e"!=p&&"f"!=p||(h=Math.max(0,Math.min(20,h)))),p=vs.get(p)||Ut;var b=l&&f;return function(t){var n=v;if(y&&t%1)return"";var i=t<0||0===t&&1/t<0?(t=-t,"-"):"-"===s?"":s;if(d<0){var u=pa.formatPrefix(t,h);t=u.scale(t),n=u.symbol+v}else t*=d;t=p(t,h);var x,w,M=t.lastIndexOf(".");if(M<0){var E=m?t.lastIndexOf("e"):-1;E<0?(x=t,w=""):(x=t.substring(0,E),w=t.substring(E))}else x=t.substring(0,M),w=e+t.substring(M+1);!l&&f&&(x=o(x,1/0));var T=g.length+x.length+w.length+(b?0:i.length),C=T<c?new Array(T=c-T+1).join(r):"";return b&&(x=o(C+x,C.length?c-w.length:1/0)),i+=g,t=x+w,("<"===a?i+t+C:">"===a?C+i+t:"^"===a?C.substring(0,T>>=1)+i+t+C.substring(T):i+(b?t:C+t))+n}}}function Ut(t){return t+""}function Vt(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}function Bt(t,e,n){function r(e){var n=t(e),r=o(n,1);return e-n<r-e?n:r}function i(n){return e(n=t(new ms(n-1)),1),n}function o(t,n){return e(t=new ms(+t),n),t}function a(t,r,o){var a=i(t),s=[];if(o>1)for(;a<r;)n(a)%o||s.push(new Date(+a)),e(a,1);else for(;a<r;)s.push(new Date(+a)),e(a,1);return s}function s(t,e,n){try{ms=Vt;var r=new Vt;return r._=t,a(r,e,n)}finally{ms=Date}}t.floor=t,t.round=r,t.ceil=i,t.offset=o,t.range=a;var u=t.utc=Wt(t);return u.floor=u,u.round=Wt(r),u.ceil=Wt(i),u.offset=Wt(o),u.range=s,t}function Wt(t){return function(e,n){try{ms=Vt;var r=new Vt;return r._=e,t(r,n)._}finally{ms=Date}}}function Yt(t){function e(t){function e(e){for(var n,i,o,a=[],s=-1,u=0;++s<r;)37===t.charCodeAt(s)&&(a.push(t.slice(u,s)),null!=(i=xs[n=t.charAt(++s)])&&(n=t.charAt(++s)),(o=k[n])&&(n=o(e,null==i?"e"===n?" ":"0":i)),a.push(n),u=s+1);return a.push(t.slice(u,s)),a.join("")}var r=t.length;return e.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null};if(n(r,t,e,0)!=e.length)return null;"p"in r&&(r.H=r.H%12+12*r.p);var i=null!=r.Z&&ms!==Vt,o=new(i?Vt:ms);return"j"in r?o.setFullYear(r.y,0,r.j):"W"in r||"U"in r?("w"in r||(r.w="W"in r?1:0),o.setFullYear(r.y,0,1),o.setFullYear(r.y,0,"W"in r?(r.w+6)%7+7*r.W-(o.getDay()+5)%7:r.w+7*r.U-(o.getDay()+6)%7)):o.setFullYear(r.y,r.m,r.d),o.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),i?o._:o},e.toString=function(){return t},e}function n(t,e,n,r){for(var i,o,a,s=0,u=e.length,l=n.length;s<u;){if(r>=l)return-1;if(37===(i=e.charCodeAt(s++))){if(a=e.charAt(s++),!(o=_[a in xs?e.charAt(s++):a])||(r=o(t,n,r))<0)return-1}else if(i!=n.charCodeAt(r++))return-1}return r}function r(t,e,n){M.lastIndex=0;var r=M.exec(e.slice(n));return r?(t.w=E.get(r[0].toLowerCase()),n+r[0].length):-1}function i(t,e,n){x.lastIndex=0;var r=x.exec(e.slice(n));return r?(t.w=w.get(r[0].toLowerCase()),n+r[0].length):-1}function o(t,e,n){S.lastIndex=0;var r=S.exec(e.slice(n));return r?(t.m=N.get(r[0].toLowerCase()),n+r[0].length):-1}function a(t,e,n){T.lastIndex=0;var r=T.exec(e.slice(n));return r?(t.m=C.get(r[0].toLowerCase()),n+r[0].length):-1}function s(t,e,r){return n(t,k.c.toString(),e,r)}function u(t,e,r){return n(t,k.x.toString(),e,r)}function l(t,e,r){return n(t,k.X.toString(),e,r)}function c(t,e,n){var r=b.get(e.slice(n,n+=2).toLowerCase());return null==r?-1:(t.p=r,n)}var f=t.dateTime,h=t.date,p=t.time,d=t.periods,g=t.days,v=t.shortDays,y=t.months,m=t.shortMonths;e.utc=function(t){function n(t){try{ms=Vt;var e=new ms;return e._=t,r(e)}finally{ms=Date}}var r=e(t);return n.parse=function(t){try{ms=Vt;var e=r.parse(t);return e&&e._}finally{ms=Date}},n.toString=r.toString,n},e.multi=e.utc.multi=pe;var b=pa.map(),x=Zt(g),w=Xt(g),M=Zt(v),E=Xt(v),T=Zt(y),C=Xt(y),S=Zt(m),N=Xt(m);d.forEach(function(t,e){b.set(t.toLowerCase(),e)});var k={a:function(t){return v[t.getDay()]},A:function(t){return g[t.getDay()]},b:function(t){return m[t.getMonth()]},B:function(t){return y[t.getMonth()]},c:e(f),d:function(t,e){return Gt(t.getDate(),e,2)},e:function(t,e){return Gt(t.getDate(),e,2)},H:function(t,e){return Gt(t.getHours(),e,2)},I:function(t,e){return Gt(t.getHours()%12||12,e,2)},j:function(t,e){return Gt(1+ys.dayOfYear(t),e,3)},L:function(t,e){return Gt(t.getMilliseconds(),e,3)},m:function(t,e){return Gt(t.getMonth()+1,e,2)},M:function(t,e){return Gt(t.getMinutes(),e,2)},p:function(t){return d[+(t.getHours()>=12)]},S:function(t,e){return Gt(t.getSeconds(),e,2)},U:function(t,e){return Gt(ys.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Gt(ys.mondayOfYear(t),e,2)},x:e(h),X:e(p),y:function(t,e){return Gt(t.getFullYear()%100,e,2)},Y:function(t,e){return Gt(t.getFullYear()%1e4,e,4)},Z:fe,"%":function(){return"%"}},_={a:r,A:i,b:o,B:a,c:s,d:oe,e:oe,H:se,I:se,j:ae,L:ce,m:ie,M:ue,p:c,S:le,U:Qt,w:Jt,W:Kt,x:u,X:l,y:ee,Y:te,Z:ne,"%":he};return e}function Gt(t,e,n){var r=t<0?"-":"",i=(r?-t:t)+"",o=i.length;return r+(o<n?new Array(n-o+1).join(e)+i:i)}function Zt(t){return new RegExp("^(?:"+t.map(pa.requote).join("|")+")","i")}function Xt(t){for(var e=new d,n=-1,r=t.length;++n<r;)e.set(t[n].toLowerCase(),n);return e}function Jt(t,e,n){ws.lastIndex=0;var r=ws.exec(e.slice(n,n+1));return r?(t.w=+r[0],n+r[0].length):-1}function Qt(t,e,n){ws.lastIndex=0;var r=ws.exec(e.slice(n));return r?(t.U=+r[0],n+r[0].length):-1}function Kt(t,e,n){ws.lastIndex=0;var r=ws.exec(e.slice(n));return r?(t.W=+r[0],n+r[0].length):-1}function te(t,e,n){ws.lastIndex=0;var r=ws.exec(e.slice(n,n+4));return r?(t.y=+r[0],n+r[0].length):-1}function ee(t,e,n){ws.lastIndex=0;var r=ws.exec(e.slice(n,n+2));return r?(t.y=re(+r[0]),n+r[0].length):-1}function ne(t,e,n){return/^[+-]\d{4}$/.test(e=e.slice(n,n+5))?(t.Z=-e,n+5):-1}function re(t){return t+(t>68?1900:2e3)}function ie(t,e,n){ws.lastIndex=0;var r=ws.exec(e.slice(n,n+2));return r?(t.m=r[0]-1,n+r[0].length):-1}function oe(t,e,n){ws.lastIndex=0;var r=ws.exec(e.slice(n,n+2));return r?(t.d=+r[0],n+r[0].length):-1}function ae(t,e,n){ws.lastIndex=0;var r=ws.exec(e.slice(n,n+3));return r?(t.j=+r[0],n+r[0].length):-1}function se(t,e,n){ws.lastIndex=0;var r=ws.exec(e.slice(n,n+2));return r?(t.H=+r[0],n+r[0].length):-1}function ue(t,e,n){ws.lastIndex=0;var r=ws.exec(e.slice(n,n+2));return r?(t.M=+r[0],n+r[0].length):-1}function le(t,e,n){ws.lastIndex=0;var r=ws.exec(e.slice(n,n+2));return r?(t.S=+r[0],n+r[0].length):-1}function ce(t,e,n){ws.lastIndex=0;var r=ws.exec(e.slice(n,n+3));return r?(t.L=+r[0],n+r[0].length):-1}function fe(t){var e=t.getTimezoneOffset(),n=e>0?"-":"+",r=Ea(e)/60|0,i=Ea(e)%60;return n+Gt(r,"0",2)+Gt(i,"0",2)}function he(t,e,n){Ms.lastIndex=0;var r=Ms.exec(e.slice(n,n+1));return r?n+r[0].length:-1}function pe(t){for(var e=t.length,n=-1;++n<e;)t[n][0]=this(t[n][0]);return function(e){for(var n=0,r=t[n];!r[1](e);)r=t[++n];return r[0](e)}}function de(){}function ge(t,e,n){var r=n.s=t+e,i=r-t,o=r-i;n.t=t-o+(e-i)}function ve(t,e){t&&Ss.hasOwnProperty(t.type)&&Ss[t.type](t,e)}function ye(t,e,n){var r,i=-1,o=t.length-n;for(e.lineStart();++i<o;)r=t[i],e.point(r[0],r[1],r[2]);e.lineEnd()}function me(t,e){var n=-1,r=t.length;for(e.polygonStart();++n<r;)ye(t[n],e,1);e.polygonEnd()}function be(){function t(t,e){t*=Wa,e=e*Wa/2+za/4;var n=t-r,a=n>=0?1:-1,s=a*n,u=Math.cos(e),l=Math.sin(e),c=o*l,f=i*u+c*Math.cos(s),h=c*a*Math.sin(s);ks.add(Math.atan2(h,f)),r=t,i=u,o=l}var e,n,r,i,o;_s.point=function(a,s){_s.point=t,r=(e=a)*Wa,i=Math.cos(s=(n=s)*Wa/2+za/4),o=Math.sin(s)},_s.lineEnd=function(){t(e,n)}}function xe(t){var e=t[0],n=t[1],r=Math.cos(n);return[r*Math.cos(e),r*Math.sin(e),Math.sin(n)]}function we(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function Me(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function Ee(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Te(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function Ce(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Se(t){return[Math.atan2(t[1],t[0]),at(t[2])]}function Ne(t,e){return Ea(t[0]-e[0])<Ha&&Ea(t[1]-e[1])<Ha}function ke(t,e){t*=Wa;var n=Math.cos(e*=Wa);_e(n*Math.cos(t),n*Math.sin(t),Math.sin(e))}function _e(t,e,n){++As,Ds+=(t-Ds)/As,Rs+=(e-Rs)/As,js+=(n-js)/As}function Ae(){function t(t,i){t*=Wa;var o=Math.cos(i*=Wa),a=o*Math.cos(t),s=o*Math.sin(t),u=Math.sin(i),l=Math.atan2(Math.sqrt((l=n*u-r*s)*l+(l=r*a-e*u)*l+(l=e*s-n*a)*l),e*a+n*s+r*u);Ls+=l,Os+=l*(e+(e=a)),Is+=l*(n+(n=s)),Ps+=l*(r+(r=u)),_e(e,n,r)}var e,n,r;Fs.point=function(i,o){i*=Wa;var a=Math.cos(o*=Wa);e=a*Math.cos(i),n=a*Math.sin(i),r=Math.sin(o),Fs.point=t,_e(e,n,r)}}function Le(){Fs.point=ke}function De(){function t(t,e){t*=Wa;var n=Math.cos(e*=Wa),a=n*Math.cos(t),s=n*Math.sin(t),u=Math.sin(e),l=i*u-o*s,c=o*a-r*u,f=r*s-i*a,h=Math.sqrt(l*l+c*c+f*f),p=r*a+i*s+o*u,d=h&&-ot(p)/h,g=Math.atan2(h,p);$s+=d*l,qs+=d*c,Hs+=d*f,Ls+=g,Os+=g*(r+(r=a)),Is+=g*(i+(i=s)),Ps+=g*(o+(o=u)),_e(r,i,o)}var e,n,r,i,o;Fs.point=function(a,s){e=a,n=s,Fs.point=t,a*=Wa;var u=Math.cos(s*=Wa);r=u*Math.cos(a),i=u*Math.sin(a),o=Math.sin(s),_e(r,i,o)},Fs.lineEnd=function(){t(e,n),Fs.lineEnd=Le,Fs.point=ke}}function Re(t,e){function n(n,r){return n=t(n,r),e(n[0],n[1])}return t.invert&&e.invert&&(n.invert=function(n,r){return(n=e.invert(n,r))&&t.invert(n[0],n[1])}),n}function je(){return!0}function Oe(t,e,n,r,i){var o=[],a=[];if(t.forEach(function(t){if(!((e=t.length-1)<=0)){var e,n=t[0],r=t[e];if(Ne(n,r)){i.lineStart();for(var s=0;s<e;++s)i.point((n=t[s])[0],n[1]);return void i.lineEnd()}var u=new Pe(n,t,null,!0),l=new Pe(n,null,u,!1);u.o=l,o.push(u),a.push(l),u=new Pe(r,t,null,!1),l=new Pe(r,null,u,!0),u.o=l,o.push(u),a.push(l)}}),a.sort(e),Ie(o),Ie(a),o.length){for(var s=0,u=n,l=a.length;s<l;++s)a[s].e=u=!u;for(var c,f,h=o[0];;){for(var p=h,d=!0;p.v;)if((p=p.n)===h)return;c=p.z,i.lineStart();do{if(p.v=p.o.v=!0,p.e){if(d)for(var s=0,l=c.length;s<l;++s)i.point((f=c[s])[0],f[1]);else r(p.x,p.n.x,1,i);p=p.n}else{if(d){c=p.p.z;for(var s=c.length-1;s>=0;--s)i.point((f=c[s])[0],f[1])}else r(p.x,p.p.x,-1,i);p=p.p}p=p.o,c=p.z,d=!d}while(!p.v);i.lineEnd()}}}function Ie(t){if(e=t.length){for(var e,n,r=0,i=t[0];++r<e;)i.n=n=t[r],n.p=i,i=n;i.n=n=t[0],n.p=i}}function Pe(t,e,n,r){this.x=t,this.z=e,this.o=n,this.e=r,this.v=!1,this.n=this.p=null}function $e(t,e,n,r){return function(i,o){function a(e,n){var r=i(e,n);t(e=r[0],n=r[1])&&o.point(e,n)}function s(t,e){var n=i(t,e);v.point(n[0],n[1])}function u(){m.point=s,v.lineStart()}function l(){m.point=a,v.lineEnd()}function c(t,e){g.push([t,e]);var n=i(t,e);x.point(n[0],n[1])}function f(){x.lineStart(),g=[]}function h(){c(g[0][0],g[0][1]),x.lineEnd();var t,e=x.clean(),n=b.buffer(),r=n.length;if(g.pop(),d.push(g),g=null,r)if(1&e){t=n[0];var i,r=t.length-1,a=-1;if(r>0){for(w||(o.polygonStart(),w=!0),o.lineStart();++a<r;)o.point((i=t[a])[0],i[1]);o.lineEnd()}}else r>1&&2&e&&n.push(n.pop().concat(n.shift())),p.push(n.filter(qe))}var p,d,g,v=e(o),y=i.invert(r[0],r[1]),m={point:a,lineStart:u,lineEnd:l,polygonStart:function(){m.point=c,m.lineStart=f,m.lineEnd=h,p=[],d=[]},polygonEnd:function(){m.point=a,m.lineStart=u,m.lineEnd=l,p=pa.merge(p);var t=Be(y,d);p.length?(w||(o.polygonStart(),w=!0),Oe(p,Fe,t,n,o)):t&&(w||(o.polygonStart(),w=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),w&&(o.polygonEnd(),w=!1),p=d=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}},b=He(),x=e(b),w=!1;return m}}function qe(t){return t.length>1}function He(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,n){t.push([e,n])},lineEnd:S,buffer:function(){var n=e;return e=[],t=null,n},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function Fe(t,e){return((t=t.x)[0]<0?t[1]-Ba-Ha:Ba-t[1])-((e=e.x)[0]<0?e[1]-Ba-Ha:Ba-e[1])}function ze(t){var e,n=NaN,r=NaN,i=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(o,a){var s=o>0?za:-za,u=Ea(o-n);Ea(u-za)<Ha?(t.point(n,r=(r+a)/2>0?Ba:-Ba),t.point(i,r),t.lineEnd(),t.lineStart(),t.point(s,r),t.point(o,r),e=0):i!==s&&u>=za&&(Ea(n-i)<Ha&&(n-=i*Ha),Ea(o-s)<Ha&&(o-=s*Ha),r=Ue(n,r,o,a),t.point(i,r),t.lineEnd(),t.lineStart(),t.point(s,r),e=0),t.point(n=o,r=a),i=s},lineEnd:function(){t.lineEnd(),n=r=NaN},clean:function(){return 2-e}}}function Ue(t,e,n,r){var i,o,a=Math.sin(t-n);return Ea(a)>Ha?Math.atan((Math.sin(e)*(o=Math.cos(r))*Math.sin(n)-Math.sin(r)*(i=Math.cos(e))*Math.sin(t))/(i*o*a)):(e+r)/2}function Ve(t,e,n,r){var i;if(null==t)i=n*Ba,r.point(-za,i),r.point(0,i),r.point(za,i),r.point(za,0),r.point(za,-i),r.point(0,-i),r.point(-za,-i),r.point(-za,0),r.point(-za,i);else if(Ea(t[0]-e[0])>Ha){var o=t[0]<e[0]?za:-za;i=n*o/2,r.point(-o,i),r.point(0,i),r.point(o,i)}else r.point(e[0],e[1])}function Be(t,e){var n=t[0],r=t[1],i=[Math.sin(n),-Math.cos(n),0],o=0,a=0;ks.reset();for(var s=0,u=e.length;s<u;++s){var l=e[s],c=l.length;if(c)for(var f=l[0],h=f[0],p=f[1]/2+za/4,d=Math.sin(p),g=Math.cos(p),v=1;;){v===c&&(v=0),t=l[v];var y=t[0],m=t[1]/2+za/4,b=Math.sin(m),x=Math.cos(m),w=y-h,M=w>=0?1:-1,E=M*w,T=E>za,C=d*b;if(ks.add(Math.atan2(C*M*Math.sin(E),g*x+C*Math.cos(E))),o+=T?w+M*Ua:w,T^h>=n^y>=n){var S=Me(xe(f),xe(t));Ce(S);var N=Me(i,S);Ce(N);var k=(T^w>=0?-1:1)*at(N[2]);(r>k||r===k&&(S[0]||S[1]))&&(a+=T^w>=0?1:-1)}if(!v++)break;h=y,d=b,g=x,f=t}}return(o<-Ha||o<Ha&&ks<-Ha)^1&a}function We(t){function e(t,e){return Math.cos(t)*Math.cos(e)>o}function n(t){var n,o,u,l,c;return{lineStart:function(){l=u=!1,c=1},point:function(f,h){var p,d=[f,h],g=e(f,h),v=a?g?0:i(f,h):g?i(f+(f<0?za:-za),h):0;if(!n&&(l=u=g)&&t.lineStart(),g!==u&&(p=r(n,d),(Ne(n,p)||Ne(d,p))&&(d[0]+=Ha,d[1]+=Ha,g=e(d[0],d[1]))),g!==u)c=0,g?(t.lineStart(),p=r(d,n),t.point(p[0],p[1])):(p=r(n,d),t.point(p[0],p[1]),t.lineEnd()),n=p;else if(s&&n&&a^g){var y;v&o||!(y=r(d,n,!0))||(c=0,a?(t.lineStart(),t.point(y[0][0],y[0][1]),t.point(y[1][0],y[1][1]),t.lineEnd()):(t.point(y[1][0],y[1][1]),t.lineEnd(),t.lineStart(),t.point(y[0][0],y[0][1])))}!g||n&&Ne(n,d)||t.point(d[0],d[1]),n=d,u=g,o=v},lineEnd:function(){u&&t.lineEnd(),n=null},clean:function(){return c|(l&&u)<<1}}}function r(t,e,n){var r=xe(t),i=xe(e),a=[1,0,0],s=Me(r,i),u=we(s,s),l=s[0],c=u-l*l;if(!c)return!n&&t;var f=o*u/c,h=-o*l/c,p=Me(a,s),d=Te(a,f);Ee(d,Te(s,h));var g=p,v=we(d,g),y=we(g,g),m=v*v-y*(we(d,d)-1);if(!(m<0)){var b=Math.sqrt(m),x=Te(g,(-v-b)/y);if(Ee(x,d),x=Se(x),!n)return x;var w,M=t[0],E=e[0],T=t[1],C=e[1];E<M&&(w=M,M=E,E=w);var S=E-M,N=Ea(S-za)<Ha,k=N||S<Ha;if(!N&&C<T&&(w=T,T=C,C=w),k?N?T+C>0^x[1]<(Ea(x[0]-M)<Ha?T:C):T<=x[1]&&x[1]<=C:S>za^(M<=x[0]&&x[0]<=E)){var _=Te(g,(-v+b)/y);return Ee(_,d),[x,Se(_)]}}}function i(e,n){var r=a?t:za-t,i=0;return e<-r?i|=1:e>r&&(i|=2),n<-r?i|=4:n>r&&(i|=8),i}var o=Math.cos(t),a=o>0,s=Ea(o)>Ha;return $e(e,n,xn(t,6*Wa),a?[0,-t]:[-za,t-za])}function Ye(t,e,n,r){return function(i){var o,a=i.a,s=i.b,u=a.x,l=a.y,c=s.x,f=s.y,h=0,p=1,d=c-u,g=f-l;if(o=t-u,d||!(o>0)){if(o/=d,d<0){if(o<h)return;o<p&&(p=o)}else if(d>0){if(o>p)return;o>h&&(h=o)}if(o=n-u,d||!(o<0)){if(o/=d,d<0){if(o>p)return;o>h&&(h=o)}else if(d>0){if(o<h)return;o<p&&(p=o)}if(o=e-l,g||!(o>0)){if(o/=g,g<0){if(o<h)return;o<p&&(p=o)}else if(g>0){if(o>p)return;o>h&&(h=o)}if(o=r-l,g||!(o<0)){if(o/=g,g<0){if(o>p)return;o>h&&(h=o)}else if(g>0){if(o<h)return;o<p&&(p=o)}return h>0&&(i.a={x:u+h*d,y:l+h*g}),p<1&&(i.b={x:u+p*d,y:l+p*g}),i}}}}}}function Ge(t,e,n,r){function i(r,i){return Ea(r[0]-t)<Ha?i>0?0:3:Ea(r[0]-n)<Ha?i>0?2:1:Ea(r[1]-e)<Ha?i>0?1:0:i>0?3:2}function o(t,e){return a(t.x,e.x)}function a(t,e){var n=i(t,1),r=i(e,1);return n!==r?n-r:0===n?e[1]-t[1]:1===n?t[0]-e[0]:2===n?t[1]-e[1]:e[0]-t[0]}return function(s){function u(t){for(var e=0,n=v.length,r=t[1],i=0;i<n;++i)for(var o,a=1,s=v[i],u=s.length,l=s[0];a<u;++a)o=s[a],l[1]<=r?o[1]>r&&it(l,o,t)>0&&++e:o[1]<=r&&it(l,o,t)<0&&--e,l=o;return 0!==e}function l(o,s,u,l){var c=0,f=0;if(null==o||(c=i(o,u))!==(f=i(s,u))||a(o,s)<0^u>0)do{l.point(0===c||3===c?t:n,c>1?r:e)}while((c=(c+u+4)%4)!==f);else l.point(s[0],s[1])}function c(i,o){return t<=i&&i<=n&&e<=o&&o<=r}function f(t,e){c(t,e)&&s.point(t,e)}function h(){_.point=d,v&&v.push(y=[]),T=!0,E=!1,w=M=NaN}function p(){g&&(d(m,b),x&&E&&N.rejoin(),g.push(N.buffer())),_.point=f,E&&s.lineEnd()}function d(t,e){t=Math.max(-Us,Math.min(Us,t)),e=Math.max(-Us,Math.min(Us,e));var n=c(t,e);if(v&&y.push([t,e]),T)m=t,b=e,x=n,T=!1,n&&(s.lineStart(),s.point(t,e));else if(n&&E)s.point(t,e);else{var r={a:{x:w,y:M},b:{x:t,y:e}};k(r)?(E||(s.lineStart(),s.point(r.a.x,r.a.y)),s.point(r.b.x,r.b.y),n||s.lineEnd(),C=!1):n&&(s.lineStart(),s.point(t,e),C=!1)}w=t,M=e,E=n}var g,v,y,m,b,x,w,M,E,T,C,S=s,N=He(),k=Ye(t,e,n,r),_={point:f,lineStart:h,lineEnd:p,polygonStart:function(){s=N,g=[],v=[],C=!0},polygonEnd:function(){s=S,g=pa.merge(g);var e=u([t,r]),n=C&&e,i=g.length;(n||i)&&(s.polygonStart(),n&&(s.lineStart(),l(null,null,1,s),s.lineEnd()),i&&Oe(g,o,e,l,s),s.polygonEnd()),g=v=y=null}};return _}}function Ze(t){var e=0,n=za/3,r=hn(t),i=r(e,n);return i.parallels=function(t){return arguments.length?r(e=t[0]*za/180,n=t[1]*za/180):[e/za*180,n/za*180]},i}function Xe(t,e){function n(t,e){var n=Math.sqrt(o-2*i*Math.sin(e))/i;return[n*Math.sin(t*=i),a-n*Math.cos(t)]}var r=Math.sin(t),i=(r+Math.sin(e))/2,o=1+r*(2*i-r),a=Math.sqrt(o)/i;return n.invert=function(t,e){var n=a-e;return[Math.atan2(t,n)/i,at((o-(t*t+n*n)*i*i)/(2*i))]},n}function Je(){function t(t,e){Bs+=i*t-r*e,r=t,i=e}var e,n,r,i;Xs.point=function(o,a){Xs.point=t,e=r=o,n=i=a},Xs.lineEnd=function(){t(e,n)}}function Qe(t,e){t<Ws&&(Ws=t),t>Gs&&(Gs=t),e<Ys&&(Ys=e),e>Zs&&(Zs=e)}function Ke(){function t(t,e){a.push("M",t,",",e,o)}function e(t,e){a.push("M",t,",",e),s.point=n}function n(t,e){a.push("L",t,",",e)}function r(){s.point=t}function i(){a.push("Z")}var o=tn(4.5),a=[],s={point:t,lineStart:function(){s.point=e},lineEnd:r,polygonStart:function(){s.lineEnd=i},polygonEnd:function(){s.lineEnd=r,s.point=t},pointRadius:function(t){return o=tn(t),s},result:function(){if(a.length){var t=a.join("");return a=[],t}}};return s}function tn(t){return"m0,"+t+"a"+t+","+t+" 0 1,1 0,"+-2*t+"a"+t+","+t+" 0 1,1 0,"+2*t+"z"}function en(t,e){Ds+=t,Rs+=e,++js}function nn(){function t(t,r){var i=t-e,o=r-n,a=Math.sqrt(i*i+o*o);Os+=a*(e+t)/2,Is+=a*(n+r)/2,Ps+=a,en(e=t,n=r)}var e,n;Qs.point=function(r,i){Qs.point=t,en(e=r,n=i)}}function rn(){Qs.point=en}function on(){function t(t,e){var n=t-r,o=e-i,a=Math.sqrt(n*n+o*o);Os+=a*(r+t)/2,Is+=a*(i+e)/2,Ps+=a,a=i*t-r*e,$s+=a*(r+t),qs+=a*(i+e),Hs+=3*a,en(r=t,i=e)}var e,n,r,i;Qs.point=function(o,a){Qs.point=t,en(e=r=o,n=i=a)},Qs.lineEnd=function(){t(e,n)}}function an(t){function e(e,n){t.moveTo(e+a,n),t.arc(e,n,a,0,Ua)}function n(e,n){t.moveTo(e,n),s.point=r}function r(e,n){t.lineTo(e,n)}function i(){s.point=e}function o(){t.closePath()}var a=4.5,s={point:e,lineStart:function(){s.point=n},lineEnd:i,polygonStart:function(){s.lineEnd=o},polygonEnd:function(){s.lineEnd=i,s.point=e},pointRadius:function(t){return a=t,s},result:S};return s}function sn(t){function e(t){return(s?r:n)(t)}function n(e){return cn(e,function(n,r){n=t(n,r),e.point(n[0],n[1])})}function r(e){function n(n,r){n=t(n,r),e.point(n[0],n[1])}function r(){b=NaN,T.point=o,e.lineStart()}function o(n,r){var o=xe([n,r]),a=t(n,r);i(b,x,m,w,M,E,b=a[0],x=a[1],m=n,w=o[0],M=o[1],E=o[2],s,e),e.point(b,x)}function a(){T.point=n,e.lineEnd()}function u(){r(),T.point=l,T.lineEnd=c}function l(t,e){o(f=t,h=e),p=b,d=x,g=w,v=M,y=E,T.point=o}function c(){i(b,x,m,w,M,E,p,d,f,g,v,y,s,e),T.lineEnd=a,a()}var f,h,p,d,g,v,y,m,b,x,w,M,E,T={point:n,lineStart:r,lineEnd:a,polygonStart:function(){e.polygonStart(),T.lineStart=u},polygonEnd:function(){e.polygonEnd(),T.lineStart=r}};return T}function i(e,n,r,s,u,l,c,f,h,p,d,g,v,y){var m=c-e,b=f-n,x=m*m+b*b;if(x>4*o&&v--){var w=s+p,M=u+d,E=l+g,T=Math.sqrt(w*w+M*M+E*E),C=Math.asin(E/=T),S=Ea(Ea(E)-1)<Ha||Ea(r-h)<Ha?(r+h)/2:Math.atan2(M,w),N=t(S,C),k=N[0],_=N[1],A=k-e,L=_-n,D=b*A-m*L;(D*D/x>o||Ea((m*A+b*L)/x-.5)>.3||s*p+u*d+l*g<a)&&(i(e,n,r,s,u,l,k,_,S,w/=T,M/=T,E,v,y),y.point(k,_),i(k,_,S,w,M,E,c,f,h,p,d,g,v,y))}}var o=.5,a=Math.cos(30*Wa),s=16;return e.precision=function(t){return arguments.length?(s=(o=t*t)>0&&16,e):Math.sqrt(o)},e}function un(t){var e=sn(function(e,n){return t([e*Ya,n*Ya])});return function(t){return pn(e(t))}}function ln(t){this.stream=t}function cn(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function fn(t){return hn(function(){return t})()}function hn(t){function e(t){return t=s(t[0]*Wa,t[1]*Wa),[t[0]*h+u,l-t[1]*h]}function n(t){return(t=s.invert((t[0]-u)/h,(l-t[1])/h))&&[t[0]*Ya,t[1]*Ya]}function r(){s=Re(a=vn(y,m,b),o);var t=o(g,v);return u=p-t[0]*h,l=d+t[1]*h,i()}function i(){return c&&(c.valid=!1,c=null),e}var o,a,s,u,l,c,f=sn(function(t,e){return t=o(t,e),[t[0]*h+u,l-t[1]*h]}),h=150,p=480,d=250,g=0,v=0,y=0,m=0,b=0,x=zs,w=E,M=null,T=null;return e.stream=function(t){return c&&(c.valid=!1),c=pn(x(a,f(w(t)))),c.valid=!0,c},e.clipAngle=function(t){return arguments.length?(x=null==t?(M=t,zs):We((M=+t)*Wa),i()):M},e.clipExtent=function(t){return arguments.length?(T=t,w=t?Ge(t[0][0],t[0][1],t[1][0],t[1][1]):E,i()):T},e.scale=function(t){return arguments.length?(h=+t,r()):h},e.translate=function(t){return arguments.length?(p=+t[0],d=+t[1],r()):[p,d]},e.center=function(t){return arguments.length?(g=t[0]%360*Wa,v=t[1]%360*Wa,r()):[g*Ya,v*Ya]},e.rotate=function(t){return arguments.length?(y=t[0]%360*Wa,m=t[1]%360*Wa,b=t.length>2?t[2]%360*Wa:0,r()):[y*Ya,m*Ya,b*Ya]},pa.rebind(e,f,"precision"),function(){return o=t.apply(this,arguments),e.invert=o.invert&&n,r()}}function pn(t){return cn(t,function(e,n){t.point(e*Wa,n*Wa)})}function dn(t,e){return[t,e]}function gn(t,e){return[t>za?t-Ua:t<-za?t+Ua:t,e]}function vn(t,e,n){return t?e||n?Re(mn(t),bn(e,n)):mn(t):e||n?bn(e,n):gn}function yn(t){return function(e,n){return e+=t,[e>za?e-Ua:e<-za?e+Ua:e,n]}}function mn(t){var e=yn(t);return e.invert=yn(-t),e}function bn(t,e){function n(t,e){var n=Math.cos(e),s=Math.cos(t)*n,u=Math.sin(t)*n,l=Math.sin(e),c=l*r+s*i;return[Math.atan2(u*o-c*a,s*r-l*i),at(c*o+u*a)]}var r=Math.cos(t),i=Math.sin(t),o=Math.cos(e),a=Math.sin(e);return n.invert=function(t,e){var n=Math.cos(e),s=Math.cos(t)*n,u=Math.sin(t)*n,l=Math.sin(e),c=l*o-u*a;return[Math.atan2(u*o+l*a,s*r+c*i),at(c*r-s*i)]},n}function xn(t,e){var n=Math.cos(t),r=Math.sin(t);return function(i,o,a,s){var u=a*e;null!=i?(i=wn(n,i),o=wn(n,o),(a>0?i<o:i>o)&&(i+=a*Ua)):(i=t+a*Ua,o=t-.5*u);for(var l,c=i;a>0?c>o:c<o;c-=u)s.point((l=Se([n,-r*Math.cos(c),-r*Math.sin(c)]))[0],l[1])}}function wn(t,e){var n=xe(e);n[0]-=t,Ce(n);var r=ot(-n[1]);return((-n[2]<0?-r:r)+2*Math.PI-Ha)%(2*Math.PI)}function Mn(t,e,n){var r=pa.range(t,e-Ha,n).concat(e);return function(t){return r.map(function(e){return[t,e]})}}function En(t,e,n){var r=pa.range(t,e-Ha,n).concat(e);return function(t){return r.map(function(e){return[e,t]})}}function Tn(t){return t.source}function Cn(t){return t.target}function Sn(t,e,n,r){var i=Math.cos(e),o=Math.sin(e),a=Math.cos(r),s=Math.sin(r),u=i*Math.cos(t),l=i*Math.sin(t),c=a*Math.cos(n),f=a*Math.sin(n),h=2*Math.asin(Math.sqrt(ct(r-e)+i*a*ct(n-t))),p=1/Math.sin(h),d=h?function(t){var e=Math.sin(t*=h)*p,n=Math.sin(h-t)*p,r=n*u+e*c,i=n*l+e*f,a=n*o+e*s;return[Math.atan2(i,r)*Ya,Math.atan2(a,Math.sqrt(r*r+i*i))*Ya]}:function(){return[t*Ya,e*Ya]};return d.distance=h,d}function Nn(){function t(t,i){var o=Math.sin(i*=Wa),a=Math.cos(i),s=Ea((t*=Wa)-e),u=Math.cos(s);Ks+=Math.atan2(Math.sqrt((s=a*Math.sin(s))*s+(s=r*o-n*a*u)*s),n*o+r*a*u),e=t,n=o,r=a}var e,n,r;tu.point=function(i,o){e=i*Wa,n=Math.sin(o*=Wa),r=Math.cos(o),tu.point=t},tu.lineEnd=function(){tu.point=tu.lineEnd=S}}function kn(t,e){function n(e,n){var r=Math.cos(e),i=Math.cos(n),o=t(r*i);return[o*i*Math.sin(e),o*Math.sin(n)]}return n.invert=function(t,n){var r=Math.sqrt(t*t+n*n),i=e(r),o=Math.sin(i),a=Math.cos(i);return[Math.atan2(t*o,r*a),Math.asin(r&&n*o/r)]},n}function _n(t,e){function n(t,e){a>0?e<-Ba+Ha&&(e=-Ba+Ha):e>Ba-Ha&&(e=Ba-Ha);var n=a/Math.pow(i(e),o);return[n*Math.sin(o*t),a-n*Math.cos(o*t)]}var r=Math.cos(t),i=function(t){return Math.tan(za/4+t/2)},o=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(i(e)/i(t)),a=r*Math.pow(i(t),o)/o;return o?(n.invert=function(t,e){var n=a-e,r=rt(o)*Math.sqrt(t*t+n*n);return[Math.atan2(t,n)/o,2*Math.atan(Math.pow(a/r,1/o))-Ba]},n):Ln}function An(t,e){function n(t,e){var n=o-e;return[n*Math.sin(i*t),o-n*Math.cos(i*t)]}var r=Math.cos(t),i=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),o=r/i+t;return Ea(i)<Ha?dn:(n.invert=function(t,e){var n=o-e;return[Math.atan2(t,n)/i,o-rt(i)*Math.sqrt(t*t+n*n)]},n)}function Ln(t,e){return[t,Math.log(Math.tan(za/4+e/2))]}function Dn(t){var e,n=fn(t),r=n.scale,i=n.translate,o=n.clipExtent;return n.scale=function(){var t=r.apply(n,arguments);return t===n?e?n.clipExtent(null):n:t},n.translate=function(){var t=i.apply(n,arguments);return t===n?e?n.clipExtent(null):n:t},n.clipExtent=function(t){var a=o.apply(n,arguments);if(a===n){if(e=null==t){var s=za*r(),u=i();o([[u[0]-s,u[1]-s],[u[0]+s,u[1]+s]])}}else e&&(a=null);return a},n.clipExtent(null)}function Rn(t,e){return[Math.log(Math.tan(za/4+e/2)),-t]}function jn(t){return t[0]}function On(t){return t[1]}function In(t){for(var e=t.length,n=[0,1],r=2,i=2;i<e;i++){for(;r>1&&it(t[n[r-2]],t[n[r-1]],t[i])<=0;)--r;n[r++]=i}return n.slice(0,r)}function Pn(t,e){return t[0]-e[0]||t[1]-e[1]}function $n(t,e,n){return(n[0]-e[0])*(t[1]-e[1])<(n[1]-e[1])*(t[0]-e[0])}function qn(t,e,n,r){var i=t[0],o=n[0],a=e[0]-i,s=r[0]-o,u=t[1],l=n[1],c=e[1]-u,f=r[1]-l,h=(s*(u-l)-f*(i-o))/(f*a-s*c);return[i+h*a,u+h*c]}function Hn(t){var e=t[0],n=t[t.length-1];return!(e[0]-n[0]||e[1]-n[1])}function Fn(){ur(this),this.edge=this.site=this.circle=null}function zn(t){var e=hu.pop()||new Fn;return e.site=t,e}function Un(t){Kn(t),lu.remove(t),hu.push(t),ur(t)}function Vn(t){var e=t.circle,n=e.x,r=e.cy,i={x:n,y:r},o=t.P,a=t.N,s=[t];Un(t);for(var u=o;u.circle&&Ea(n-u.circle.x)<Ha&&Ea(r-u.circle.cy)<Ha;)o=u.P,s.unshift(u),Un(u),u=o;s.unshift(u),Kn(u);for(var l=a;l.circle&&Ea(n-l.circle.x)<Ha&&Ea(r-l.circle.cy)<Ha;)a=l.N,s.push(l),Un(l),l=a;s.push(l),Kn(l);var c,f=s.length;for(c=1;c<f;++c)l=s[c],u=s[c-1],or(l.edge,u.site,l.site,i);u=s[0],l=s[f-1],l.edge=rr(u.site,l.site,null,i),Qn(u),Qn(l)}function Bn(t){for(var e,n,r,i,o=t.x,a=t.y,s=lu._;s;)if((r=Wn(s,a)-o)>Ha)s=s.L;else{if(!((i=o-Yn(s,a))>Ha)){r>-Ha?(e=s.P,n=s):i>-Ha?(e=s,n=s.N):e=n=s;break}if(!s.R){e=s;break}s=s.R}var u=zn(t);if(lu.insert(e,u),e||n){if(e===n)return Kn(e),n=zn(e.site),lu.insert(u,n),u.edge=n.edge=rr(e.site,u.site),Qn(e),void Qn(n);if(!n)return void(u.edge=rr(e.site,u.site));Kn(e),Kn(n);var l=e.site,c=l.x,f=l.y,h=t.x-c,p=t.y-f,d=n.site,g=d.x-c,v=d.y-f,y=2*(h*v-p*g),m=h*h+p*p,b=g*g+v*v,x={x:(v*m-p*b)/y+c,y:(h*b-g*m)/y+f};or(n.edge,l,d,x),u.edge=rr(l,t,null,x),n.edge=rr(t,d,null,x),Qn(e),Qn(n)}}function Wn(t,e){var n=t.site,r=n.x,i=n.y,o=i-e;if(!o)return r;var a=t.P;if(!a)return-1/0;n=a.site;var s=n.x,u=n.y,l=u-e;if(!l)return s;var c=s-r,f=1/o-1/l,h=c/l;return f?(-h+Math.sqrt(h*h-2*f*(c*c/(-2*l)-u+l/2+i-o/2)))/f+r:(r+s)/2}function Yn(t,e){var n=t.N;if(n)return Wn(n,e);var r=t.site;return r.y===e?r.x:1/0}function Gn(t){this.site=t,this.edges=[]}function Zn(t){for(var e,n,r,i,o,a,s,u,l,c,f=t[0][0],h=t[1][0],p=t[0][1],d=t[1][1],g=uu,v=g.length;v--;)if((o=g[v])&&o.prepare())for(s=o.edges,u=s.length,a=0;a<u;)c=s[a].end(),r=c.x,i=c.y,l=s[++a%u].start(),e=l.x,n=l.y,(Ea(r-e)>Ha||Ea(i-n)>Ha)&&(s.splice(a,0,new ar(ir(o.site,c,Ea(r-f)<Ha&&d-i>Ha?{x:f,y:Ea(e-f)<Ha?n:d}:Ea(i-d)<Ha&&h-r>Ha?{x:Ea(n-d)<Ha?e:h,y:d}:Ea(r-h)<Ha&&i-p>Ha?{x:h,y:Ea(e-h)<Ha?n:p}:Ea(i-p)<Ha&&r-f>Ha?{x:Ea(n-p)<Ha?e:f,y:p}:null),o.site,null)),++u)}function Xn(t,e){return e.angle-t.angle}function Jn(){ur(this),this.x=this.y=this.arc=this.site=this.cy=null}function Qn(t){var e=t.P,n=t.N;if(e&&n){var r=e.site,i=t.site,o=n.site;if(r!==o){var a=i.x,s=i.y,u=r.x-a,l=r.y-s,c=o.x-a,f=o.y-s,h=2*(u*f-l*c);if(!(h>=-Fa)){var p=u*u+l*l,d=c*c+f*f,g=(f*p-l*d)/h,v=(u*d-c*p)/h,f=v+s,y=pu.pop()||new Jn;y.arc=t,y.site=i,y.x=g+a,y.y=f+Math.sqrt(g*g+v*v),y.cy=f,t.circle=y;for(var m=null,b=fu._;b;)if(y.y<b.y||y.y===b.y&&y.x<=b.x){if(!b.L){m=b.P;break}b=b.L}else{if(!b.R){m=b;break}b=b.R}fu.insert(m,y),m||(cu=y)}}}}function Kn(t){var e=t.circle;e&&(e.P||(cu=e.N),fu.remove(e),pu.push(e),ur(e),t.circle=null)}function tr(t){for(var e,n=su,r=Ye(t[0][0],t[0][1],t[1][0],t[1][1]),i=n.length;i--;)e=n[i],(!er(e,t)||!r(e)||Ea(e.a.x-e.b.x)<Ha&&Ea(e.a.y-e.b.y)<Ha)&&(e.a=e.b=null,n.splice(i,1))}function er(t,e){var n=t.b;if(n)return!0;var r,i,o=t.a,a=e[0][0],s=e[1][0],u=e[0][1],l=e[1][1],c=t.l,f=t.r,h=c.x,p=c.y,d=f.x,g=f.y,v=(h+d)/2,y=(p+g)/2;if(g===p){if(v<a||v>=s)return;if(h>d){if(o){if(o.y>=l)return}else o={x:v,y:u};n={x:v,y:l}}else{if(o){if(o.y<u)return}else o={x:v,y:l};n={x:v,y:u}}}else if(r=(h-d)/(g-p),i=y-r*v,r<-1||r>1)if(h>d){if(o){if(o.y>=l)return}else o={x:(u-i)/r,y:u};n={x:(l-i)/r,y:l}}else{if(o){if(o.y<u)return}else o={x:(l-i)/r,y:l};n={x:(u-i)/r,y:u}}else if(p<g){if(o){if(o.x>=s)return}else o={x:a,y:r*a+i};n={x:s,y:r*s+i}}else{if(o){if(o.x<a)return}else o={x:s,y:r*s+i};n={x:a,y:r*a+i}}return t.a=o,t.b=n,!0}function nr(t,e){this.l=t,this.r=e,this.a=this.b=null}function rr(t,e,n,r){var i=new nr(t,e);return su.push(i),n&&or(i,t,e,n),r&&or(i,e,t,r),uu[t.i].edges.push(new ar(i,t,e)),uu[e.i].edges.push(new ar(i,e,t)),i}function ir(t,e,n){var r=new nr(t,null);return r.a=e,r.b=n,su.push(r),r}function or(t,e,n,r){t.a||t.b?t.l===n?t.b=r:t.a=r:(t.a=r,t.l=e,t.r=n)}function ar(t,e,n){var r=t.a,i=t.b;this.edge=t,this.site=e,this.angle=n?Math.atan2(n.y-e.y,n.x-e.x):t.l===e?Math.atan2(i.x-r.x,r.y-i.y):Math.atan2(r.x-i.x,i.y-r.y)}function sr(){this._=null}function ur(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function lr(t,e){var n=e,r=e.R,i=n.U;i?i.L===n?i.L=r:i.R=r:t._=r,r.U=i,n.U=r,n.R=r.L,n.R&&(n.R.U=n),r.L=n}function cr(t,e){var n=e,r=e.L,i=n.U;i?i.L===n?i.L=r:i.R=r:t._=r,r.U=i,n.U=r,n.L=r.R,n.L&&(n.L.U=n),r.R=n}function fr(t){for(;t.L;)t=t.L;return t}function hr(t,e){var n,r,i,o=t.sort(pr).pop();for(su=[],uu=new Array(t.length),lu=new sr,fu=new sr;;)if(i=cu,o&&(!i||o.y<i.y||o.y===i.y&&o.x<i.x))o.x===n&&o.y===r||(uu[o.i]=new Gn(o),Bn(o),n=o.x,r=o.y),o=t.pop();else{if(!i)break;Vn(i.arc)}e&&(tr(e),Zn(e));var a={cells:uu,edges:su};return lu=fu=su=uu=null,a}function pr(t,e){return e.y-t.y||e.x-t.x}function dr(t,e,n){return(t.x-n.x)*(e.y-t.y)-(t.x-e.x)*(n.y-t.y)}function gr(t){return t.x}function vr(t){return t.y}function yr(){return{leaf:!0,nodes:[],point:null,x:null,y:null}}function mr(t,e,n,r,i,o){if(!t(e,n,r,i,o)){var a=.5*(n+i),s=.5*(r+o),u=e.nodes;u[0]&&mr(t,u[0],n,r,a,s),u[1]&&mr(t,u[1],a,r,i,s),u[2]&&mr(t,u[2],n,s,a,o),u[3]&&mr(t,u[3],a,s,i,o)}}function br(t,e,n,r,i,o,a){var s,u=1/0;return function t(l,c,f,h,p){if(!(c>o||f>a||h<r||p<i)){if(d=l.point){var d,g=e-l.x,v=n-l.y,y=g*g+v*v;if(y<u){var m=Math.sqrt(u=y);r=e-m,i=n-m,o=e+m,a=n+m,s=d}}for(var b=l.nodes,x=.5*(c+h),w=.5*(f+p),M=e>=x,E=n>=w,T=E<<1|M,C=T+4;T<C;++T)if(l=b[3&T])switch(3&T){case 0:t(l,c,f,x,w);break;case 1:t(l,x,f,h,w);break;case 2:t(l,c,w,x,p);break;case 3:t(l,x,w,h,p)}}}(t,r,i,o,a),s}function xr(t,e){t=pa.rgb(t),e=pa.rgb(e);var n=t.r,r=t.g,i=t.b,o=e.r-n,a=e.g-r,s=e.b-i;return function(t){return"#"+Ct(Math.round(n+o*t))+Ct(Math.round(r+a*t))+Ct(Math.round(i+s*t))}}function wr(t,e){var n,r={},i={};for(n in t)n in e?r[n]=Tr(t[n],e[n]):i[n]=t[n];for(n in e)n in t||(i[n]=e[n]);return function(t){for(n in r)i[n]=r[n](t);return i}}function Mr(t,e){return t=+t,e=+e,function(n){return t*(1-n)+e*n}}function Er(t,e){var n,r,i,o=gu.lastIndex=vu.lastIndex=0,a=-1,s=[],u=[];for(t+="",e+="";(n=gu.exec(t))&&(r=vu.exec(e));)(i=r.index)>o&&(i=e.slice(o,i),s[a]?s[a]+=i:s[++a]=i),(n=n[0])===(r=r[0])?s[a]?s[a]+=r:s[++a]=r:(s[++a]=null,u.push({i:a,x:Mr(n,r)})),o=vu.lastIndex;return o<e.length&&(i=e.slice(o),s[a]?s[a]+=i:s[++a]=i),s.length<2?u[0]?(e=u[0].x,function(t){return e(t)+""}):function(){return e}:(e=u.length,function(t){for(var n,r=0;r<e;++r)s[(n=u[r]).i]=n.x(t);return s.join("")})}function Tr(t,e){for(var n,r=pa.interpolators.length;--r>=0&&!(n=pa.interpolators[r](t,e)););return n}function Cr(t,e){var n,r=[],i=[],o=t.length,a=e.length,s=Math.min(t.length,e.length);for(n=0;n<s;++n)r.push(Tr(t[n],e[n]));for(;n<o;++n)i[n]=t[n];for(;n<a;++n)i[n]=e[n];return function(t){for(n=0;n<s;++n)i[n]=r[n](t);return i}}function Sr(t){return function(e){return e<=0?0:e>=1?1:t(e)}}function Nr(t){return function(e){return 1-t(1-e)}}function kr(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function _r(t){return t*t}function Ar(t){return t*t*t}function Lr(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,n=e*t;return 4*(t<.5?n:3*(t-e)+n-.75)}function Dr(t){return function(e){return Math.pow(e,t)}}function Rr(t){return 1-Math.cos(t*Ba)}function jr(t){return Math.pow(2,10*(t-1))}function Or(t){return 1-Math.sqrt(1-t*t)}function Ir(t,e){var n;return arguments.length<2&&(e=.45),arguments.length?n=e/Ua*Math.asin(1/t):(t=1,n=e/4),function(r){return 1+t*Math.pow(2,-10*r)*Math.sin((r-n)*Ua/e)}}function Pr(t){return t||(t=1.70158),function(e){return e*e*((t+1)*e-t)}}function $r(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function qr(t,e){t=pa.hcl(t),e=pa.hcl(e);var n=t.h,r=t.c,i=t.l,o=e.h-n,a=e.c-r,s=e.l-i;return isNaN(a)&&(a=0,r=isNaN(r)?e.c:r),isNaN(o)?(o=0,n=isNaN(n)?e.h:n):o>180?o-=360:o<-180&&(o+=360),function(t){return gt(n+o*t,r+a*t,i+s*t)+""}}function Hr(t,e){t=pa.hsl(t),e=pa.hsl(e);var n=t.h,r=t.s,i=t.l,o=e.h-n,a=e.s-r,s=e.l-i;return isNaN(a)&&(a=0,r=isNaN(r)?e.s:r),isNaN(o)?(o=0,n=isNaN(n)?e.h:n):o>180?o-=360:o<-180&&(o+=360),function(t){return pt(n+o*t,r+a*t,i+s*t)+""}}function Fr(t,e){t=pa.lab(t),e=pa.lab(e);var n=t.l,r=t.a,i=t.b,o=e.l-n,a=e.a-r,s=e.b-i;return function(t){return yt(n+o*t,r+a*t,i+s*t)+""}}function zr(t,e){return e-=t,function(n){return Math.round(t+e*n)}}function Ur(t){var e=[t.a,t.b],n=[t.c,t.d],r=Br(e),i=Vr(e,n),o=Br(Wr(n,e,-i))||0;e[0]*n[1]<n[0]*e[1]&&(e[0]*=-1,e[1]*=-1,r*=-1,i*=-1),this.rotate=(r?Math.atan2(e[1],e[0]):Math.atan2(-n[0],n[1]))*Ya,this.translate=[t.e,t.f],this.scale=[r,o],this.skew=o?Math.atan2(i,o)*Ya:0}function Vr(t,e){return t[0]*e[0]+t[1]*e[1]}function Br(t){var e=Math.sqrt(Vr(t,t));return e&&(t[0]/=e,t[1]/=e),e}function Wr(t,e,n){return t[0]+=n*e[0],t[1]+=n*e[1],t}function Yr(t){return t.length?t.pop()+",":""}function Gr(t,e,n,r){if(t[0]!==e[0]||t[1]!==e[1]){var i=n.push("translate(",null,",",null,")");r.push({i:i-4,x:Mr(t[0],e[0])},{i:i-2,x:Mr(t[1],e[1])})}else(e[0]||e[1])&&n.push("translate("+e+")")}function Zr(t,e,n,r){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),r.push({i:n.push(Yr(n)+"rotate(",null,")")-2,x:Mr(t,e)})):e&&n.push(Yr(n)+"rotate("+e+")")}function Xr(t,e,n,r){t!==e?r.push({i:n.push(Yr(n)+"skewX(",null,")")-2,x:Mr(t,e)}):e&&n.push(Yr(n)+"skewX("+e+")")}function Jr(t,e,n,r){if(t[0]!==e[0]||t[1]!==e[1]){var i=n.push(Yr(n)+"scale(",null,",",null,")");r.push({i:i-4,x:Mr(t[0],e[0])},{i:i-2,x:Mr(t[1],e[1])})}else 1===e[0]&&1===e[1]||n.push(Yr(n)+"scale("+e+")")}function Qr(t,e){var n=[],r=[];return t=pa.transform(t),e=pa.transform(e),Gr(t.translate,e.translate,n,r),Zr(t.rotate,e.rotate,n,r),Xr(t.skew,e.skew,n,r),Jr(t.scale,e.scale,n,r),t=e=null,function(t){for(var e,i=-1,o=r.length;++i<o;)n[(e=r[i]).i]=e.x(t);return n.join("")}}function Kr(t,e){return e=(e-=t=+t)||1/e,function(n){return(n-t)/e}}function ti(t,e){return e=(e-=t=+t)||1/e,function(n){return Math.max(0,Math.min(1,(n-t)/e))}}function ei(t){for(var e=t.source,n=t.target,r=ri(e,n),i=[e];e!==r;)e=e.parent,i.push(e);for(var o=i.length;n!==r;)i.splice(o,0,n),n=n.parent;return i}function ni(t){for(var e=[],n=t.parent;null!=n;)e.push(t),t=n,n=n.parent;return e.push(t),e}function ri(t,e){if(t===e)return t;for(var n=ni(t),r=ni(e),i=n.pop(),o=r.pop(),a=null;i===o;)a=i,i=n.pop(),o=r.pop();return a}function ii(t){t.fixed|=2}function oi(t){t.fixed&=-7}function ai(t){t.fixed|=4,t.px=t.x,t.py=t.y}function si(t){t.fixed&=-5}function ui(t,e,n){var r=0,i=0;if(t.charge=0,!t.leaf)for(var o,a=t.nodes,s=a.length,u=-1;++u<s;)null!=(o=a[u])&&(ui(o,e,n),t.charge+=o.charge,r+=o.charge*o.cx,i+=o.charge*o.cy);if(t.point){t.leaf||(t.point.x+=Math.random()-.5,t.point.y+=Math.random()-.5);var l=e*n[t.point.index];t.charge+=t.pointCharge=l,r+=l*t.point.x,i+=l*t.point.y}t.cx=r/t.charge,t.cy=i/t.charge}function li(t,e){return pa.rebind(t,e,"sort","children","value"),t.nodes=t,t.links=gi,t}function ci(t,e){for(var n=[t];null!=(t=n.pop());)if(e(t),(i=t.children)&&(r=i.length))for(var r,i;--r>=0;)n.push(i[r])}function fi(t,e){for(var n=[t],r=[];null!=(t=n.pop());)if(r.push(t),(o=t.children)&&(i=o.length))for(var i,o,a=-1;++a<i;)n.push(o[a]);for(;null!=(t=r.pop());)e(t)}function hi(t){return t.children}function pi(t){return t.value}function di(t,e){return e.value-t.value}function gi(t){return pa.merge(t.map(function(t){return(t.children||[]).map(function(e){return{source:t,target:e}})}))}function vi(t){return t.x}function yi(t){return t.y}function mi(t,e,n){t.y0=e,t.y=n}function bi(t){return pa.range(t.length)}function xi(t){for(var e=-1,n=t[0].length,r=[];++e<n;)r[e]=0;return r}function wi(t){for(var e,n=1,r=0,i=t[0][1],o=t.length;n<o;++n)(e=t[n][1])>i&&(r=n,i=e);return r}function Mi(t){return t.reduce(Ei,0)}function Ei(t,e){return t+e[1]}function Ti(t,e){return Ci(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Ci(t,e){for(var n=-1,r=+t[0],i=(t[1]-r)/e,o=[];++n<=e;)o[n]=i*n+r;return o}function Si(t){return[pa.min(t),pa.max(t)]}function Ni(t,e){return t.value-e.value}function ki(t,e){var n=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=n,n._pack_prev=e}function _i(t,e){t._pack_next=e,e._pack_prev=t}function Ai(t,e){var n=e.x-t.x,r=e.y-t.y,i=t.r+e.r;return.999*i*i>n*n+r*r}function Li(t){function e(t){c=Math.min(t.x-t.r,c),f=Math.max(t.x+t.r,f),h=Math.min(t.y-t.r,h),p=Math.max(t.y+t.r,p)}if((n=t.children)&&(l=n.length)){var n,r,i,o,a,s,u,l,c=1/0,f=-1/0,h=1/0,p=-1/0;if(n.forEach(Di),r=n[0],r.x=-r.r,r.y=0,e(r),l>1&&(i=n[1],i.x=i.r,i.y=0,e(i),l>2))for(o=n[2],Oi(r,i,o),e(o),ki(r,o),r._pack_prev=o,ki(o,i),i=r._pack_next,a=3;a<l;a++){Oi(r,i,o=n[a]);var d=0,g=1,v=1;for(s=i._pack_next;s!==i;s=s._pack_next,g++)if(Ai(s,o)){d=1;break}if(1==d)for(u=r._pack_prev;u!==s._pack_prev&&!Ai(u,o);u=u._pack_prev,v++);d?(g<v||g==v&&i.r<r.r?_i(r,i=s):_i(r=u,i),a--):(ki(r,o),i=o,e(o))}var y=(c+f)/2,m=(h+p)/2,b=0;for(a=0;a<l;a++)o=n[a],o.x-=y,o.y-=m,b=Math.max(b,o.r+Math.sqrt(o.x*o.x+o.y*o.y));t.r=b,n.forEach(Ri)}}function Di(t){t._pack_next=t._pack_prev=t}function Ri(t){delete t._pack_next,delete t._pack_prev}function ji(t,e,n,r){var i=t.children;if(t.x=e+=r*t.x,t.y=n+=r*t.y,t.r*=r,i)for(var o=-1,a=i.length;++o<a;)ji(i[o],e,n,r)}function Oi(t,e,n){var r=t.r+n.r,i=e.x-t.x,o=e.y-t.y;if(r&&(i||o)){var a=e.r+n.r,s=i*i+o*o;a*=a,r*=r;var u=.5+(r-a)/(2*s),l=Math.sqrt(Math.max(0,2*a*(r+s)-(r-=s)*r-a*a))/(2*s);n.x=t.x+u*i+l*o,n.y=t.y+u*o-l*i}else n.x=t.x+r,n.y=t.y}function Ii(t,e){return t.parent==e.parent?1:2}function Pi(t){var e=t.children;return e.length?e[0]:t.t}function $i(t){var e,n=t.children;return(e=n.length)?n[e-1]:t.t}function qi(t,e,n){var r=n/(e.i-t.i);e.c-=r,e.s+=n,t.c+=r,e.z+=n,e.m+=n}function Hi(t){for(var e,n=0,r=0,i=t.children,o=i.length;--o>=0;)e=i[o],e.z+=n,e.m+=n,n+=e.s+(r+=e.c)}function Fi(t,e,n){return t.a.parent===e.parent?t.a:n}function zi(t){return 1+pa.max(t,function(t){return t.y})}function Ui(t){return t.reduce(function(t,e){return t+e.x},0)/t.length}function Vi(t){var e=t.children;return e&&e.length?Vi(e[0]):t}function Bi(t){var e,n=t.children;return n&&(e=n.length)?Bi(n[e-1]):t}function Wi(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function Yi(t,e){var n=t.x+e[3],r=t.y+e[0],i=t.dx-e[1]-e[3],o=t.dy-e[0]-e[2];return i<0&&(n+=i/2,i=0),o<0&&(r+=o/2,o=0),{x:n,y:r,dx:i,dy:o}}function Gi(t){var e=t[0],n=t[t.length-1];return e<n?[e,n]:[n,e]}function Zi(t){return t.rangeExtent?t.rangeExtent():Gi(t.range())}function Xi(t,e,n,r){var i=n(t[0],t[1]),o=r(e[0],e[1]);return function(t){return o(i(t))}}function Ji(t,e){var n,r=0,i=t.length-1,o=t[r],a=t[i];return a<o&&(n=r,r=i,i=n,n=o,o=a,a=n),t[r]=e.floor(o),t[i]=e.ceil(a),t}function Qi(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:Nu}function Ki(t,e,n,r){var i=[],o=[],a=0,s=Math.min(t.length,e.length)-1;for(t[s]<t[0]&&(t=t.slice().reverse(),e=e.slice().reverse());++a<=s;)i.push(n(t[a-1],t[a])),o.push(r(e[a-1],e[a]));return function(e){var n=pa.bisect(t,e,1,s)-1;return o[n](i[n](e))}}function to(t,e,n,r){function i(){var i=Math.min(t.length,e.length)>2?Ki:Xi,u=r?ti:Kr;return a=i(t,e,u,n),s=i(e,t,u,Tr),o}function o(t){return a(t)}var a,s;return o.invert=function(t){return s(t)},o.domain=function(e){return arguments.length?(t=e.map(Number),i()):t},o.range=function(t){return arguments.length?(e=t,i()):e},o.rangeRound=function(t){return o.range(t).interpolate(zr)},o.clamp=function(t){return arguments.length?(r=t,i()):r},o.interpolate=function(t){return arguments.length?(n=t,i()):n},o.ticks=function(e){return io(t,e)},o.tickFormat=function(e,n){return oo(t,e,n)},o.nice=function(e){return no(t,e),i()},o.copy=function(){return to(t,e,n,r)},i()}function eo(t,e){return pa.rebind(t,e,"range","rangeRound","interpolate","clamp")}function no(t,e){return Ji(t,Qi(ro(t,e)[2])),Ji(t,Qi(ro(t,e)[2])),t}function ro(t,e){null==e&&(e=10);var n=Gi(t),r=n[1]-n[0],i=Math.pow(10,Math.floor(Math.log(r/e)/Math.LN10)),o=e/r*i;return o<=.15?i*=10:o<=.35?i*=5:o<=.75&&(i*=2),n[0]=Math.ceil(n[0]/i)*i,n[1]=Math.floor(n[1]/i)*i+.5*i,n[2]=i,n}function io(t,e){return pa.range.apply(pa,ro(t,e))}function oo(t,e,n){var r=ro(t,e);if(n){var i=gs.exec(n);if(i.shift(),"s"===i[8]){var o=pa.formatPrefix(Math.max(Ea(r[0]),Ea(r[1])));return i[7]||(i[7]="."+ao(o.scale(r[2]))),i[8]="f",n=pa.format(i.join("")),function(t){return n(o.scale(t))+o.symbol}}i[7]||(i[7]="."+so(i[8],r)),n=i.join("")}else n=",."+ao(r[2])+"f";return pa.format(n)}function ao(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}function so(t,e){var n=ao(e[2]);return t in ku?Math.abs(n-ao(Math.max(Ea(e[0]),Ea(e[1]))))+ +("e"!==t):n-2*("%"===t)}function uo(t,e,n,r){function i(t){return(n?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(e)}function o(t){return n?Math.pow(e,t):-Math.pow(e,-t)}function a(e){return t(i(e))}return a.invert=function(e){return o(t.invert(e))},a.domain=function(e){return arguments.length?(n=e[0]>=0,t.domain((r=e.map(Number)).map(i)),a):r},a.base=function(n){return arguments.length?(e=+n,t.domain(r.map(i)),a):e},a.nice=function(){var e=Ji(r.map(i),n?Math:Au);return t.domain(e),r=e.map(o),a},a.ticks=function(){var t=Gi(r),a=[],s=t[0],u=t[1],l=Math.floor(i(s)),c=Math.ceil(i(u)),f=e%1?2:e;if(isFinite(c-l)){if(n){for(;l<c;l++)for(var h=1;h<f;h++)a.push(o(l)*h);a.push(o(l))}else for(a.push(o(l));l++<c;)for(var h=f-1;h>0;h--)a.push(o(l)*h);for(l=0;a[l]<s;l++);for(c=a.length;a[c-1]>u;c--);a=a.slice(l,c)}return a},a.tickFormat=function(t,n){if(!arguments.length)return _u;arguments.length<2?n=_u:"function"!=typeof n&&(n=pa.format(n));var r=Math.max(1,e*t/a.ticks().length);return function(t){var a=t/o(Math.round(i(t)));return a*e<e-.5&&(a*=e),a<=r?n(t):""}},a.copy=function(){return uo(t.copy(),e,n,r)},eo(a,t)}function lo(t,e,n){function r(e){return t(i(e))}var i=co(e),o=co(1/e);return r.invert=function(e){return o(t.invert(e))},r.domain=function(e){return arguments.length?(t.domain((n=e.map(Number)).map(i)),r):n},r.ticks=function(t){return io(n,t)},r.tickFormat=function(t,e){return oo(n,t,e)},r.nice=function(t){return r.domain(no(n,t))},r.exponent=function(a){return arguments.length?(i=co(e=a),o=co(1/e),t.domain(n.map(i)),r):e},r.copy=function(){return lo(t.copy(),e,n)},eo(r,t)}function co(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}function fo(t,e){function n(n){return o[((i.get(n)||("range"===e.t?i.set(n,t.push(n)):NaN))-1)%o.length]}function r(e,n){return pa.range(t.length).map(function(t){return e+n*t})}var i,o,a;return n.domain=function(r){if(!arguments.length)return t;t=[],i=new d;for(var o,a=-1,s=r.length;++a<s;)i.has(o=r[a])||i.set(o,t.push(o));return n[e.t].apply(n,e.a)},n.range=function(t){return arguments.length?(o=t,a=0,e={t:"range",a:arguments},n):o},n.rangePoints=function(i,s){arguments.length<2&&(s=0);var u=i[0],l=i[1],c=t.length<2?(u=(u+l)/2,0):(l-u)/(t.length-1+s);return o=r(u+c*s/2,c),a=0,e={t:"rangePoints",a:arguments},n},n.rangeRoundPoints=function(i,s){arguments.length<2&&(s=0);var u=i[0],l=i[1],c=t.length<2?(u=l=Math.round((u+l)/2),0):(l-u)/(t.length-1+s)|0;return o=r(u+Math.round(c*s/2+(l-u-(t.length-1+s)*c)/2),c),a=0,e={t:"rangeRoundPoints",a:arguments},n},n.rangeBands=function(i,s,u){arguments.length<2&&(s=0),arguments.length<3&&(u=s);var l=i[1]<i[0],c=i[l-0],f=i[1-l],h=(f-c)/(t.length-s+2*u);return o=r(c+h*u,h),l&&o.reverse(),a=h*(1-s),e={t:"rangeBands",a:arguments},n},n.rangeRoundBands=function(i,s,u){arguments.length<2&&(s=0),arguments.length<3&&(u=s);var l=i[1]<i[0],c=i[l-0],f=i[1-l],h=Math.floor((f-c)/(t.length-s+2*u));return o=r(c+Math.round((f-c-(t.length-s)*h)/2),h),l&&o.reverse(),a=Math.round(h*(1-s)),e={t:"rangeRoundBands",a:arguments},n},n.rangeBand=function(){return a},n.rangeExtent=function(){return Gi(e.a[0])},n.copy=function(){return fo(t,e)},n.domain(t)}function ho(t,e){function n(){var n=0,o=e.length;for(i=[];++n<o;)i[n-1]=pa.quantile(t,n/o);return r}function r(t){if(!isNaN(t=+t))return e[pa.bisect(i,t)]}var i;return r.domain=function(e){return arguments.length?(t=e.map(u).filter(l).sort(s),n()):t},r.range=function(t){return arguments.length?(e=t,n()):e},r.quantiles=function(){return i},r.invertExtent=function(n){return n=e.indexOf(n),n<0?[NaN,NaN]:[n>0?i[n-1]:t[0],n<i.length?i[n]:t[t.length-1]]},r.copy=function(){return ho(t,e)},n()}function po(t,e,n){function r(e){return n[Math.max(0,Math.min(a,Math.floor(o*(e-t))))]}function i(){return o=n.length/(e-t),a=n.length-1,r}var o,a;return r.domain=function(n){return arguments.length?(t=+n[0],e=+n[n.length-1],i()):[t,e]},r.range=function(t){return arguments.length?(n=t,i()):n},r.invertExtent=function(e){return e=n.indexOf(e),e=e<0?NaN:e/o+t,[e,e+1/o]},r.copy=function(){return po(t,e,n)},i()}function go(t,e){function n(n){if(n<=n)return e[pa.bisect(t,n)]}return n.domain=function(e){return arguments.length?(t=e,n):t},n.range=function(t){return arguments.length?(e=t,n):e},n.invertExtent=function(n){return n=e.indexOf(n),[t[n-1],t[n]]},n.copy=function(){return go(t,e)},n}function vo(t){function e(t){return+t}return e.invert=e,e.domain=e.range=function(n){return arguments.length?(t=n.map(e),e):t},e.ticks=function(e){return io(t,e)},e.tickFormat=function(e,n){return oo(t,e,n)},e.copy=function(){return vo(t)},e}function yo(){return 0}function mo(t){return t.innerRadius}function bo(t){return t.outerRadius}function xo(t){return t.startAngle}function wo(t){return t.endAngle}function Mo(t){return t&&t.padAngle}function Eo(t,e,n,r){return(t-n)*e-(e-r)*t>0?0:1}function To(t,e,n,r,i){var o=t[0]-e[0],a=t[1]-e[1],s=(i?r:-r)/Math.sqrt(o*o+a*a),u=s*a,l=-s*o,c=t[0]+u,f=t[1]+l,h=e[0]+u,p=e[1]+l,d=(c+h)/2,g=(f+p)/2,v=h-c,y=p-f,m=v*v+y*y,b=n-r,x=c*p-h*f,w=(y<0?-1:1)*Math.sqrt(Math.max(0,b*b*m-x*x)),M=(x*y-v*w)/m,E=(-x*v-y*w)/m,T=(x*y+v*w)/m,C=(-x*v+y*w)/m,S=M-d,N=E-g,k=T-d,_=C-g;return S*S+N*N>k*k+_*_&&(M=T,E=C),[[M-u,E-l],[M*n/b,E*n/b]]}function Co(t){function e(e){function a(){l.push("M",o(t(c),s))}for(var u,l=[],c=[],f=-1,h=e.length,p=Lt(n),d=Lt(r);++f<h;)i.call(this,u=e[f],f)?c.push([+p.call(this,u,f),+d.call(this,u,f)]):c.length&&(a(),c=[]);return c.length&&a(),l.length?l.join(""):null}var n=jn,r=On,i=je,o=So,a=o.key,s=.7;return e.x=function(t){return arguments.length?(n=t,e):n},e.y=function(t){return arguments.length?(r=t,e):r},e.defined=function(t){return arguments.length?(i=t,e):i},e.interpolate=function(t){return arguments.length?(a="function"==typeof t?o=t:(o=Iu.get(t)||So).key,e):a},e.tension=function(t){return arguments.length?(s=t,e):s},e}function So(t){return t.length>1?t.join("L"):t+"Z"}function No(t){return t.join("L")+"Z"}function ko(t){for(var e=0,n=t.length,r=t[0],i=[r[0],",",r[1]];++e<n;)i.push("H",(r[0]+(r=t[e])[0])/2,"V",r[1]);return n>1&&i.push("H",r[0]),i.join("")}function _o(t){for(var e=0,n=t.length,r=t[0],i=[r[0],",",r[1]];++e<n;)i.push("V",(r=t[e])[1],"H",r[0]);return i.join("")}function Ao(t){for(var e=0,n=t.length,r=t[0],i=[r[0],",",r[1]];++e<n;)i.push("H",(r=t[e])[0],"V",r[1]);return i.join("")}function Lo(t,e){return t.length<4?So(t):t[1]+jo(t.slice(1,-1),Oo(t,e))}function Do(t,e){return t.length<3?No(t):t[0]+jo((t.push(t[0]),t),Oo([t[t.length-2]].concat(t,[t[1]]),e))}function Ro(t,e){return t.length<3?So(t):t[0]+jo(t,Oo(t,e))}function jo(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return So(t);var n=t.length!=e.length,r="",i=t[0],o=t[1],a=e[0],s=a,u=1;if(n&&(r+="Q"+(o[0]-2*a[0]/3)+","+(o[1]-2*a[1]/3)+","+o[0]+","+o[1],i=t[1],u=2),e.length>1){s=e[1],o=t[u],u++,r+="C"+(i[0]+a[0])+","+(i[1]+a[1])+","+(o[0]-s[0])+","+(o[1]-s[1])+","+o[0]+","+o[1];for(var l=2;l<e.length;l++,u++)o=t[u],s=e[l],r+="S"+(o[0]-s[0])+","+(o[1]-s[1])+","+o[0]+","+o[1]}if(n){var c=t[u];r+="Q"+(o[0]+2*s[0]/3)+","+(o[1]+2*s[1]/3)+","+c[0]+","+c[1]}return r}function Oo(t,e){for(var n,r=[],i=(1-e)/2,o=t[0],a=t[1],s=1,u=t.length;++s<u;)n=o,o=a,a=t[s],r.push([i*(a[0]-n[0]),i*(a[1]-n[1])]);return r}function Io(t){if(t.length<3)return So(t);var e=1,n=t.length,r=t[0],i=r[0],o=r[1],a=[i,i,i,(r=t[1])[0]],s=[o,o,o,r[1]],u=[i,",",o,"L",Ho(qu,a),",",Ho(qu,s)];for(t.push(t[n-1]);++e<=n;)r=t[e],a.shift(),a.push(r[0]),s.shift(),s.push(r[1]),Fo(u,a,s);return t.pop(),u.push("L",r),u.join("")}function Po(t){if(t.length<4)return So(t);for(var e,n=[],r=-1,i=t.length,o=[0],a=[0];++r<3;)e=t[r],o.push(e[0]),a.push(e[1]);for(n.push(Ho(qu,o)+","+Ho(qu,a)),--r;++r<i;)e=t[r],o.shift(),o.push(e[0]),a.shift(),a.push(e[1]),Fo(n,o,a);return n.join("")}function $o(t){for(var e,n,r=-1,i=t.length,o=i+4,a=[],s=[];++r<4;)n=t[r%i],a.push(n[0]),s.push(n[1]);for(e=[Ho(qu,a),",",Ho(qu,s)],--r;++r<o;)n=t[r%i],a.shift(),a.push(n[0]),s.shift(),s.push(n[1]),Fo(e,a,s);return e.join("")}function qo(t,e){var n=t.length-1;if(n)for(var r,i,o=t[0][0],a=t[0][1],s=t[n][0]-o,u=t[n][1]-a,l=-1;++l<=n;)r=t[l],i=l/n,r[0]=e*r[0]+(1-e)*(o+i*s),r[1]=e*r[1]+(1-e)*(a+i*u);return Io(t)}function Ho(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}function Fo(t,e,n){t.push("C",Ho(Pu,e),",",Ho(Pu,n),",",Ho($u,e),",",Ho($u,n),",",Ho(qu,e),",",Ho(qu,n))}function zo(t,e){return(e[1]-t[1])/(e[0]-t[0])}function Uo(t){for(var e=0,n=t.length-1,r=[],i=t[0],o=t[1],a=r[0]=zo(i,o);++e<n;)r[e]=(a+(a=zo(i=o,o=t[e+1])))/2;return r[e]=a,r}function Vo(t){for(var e,n,r,i,o=[],a=Uo(t),s=-1,u=t.length-1;++s<u;)e=zo(t[s],t[s+1]),Ea(e)<Ha?a[s]=a[s+1]=0:(n=a[s]/e,r=a[s+1]/e,(i=n*n+r*r)>9&&(i=3*e/Math.sqrt(i),a[s]=i*n,a[s+1]=i*r));for(s=-1;++s<=u;)i=(t[Math.min(u,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+a[s]*a[s])),o.push([i||0,a[s]*i||0]);return o}function Bo(t){return t.length<3?So(t):t[0]+jo(t,Vo(t))}function Wo(t){for(var e,n,r,i=-1,o=t.length;++i<o;)e=t[i],n=e[0],r=e[1]-Ba,e[0]=n*Math.cos(r),e[1]=n*Math.sin(r);return t}function Yo(t){function e(e){function u(){g.push("M",s(t(y),f),c,l(t(v.reverse()),f),"Z")}for(var h,p,d,g=[],v=[],y=[],m=-1,b=e.length,x=Lt(n),w=Lt(i),M=n===r?function(){return p}:Lt(r),E=i===o?function(){return d}:Lt(o);++m<b;)a.call(this,h=e[m],m)?(v.push([p=+x.call(this,h,m),d=+w.call(this,h,m)]),y.push([+M.call(this,h,m),+E.call(this,h,m)])):v.length&&(u(),v=[],y=[]);return v.length&&u(),g.length?g.join(""):null}var n=jn,r=jn,i=0,o=On,a=je,s=So,u=s.key,l=s,c="L",f=.7;return e.x=function(t){return arguments.length?(n=r=t,e):r},e.x0=function(t){return arguments.length?(n=t,e):n},e.x1=function(t){return arguments.length?(r=t,e):r},e.y=function(t){return arguments.length?(i=o=t,e):o},e.y0=function(t){return arguments.length?(i=t,e):i},e.y1=function(t){return arguments.length?(o=t,e):o},e.defined=function(t){return arguments.length?(a=t,e):a},e.interpolate=function(t){return arguments.length?(u="function"==typeof t?s=t:(s=Iu.get(t)||So).key,l=s.reverse||s,c=s.closed?"M":"L",e):u},e.tension=function(t){return arguments.length?(f=t,e):f},e}function Go(t){return t.radius}function Zo(t){return[t.x,t.y]}function Xo(t){return function(){var e=t.apply(this,arguments),n=e[0],r=e[1]-Ba;return[n*Math.cos(r),n*Math.sin(r)]}}function Jo(){return 64}function Qo(){return"circle"}function Ko(t){var e=Math.sqrt(t/za);return"M0,"+e+"A"+e+","+e+" 0 1,1 0,"+-e+"A"+e+","+e+" 0 1,1 0,"+e+"Z"}function ta(t){return function(){var e,n,r;(e=this[t])&&(r=e[n=e.active])&&(r.timer.c=null,r.timer.t=NaN,--e.count?delete e[n]:delete this[t],e.active+=.5,r.event&&r.event.interrupt.call(this,this.__data__,r.index))}}function ea(t,e,n){return ka(t,Wu),t.namespace=e,t.id=n,t}function na(t,e,n,r){var i=t.id,o=t.namespace;return G(t,"function"==typeof n?function(t,a,s){t[o][i].tween.set(e,r(n.call(t,t.__data__,a,s)))}:(n=r(n),function(t){t[o][i].tween.set(e,n)}))}function ra(t){return null==t&&(t=""),function(){this.textContent=t}}function ia(t){return null==t?"__transition__":"__transition_"+t+"__"}function oa(t,e,n,r,i){function o(t){var e=g.delay;if(l.t=e+u,e<=t)return a(t-e);l.c=a}function a(n){var i=p.active,o=p[i];o&&(o.timer.c=null,o.timer.t=NaN,--p.count,delete p[i],o.event&&o.event.interrupt.call(t,t.__data__,o.index));for(var a in p)if(+a<r){var d=p[a];d.timer.c=null,d.timer.t=NaN,--p.count,delete p[a]}l.c=s,It(function(){return l.c&&s(n||1)&&(l.c=null,l.t=NaN),1},0,u),p.active=r,g.event&&g.event.start.call(t,t.__data__,e),h=[],g.tween.forEach(function(n,r){(r=r.call(t,t.__data__,e))&&h.push(r)}),f=g.ease,c=g.duration}function s(i){for(var o=i/c,a=f(o),s=h.length;s>0;)h[--s].call(t,a);if(o>=1)return g.event&&g.event.end.call(t,t.__data__,e),--p.count?delete p[r]:delete t[n],1}var u,l,c,f,h,p=t[n]||(t[n]={active:0,count:0}),g=p[r];g||(u=i.time,l=It(o,0,u),g=p[r]={tween:new d,time:u,timer:l,delay:i.delay,duration:i.duration,ease:i.ease,index:e},i=null,++p.count)}function aa(t,e,n){t.attr("transform",function(t){var r=e(t);return"translate("+(isFinite(r)?r:n(t))+",0)"})}function sa(t,e,n){t.attr("transform",function(t){var r=e(t);return"translate(0,"+(isFinite(r)?r:n(t))+")"})}function ua(t){return t.toISOString()}function la(t,e,n){function r(e){return t(e)}function i(t,n){var r=t[1]-t[0],i=r/n,o=pa.bisect(el,i);return o==el.length?[e.year,ro(t.map(function(t){return t/31536e6}),n)[2]]:o?e[i/el[o-1]<el[o]/i?o-1:o]:[il,ro(t,n)[2]]}return r.invert=function(e){return ca(t.invert(e))},r.domain=function(e){return arguments.length?(t.domain(e),r):t.domain().map(ca)},r.nice=function(t,e){function n(n){return!isNaN(n)&&!t.range(n,ca(+n+1),e).length}var o=r.domain(),a=Gi(o),s=null==t?i(a,10):"number"==typeof t&&i(a,t);return s&&(t=s[0],e=s[1]),r.domain(Ji(o,e>1?{floor:function(e){for(;n(e=t.floor(e));)e=ca(e-1);return e},ceil:function(e){for(;n(e=t.ceil(e));)e=ca(+e+1);return e}}:t))},r.ticks=function(t,e){var n=Gi(r.domain()),o=null==t?i(n,10):"number"==typeof t?i(n,t):!t.range&&[{range:t},e];return o&&(t=o[0],e=o[1]),t.range(n[0],ca(+n[1]+1),e<1?1:e)},r.tickFormat=function(){return n},r.copy=function(){return la(t.copy(),e,n)},eo(r,t)}function ca(t){return new Date(t)}function fa(t){return JSON.parse(t.responseText)}function ha(t){var e=va.createRange();return e.selectNode(va.body),e.createContextualFragment(t.responseText)}var pa={version:"3.5.17"},da=[].slice,ga=function(t){return da.call(t)},va=this.document;if(va)try{ga(va.documentElement.childNodes)[0].nodeType}catch(t){ga=function(t){for(var e=t.length,n=new Array(e);e--;)n[e]=t[e];return n}}if(Date.now||(Date.now=function(){return+new Date}),va)try{va.createElement("DIV").style.setProperty("opacity",0,"")}catch(t){var ya=this.Element.prototype,ma=ya.setAttribute,ba=ya.setAttributeNS,xa=this.CSSStyleDeclaration.prototype,wa=xa.setProperty;ya.setAttribute=function(t,e){ma.call(this,t,e+"")},ya.setAttributeNS=function(t,e,n){ba.call(this,t,e,n+"")},xa.setProperty=function(t,e,n){wa.call(this,t,e+"",n)}}pa.ascending=s,pa.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},pa.min=function(t,e){var n,r,i=-1,o=t.length;if(1===arguments.length){for(;++i<o;)if(null!=(r=t[i])&&r>=r){n=r;break}for(;++i<o;)null!=(r=t[i])&&n>r&&(n=r)}else{for(;++i<o;)if(null!=(r=e.call(t,t[i],i))&&r>=r){n=r;break}for(;++i<o;)null!=(r=e.call(t,t[i],i))&&n>r&&(n=r)}return n},pa.max=function(t,e){var n,r,i=-1,o=t.length;if(1===arguments.length){for(;++i<o;)if(null!=(r=t[i])&&r>=r){n=r;break}for(;++i<o;)null!=(r=t[i])&&r>n&&(n=r)}else{for(;++i<o;)if(null!=(r=e.call(t,t[i],i))&&r>=r){n=r;break}for(;++i<o;)null!=(r=e.call(t,t[i],i))&&r>n&&(n=r)}return n},pa.extent=function(t,e){var n,r,i,o=-1,a=t.length;if(1===arguments.length){for(;++o<a;)if(null!=(r=t[o])&&r>=r){n=i=r;break}for(;++o<a;)null!=(r=t[o])&&(n>r&&(n=r),i<r&&(i=r))}else{for(;++o<a;)if(null!=(r=e.call(t,t[o],o))&&r>=r){n=i=r;break}for(;++o<a;)null!=(r=e.call(t,t[o],o))&&(n>r&&(n=r),i<r&&(i=r))}return[n,i]},pa.sum=function(t,e){var n,r=0,i=t.length,o=-1;if(1===arguments.length)for(;++o<i;)l(n=+t[o])&&(r+=n);else for(;++o<i;)l(n=+e.call(t,t[o],o))&&(r+=n);return r},pa.mean=function(t,e){var n,r=0,i=t.length,o=-1,a=i;if(1===arguments.length)for(;++o<i;)l(n=u(t[o]))?r+=n:--a;else for(;++o<i;)l(n=u(e.call(t,t[o],o)))?r+=n:--a;if(a)return r/a},pa.quantile=function(t,e){var n=(t.length-1)*e+1,r=Math.floor(n),i=+t[r-1],o=n-r;return o?i+o*(t[r]-i):i},pa.median=function(t,e){var n,r=[],i=t.length,o=-1;if(1===arguments.length)for(;++o<i;)l(n=u(t[o]))&&r.push(n);else for(;++o<i;)l(n=u(e.call(t,t[o],o)))&&r.push(n);if(r.length)return pa.quantile(r.sort(s),.5)},pa.variance=function(t,e){var n,r,i=t.length,o=0,a=0,s=-1,c=0;if(1===arguments.length)for(;++s<i;)l(n=u(t[s]))&&(r=n-o,o+=r/++c,a+=r*(n-o));else for(;++s<i;)l(n=u(e.call(t,t[s],s)))&&(r=n-o,o+=r/++c,a+=r*(n-o));if(c>1)return a/(c-1)},pa.deviation=function(){var t=pa.variance.apply(this,arguments);return t?Math.sqrt(t):t};var Ma=c(s);pa.bisectLeft=Ma.left,pa.bisect=pa.bisectRight=Ma.right,pa.bisector=function(t){return c(1===t.length?function(e,n){return s(t(e),n)}:t)},pa.shuffle=function(t,e,n){(o=arguments.length)<3&&(n=t.length,o<2&&(e=0));for(var r,i,o=n-e;o;)i=Math.random()*o--|0,r=t[o+e],t[o+e]=t[i+e],t[i+e]=r;return t},pa.permute=function(t,e){for(var n=e.length,r=new Array(n);n--;)r[n]=t[e[n]];return r},pa.pairs=function(t){for(var e=0,n=t.length-1,r=t[0],i=new Array(n<0?0:n);e<n;)i[e]=[r,r=t[++e]];return i},pa.transpose=function(t){if(!(i=t.length))return[];for(var e=-1,n=pa.min(t,f),r=new Array(n);++e<n;)for(var i,o=-1,a=r[e]=new Array(i);++o<i;)a[o]=t[o][e];return r},pa.zip=function(){return pa.transpose(arguments)},pa.keys=function(t){var e=[];for(var n in t)e.push(n);return e},pa.values=function(t){var e=[];for(var n in t)e.push(t[n]);return e},pa.entries=function(t){var e=[];for(var n in t)e.push({key:n,value:t[n]});return e},pa.merge=function(t){for(var e,n,r,i=t.length,o=-1,a=0;++o<i;)a+=t[o].length;for(n=new Array(a);--i>=0;)for(r=t[i],e=r.length;--e>=0;)n[--a]=r[e];return n};var Ea=Math.abs;pa.range=function(t,e,n){if(arguments.length<3&&(n=1,arguments.length<2&&(e=t,t=0)),(e-t)/n==1/0)throw new Error("infinite range");var r,i=[],o=h(Ea(n)),a=-1;if(t*=o,e*=o,n*=o,n<0)for(;(r=t+n*++a)>e;)i.push(r/o);else for(;(r=t+n*++a)<e;)i.push(r/o);return i},pa.map=function(t,e){var n=new d;if(t instanceof d)t.forEach(function(t,e){n.set(t,e)});else if(Array.isArray(t)){var r,i=-1,o=t.length;if(1===arguments.length)for(;++i<o;)n.set(i,t[i]);else for(;++i<o;)n.set(e.call(t,r=t[i],i),r)}else for(var a in t)n.set(a,t[a]);return n};var Ta="__proto__",Ca="\0";p(d,{has:y,get:function(t){return this._[g(t)]},set:function(t,e){return this._[g(t)]=e},remove:m,keys:b,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:v(e),value:this._[e]});return t},size:x,empty:w,forEach:function(t){for(var e in this._)t.call(this,v(e),this._[e])}}),pa.nest=function(){function t(e,a,s){if(s>=o.length)return r?r.call(i,a):n?a.sort(n):a;for(var u,l,c,f,h=-1,p=a.length,g=o[s++],v=new d;++h<p;)(f=v.get(u=g(l=a[h])))?f.push(l):v.set(u,[l]);return e?(l=e(),c=function(n,r){l.set(n,t(e,r,s))}):(l={},c=function(n,r){l[n]=t(e,r,s)}),v.forEach(c),l}function e(t,n){if(n>=o.length)return t;var r=[],i=a[n++];return t.forEach(function(t,i){r.push({key:t,values:e(i,n)})}),i?r.sort(function(t,e){return i(t.key,e.key)}):r}var n,r,i={},o=[],a=[];return i.map=function(e,n){return t(n,e,0)},i.entries=function(n){return e(t(pa.map,n,0),0)},i.key=function(t){return o.push(t),i},i.sortKeys=function(t){return a[o.length-1]=t,i},i.sortValues=function(t){return n=t,i},i.rollup=function(t){return r=t,i},i},pa.set=function(t){var e=new M;if(t)for(var n=0,r=t.length;n<r;++n)e.add(t[n]);return e},p(M,{has:y,add:function(t){return this._[g(t+="")]=!0,t},remove:m,values:b,size:x,empty:w,forEach:function(t){for(var e in this._)t.call(this,v(e))}}),pa.behavior={},pa.rebind=function(t,e){for(var n,r=1,i=arguments.length;++r<i;)t[n=arguments[r]]=T(t,e,e[n]);return t};var Sa=["webkit","ms","moz","Moz","o","O"];pa.dispatch=function(){for(var t=new N,e=-1,n=arguments.length;++e<n;)t[arguments[e]]=k(t);return t},N.prototype.on=function(t,e){var n=t.indexOf("."),r="";if(n>=0&&(r=t.slice(n+1),t=t.slice(0,n)),t)return arguments.length<2?this[t].on(r):this[t].on(r,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(r,null);return this}},pa.event=null,pa.requote=function(t){return t.replace(Na,"\\$&")};var Na=/[\\\^\$\*\+\?\|\[\]\(\)\.\{\}]/g,ka={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var n in e)t[n]=e[n]},_a=function(t,e){return e.querySelector(t)},Aa=function(t,e){return e.querySelectorAll(t)},La=function(t,e){var n=t.matches||t[C(t,"matchesSelector")];return(La=function(t,e){return n.call(t,e)})(t,e)};"function"==typeof Sizzle&&(_a=function(t,e){return Sizzle(t,e)[0]||null},Aa=Sizzle,La=Sizzle.matchesSelector),pa.selection=function(){return pa.select(va.documentElement)};var Da=pa.selection.prototype=[];Da.select=function(t){var e,n,r,i,o=[];t=R(t);for(var a=-1,s=this.length;++a<s;){o.push(e=[]),e.parentNode=(r=this[a]).parentNode;for(var u=-1,l=r.length;++u<l;)(i=r[u])?(e.push(n=t.call(i,i.__data__,u,a)),n&&"__data__"in i&&(n.__data__=i.__data__)):e.push(null)}return D(o)},Da.selectAll=function(t){var e,n,r=[];t=j(t);for(var i=-1,o=this.length;++i<o;)for(var a=this[i],s=-1,u=a.length;++s<u;)(n=a[s])&&(r.push(e=ga(t.call(n,n.__data__,s,i))),e.parentNode=n);return D(r)};var Ra="http://www.w3.org/1999/xhtml",ja={svg:"http://www.w3.org/2000/svg",xhtml:Ra,xlink:"http://www.w3.org/1999/xlink",xml:"http://www.w3.org/XML/1998/namespace",xmlns:"http://www.w3.org/2000/xmlns/"};pa.ns={prefix:ja,qualify:function(t){var e=t.indexOf(":"),n=t;return e>=0&&"xmlns"!==(n=t.slice(0,e))&&(t=t.slice(e+1)),ja.hasOwnProperty(n)?{space:ja[n],local:t}:t}},Da.attr=function(t,e){if(arguments.length<2){if("string"==typeof t){var n=this.node();return t=pa.ns.qualify(t),t.local?n.getAttributeNS(t.space,t.local):n.getAttribute(t)}for(e in t)this.each(O(e,t[e]));return this}return this.each(O(t,e))},Da.classed=function(t,e){if(arguments.length<2){if("string"==typeof t){var n=this.node(),r=(t=$(t)).length,i=-1;if(e=n.classList){for(;++i<r;)if(!e.contains(t[i]))return!1}else for(e=n.getAttribute("class");++i<r;)if(!P(t[i]).test(e))return!1;return!0}for(e in t)this.each(q(e,t[e]));return this}return this.each(q(t,e))},Da.style=function(t,e,n){var r=arguments.length;if(r<3){if("string"!=typeof t){r<2&&(e="");for(n in t)this.each(F(n,t[n],e));return this}if(r<2){var i=this.node();return a(i).getComputedStyle(i,null).getPropertyValue(t)}n=""}return this.each(F(t,e,n))},Da.property=function(t,e){if(arguments.length<2){if("string"==typeof t)return this.node()[t];for(e in t)this.each(z(e,t[e]));return this}return this.each(z(t,e))},Da.text=function(t){return arguments.length?this.each("function"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?"":e}:null==t?function(){this.textContent=""}:function(){this.textContent=t}):this.node().textContent},Da.html=function(t){return arguments.length?this.each("function"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?"":e}:null==t?function(){this.innerHTML=""}:function(){this.innerHTML=t}):this.node().innerHTML},Da.append=function(t){return t=U(t),this.select(function(){return this.appendChild(t.apply(this,arguments))})},Da.insert=function(t,e){return t=U(t),e=R(e),this.select(function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)})},Da.remove=function(){return this.each(V)},Da.data=function(t,e){function n(t,n){var r,i,o,a=t.length,c=n.length,f=Math.min(a,c),h=new Array(c),p=new Array(c),g=new Array(a);if(e){var v,y=new d,m=new Array(a);for(r=-1;++r<a;)(i=t[r])&&(y.has(v=e.call(i,i.__data__,r))?g[r]=i:y.set(v,i),m[r]=v);for(r=-1;++r<c;)(i=y.get(v=e.call(n,o=n[r],r)))?!0!==i&&(h[r]=i,i.__data__=o):p[r]=B(o),y.set(v,!0);for(r=-1;++r<a;)r in m&&!0!==y.get(m[r])&&(g[r]=t[r])}else{for(r=-1;++r<f;)i=t[r],o=n[r],i?(i.__data__=o,h[r]=i):p[r]=B(o);for(;r<c;++r)p[r]=B(n[r]);for(;r<a;++r)g[r]=t[r]}p.update=h,p.parentNode=h.parentNode=g.parentNode=t.parentNode,s.push(p),u.push(h),l.push(g)}var r,i,o=-1,a=this.length;if(!arguments.length){for(t=new Array(a=(r=this[0]).length);++o<a;)(i=r[o])&&(t[o]=i.__data__);return t}var s=Z([]),u=D([]),l=D([]);if("function"==typeof t)for(;++o<a;)n(r=this[o],t.call(r,r.parentNode.__data__,o));else for(;++o<a;)n(r=this[o],t);return u.enter=function(){return s},u.exit=function(){return l},u},Da.datum=function(t){return arguments.length?this.property("__data__",t):this.property("__data__")},Da.filter=function(t){var e,n,r,i=[];"function"!=typeof t&&(t=W(t));for(var o=0,a=this.length;o<a;o++){i.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var s=0,u=n.length;s<u;s++)(r=n[s])&&t.call(r,r.__data__,s,o)&&e.push(r)}return D(i)},Da.order=function(){for(var t=-1,e=this.length;++t<e;)for(var n,r=this[t],i=r.length-1,o=r[i];--i>=0;)(n=r[i])&&(o&&o!==n.nextSibling&&o.parentNode.insertBefore(n,o),o=n);return this},Da.sort=function(t){t=Y.apply(this,arguments);for(var e=-1,n=this.length;++e<n;)this[e].sort(t);return this.order()},Da.each=function(t){return G(this,function(e,n,r){t.call(e,e.__data__,n,r)})},Da.call=function(t){var e=ga(arguments);return t.apply(e[0]=this,e),this},Da.empty=function(){return!this.node()},Da.node=function(){for(var t=0,e=this.length;t<e;t++)for(var n=this[t],r=0,i=n.length;r<i;r++){var o=n[r];if(o)return o}return null},Da.size=function(){var t=0;return G(this,function(){++t}),t};var Oa=[];pa.selection.enter=Z,pa.selection.enter.prototype=Oa,Oa.append=Da.append,Oa.empty=Da.empty,Oa.node=Da.node,Oa.call=Da.call,Oa.size=Da.size,Oa.select=function(t){for(var e,n,r,i,o,a=[],s=-1,u=this.length;++s<u;){r=(i=this[s]).update,a.push(e=[]),e.parentNode=i.parentNode;for(var l=-1,c=i.length;++l<c;)(o=i[l])?(e.push(r[l]=n=t.call(i.parentNode,o.__data__,l,s)),n.__data__=o.__data__):e.push(null)}return D(a)},Oa.insert=function(t,e){return arguments.length<2&&(e=X(this)),Da.insert.call(this,t,e)},pa.select=function(t){var e;return"string"==typeof t?(e=[_a(t,va)],e.parentNode=va.documentElement):(e=[t],e.parentNode=o(t)),D([e])},pa.selectAll=function(t){var e;return"string"==typeof t?(e=ga(Aa(t,va)),e.parentNode=va.documentElement):(e=ga(t),e.parentNode=null),D([e])},Da.on=function(t,e,n){var r=arguments.length;if(r<3){if("string"!=typeof t){r<2&&(e=!1);for(n in t)this.each(J(n,t[n],e));return this}if(r<2)return(r=this.node()["__on"+t])&&r._;n=!1}return this.each(J(t,e,n))};var Ia=pa.map({mouseenter:"mouseover",mouseleave:"mouseout"});va&&Ia.forEach(function(t){"on"+t in va&&Ia.remove(t)});var Pa,$a=0;pa.mouse=function(t){return et(t,A())};var qa=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;pa.touch=function(t,e,n){if(arguments.length<3&&(n=e,e=A().changedTouches),e)for(var r,i=0,o=e.length;i<o;++i)if((r=e[i]).identifier===n)return et(t,r)},pa.behavior.drag=function(){function t(){this.on("mousedown.drag",i).on("touchstart.drag",o)}function e(t,e,i,o,a){return function(){function s(){var t,n,r=e(h,g);r&&(t=r[0]-b[0],n=r[1]-b[1],d|=t|n,b=r,p({type:"drag",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:n}))}function u(){e(h,g)&&(y.on(o+v,null).on(a+v,null),m(d),p({type:"dragend"}))}var l,c=this,f=pa.event.target.correspondingElement||pa.event.target,h=c.parentNode,p=n.of(c,arguments),d=0,g=t(),v=".drag"+(null==g?"":"-"+g),y=pa.select(i(f)).on(o+v,s).on(a+v,u),m=tt(f),b=e(h,g);r?(l=r.apply(c,arguments),l=[l.x-b[0],l.y-b[1]]):l=[0,0],p({type:"dragstart"})}}var n=L(t,"drag","dragstart","dragend"),r=null,i=e(S,pa.mouse,a,"mousemove","mouseup"),o=e(nt,pa.touch,E,"touchmove","touchend");return t.origin=function(e){return arguments.length?(r=e,t):r},pa.rebind(t,n,"on")},pa.touches=function(t,e){return arguments.length<2&&(e=A().touches),e?ga(e).map(function(e){var n=et(t,e);return n.identifier=e.identifier,n}):[]};var Ha=1e-6,Fa=Ha*Ha,za=Math.PI,Ua=2*za,Va=Ua-Ha,Ba=za/2,Wa=za/180,Ya=180/za,Ga=Math.SQRT2,Za=2,Xa=4;pa.interpolateZoom=function(t,e){var n,r,i=t[0],o=t[1],a=t[2],s=e[0],u=e[1],l=e[2],c=s-i,f=u-o,h=c*c+f*f;if(h<Fa)r=Math.log(l/a)/Ga,n=function(t){return[i+t*c,o+t*f,a*Math.exp(Ga*t*r)]};else{var p=Math.sqrt(h),d=(l*l-a*a+Xa*h)/(2*a*Za*p),g=(l*l-a*a-Xa*h)/(2*l*Za*p),v=Math.log(Math.sqrt(d*d+1)-d),y=Math.log(Math.sqrt(g*g+1)-g);r=(y-v)/Ga,n=function(t){var e=t*r,n=ut(v),s=a/(Za*p)*(n*lt(Ga*e+v)-st(v));return[i+s*c,o+s*f,a*n/ut(Ga*e+v)]}}return n.duration=1e3*r,n},pa.behavior.zoom=function(){function t(t){t.on(A,f).on(Qa+".zoom",p).on("dblclick.zoom",d).on(j,h)}function e(t){return[(t[0]-T.x)/T.k,(t[1]-T.y)/T.k]}function n(t){return[t[0]*T.k+T.x,t[1]*T.k+T.y]}function r(t){T.k=Math.max(S[0],Math.min(S[1],t))}function i(t,e){e=n(e),T.x+=t[0]-e[0],T.y+=t[1]-e[1]}function o(e,n,o,a){e.__chart__={x:T.x,y:T.y,k:T.k},r(Math.pow(2,a)),i(v=n,o),e=pa.select(e),N>0&&(e=e.transition().duration(N)),e.call(t.event)}function s(){w&&w.domain(x.range().map(function(t){return(t-T.x)/T.k}).map(x.invert)),E&&E.domain(M.range().map(function(t){return(t-T.y)/T.k}).map(M.invert))}function u(t){k++||t({type:"zoomstart"})}function l(t){s(),t({type:"zoom",scale:T.k,translate:[T.x,T.y]})}function c(t){--k||(t({type:"zoomend"}),v=null)}function f(){function t(){s=1,i(pa.mouse(r),h),l(o)}function n(){f.on(D,null).on(R,null),p(s),c(o)}var r=this,o=O.of(r,arguments),s=0,f=pa.select(a(r)).on(D,t).on(R,n),h=e(pa.mouse(r)),p=tt(r);Bu.call(r),u(o)}function h(){function t(){var t=pa.touches(d);return p=T.k,t.forEach(function(t){t.identifier in v&&(v[t.identifier]=e(t))}),t}function n(){var e=pa.event.target;pa.select(e).on(x,a).on(w,s),M.push(e);for(var n=pa.event.changedTouches,r=0,i=n.length;r<i;++r)v[n[r].identifier]=null;var u=t(),l=Date.now();if(1===u.length){if(l-b<500){var c=u[0];o(d,c,v[c.identifier],Math.floor(Math.log(T.k)/Math.LN2)+1),_()}b=l}else if(u.length>1){var c=u[0],f=u[1],h=c[0]-f[0],p=c[1]-f[1];y=h*h+p*p}}function a(){var t,e,n,o,a=pa.touches(d);Bu.call(d);for(var s=0,u=a.length;s<u;++s,o=null)if(n=a[s],o=v[n.identifier]){if(e)break;t=n,e=o}if(o){var c=(c=n[0]-t[0])*c+(c=n[1]-t[1])*c,f=y&&Math.sqrt(c/y);t=[(t[0]+n[0])/2,(t[1]+n[1])/2],e=[(e[0]+o[0])/2,(e[1]+o[1])/2],r(f*p)}b=null,i(t,e),l(g)}function s(){if(pa.event.touches.length){for(var e=pa.event.changedTouches,n=0,r=e.length;n<r;++n)delete v[e[n].identifier];for(var i in v)return void t()}pa.selectAll(M).on(m,null),E.on(A,f).on(j,h),C(),c(g)}var p,d=this,g=O.of(d,arguments),v={},y=0,m=".zoom-"+pa.event.changedTouches[0].identifier,x="touchmove"+m,w="touchend"+m,M=[],E=pa.select(d),C=tt(d);n(),u(g),E.on(A,null).on(j,n)}function p(){var t=O.of(this,arguments);m?clearTimeout(m):(Bu.call(this),g=e(v=y||pa.mouse(this)),u(t)),m=setTimeout(function(){m=null,c(t)},50),_(),r(Math.pow(2,.002*Ja())*T.k),i(v,g),l(t)}function d(){var t=pa.mouse(this),n=Math.log(T.k)/Math.LN2;o(this,t,e(t),pa.event.shiftKey?Math.ceil(n)-1:Math.floor(n)+1)}var g,v,y,m,b,x,w,M,E,T={x:0,y:0,k:1},C=[960,500],S=Ka,N=250,k=0,A="mousedown.zoom",D="mousemove.zoom",R="mouseup.zoom",j="touchstart.zoom",O=L(t,"zoomstart","zoom","zoomend");return Qa||(Qa="onwheel"in va?(Ja=function(){return-pa.event.deltaY*(pa.event.deltaMode?120:1)},"wheel"):"onmousewheel"in va?(Ja=function(){return pa.event.wheelDelta},"mousewheel"):(Ja=function(){return-pa.event.detail},"MozMousePixelScroll")),t.event=function(t){t.each(function(){var t=O.of(this,arguments),e=T;Uu?pa.select(this).transition().each("start.zoom",function(){T=this.__chart__||{x:0,y:0,k:1},u(t)}).tween("zoom:zoom",function(){var n=C[0],r=C[1],i=v?v[0]:n/2,o=v?v[1]:r/2,a=pa.interpolateZoom([(i-T.x)/T.k,(o-T.y)/T.k,n/T.k],[(i-e.x)/e.k,(o-e.y)/e.k,n/e.k]);return function(e){var r=a(e),s=n/r[2];this.__chart__=T={x:i-r[0]*s,y:o-r[1]*s,k:s},l(t)}}).each("interrupt.zoom",function(){c(t)}).each("end.zoom",function(){c(t)}):(this.__chart__=T,u(t),l(t),c(t))})},t.translate=function(e){return arguments.length?(T={x:+e[0],y:+e[1],k:T.k},s(),t):[T.x,T.y]},t.scale=function(e){return arguments.length?(T={x:T.x,y:T.y,k:null},r(+e),s(),t):T.k},t.scaleExtent=function(e){return arguments.length?(S=null==e?Ka:[+e[0],+e[1]],t):S},t.center=function(e){return arguments.length?(y=e&&[+e[0],+e[1]],t):y},t.size=function(e){return arguments.length?(C=e&&[+e[0],+e[1]],t):C},t.duration=function(e){return arguments.length?(N=+e,t):N},t.x=function(e){return arguments.length?(w=e,x=e.copy(),T={x:0,y:0,k:1},t):w},t.y=function(e){return arguments.length?(E=e,M=e.copy(),T={x:0,y:0,k:1},t):E},pa.rebind(t,O,"on")};var Ja,Qa,Ka=[0,1/0];pa.color=ft,ft.prototype.toString=function(){return this.rgb()+""},pa.hsl=ht;var ts=ht.prototype=new ft;ts.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new ht(this.h,this.s,this.l/t)},ts.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new ht(this.h,this.s,t*this.l)},ts.rgb=function(){return pt(this.h,this.s,this.l)},pa.hcl=dt;var es=dt.prototype=new ft;es.brighter=function(t){return new dt(this.h,this.c,Math.min(100,this.l+ns*(arguments.length?t:1)))},es.darker=function(t){return new dt(this.h,this.c,Math.max(0,this.l-ns*(arguments.length?t:1)))},es.rgb=function(){return gt(this.h,this.c,this.l).rgb()},pa.lab=vt;var ns=18,rs=.95047,is=1,os=1.08883,as=vt.prototype=new ft;as.brighter=function(t){return new vt(Math.min(100,this.l+ns*(arguments.length?t:1)),this.a,this.b)},as.darker=function(t){return new vt(Math.max(0,this.l-ns*(arguments.length?t:1)),this.a,this.b)},as.rgb=function(){return yt(this.l,this.a,this.b)},pa.rgb=Mt;var ss=Mt.prototype=new ft;ss.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,n=this.g,r=this.b,i=30;return e||n||r?(e&&e<i&&(e=i),n&&n<i&&(n=i),r&&r<i&&(r=i),new Mt(Math.min(255,e/t),Math.min(255,n/t),Math.min(255,r/t))):new Mt(i,i,i)},ss.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new Mt(t*this.r,t*this.g,t*this.b)},ss.hsl=function(){return Nt(this.r,this.g,this.b)},ss.toString=function(){return"#"+Ct(this.r)+Ct(this.g)+Ct(this.b)};var us=pa.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});us.forEach(function(t,e){us.set(t,Et(e))}),pa.functor=Lt,pa.xhr=Dt(E),pa.dsv=function(t,e){function n(t,n,o){arguments.length<3&&(o=n,n=null);var a=Rt(t,e,null==n?r:i(n),o);return a.row=function(t){return arguments.length?a.response(null==(n=t)?r:i(t)):n},a}function r(t){return n.parse(t.responseText)}function i(t){return function(e){return n.parse(e.responseText,t)}}function o(e){return e.map(a).join(t)}function a(t){return s.test(t)?'"'+t.replace(/\"/g,'""')+'"':t}var s=new RegExp('["'+t+"\n]"),u=t.charCodeAt(0);return n.parse=function(t,e){var r;return n.parseRows(t,function(t,n){if(r)return r(t,n-1);var i=new Function("d","return {"+t.map(function(t,e){return JSON.stringify(t)+": d["+e+"]"}).join(",")+"}");r=e?function(t,n){return e(i(t),n)}:i})},n.parseRows=function(t,e){function n(){if(c>=l)return a;if(i)return i=!1,o;var e=c;if(34===t.charCodeAt(e)){for(var n=e;n++<l;)if(34===t.charCodeAt(n)){if(34!==t.charCodeAt(n+1))break;++n}c=n+2;var r=t.charCodeAt(n+1);return 13===r?(i=!0,10===t.charCodeAt(n+2)&&++c):10===r&&(i=!0),t.slice(e+1,n).replace(/""/g,'"')}for(;c<l;){var r=t.charCodeAt(c++),s=1;if(10===r)i=!0;else if(13===r)i=!0,10===t.charCodeAt(c)&&(++c,++s);else if(r!==u)continue;return t.slice(e,c-s)}return t.slice(e)}for(var r,i,o={},a={},s=[],l=t.length,c=0,f=0;(r=n())!==a;){for(var h=[];r!==o&&r!==a;)h.push(r),r=n();e&&null==(h=e(h,f++))||s.push(h)}return s},n.format=function(e){if(Array.isArray(e[0]))return n.formatRows(e);var r=new M,i=[];return e.forEach(function(t){for(var e in t)r.has(e)||i.push(r.add(e))}),[i.map(a).join(t)].concat(e.map(function(e){return i.map(function(t){return a(e[t])}).join(t)})).join("\n")},n.formatRows=function(t){return t.map(o).join("\n")},n},pa.csv=pa.dsv(",","text/csv"),pa.tsv=pa.dsv("\t","text/tab-separated-values");var ls,cs,fs,hs,ps=this[C(this,"requestAnimationFrame")]||function(t){setTimeout(t,17)};pa.timer=function(){It.apply(this,arguments)},pa.timer.flush=function(){$t(),qt()},pa.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var ds=["y","z","a","f","p","n","µ","m","","k","M","G","T","P","E","Z","Y"].map(Ft);pa.formatPrefix=function(t,e){var n=0;return(t=+t)&&(t<0&&(t*=-1),e&&(t=pa.round(t,Ht(t,e))),n=1+Math.floor(1e-12+Math.log(t)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),ds[8+n/3]};var gs=/(?:([^{])?([<>=^]))?([+\- ])?([$#])?(0)?(\d+)?(,)?(\.-?\d+)?([a-z%])?/i,vs=pa.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(t,e){return(t=pa.round(t,Ht(t,e))).toFixed(Math.max(0,Math.min(20,Ht(t*(1+1e-15),e))))}}),ys=pa.time={},ms=Date;Vt.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){bs.setUTCDate.apply(this._,arguments)},setDay:function(){bs.setUTCDay.apply(this._,arguments)},setFullYear:function(){bs.setUTCFullYear.apply(this._,arguments)},setHours:function(){bs.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){bs.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){bs.setUTCMinutes.apply(this._,arguments)},setMonth:function(){bs.setUTCMonth.apply(this._,arguments)},setSeconds:function(){bs.setUTCSeconds.apply(this._,arguments)},setTime:function(){bs.setTime.apply(this._,arguments)}};var bs=Date.prototype;ys.year=Bt(function(t){return t=ys.day(t),t.setMonth(0,1),t},function(t,e){t.setFullYear(t.getFullYear()+e)},function(t){return t.getFullYear()}),ys.years=ys.year.range,ys.years.utc=ys.year.utc.range,ys.day=Bt(function(t){var e=new ms(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e},function(t,e){t.setDate(t.getDate()+e)},function(t){return t.getDate()-1}),ys.days=ys.day.range,ys.days.utc=ys.day.utc.range,ys.dayOfYear=function(t){var e=ys.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},["sunday","monday","tuesday","wednesday","thursday","friday","saturday"].forEach(function(t,e){e=7-e;var n=ys[t]=Bt(function(t){return(t=ys.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t},function(t,e){t.setDate(t.getDate()+7*Math.floor(e))},function(t){var n=ys.year(t).getDay();return Math.floor((ys.dayOfYear(t)+(n+e)%7)/7)-(n!==e)});ys[t+"s"]=n.range,ys[t+"s"].utc=n.utc.range,ys[t+"OfYear"]=function(t){var n=ys.year(t).getDay();return Math.floor((ys.dayOfYear(t)+(n+e)%7)/7)}}),ys.week=ys.sunday,ys.weeks=ys.sunday.range,ys.weeks.utc=ys.sunday.utc.range,ys.weekOfYear=ys.sundayOfYear;var xs={"-":"",_:" ",0:"0"},ws=/^\s*\d+/,Ms=/^%/;pa.locale=function(t){return{numberFormat:zt(t),timeFormat:Yt(t)}};var Es=pa.locale({decimal:".",thousands:",",grouping:[3],currency:["$",""],dateTime:"%a %b %e %X %Y",date:"%m/%d/%Y",time:"%H:%M:%S",periods:["AM","PM"],days:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],shortDays:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],months:["January","February","March","April","May","June","July","August","September","October","November","December"],shortMonths:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"]});pa.format=Es.numberFormat,pa.geo={},de.prototype={s:0,t:0,add:function(t){ge(t,this.t,Ts),ge(Ts.s,this.s,this),this.s?this.t+=Ts.t:this.s=Ts.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var Ts=new de;pa.geo.stream=function(t,e){t&&Cs.hasOwnProperty(t.type)?Cs[t.type](t,e):ve(t,e)};var Cs={Feature:function(t,e){ve(t.geometry,e)},FeatureCollection:function(t,e){for(var n=t.features,r=-1,i=n.length;++r<i;)ve(n[r].geometry,e)}},Ss={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var n=t.coordinates,r=-1,i=n.length;++r<i;)t=n[r],e.point(t[0],t[1],t[2])},LineString:function(t,e){ye(t.coordinates,e,0)},MultiLineString:function(t,e){for(var n=t.coordinates,r=-1,i=n.length;++r<i;)ye(n[r],e,0)},Polygon:function(t,e){me(t.coordinates,e)},MultiPolygon:function(t,e){for(var n=t.coordinates,r=-1,i=n.length;++r<i;)me(n[r],e)},GeometryCollection:function(t,e){for(var n=t.geometries,r=-1,i=n.length;++r<i;)ve(n[r],e)}};pa.geo.area=function(t){return Ns=0,pa.geo.stream(t,_s),Ns};var Ns,ks=new de,_s={sphere:function(){Ns+=4*za},point:S,lineStart:S,lineEnd:S,polygonStart:function(){ks.reset(),_s.lineStart=be},polygonEnd:function(){var t=2*ks;Ns+=t<0?4*za+t:t,_s.lineStart=_s.lineEnd=_s.point=S}};pa.geo.bounds=function(){function t(t,e){b.push(x=[c=t,h=t]),e<f&&(f=e),e>p&&(p=e)}function e(e,n){var r=xe([e*Wa,n*Wa]);if(y){var i=Me(y,r),o=[i[1],-i[0],0],a=Me(o,i);Ce(a),a=Se(a);var u=e-d,l=u>0?1:-1,g=a[0]*Ya*l,v=Ea(u)>180;if(v^(l*d<g&&g<l*e)){var m=a[1]*Ya;m>p&&(p=m)}else if(g=(g+360)%360-180,v^(l*d<g&&g<l*e)){var m=-a[1]*Ya;m<f&&(f=m)}else n<f&&(f=n),n>p&&(p=n);v?e<d?s(c,e)>s(c,h)&&(h=e):s(e,h)>s(c,h)&&(c=e):h>=c?(e<c&&(c=e),e>h&&(h=e)):e>d?s(c,e)>s(c,h)&&(h=e):s(e,h)>s(c,h)&&(c=e)}else t(e,n);y=r,d=e}function n(){w.point=e}function r(){x[0]=c,x[1]=h,w.point=t,y=null}function i(t,n){if(y){var r=t-d;m+=Ea(r)>180?r+(r>0?360:-360):r}else g=t,v=n;_s.point(t,n),e(t,n)}function o(){_s.lineStart()}function a(){i(g,v),_s.lineEnd(),Ea(m)>Ha&&(c=-(h=180)),x[0]=c,x[1]=h,y=null}function s(t,e){return(e-=t)<0?e+360:e}function u(t,e){return t[0]-e[0]}function l(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}var c,f,h,p,d,g,v,y,m,b,x,w={point:t,lineStart:n,lineEnd:r,polygonStart:function(){w.point=i,w.lineStart=o,w.lineEnd=a,m=0,_s.polygonStart()},polygonEnd:function(){_s.polygonEnd(),w.point=t,w.lineStart=n,w.lineEnd=r,ks<0?(c=-(h=180),f=-(p=90)):m>Ha?p=90:m<-Ha&&(f=-90),x[0]=c,x[1]=h}};return function(t){p=h=-(c=f=1/0),b=[],pa.geo.stream(t,w);var e=b.length;if(e){b.sort(u);for(var n,r=1,i=b[0],o=[i];r<e;++r)n=b[r],l(n[0],i)||l(n[1],i)?(s(i[0],n[1])>s(i[0],i[1])&&(i[1]=n[1]),s(n[0],i[1])>s(i[0],i[1])&&(i[0]=n[0])):o.push(i=n);for(var a,n,d=-1/0,e=o.length-1,r=0,i=o[e];r<=e;i=n,++r)n=o[r],(a=s(i[1],n[0]))>d&&(d=a,c=n[0],h=i[1])}return b=x=null,c===1/0||f===1/0?[[NaN,NaN],[NaN,NaN]]:[[c,f],[h,p]]}}(),pa.geo.centroid=function(t){As=Ls=Ds=Rs=js=Os=Is=Ps=$s=qs=Hs=0,pa.geo.stream(t,Fs);var e=$s,n=qs,r=Hs,i=e*e+n*n+r*r;return i<Fa&&(e=Os,n=Is,r=Ps,Ls<Ha&&(e=Ds,n=Rs,r=js),(i=e*e+n*n+r*r)<Fa)?[NaN,NaN]:[Math.atan2(n,e)*Ya,at(r/Math.sqrt(i))*Ya]};var As,Ls,Ds,Rs,js,Os,Is,Ps,$s,qs,Hs,Fs={sphere:S,point:ke,lineStart:Ae,lineEnd:Le,polygonStart:function(){Fs.lineStart=De},polygonEnd:function(){Fs.lineStart=Ae}},zs=$e(je,ze,Ve,[-za,-za/2]),Us=1e9;pa.geo.clipExtent=function(){var t,e,n,r,i,o,a={stream:function(t){return i&&(i.valid=!1),i=o(t),i.valid=!0,i},extent:function(s){return arguments.length?(o=Ge(t=+s[0][0],e=+s[0][1],n=+s[1][0],r=+s[1][1]),i&&(i.valid=!1,i=null),a):[[t,e],[n,r]]}};return a.extent([[0,0],[960,500]])},(pa.geo.conicEqualArea=function(){return Ze(Xe)}).raw=Xe,pa.geo.albers=function(){return pa.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},pa.geo.albersUsa=function(){function t(t){var o=t[0],a=t[1];return e=null,n(o,a),e||(r(o,a),e)||i(o,a),e}var e,n,r,i,o=pa.geo.albers(),a=pa.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=pa.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),u={point:function(t,n){e=[t,n]}};return t.invert=function(t){var e=o.scale(),n=o.translate(),r=(t[0]-n[0])/e,i=(t[1]-n[1])/e;return(i>=.12&&i<.234&&r>=-.425&&r<-.214?a:i>=.166&&i<.234&&r>=-.214&&r<-.115?s:o).invert(t)},t.stream=function(t){var e=o.stream(t),n=a.stream(t),r=s.stream(t);return{point:function(t,i){e.point(t,i),n.point(t,i),r.point(t,i)},sphere:function(){e.sphere(),n.sphere(),r.sphere()},lineStart:function(){e.lineStart(),n.lineStart(),r.lineStart()},lineEnd:function(){e.lineEnd(),n.lineEnd(),r.lineEnd()},polygonStart:function(){e.polygonStart(),n.polygonStart(),r.polygonStart()},polygonEnd:function(){e.polygonEnd(),n.polygonEnd(),r.polygonEnd()}}},t.precision=function(e){return arguments.length?(o.precision(e),a.precision(e),s.precision(e),t):o.precision()},t.scale=function(e){return arguments.length?(o.scale(e),a.scale(.35*e),s.scale(e),t.translate(o.translate())):o.scale()},t.translate=function(e){if(!arguments.length)return o.translate();var l=o.scale(),c=+e[0],f=+e[1];return n=o.translate(e).clipExtent([[c-.455*l,f-.238*l],[c+.455*l,f+.238*l]]).stream(u).point,r=a.translate([c-.307*l,f+.201*l]).clipExtent([[c-.425*l+Ha,f+.12*l+Ha],[c-.214*l-Ha,f+.234*l-Ha]]).stream(u).point,i=s.translate([c-.205*l,f+.212*l]).clipExtent([[c-.214*l+Ha,f+.166*l+Ha],[c-.115*l-Ha,f+.234*l-Ha]]).stream(u).point,t},t.scale(1070)};var Vs,Bs,Ws,Ys,Gs,Zs,Xs={point:S,lineStart:S,lineEnd:S,polygonStart:function(){Bs=0,Xs.lineStart=Je},polygonEnd:function(){Xs.lineStart=Xs.lineEnd=Xs.point=S,Vs+=Ea(Bs/2)}},Js={point:Qe,lineStart:S,lineEnd:S,polygonStart:S,polygonEnd:S},Qs={point:en,lineStart:nn,lineEnd:rn,polygonStart:function(){Qs.lineStart=on},polygonEnd:function(){Qs.point=en,Qs.lineStart=nn,Qs.lineEnd=rn}};pa.geo.path=function(){function t(t){return t&&("function"==typeof s&&o.pointRadius(+s.apply(this,arguments)),a&&a.valid||(a=i(o)),pa.geo.stream(t,a)),o.result()}function e(){return a=null,t}var n,r,i,o,a,s=4.5;return t.area=function(t){return Vs=0,pa.geo.stream(t,i(Xs)),Vs},t.centroid=function(t){return Ds=Rs=js=Os=Is=Ps=$s=qs=Hs=0,pa.geo.stream(t,i(Qs)),Hs?[$s/Hs,qs/Hs]:Ps?[Os/Ps,Is/Ps]:js?[Ds/js,Rs/js]:[NaN,NaN]},t.bounds=function(t){return Gs=Zs=-(Ws=Ys=1/0),pa.geo.stream(t,i(Js)),[[Ws,Ys],[Gs,Zs]]},t.projection=function(t){return arguments.length?(i=(n=t)?t.stream||un(t):E,e()):n},t.context=function(t){return arguments.length?(o=null==(r=t)?new Ke:new an(t),"function"!=typeof s&&o.pointRadius(s),e()):r},t.pointRadius=function(e){return arguments.length?(s="function"==typeof e?e:(o.pointRadius(+e),+e),t):s},t.projection(pa.geo.albersUsa()).context(null)},pa.geo.transform=function(t){return{stream:function(e){var n=new ln(e);for(var r in t)n[r]=t[r];return n}}},ln.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},pa.geo.projection=fn,pa.geo.projectionMutator=hn,(pa.geo.equirectangular=function(){return fn(dn)}).raw=dn.invert=dn,pa.geo.rotation=function(t){function e(e){return e=t(e[0]*Wa,e[1]*Wa),e[0]*=Ya,e[1]*=Ya,e}return t=vn(t[0]%360*Wa,t[1]*Wa,t.length>2?t[2]*Wa:0),e.invert=function(e){return e=t.invert(e[0]*Wa,e[1]*Wa),e[0]*=Ya,e[1]*=Ya,e},e},gn.invert=dn,pa.geo.circle=function(){function t(){var t="function"==typeof r?r.apply(this,arguments):r,e=vn(-t[0]*Wa,-t[1]*Wa,0).invert,i=[];return n(null,null,1,{point:function(t,n){i.push(t=e(t,n)),t[0]*=Ya,t[1]*=Ya}}),{type:"Polygon",coordinates:[i]}}var e,n,r=[0,0],i=6;return t.origin=function(e){return arguments.length?(r=e,t):r},t.angle=function(r){return arguments.length?(n=xn((e=+r)*Wa,i*Wa),t):e},t.precision=function(r){return arguments.length?(n=xn(e*Wa,(i=+r)*Wa),t):i},t.angle(90)},pa.geo.distance=function(t,e){var n,r=(e[0]-t[0])*Wa,i=t[1]*Wa,o=e[1]*Wa,a=Math.sin(r),s=Math.cos(r),u=Math.sin(i),l=Math.cos(i),c=Math.sin(o),f=Math.cos(o);return Math.atan2(Math.sqrt((n=f*a)*n+(n=l*c-u*f*s)*n),u*c+l*f*s)},pa.geo.graticule=function(){function t(){return{type:"MultiLineString",coordinates:e()}}function e(){return pa.range(Math.ceil(o/v)*v,i,v).map(h).concat(pa.range(Math.ceil(l/y)*y,u,y).map(p)).concat(pa.range(Math.ceil(r/d)*d,n,d).filter(function(t){return Ea(t%v)>Ha}).map(c)).concat(pa.range(Math.ceil(s/g)*g,a,g).filter(function(t){return Ea(t%y)>Ha}).map(f))}var n,r,i,o,a,s,u,l,c,f,h,p,d=10,g=d,v=90,y=360,m=2.5;return t.lines=function(){return e().map(function(t){return{type:"LineString",coordinates:t}})},t.outline=function(){return{type:"Polygon",coordinates:[h(o).concat(p(u).slice(1),h(i).reverse().slice(1),p(l).reverse().slice(1))]}},t.extent=function(e){return arguments.length?t.majorExtent(e).minorExtent(e):t.minorExtent()},t.majorExtent=function(e){return arguments.length?(o=+e[0][0],i=+e[1][0],l=+e[0][1],u=+e[1][1],o>i&&(e=o,o=i,i=e),l>u&&(e=l,l=u,u=e),t.precision(m)):[[o,l],[i,u]]},t.minorExtent=function(e){return arguments.length?(r=+e[0][0],n=+e[1][0],s=+e[0][1],a=+e[1][1],r>n&&(e=r,r=n,n=e),s>a&&(e=s,s=a,a=e),t.precision(m)):[[r,s],[n,a]]},t.step=function(e){return arguments.length?t.majorStep(e).minorStep(e):t.minorStep()},t.majorStep=function(e){return arguments.length?(v=+e[0],y=+e[1],t):[v,y]},t.minorStep=function(e){return arguments.length?(d=+e[0],g=+e[1],t):[d,g]},t.precision=function(e){return arguments.length?(m=+e,c=Mn(s,a,90),f=En(r,n,m),h=Mn(l,u,90),p=En(o,i,m),t):m},t.majorExtent([[-180,-90+Ha],[180,90-Ha]]).minorExtent([[-180,-80-Ha],[180,80+Ha]])},pa.geo.greatArc=function(){function t(){return{type:"LineString",coordinates:[e||r.apply(this,arguments),n||i.apply(this,arguments)]}}var e,n,r=Tn,i=Cn;return t.distance=function(){return pa.geo.distance(e||r.apply(this,arguments),n||i.apply(this,arguments))},t.source=function(n){return arguments.length?(r=n,e="function"==typeof n?null:n,t):r},t.target=function(e){return arguments.length?(i=e,n="function"==typeof e?null:e,t):i},t.precision=function(){return arguments.length?t:0},t},pa.geo.interpolate=function(t,e){return Sn(t[0]*Wa,t[1]*Wa,e[0]*Wa,e[1]*Wa)},pa.geo.length=function(t){return Ks=0,pa.geo.stream(t,tu),Ks};var Ks,tu={sphere:S,point:S,lineStart:Nn,lineEnd:S,polygonStart:S,polygonEnd:S},eu=kn(function(t){return Math.sqrt(2/(1+t))},function(t){return 2*Math.asin(t/2)});(pa.geo.azimuthalEqualArea=function(){return fn(eu)}).raw=eu;var nu=kn(function(t){var e=Math.acos(t);return e&&e/Math.sin(e)},E);(pa.geo.azimuthalEquidistant=function(){return fn(nu)}).raw=nu,(pa.geo.conicConformal=function(){return Ze(_n)}).raw=_n,(pa.geo.conicEquidistant=function(){return Ze(An)}).raw=An;var ru=kn(function(t){return 1/t},Math.atan);(pa.geo.gnomonic=function(){return fn(ru)}).raw=ru,Ln.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Ba]},(pa.geo.mercator=function(){return Dn(Ln)}).raw=Ln;var iu=kn(function(){return 1},Math.asin);(pa.geo.orthographic=function(){return fn(iu)}).raw=iu;var ou=kn(function(t){return 1/(1+t)},function(t){return 2*Math.atan(t)});(pa.geo.stereographic=function(){return fn(ou)}).raw=ou,Rn.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Ba]},(pa.geo.transverseMercator=function(){var t=Dn(Rn),e=t.center,n=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):(t=e(),[t[1],-t[0]])},t.rotate=function(t){return t?n([t[0],t[1],t.length>2?t[2]+90:90]):(t=n(),[t[0],t[1],t[2]-90])},n([0,0,90])}).raw=Rn,pa.geom={},pa.geom.hull=function(t){function e(t){if(t.length<3)return[];var e,i=Lt(n),o=Lt(r),a=t.length,s=[],u=[];for(e=0;e<a;e++)s.push([+i.call(this,t[e],e),+o.call(this,t[e],e),e]);for(s.sort(Pn),e=0;e<a;e++)u.push([s[e][0],-s[e][1]]);var l=In(s),c=In(u),f=c[0]===l[0],h=c[c.length-1]===l[l.length-1],p=[];for(e=l.length-1;e>=0;--e)p.push(t[s[l[e]][2]]);for(e=+f;e<c.length-h;++e)p.push(t[s[c[e]][2]]);return p}var n=jn,r=On;return arguments.length?e(t):(e.x=function(t){return arguments.length?(n=t,e):n},e.y=function(t){return arguments.length?(r=t,e):r},e)},pa.geom.polygon=function(t){return ka(t,au),t};var au=pa.geom.polygon.prototype=[];au.area=function(){for(var t,e=-1,n=this.length,r=this[n-1],i=0;++e<n;)t=r,r=this[e],i+=t[1]*r[0]-t[0]*r[1];return.5*i},au.centroid=function(t){var e,n,r=-1,i=this.length,o=0,a=0,s=this[i-1];for(arguments.length||(t=-1/(6*this.area()));++r<i;)e=s,s=this[r],n=e[0]*s[1]-s[0]*e[1],o+=(e[0]+s[0])*n,a+=(e[1]+s[1])*n;return[o*t,a*t]},au.clip=function(t){for(var e,n,r,i,o,a,s=Hn(t),u=-1,l=this.length-Hn(this),c=this[l-1];++u<l;){for(e=t.slice(),t.length=0,i=this[u],o=e[(r=e.length-s)-1],n=-1;++n<r;)a=e[n],$n(a,c,i)?($n(o,c,i)||t.push(qn(o,a,c,i)),t.push(a)):$n(o,c,i)&&t.push(qn(o,a,c,i)),o=a;s&&t.push(t[0]),c=i}return t};var su,uu,lu,cu,fu,hu=[],pu=[];Gn.prototype.prepare=function(){for(var t,e=this.edges,n=e.length;n--;)t=e[n].edge,t.b&&t.a||e.splice(n,1);return e.sort(Xn),e.length},ar.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},sr.prototype={insert:function(t,e){var n,r,i;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;n=t}else this._?(t=fr(this._),e.P=null,e.N=t,t.P=t.L=e,n=t):(e.P=e.N=null,this._=e,n=null);for(e.L=e.R=null,e.U=n,e.C=!0,t=e;n&&n.C;)r=n.U,n===r.L?(i=r.R,i&&i.C?(n.C=i.C=!1,r.C=!0,t=r):(t===n.R&&(lr(this,n),t=n,n=t.U),n.C=!1,r.C=!0,cr(this,r))):(i=r.L,i&&i.C?(n.C=i.C=!1,r.C=!0,t=r):(t===n.L&&(cr(this,n),t=n,n=t.U),n.C=!1,r.C=!0,lr(this,r))),n=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,n,r,i=t.U,o=t.L,a=t.R;if(n=o?a?fr(a):o:a,i?i.L===t?i.L=n:i.R=n:this._=n,o&&a?(r=n.C,n.C=t.C,n.L=o,o.U=n,n!==a?(i=n.U,n.U=t.U,t=n.R,i.L=t,n.R=a,a.U=n):(n.U=i,i=n,t=n.R)):(r=t.C,t=n),t&&(t.U=i),!r){if(t&&t.C)return void(t.C=!1);do{if(t===this._)break;if(t===i.L){if(e=i.R,e.C&&(e.C=!1,i.C=!0,lr(this,i),e=i.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,cr(this,e),e=i.R),e.C=i.C,i.C=e.R.C=!1,lr(this,i),t=this._;break}}else if(e=i.L,e.C&&(e.C=!1,i.C=!0,cr(this,i),e=i.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,lr(this,e),e=i.L),e.C=i.C,i.C=e.L.C=!1,cr(this,i),t=this._;break}e.C=!0,t=i,i=i.U}while(!t.C);t&&(t.C=!1)}}},pa.geom.voronoi=function(t){function e(t){var e=new Array(t.length),r=s[0][0],i=s[0][1],o=s[1][0],a=s[1][1];return hr(n(t),s).cells.forEach(function(n,s){var u=n.edges,l=n.site;(e[s]=u.length?u.map(function(t){var e=t.start();return[e.x,e.y]}):l.x>=r&&l.x<=o&&l.y>=i&&l.y<=a?[[r,a],[o,a],[o,i],[r,i]]:[]).point=t[s]}),e}function n(t){return t.map(function(t,e){return{x:Math.round(o(t,e)/Ha)*Ha,y:Math.round(a(t,e)/Ha)*Ha,i:e}})}var r=jn,i=On,o=r,a=i,s=du;return t?e(t):(e.links=function(t){return hr(n(t)).edges.filter(function(t){return t.l&&t.r}).map(function(e){return{source:t[e.l.i],target:t[e.r.i]}})},e.triangles=function(t){var e=[];return hr(n(t)).cells.forEach(function(n,r){for(var i,o=n.site,a=n.edges.sort(Xn),s=-1,u=a.length,l=a[u-1].edge,c=l.l===o?l.r:l.l;++s<u;)l,i=c,l=a[s].edge,c=l.l===o?l.r:l.l,r<i.i&&r<c.i&&dr(o,i,c)<0&&e.push([t[r],t[i.i],t[c.i]])}),e},e.x=function(t){return arguments.length?(o=Lt(r=t),e):r},e.y=function(t){return arguments.length?(a=Lt(i=t),e):i},e.clipExtent=function(t){return arguments.length?(s=null==t?du:t,e):s===du?null:s},e.size=function(t){return arguments.length?e.clipExtent(t&&[[0,0],t]):s===du?null:s&&s[1]},e)};var du=[[-1e6,-1e6],[1e6,1e6]];pa.geom.delaunay=function(t){return pa.geom.voronoi().triangles(t)},pa.geom.quadtree=function(t,e,n,r,i){function o(t){function o(t,e,n,r,i,o,a,s){if(!isNaN(n)&&!isNaN(r))if(t.leaf){var u=t.x,c=t.y;if(null!=u)if(Ea(u-n)+Ea(c-r)<.01)l(t,e,n,r,i,o,a,s);else{var f=t.point;t.x=t.y=t.point=null,l(t,f,u,c,i,o,a,s),l(t,e,n,r,i,o,a,s)}else t.x=n,t.y=r,t.point=e}else l(t,e,n,r,i,o,a,s)}function l(t,e,n,r,i,a,s,u){var l=.5*(i+s),c=.5*(a+u),f=n>=l,h=r>=c,p=h<<1|f;t.leaf=!1,t=t.nodes[p]||(t.nodes[p]=yr()),f?i=l:s=l,h?a=c:u=c,o(t,e,n,r,i,a,s,u)}var c,f,h,p,d,g,v,y,m,b=Lt(s),x=Lt(u);if(null!=e)g=e,v=n,y=r,m=i;else if(y=m=-(g=v=1/0),f=[],h=[],d=t.length,a)for(p=0;p<d;++p)c=t[p],c.x<g&&(g=c.x),c.y<v&&(v=c.y),c.x>y&&(y=c.x),c.y>m&&(m=c.y),f.push(c.x),h.push(c.y);else for(p=0;p<d;++p){var w=+b(c=t[p],p),M=+x(c,p);w<g&&(g=w),M<v&&(v=M),w>y&&(y=w),M>m&&(m=M),f.push(w),h.push(M)}var E=y-g,T=m-v;E>T?m=v+E:y=g+T;var C=yr();if(C.add=function(t){o(C,t,+b(t,++p),+x(t,p),g,v,y,m)},C.visit=function(t){mr(t,C,g,v,y,m)},C.find=function(t){return br(C,t[0],t[1],g,v,y,m)},p=-1,null==e){for(;++p<d;)o(C,t[p],f[p],h[p],g,v,y,m);--p}else t.forEach(C.add);return f=h=t=c=null,C}var a,s=jn,u=On;return(a=arguments.length)?(s=gr,u=vr,3===a&&(i=n,r=e,n=e=0),o(t)):(o.x=function(t){return arguments.length?(s=t,o):s},o.y=function(t){return arguments.length?(u=t,o):u},o.extent=function(t){return arguments.length?(null==t?e=n=r=i=null:(e=+t[0][0],n=+t[0][1],r=+t[1][0],i=+t[1][1]),o):null==e?null:[[e,n],[r,i]]},o.size=function(t){return arguments.length?(null==t?e=n=r=i=null:(e=n=0,r=+t[0],i=+t[1]),o):null==e?null:[r-e,i-n]},o)},pa.interpolateRgb=xr,pa.interpolateObject=wr,pa.interpolateNumber=Mr,pa.interpolateString=Er;var gu=/[-+]?(?:\d+\.?\d*|\.?\d+)(?:[eE][-+]?\d+)?/g,vu=new RegExp(gu.source,"g");pa.interpolate=Tr,pa.interpolators=[function(t,e){var n=typeof e;return("string"===n?us.has(e.toLowerCase())||/^(#|rgb\(|hsl\()/i.test(e)?xr:Er:e instanceof ft?xr:Array.isArray(e)?Cr:"object"===n&&isNaN(e)?wr:Mr)(t,e)}],pa.interpolateArray=Cr;var yu=function(){return E},mu=pa.map({linear:yu,poly:Dr,quad:function(){return _r},cubic:function(){return Ar},sin:function(){return Rr},exp:function(){return jr},circle:function(){return Or},elastic:Ir,back:Pr,bounce:function(){return $r}}),bu=pa.map({in:E,out:Nr,"in-out":kr,"out-in":function(t){return kr(Nr(t))}});pa.ease=function(t){var e=t.indexOf("-"),n=e>=0?t.slice(0,e):t,r=e>=0?t.slice(e+1):"in";return n=mu.get(n)||yu,r=bu.get(r)||E,Sr(r(n.apply(null,da.call(arguments,1))))},pa.interpolateHcl=qr,pa.interpolateHsl=Hr,pa.interpolateLab=Fr,pa.interpolateRound=zr,pa.transform=function(t){var e=va.createElementNS(pa.ns.prefix.svg,"g");return(pa.transform=function(t){if(null!=t){e.setAttribute("transform",t);var n=e.transform.baseVal.consolidate()}return new Ur(n?n.matrix:xu)})(t)},Ur.prototype.toString=function(){return"translate("+this.translate+")rotate("+this.rotate+")skewX("+this.skew+")scale("+this.scale+")"};var xu={a:1,b:0,c:0,d:1,e:0,f:0};pa.interpolateTransform=Qr,pa.layout={},pa.layout.bundle=function(){return function(t){for(var e=[],n=-1,r=t.length;++n<r;)e.push(ei(t[n]));return e}},pa.layout.chord=function(){function t(){var t,l,f,h,p,d={},g=[],v=pa.range(o),y=[];for(n=[],r=[],t=0,h=-1;++h<o;){for(l=0,p=-1;++p<o;)l+=i[h][p];g.push(l),y.push(pa.range(o)),t+=l}for(a&&v.sort(function(t,e){return a(g[t],g[e])}),s&&y.forEach(function(t,e){t.sort(function(t,n){return s(i[e][t],i[e][n])})}),t=(Ua-c*o)/t,l=0,h=-1;++h<o;){for(f=l,p=-1;++p<o;){var m=v[h],b=y[m][p],x=i[m][b],w=l,M=l+=x*t;d[m+"-"+b]={index:m,subindex:b,startAngle:w,endAngle:M,value:x}}r[m]={index:m,startAngle:f,endAngle:l,value:g[m]},l+=c}for(h=-1;++h<o;)for(p=h-1;++p<o;){var E=d[h+"-"+p],T=d[p+"-"+h];(E.value||T.value)&&n.push(E.value<T.value?{source:T,target:E}:{source:E,target:T})}u&&e()}function e(){n.sort(function(t,e){return u((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)})}var n,r,i,o,a,s,u,l={},c=0;return l.matrix=function(t){return arguments.length?(o=(i=t)&&i.length,n=r=null,l):i},l.padding=function(t){return arguments.length?(c=t,n=r=null,l):c},l.sortGroups=function(t){return arguments.length?(a=t,n=r=null,l):a},l.sortSubgroups=function(t){return arguments.length?(s=t,n=null,l):s},l.sortChords=function(t){return arguments.length?(u=t,n&&e(),l):u},l.chords=function(){return n||t(),n},l.groups=function(){return r||t(),r},l},pa.layout.force=function(){function t(t){return function(e,n,r,i){if(e.point!==t){var o=e.cx-t.x,a=e.cy-t.y,s=i-n,u=o*o+a*a;if(s*s/y<u){if(u<g){var l=e.charge/u;t.px-=o*l,t.py-=a*l}return!0}if(e.point&&u&&u<g){var l=e.pointCharge/u;t.px-=o*l,t.py-=a*l}}return!e.charge}}function e(t){t.px=pa.event.x,t.py=pa.event.y,u.resume()}var n,r,i,o,a,s,u={},l=pa.dispatch("start","tick","end"),c=[1,1],f=.9,h=wu,p=Mu,d=-30,g=Eu,v=.1,y=.64,m=[],b=[];return u.tick=function(){if((i*=.99)<.005)return n=null,l.end({type:"end",alpha:i=0}),!0;var e,r,u,h,p,g,y,x,w,M=m.length,E=b.length;for(r=0;r<E;++r)u=b[r],h=u.source,p=u.target,x=p.x-h.x,w=p.y-h.y,(g=x*x+w*w)&&(g=i*a[r]*((g=Math.sqrt(g))-o[r])/g,x*=g,w*=g,p.x-=x*(y=h.weight+p.weight?h.weight/(h.weight+p.weight):.5),p.y-=w*y,h.x+=x*(y=1-y),h.y+=w*y);if((y=i*v)&&(x=c[0]/2,w=c[1]/2,r=-1,y))for(;++r<M;)u=m[r],u.x+=(x-u.x)*y,u.y+=(w-u.y)*y;if(d)for(ui(e=pa.geom.quadtree(m),i,s),r=-1;++r<M;)(u=m[r]).fixed||e.visit(t(u));for(r=-1;++r<M;)u=m[r],u.fixed?(u.x=u.px,u.y=u.py):(u.x-=(u.px-(u.px=u.x))*f,u.y-=(u.py-(u.py=u.y))*f);l.tick({type:"tick",alpha:i})},u.nodes=function(t){return arguments.length?(m=t,u):m},u.links=function(t){return arguments.length?(b=t,u):b},u.size=function(t){return arguments.length?(c=t,u):c},u.linkDistance=function(t){return arguments.length?(h="function"==typeof t?t:+t,u):h},u.distance=u.linkDistance,u.linkStrength=function(t){return arguments.length?(p="function"==typeof t?t:+t,u):p},u.friction=function(t){return arguments.length?(f=+t,u):f},u.charge=function(t){return arguments.length?(d="function"==typeof t?t:+t,u):d},u.chargeDistance=function(t){return arguments.length?(g=t*t,u):Math.sqrt(g)},u.gravity=function(t){return arguments.length?(v=+t,u):v},u.theta=function(t){return arguments.length?(y=t*t,u):Math.sqrt(y)},u.alpha=function(t){return arguments.length?(t=+t,i?t>0?i=t:(n.c=null,n.t=NaN,n=null,l.end({type:"end",alpha:i=0})):t>0&&(l.start({type:"start",alpha:i=t}),n=It(u.tick)),u):i},u.start=function(){function t(t,r){if(!n){for(n=new Array(i),u=0;u<i;++u)n[u]=[];for(u=0;u<l;++u){var o=b[u];n[o.source.index].push(o.target),n[o.target.index].push(o.source)}}for(var a,s=n[e],u=-1,c=s.length;++u<c;)if(!isNaN(a=s[u][t]))return a;return Math.random()*r}var e,n,r,i=m.length,l=b.length,f=c[0],g=c[1];for(e=0;e<i;++e)(r=m[e]).index=e,r.weight=0;for(e=0;e<l;++e)r=b[e],"number"==typeof r.source&&(r.source=m[r.source]),"number"==typeof r.target&&(r.target=m[r.target]),++r.source.weight,++r.target.weight;for(e=0;e<i;++e)r=m[e],isNaN(r.x)&&(r.x=t("x",f)),isNaN(r.y)&&(r.y=t("y",g)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(o=[],"function"==typeof h)for(e=0;e<l;++e)o[e]=+h.call(this,b[e],e);else for(e=0;e<l;++e)o[e]=h;if(a=[],"function"==typeof p)for(e=0;e<l;++e)a[e]=+p.call(this,b[e],e);else for(e=0;e<l;++e)a[e]=p;if(s=[],"function"==typeof d)for(e=0;e<i;++e)s[e]=+d.call(this,m[e],e);else for(e=0;e<i;++e)s[e]=d;return u.resume()},u.resume=function(){return u.alpha(.1)},u.stop=function(){return u.alpha(0)},u.drag=function(){if(r||(r=pa.behavior.drag().origin(E).on("dragstart.force",ii).on("drag.force",e).on("dragend.force",oi)),!arguments.length)return r;this.on("mouseover.force",ai).on("mouseout.force",si).call(r)},pa.rebind(u,l,"on")};var wu=20,Mu=1,Eu=1/0;pa.layout.hierarchy=function(){function t(i){var o,a=[i],s=[];for(i.depth=0;null!=(o=a.pop());)if(s.push(o),(l=n.call(t,o,o.depth))&&(u=l.length)){for(var u,l,c;--u>=0;)a.push(c=l[u]),c.parent=o,c.depth=o.depth+1;r&&(o.value=0),o.children=l}else r&&(o.value=+r.call(t,o,o.depth)||0),delete o.children;return fi(i,function(t){var n,i;e&&(n=t.children)&&n.sort(e),r&&(i=t.parent)&&(i.value+=t.value)}),s}var e=di,n=hi,r=pi;return t.sort=function(n){return arguments.length?(e=n,t):e},t.children=function(e){return arguments.length?(n=e,t):n},t.value=function(e){return arguments.length?(r=e,t):r},t.revalue=function(e){return r&&(ci(e,function(t){t.children&&(t.value=0)}),fi(e,function(e){var n;e.children||(e.value=+r.call(t,e,e.depth)||0),(n=e.parent)&&(n.value+=e.value)})),e},t},pa.layout.partition=function(){function t(e,n,r,i){var o=e.children;if(e.x=n,e.y=e.depth*i,e.dx=r,e.dy=i,o&&(a=o.length)){var a,s,u,l=-1;for(r=e.value?r/e.value:0;++l<a;)t(s=o[l],n,u=s.value*r,i),n+=u}}function e(t){var n=t.children,r=0;if(n&&(i=n.length))for(var i,o=-1;++o<i;)r=Math.max(r,e(n[o]));return 1+r}function n(n,o){var a=r.call(this,n,o);return t(a[0],0,i[0],i[1]/e(a[0])),a}var r=pa.layout.hierarchy(),i=[1,1];return n.size=function(t){return arguments.length?(i=t,n):i},li(n,r)},pa.layout.pie=function(){function t(a){var s,u=a.length,l=a.map(function(n,r){return+e.call(t,n,r)}),c=+("function"==typeof r?r.apply(this,arguments):r),f=("function"==typeof i?i.apply(this,arguments):i)-c,h=Math.min(Math.abs(f)/u,+("function"==typeof o?o.apply(this,arguments):o)),p=h*(f<0?-1:1),d=pa.sum(l),g=d?(f-u*p)/d:0,v=pa.range(u),y=[];return null!=n&&v.sort(n===Tu?function(t,e){return l[e]-l[t]}:function(t,e){return n(a[t],a[e])}),v.forEach(function(t){y[t]={data:a[t],value:s=l[t],startAngle:c,endAngle:c+=s*g+p,padAngle:h}}),y}var e=Number,n=Tu,r=0,i=Ua,o=0;return t.value=function(n){return arguments.length?(e=n,t):e},t.sort=function(e){return arguments.length?(n=e,t):n},t.startAngle=function(e){return arguments.length?(r=e,t):r},t.endAngle=function(e){return arguments.length?(i=e,t):i},t.padAngle=function(e){return arguments.length?(o=e,t):o},t};var Tu={};pa.layout.stack=function(){function t(s,u){if(!(h=s.length))return s;var l=s.map(function(n,r){return e.call(t,n,r)}),c=l.map(function(e){return e.map(function(e,n){return[o.call(t,e,n),a.call(t,e,n)]})}),f=n.call(t,c,u);l=pa.permute(l,f),c=pa.permute(c,f);var h,p,d,g,v=r.call(t,c,u),y=l[0].length;for(d=0;d<y;++d)for(i.call(t,l[0][d],g=v[d],c[0][d][1]),p=1;p<h;++p)i.call(t,l[p][d],g+=c[p-1][d][1],c[p][d][1]);return s}var e=E,n=bi,r=xi,i=mi,o=vi,a=yi;return t.values=function(n){return arguments.length?(e=n,t):e},t.order=function(e){return arguments.length?(n="function"==typeof e?e:Cu.get(e)||bi,t):n},t.offset=function(e){return arguments.length?(r="function"==typeof e?e:Su.get(e)||xi,t):r},t.x=function(e){return arguments.length?(o=e,t):o},t.y=function(e){return arguments.length?(a=e,t):a},t.out=function(e){return arguments.length?(i=e,t):i},t};var Cu=pa.map({"inside-out":function(t){var e,n,r=t.length,i=t.map(wi),o=t.map(Mi),a=pa.range(r).sort(function(t,e){return i[t]-i[e]}),s=0,u=0,l=[],c=[];for(e=0;e<r;++e)n=a[e],s<u?(s+=o[n],l.push(n)):(u+=o[n],c.push(n));return c.reverse().concat(l)},reverse:function(t){return pa.range(t.length).reverse()},default:bi}),Su=pa.map({silhouette:function(t){var e,n,r,i=t.length,o=t[0].length,a=[],s=0,u=[];for(n=0;n<o;++n){for(e=0,r=0;e<i;e++)r+=t[e][n][1];r>s&&(s=r),a.push(r)}for(n=0;n<o;++n)u[n]=(s-a[n])/2;return u},wiggle:function(t){var e,n,r,i,o,a,s,u,l,c=t.length,f=t[0],h=f.length,p=[];for(p[0]=u=l=0,n=1;n<h;++n){for(e=0,i=0;e<c;++e)i+=t[e][n][1];for(e=0,o=0,s=f[n][0]-f[n-1][0];e<c;++e){for(r=0,a=(t[e][n][1]-t[e][n-1][1])/(2*s);r<e;++r)a+=(t[r][n][1]-t[r][n-1][1])/s;o+=a*t[e][n][1]}p[n]=u-=i?o/i*s:0,u<l&&(l=u)}for(n=0;n<h;++n)p[n]-=l;return p},expand:function(t){var e,n,r,i=t.length,o=t[0].length,a=1/i,s=[];for(n=0;n<o;++n){for(e=0,r=0;e<i;e++)r+=t[e][n][1];if(r)for(e=0;e<i;e++)t[e][n][1]/=r;else for(e=0;e<i;e++)t[e][n][1]=a}for(n=0;n<o;++n)s[n]=0;return s},zero:xi});pa.layout.histogram=function(){function t(t,o){for(var a,s,u=[],l=t.map(n,this),c=r.call(this,l,o),f=i.call(this,c,l,o),o=-1,h=l.length,p=f.length-1,d=e?1:1/h;++o<p;)a=u[o]=[],a.dx=f[o+1]-(a.x=f[o]),a.y=0;if(p>0)for(o=-1;++o<h;)(s=l[o])>=c[0]&&s<=c[1]&&(a=u[pa.bisect(f,s,1,p)-1],a.y+=d,a.push(t[o]));return u}var e=!0,n=Number,r=Si,i=Ti;return t.value=function(e){return arguments.length?(n=e,t):n},t.range=function(e){return arguments.length?(r=Lt(e),t):r},t.bins=function(e){return arguments.length?(i="number"==typeof e?function(t){return Ci(t,e)}:Lt(e),t):i},t.frequency=function(n){return arguments.length?(e=!!n,t):e},t},pa.layout.pack=function(){function t(t,o){var a=n.call(this,t,o),s=a[0],u=i[0],l=i[1],c=null==e?Math.sqrt:"function"==typeof e?e:function(){return e};if(s.x=s.y=0,fi(s,function(t){t.r=+c(t.value)}),fi(s,Li),r){var f=r*(e?1:Math.max(2*s.r/u,2*s.r/l))/2;fi(s,function(t){t.r+=f}),fi(s,Li),fi(s,function(t){t.r-=f})}return ji(s,u/2,l/2,e?1:1/Math.max(2*s.r/u,2*s.r/l)),a}var e,n=pa.layout.hierarchy().sort(Ni),r=0,i=[1,1];return t.size=function(e){return arguments.length?(i=e,t):i},t.radius=function(n){return arguments.length?(e=null==n||"function"==typeof n?n:+n,t):e},t.padding=function(e){return arguments.length?(r=+e,t):r},li(t,n)},pa.layout.tree=function(){function t(t,i){var c=a.call(this,t,i),f=c[0],h=e(f);if(fi(h,n),h.parent.m=-h.z,ci(h,r),l)ci(f,o);else{var p=f,d=f,g=f;ci(f,function(t){t.x<p.x&&(p=t),t.x>d.x&&(d=t),t.depth>g.depth&&(g=t)});var v=s(p,d)/2-p.x,y=u[0]/(d.x+s(d,p)/2+v),m=u[1]/(g.depth||1);ci(f,function(t){t.x=(t.x+v)*y,t.y=t.depth*m})}return c}function e(t){for(var e,n={A:null,children:[t]},r=[n];null!=(e=r.pop());)for(var i,o=e.children,a=0,s=o.length;a<s;++a)r.push((o[a]=i={_:o[a],parent:e,children:(i=o[a].children)&&i.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:a}).a=i);return n.children[0]}function n(t){var e=t.children,n=t.parent.children,r=t.i?n[t.i-1]:null;if(e.length){Hi(t);var o=(e[0].z+e[e.length-1].z)/2;r?(t.z=r.z+s(t._,r._),t.m=t.z-o):t.z=o}else r&&(t.z=r.z+s(t._,r._));t.parent.A=i(t,r,t.parent.A||n[0])}function r(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function i(t,e,n){if(e){for(var r,i=t,o=t,a=e,u=i.parent.children[0],l=i.m,c=o.m,f=a.m,h=u.m;a=$i(a),i=Pi(i),a&&i;)u=Pi(u),o=$i(o),o.a=t,r=a.z+f-i.z-l+s(a._,i._),r>0&&(qi(Fi(a,t,n),t,r),l+=r,c+=r),f+=a.m,l+=i.m,h+=u.m,c+=o.m;a&&!$i(o)&&(o.t=a,o.m+=f-c),i&&!Pi(u)&&(u.t=i,u.m+=l-h,n=t)}return n}function o(t){t.x*=u[0],t.y=t.depth*u[1]}var a=pa.layout.hierarchy().sort(null).value(null),s=Ii,u=[1,1],l=null;return t.separation=function(e){return arguments.length?(s=e,t):s},t.size=function(e){return arguments.length?(l=null==(u=e)?o:null,t):l?null:u},t.nodeSize=function(e){return arguments.length?(l=null==(u=e)?null:o,t):l?u:null},li(t,a)},pa.layout.cluster=function(){function t(t,o){var a,s=e.call(this,t,o),u=s[0],l=0;fi(u,function(t){var e=t.children;e&&e.length?(t.x=Ui(e),t.y=zi(e)):(t.x=a?l+=n(t,a):0,t.y=0,a=t)});var c=Vi(u),f=Bi(u),h=c.x-n(c,f)/2,p=f.x+n(f,c)/2;return fi(u,i?function(t){t.x=(t.x-u.x)*r[0],t.y=(u.y-t.y)*r[1]}:function(t){t.x=(t.x-h)/(p-h)*r[0],t.y=(1-(u.y?t.y/u.y:1))*r[1]}),s}var e=pa.layout.hierarchy().sort(null).value(null),n=Ii,r=[1,1],i=!1;return t.separation=function(e){return arguments.length?(n=e,t):n},t.size=function(e){return arguments.length?(i=null==(r=e),t):i?null:r},t.nodeSize=function(e){return arguments.length?(i=null!=(r=e),t):i?r:null},li(t,e)},pa.layout.treemap=function(){function t(t,e){for(var n,r,i=-1,o=t.length;++i<o;)r=(n=t[i]).value*(e<0?0:e),n.area=isNaN(r)||r<=0?0:r}function e(n){var o=n.children;if(o&&o.length){var a,s,u,l=f(n),c=[],h=o.slice(),d=1/0,g="slice"===p?l.dx:"dice"===p?l.dy:"slice-dice"===p?1&n.depth?l.dy:l.dx:Math.min(l.dx,l.dy);for(t(h,l.dx*l.dy/n.value),c.area=0;(u=h.length)>0;)c.push(a=h[u-1]),c.area+=a.area,"squarify"!==p||(s=r(c,g))<=d?(h.pop(),d=s):(c.area-=c.pop().area,i(c,g,l,!1),g=Math.min(l.dx,l.dy),c.length=c.area=0,d=1/0);c.length&&(i(c,g,l,!0),c.length=c.area=0),o.forEach(e)}}function n(e){var r=e.children;if(r&&r.length){var o,a=f(e),s=r.slice(),u=[];for(t(s,a.dx*a.dy/e.value),u.area=0;o=s.pop();)u.push(o),u.area+=o.area,null!=o.z&&(i(u,o.z?a.dx:a.dy,a,!s.length),u.length=u.area=0);r.forEach(n)}}function r(t,e){for(var n,r=t.area,i=0,o=1/0,a=-1,s=t.length;++a<s;)(n=t[a].area)&&(n<o&&(o=n),n>i&&(i=n));return r*=r,e*=e,r?Math.max(e*i*d/r,r/(e*o*d)):1/0}function i(t,e,n,r){var i,o=-1,a=t.length,s=n.x,l=n.y,c=e?u(t.area/e):0;if(e==n.dx){for((r||c>n.dy)&&(c=n.dy);++o<a;)i=t[o],i.x=s,i.y=l,i.dy=c,s+=i.dx=Math.min(n.x+n.dx-s,c?u(i.area/c):0);i.z=!0,i.dx+=n.x+n.dx-s,n.y+=c,n.dy-=c}else{for((r||c>n.dx)&&(c=n.dx);++o<a;)i=t[o],i.x=s,i.y=l,i.dx=c,l+=i.dy=Math.min(n.y+n.dy-l,c?u(i.area/c):0);i.z=!1,i.dy+=n.y+n.dy-l,n.x+=c,n.dx-=c}}function o(r){var i=a||s(r),o=i[0];return o.x=o.y=0,o.value?(o.dx=l[0],o.dy=l[1]):o.dx=o.dy=0,a&&s.revalue(o),t([o],o.dx*o.dy/o.value),(a?n:e)(o),h&&(a=i),i}var a,s=pa.layout.hierarchy(),u=Math.round,l=[1,1],c=null,f=Wi,h=!1,p="squarify",d=.5*(1+Math.sqrt(5));return o.size=function(t){return arguments.length?(l=t,o):l},o.padding=function(t){function e(e){var n=t.call(o,e,e.depth);return null==n?Wi(e):Yi(e,"number"==typeof n?[n,n,n,n]:n)}function n(e){return Yi(e,t)}if(!arguments.length)return c;var r;return f=null==(c=t)?Wi:"function"==(r=typeof t)?e:"number"===r?(t=[t,t,t,t],n):n,o},o.round=function(t){return arguments.length?(u=t?Math.round:Number,o):u!=Number},o.sticky=function(t){return arguments.length?(h=t,a=null,o):h},o.ratio=function(t){return arguments.length?(d=t,o):d},o.mode=function(t){return arguments.length?(p=t+"",o):p},li(o,s)},pa.random={normal:function(t,e){var n=arguments.length;return n<2&&(e=1),n<1&&(t=0),function(){var n,r,i;do{n=2*Math.random()-1,r=2*Math.random()-1,i=n*n+r*r}while(!i||i>1);return t+e*n*Math.sqrt(-2*Math.log(i)/i)}},logNormal:function(){var t=pa.random.normal.apply(pa,arguments);return function(){return Math.exp(t())}},bates:function(t){var e=pa.random.irwinHall(t);return function(){return e()/t}},irwinHall:function(t){return function(){for(var e=0,n=0;n<t;n++)e+=Math.random();return e}}},pa.scale={};var Nu={floor:E,ceil:E};pa.scale.linear=function(){return to([0,1],[0,1],Tr,!1)};var ku={s:1,g:1,p:1,r:1,e:1};pa.scale.log=function(){return uo(pa.scale.linear().domain([0,1]),10,!0,[1,10])};var _u=pa.format(".0e"),Au={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};pa.scale.pow=function(){return lo(pa.scale.linear(),1,[0,1])},pa.scale.sqrt=function(){return pa.scale.pow().exponent(.5)},pa.scale.ordinal=function(){return fo([],{t:"range",a:[[]]})},pa.scale.category10=function(){return pa.scale.ordinal().range(Lu)},pa.scale.category20=function(){return pa.scale.ordinal().range(Du)},pa.scale.category20b=function(){return pa.scale.ordinal().range(Ru)},pa.scale.category20c=function(){return pa.scale.ordinal().range(ju)};var Lu=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(Tt),Du=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(Tt),Ru=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(Tt),ju=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(Tt);pa.scale.quantile=function(){return ho([],[])},pa.scale.quantize=function(){return po(0,1,[0,1])},pa.scale.threshold=function(){return go([.5],[0,1])},pa.scale.identity=function(){return vo([0,1])},pa.svg={},pa.svg.arc=function(){function t(){var t=Math.max(0,+n.apply(this,arguments)),l=Math.max(0,+r.apply(this,arguments)),c=a.apply(this,arguments)-Ba,f=s.apply(this,arguments)-Ba,h=Math.abs(f-c),p=c>f?0:1;if(l<t&&(d=l,l=t,t=d),h>=Va)return e(l,p)+(t?e(t,1-p):"")+"Z";var d,g,v,y,m,b,x,w,M,E,T,C,S=0,N=0,k=[];if((y=(+u.apply(this,arguments)||0)/2)&&(v=o===Ou?Math.sqrt(t*t+l*l):+o.apply(this,arguments),p||(N*=-1),l&&(N=at(v/l*Math.sin(y))),t&&(S=at(v/t*Math.sin(y)))),l){m=l*Math.cos(c+N),b=l*Math.sin(c+N),x=l*Math.cos(f-N),w=l*Math.sin(f-N);var _=Math.abs(f-c-2*N)<=za?0:1;if(N&&Eo(m,b,x,w)===p^_){var A=(c+f)/2;m=l*Math.cos(A),b=l*Math.sin(A),x=w=null}}else m=b=0;if(t){M=t*Math.cos(f-S),E=t*Math.sin(f-S),T=t*Math.cos(c+S),C=t*Math.sin(c+S);var L=Math.abs(c-f+2*S)<=za?0:1;if(S&&Eo(M,E,T,C)===1-p^L){var D=(c+f)/2;M=t*Math.cos(D),E=t*Math.sin(D),T=C=null}}else M=E=0;if(h>Ha&&(d=Math.min(Math.abs(l-t)/2,+i.apply(this,arguments)))>.001){g=t<l^p?0:1;var R=d,j=d;if(h<za){var O=null==T?[M,E]:null==x?[m,b]:qn([m,b],[T,C],[x,w],[M,E]),I=m-O[0],P=b-O[1],$=x-O[0],q=w-O[1],H=1/Math.sin(Math.acos((I*$+P*q)/(Math.sqrt(I*I+P*P)*Math.sqrt($*$+q*q)))/2),F=Math.sqrt(O[0]*O[0]+O[1]*O[1]);j=Math.min(d,(t-F)/(H-1)),R=Math.min(d,(l-F)/(H+1))}if(null!=x){var z=To(null==T?[M,E]:[T,C],[m,b],l,R,p),U=To([x,w],[M,E],l,R,p);d===R?k.push("M",z[0],"A",R,",",R," 0 0,",g," ",z[1],"A",l,",",l," 0 ",1-p^Eo(z[1][0],z[1][1],U[1][0],U[1][1]),",",p," ",U[1],"A",R,",",R," 0 0,",g," ",U[0]):k.push("M",z[0],"A",R,",",R," 0 1,",g," ",U[0])}else k.push("M",m,",",b);if(null!=T){var V=To([m,b],[T,C],t,-j,p),B=To([M,E],null==x?[m,b]:[x,w],t,-j,p);d===j?k.push("L",B[0],"A",j,",",j," 0 0,",g," ",B[1],"A",t,",",t," 0 ",p^Eo(B[1][0],B[1][1],V[1][0],V[1][1]),",",1-p," ",V[1],"A",j,",",j," 0 0,",g," ",V[0]):k.push("L",B[0],"A",j,",",j," 0 0,",g," ",V[0])}else k.push("L",M,",",E)}else k.push("M",m,",",b),null!=x&&k.push("A",l,",",l," 0 ",_,",",p," ",x,",",w),k.push("L",M,",",E),null!=T&&k.push("A",t,",",t," 0 ",L,",",1-p," ",T,",",C);return k.push("Z"),k.join("")}function e(t,e){return"M0,"+t+"A"+t+","+t+" 0 1,"+e+" 0,"+-t+"A"+t+","+t+" 0 1,"+e+" 0,"+t}var n=mo,r=bo,i=yo,o=Ou,a=xo,s=wo,u=Mo;return t.innerRadius=function(e){return arguments.length?(n=Lt(e),t):n},t.outerRadius=function(e){return arguments.length?(r=Lt(e),t):r},t.cornerRadius=function(e){return arguments.length?(i=Lt(e),t):i},t.padRadius=function(e){return arguments.length?(o=e==Ou?Ou:Lt(e),t):o},t.startAngle=function(e){return arguments.length?(a=Lt(e),t):a},t.endAngle=function(e){return arguments.length?(s=Lt(e),t):s},t.padAngle=function(e){return arguments.length?(u=Lt(e),t):u},t.centroid=function(){var t=(+n.apply(this,arguments)+ +r.apply(this,arguments))/2,e=(+a.apply(this,arguments)+ +s.apply(this,arguments))/2-Ba;return[Math.cos(e)*t,Math.sin(e)*t]},t};var Ou="auto";pa.svg.line=function(){return Co(E)};var Iu=pa.map({linear:So,"linear-closed":No,step:ko,"step-before":_o,"step-after":Ao,basis:Io,"basis-open":Po,"basis-closed":$o,bundle:qo,cardinal:Ro,"cardinal-open":Lo,"cardinal-closed":Do,monotone:Bo});Iu.forEach(function(t,e){e.key=t,e.closed=/-closed$/.test(t)});var Pu=[0,2/3,1/3,0],$u=[0,1/3,2/3,0],qu=[0,1/6,2/3,1/6];pa.svg.line.radial=function(){var t=Co(Wo);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},_o.reverse=Ao,Ao.reverse=_o,pa.svg.area=function(){return Yo(E)},pa.svg.area.radial=function(){var t=Yo(Wo);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},pa.svg.chord=function(){function t(t,s){var u=e(this,o,t,s),l=e(this,a,t,s);return"M"+u.p0+r(u.r,u.p1,u.a1-u.a0)+(n(u,l)?i(u.r,u.p1,u.r,u.p0):i(u.r,u.p1,l.r,l.p0)+r(l.r,l.p1,l.a1-l.a0)+i(l.r,l.p1,u.r,u.p0))+"Z"}function e(t,e,n,r){var i=e.call(t,n,r),o=s.call(t,i,r),a=u.call(t,i,r)-Ba,c=l.call(t,i,r)-Ba;return{r:o,a0:a,a1:c,p0:[o*Math.cos(a),o*Math.sin(a)],p1:[o*Math.cos(c),o*Math.sin(c)]}}function n(t,e){return t.a0==e.a0&&t.a1==e.a1}function r(t,e,n){return"A"+t+","+t+" 0 "+ +(n>za)+",1 "+e}function i(t,e,n,r){return"Q 0,0 "+r}var o=Tn,a=Cn,s=Go,u=xo,l=wo;return t.radius=function(e){return arguments.length?(s=Lt(e),t):s},t.source=function(e){return arguments.length?(o=Lt(e),t):o},t.target=function(e){return arguments.length?(a=Lt(e),t):a},t.startAngle=function(e){return arguments.length?(u=Lt(e),t):u},t.endAngle=function(e){return arguments.length?(l=Lt(e),t):l},t},pa.svg.diagonal=function(){function t(t,i){var o=e.call(this,t,i),a=n.call(this,t,i),s=(o.y+a.y)/2,u=[o,{x:o.x,y:s},{x:a.x,y:s},a];return u=u.map(r),"M"+u[0]+"C"+u[1]+" "+u[2]+" "+u[3]}var e=Tn,n=Cn,r=Zo;return t.source=function(n){return arguments.length?(e=Lt(n),t):e},t.target=function(e){return arguments.length?(n=Lt(e),t):n},t.projection=function(e){return arguments.length?(r=e,t):r},t},pa.svg.diagonal.radial=function(){var t=pa.svg.diagonal(),e=Zo,n=t.projection;return t.projection=function(t){return arguments.length?n(Xo(e=t)):e},t},pa.svg.symbol=function(){function t(t,r){return(Hu.get(e.call(this,t,r))||Ko)(n.call(this,t,r))}var e=Qo,n=Jo;return t.type=function(n){return arguments.length?(e=Lt(n),t):e},t.size=function(e){return arguments.length?(n=Lt(e),t):n},t};var Hu=pa.map({circle:Ko,cross:function(t){var e=Math.sqrt(t/5)/2;return"M"+-3*e+","+-e+"H"+-e+"V"+-3*e+"H"+e+"V"+-e+"H"+3*e+"V"+e+"H"+e+"V"+3*e+"H"+-e+"V"+e+"H"+-3*e+"Z"},diamond:function(t){var e=Math.sqrt(t/(2*zu)),n=e*zu;return"M0,"+-e+"L"+n+",0 0,"+e+" "+-n+",0Z"},square:function(t){var e=Math.sqrt(t)/2;return"M"+-e+","+-e+"L"+e+","+-e+" "+e+","+e+" "+-e+","+e+"Z"},"triangle-down":function(t){var e=Math.sqrt(t/Fu),n=e*Fu/2;return"M0,"+n+"L"+e+","+-n+" "+-e+","+-n+"Z"},"triangle-up":function(t){var e=Math.sqrt(t/Fu),n=e*Fu/2;return"M0,"+-n+"L"+e+","+n+" "+-e+","+n+"Z"}});pa.svg.symbolTypes=Hu.keys();var Fu=Math.sqrt(3),zu=Math.tan(30*Wa);Da.transition=function(t){for(var e,n,r=Uu||++Yu,i=ia(t),o=[],a=Vu||{time:Date.now(),ease:Lr,delay:0,duration:250},s=-1,u=this.length;++s<u;){o.push(e=[]);for(var l=this[s],c=-1,f=l.length;++c<f;)(n=l[c])&&oa(n,c,i,r,a),e.push(n)}return ea(o,i,r)},Da.interrupt=function(t){return this.each(null==t?Bu:ta(ia(t)))};var Uu,Vu,Bu=ta(ia()),Wu=[],Yu=0;Wu.call=Da.call,Wu.empty=Da.empty,Wu.node=Da.node,Wu.size=Da.size,pa.transition=function(t,e){return t&&t.transition?Uu?t.transition(e):t:pa.selection().transition(t)},pa.transition.prototype=Wu,Wu.select=function(t){var e,n,r,i=this.id,o=this.namespace,a=[];t=R(t);for(var s=-1,u=this.length;++s<u;){a.push(e=[]);for(var l=this[s],c=-1,f=l.length;++c<f;)(r=l[c])&&(n=t.call(r,r.__data__,c,s))?("__data__"in r&&(n.__data__=r.__data__),oa(n,c,o,i,r[o][i]),e.push(n)):e.push(null)}return ea(a,o,i)},Wu.selectAll=function(t){var e,n,r,i,o,a=this.id,s=this.namespace,u=[];t=j(t);for(var l=-1,c=this.length;++l<c;)for(var f=this[l],h=-1,p=f.length;++h<p;)if(r=f[h]){o=r[s][a],n=t.call(r,r.__data__,h,l),u.push(e=[]);for(var d=-1,g=n.length;++d<g;)(i=n[d])&&oa(i,d,s,a,o),e.push(i)}return ea(u,s,a)},Wu.filter=function(t){var e,n,r,i=[];"function"!=typeof t&&(t=W(t));for(var o=0,a=this.length;o<a;o++){i.push(e=[]);for(var n=this[o],s=0,u=n.length;s<u;s++)(r=n[s])&&t.call(r,r.__data__,s,o)&&e.push(r)}return ea(i,this.namespace,this.id)},Wu.tween=function(t,e){var n=this.id,r=this.namespace;return arguments.length<2?this.node()[r][n].tween.get(t):G(this,null==e?function(e){e[r][n].tween.remove(t)}:function(i){i[r][n].tween.set(t,e)})},Wu.attr=function(t,e){function n(){this.removeAttribute(s)}function r(){this.removeAttributeNS(s.space,s.local)}function i(t){return null==t?n:(t+="",function(){var e,n=this.getAttribute(s);return n!==t&&(e=a(n,t),function(t){this.setAttribute(s,e(t))})})}function o(t){return null==t?r:(t+="",function(){var e,n=this.getAttributeNS(s.space,s.local);return n!==t&&(e=a(n,t),function(t){this.setAttributeNS(s.space,s.local,e(t))})})}if(arguments.length<2){for(e in t)this.attr(e,t[e]);return this}var a="transform"==t?Qr:Tr,s=pa.ns.qualify(t);return na(this,"attr."+t,e,s.local?o:i)},Wu.attrTween=function(t,e){function n(t,n){var r=e.call(this,t,n,this.getAttribute(i));return r&&function(t){this.setAttribute(i,r(t))}}function r(t,n){var r=e.call(this,t,n,this.getAttributeNS(i.space,i.local));return r&&function(t){this.setAttributeNS(i.space,i.local,r(t))}}var i=pa.ns.qualify(t);return this.tween("attr."+t,i.local?r:n)},Wu.style=function(t,e,n){function r(){this.style.removeProperty(t)}function i(e){return null==e?r:(e+="",function(){var r,i=a(this).getComputedStyle(this,null).getPropertyValue(t);return i!==e&&(r=Tr(i,e),function(e){this.style.setProperty(t,r(e),n)})})}var o=arguments.length;if(o<3){if("string"!=typeof t){o<2&&(e="");for(n in t)this.style(n,t[n],e);return this}n=""}return na(this,"style."+t,e,i)},Wu.styleTween=function(t,e,n){function r(r,i){var o=e.call(this,r,i,a(this).getComputedStyle(this,null).getPropertyValue(t));return o&&function(e){this.style.setProperty(t,o(e),n)}}return arguments.length<3&&(n=""),this.tween("style."+t,r)},Wu.text=function(t){return na(this,"text",t,ra)},Wu.remove=function(){var t=this.namespace;return this.each("end.transition",function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)})},Wu.ease=function(t){var e=this.id,n=this.namespace;return arguments.length<1?this.node()[n][e].ease:("function"!=typeof t&&(t=pa.ease.apply(pa,arguments)),G(this,function(r){r[n][e].ease=t}))},Wu.delay=function(t){var e=this.id,n=this.namespace;return arguments.length<1?this.node()[n][e].delay:G(this,"function"==typeof t?function(r,i,o){r[n][e].delay=+t.call(r,r.__data__,i,o)}:(t=+t,function(r){r[n][e].delay=t}))},Wu.duration=function(t){var e=this.id,n=this.namespace;return arguments.length<1?this.node()[n][e].duration:G(this,"function"==typeof t?function(r,i,o){r[n][e].duration=Math.max(1,t.call(r,r.__data__,i,o))}:(t=Math.max(1,t),function(r){r[n][e].duration=t}))},Wu.each=function(t,e){var n=this.id,r=this.namespace;if(arguments.length<2){var i=Vu,o=Uu;try{Uu=n,G(this,function(e,i,o){Vu=e[r][n],t.call(e,e.__data__,i,o)})}finally{Vu=i,Uu=o}}else G(this,function(i){var o=i[r][n];(o.event||(o.event=pa.dispatch("start","end","interrupt"))).on(t,e)});return this},Wu.transition=function(){for(var t,e,n,r,i=this.id,o=++Yu,a=this.namespace,s=[],u=0,l=this.length;u<l;u++){s.push(t=[]);for(var e=this[u],c=0,f=e.length;c<f;c++)(n=e[c])&&(r=n[a][i],oa(n,c,a,o,{time:r.time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration})),t.push(n)}return ea(s,a,o)},pa.svg.axis=function(){function t(t){t.each(function(){var t,l=pa.select(this),c=this.__chart__||n,f=this.__chart__=n.copy(),h=null==u?f.ticks?f.ticks.apply(f,s):f.domain():u,p=null==e?f.tickFormat?f.tickFormat.apply(f,s):E:e,d=l.selectAll(".tick").data(h,f),g=d.enter().insert("g",".domain").attr("class","tick").style("opacity",Ha),v=pa.transition(d.exit()).style("opacity",Ha).remove(),y=pa.transition(d.order()).style("opacity",1),m=Math.max(i,0)+a,b=Zi(f),x=l.selectAll(".domain").data([0]),w=(x.enter().append("path").attr("class","domain"),pa.transition(x));g.append("line"),g.append("text");var M,T,C,S,N=g.select("line"),k=y.select("line"),_=d.select("text").text(p),A=g.select("text"),L=y.select("text"),D="top"===r||"left"===r?-1:1;if("bottom"===r||"top"===r?(t=aa,M="x",C="y",T="x2",S="y2",_.attr("dy",D<0?"0em":".71em").style("text-anchor","middle"),w.attr("d","M"+b[0]+","+D*o+"V0H"+b[1]+"V"+D*o)):(t=sa,M="y",C="x",T="y2",S="x2",_.attr("dy",".32em").style("text-anchor",D<0?"end":"start"),w.attr("d","M"+D*o+","+b[0]+"H0V"+b[1]+"H"+D*o)),N.attr(S,D*i),A.attr(C,D*m),k.attr(T,0).attr(S,D*i),L.attr(M,0).attr(C,D*m),f.rangeBand){var R=f,j=R.rangeBand()/2;c=f=function(t){return R(t)+j}}else c.rangeBand?c=f:v.call(t,f,c);g.call(t,c,f),y.call(t,f,f)})}var e,n=pa.scale.linear(),r=Gu,i=6,o=6,a=3,s=[10],u=null;return t.scale=function(e){return arguments.length?(n=e,t):n},t.orient=function(e){return arguments.length?(r=e in Zu?e+"":Gu,t):r},t.ticks=function(){return arguments.length?(s=ga(arguments),t):s},t.tickValues=function(e){return arguments.length?(u=e,t):u},t.tickFormat=function(n){return arguments.length?(e=n,t):e},t.tickSize=function(e){var n=arguments.length;return n?(i=+e,o=+arguments[n-1],t):i},t.innerTickSize=function(e){return arguments.length?(i=+e,t):i},t.outerTickSize=function(e){return arguments.length?(o=+e,t):o},t.tickPadding=function(e){return arguments.length?(a=+e,t):a},t.tickSubdivide=function(){return arguments.length&&t},t};var Gu="bottom",Zu={top:1,right:1,bottom:1,left:1};pa.svg.brush=function(){function t(o){o.each(function(){var o=pa.select(this).style("pointer-events","all").style("-webkit-tap-highlight-color","rgba(0,0,0,0)").on("mousedown.brush",i).on("touchstart.brush",i),a=o.selectAll(".background").data([0]);a.enter().append("rect").attr("class","background").style("visibility","hidden").style("cursor","crosshair"),o.selectAll(".extent").data([0]).enter().append("rect").attr("class","extent").style("cursor","move");var s=o.selectAll(".resize").data(g,E);s.exit().remove(),s.enter().append("g").attr("class",function(t){return"resize "+t}).style("cursor",function(t){return Xu[t]}).append("rect").attr("x",function(t){return/[ew]$/.test(t)?-3:null}).attr("y",function(t){return/^[ns]/.test(t)?-3:null}).attr("width",6).attr("height",6).style("visibility","hidden"),s.style("display",t.empty()?"none":null);var u,f=pa.transition(o),h=pa.transition(a);l&&(u=Zi(l),h.attr("x",u[0]).attr("width",u[1]-u[0]),n(f)),c&&(u=Zi(c),h.attr("y",u[0]).attr("height",u[1]-u[0]),r(f)),e(f)})}function e(t){t.selectAll(".resize").attr("transform",function(t){return"translate("+f[+/e$/.test(t)]+","+h[+/^s/.test(t)]+")"})}function n(t){t.select(".extent").attr("x",f[0]),t.selectAll(".extent,.n>rect,.s>rect").attr("width",f[1]-f[0])}function r(t){t.select(".extent").attr("y",h[0]),t.selectAll(".extent,.e>rect,.w>rect").attr("height",h[1]-h[0])}function i(){function i(){32==pa.event.keyCode&&(k||(b=null,L[0]-=f[1],L[1]-=h[1],k=2),_())}function g(){32==pa.event.keyCode&&2==k&&(L[0]+=f[1],L[1]+=h[1],k=0,_())}function v(){var t=pa.mouse(w),i=!1;x&&(t[0]+=x[0],t[1]+=x[1]),k||(pa.event.altKey?(b||(b=[(f[0]+f[1])/2,(h[0]+h[1])/2]),L[0]=f[+(t[0]<b[0])],L[1]=h[+(t[1]<b[1])]):b=null),S&&y(t,l,0)&&(n(T),i=!0),N&&y(t,c,1)&&(r(T),i=!0),i&&(e(T),E({type:"brush",mode:k?"move":"resize"}))}function y(t,e,n){var r,i,a=Zi(e),u=a[0],l=a[1],c=L[n],g=n?h:f,v=g[1]-g[0];if(k&&(u-=c,l-=v+c),r=(n?d:p)?Math.max(u,Math.min(l,t[n])):t[n],k?i=(r+=c)+v:(b&&(c=Math.max(u,Math.min(l,2*b[n]-r))),c<r?(i=r,r=c):i=c),g[0]!=r||g[1]!=i)return n?s=null:o=null,g[0]=r,g[1]=i,!0}function m(){v(),T.style("pointer-events","all").selectAll(".resize").style("display",t.empty()?"none":null),pa.select("body").style("cursor",null),D.on("mousemove.brush",null).on("mouseup.brush",null).on("touchmove.brush",null).on("touchend.brush",null).on("keydown.brush",null).on("keyup.brush",null),A(),E({type:"brushend"})}var b,x,w=this,M=pa.select(pa.event.target),E=u.of(w,arguments),T=pa.select(w),C=M.datum(),S=!/^(n|s)$/.test(C)&&l,N=!/^(e|w)$/.test(C)&&c,k=M.classed("extent"),A=tt(w),L=pa.mouse(w),D=pa.select(a(w)).on("keydown.brush",i).on("keyup.brush",g);if(pa.event.changedTouches?D.on("touchmove.brush",v).on("touchend.brush",m):D.on("mousemove.brush",v).on("mouseup.brush",m),T.interrupt().selectAll("*").interrupt(),k)L[0]=f[0]-L[0],L[1]=h[0]-L[1];else if(C){var R=+/w$/.test(C),j=+/^n/.test(C);x=[f[1-R]-L[0],h[1-j]-L[1]],L[0]=f[R],L[1]=h[j]}else pa.event.altKey&&(b=L.slice());T.style("pointer-events","none").selectAll(".resize").style("display",null),pa.select("body").style("cursor",M.style("cursor")),E({type:"brushstart"}),v()}var o,s,u=L(t,"brushstart","brush","brushend"),l=null,c=null,f=[0,0],h=[0,0],p=!0,d=!0,g=Ju[0];return t.event=function(t){t.each(function(){var t=u.of(this,arguments),e={x:f,y:h,i:o,j:s},n=this.__chart__||e;this.__chart__=e,Uu?pa.select(this).transition().each("start.brush",function(){o=n.i,s=n.j,f=n.x,h=n.y,t({type:"brushstart"})}).tween("brush:brush",function(){var n=Cr(f,e.x),r=Cr(h,e.y);return o=s=null,function(i){f=e.x=n(i),h=e.y=r(i),t({type:"brush",mode:"resize"})}}).each("end.brush",function(){o=e.i,s=e.j,t({type:"brush",mode:"resize"}),t({type:"brushend"})}):(t({type:"brushstart"}),t({type:"brush",mode:"resize"}),t({type:"brushend"}))})},t.x=function(e){return arguments.length?(l=e,g=Ju[!l<<1|!c],t):l},t.y=function(e){return arguments.length?(c=e,g=Ju[!l<<1|!c],t):c},t.clamp=function(e){return arguments.length?(l&&c?(p=!!e[0],d=!!e[1]):l?p=!!e:c&&(d=!!e),t):l&&c?[p,d]:l?p:c?d:null},t.extent=function(e){var n,r,i,a,u;return arguments.length?(l&&(n=e[0],r=e[1],c&&(n=n[0],r=r[0]),o=[n,r],l.invert&&(n=l(n),r=l(r)),r<n&&(u=n,n=r,r=u),n==f[0]&&r==f[1]||(f=[n,r])),c&&(i=e[0],a=e[1],l&&(i=i[1],a=a[1]),s=[i,a],c.invert&&(i=c(i),a=c(a)),a<i&&(u=i,i=a,a=u),i==h[0]&&a==h[1]||(h=[i,a])),t):(l&&(o?(n=o[0],r=o[1]):(n=f[0],r=f[1],l.invert&&(n=l.invert(n),r=l.invert(r)),r<n&&(u=n,n=r,r=u))),c&&(s?(i=s[0],a=s[1]):(i=h[0],a=h[1],c.invert&&(i=c.invert(i),a=c.invert(a)),a<i&&(u=i,i=a,a=u))),l&&c?[[n,i],[r,a]]:l?[n,r]:c&&[i,a])},t.clear=function(){return t.empty()||(f=[0,0],h=[0,0],o=s=null),t},t.empty=function(){return!!l&&f[0]==f[1]||!!c&&h[0]==h[1]},pa.rebind(t,u,"on")};var Xu={n:"ns-resize",e:"ew-resize",s:"ns-resize",w:"ew-resize",nw:"nwse-resize",ne:"nesw-resize",se:"nwse-resize",sw:"nesw-resize"},Ju=[["n","e","s","w","nw","ne","se","sw"],["e","w"],["n","s"],[]],Qu=ys.format=Es.timeFormat,Ku=Qu.utc,tl=Ku("%Y-%m-%dT%H:%M:%S.%LZ");Qu.iso=Date.prototype.toISOString&&+new Date("2000-01-01T00:00:00.000Z")?ua:tl,ua.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},ua.toString=tl.toString,ys.second=Bt(function(t){return new ms(1e3*Math.floor(t/1e3))},function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))},function(t){return t.getSeconds()}),ys.seconds=ys.second.range,ys.seconds.utc=ys.second.utc.range,ys.minute=Bt(function(t){return new ms(6e4*Math.floor(t/6e4))},function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))},function(t){return t.getMinutes()}),ys.minutes=ys.minute.range,ys.minutes.utc=ys.minute.utc.range,ys.hour=Bt(function(t){var e=t.getTimezoneOffset()/60;return new ms(36e5*(Math.floor(t/36e5-e)+e))},function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))},function(t){return t.getHours()}),ys.hours=ys.hour.range,ys.hours.utc=ys.hour.utc.range,ys.month=Bt(function(t){return t=ys.day(t),t.setDate(1),t},function(t,e){t.setMonth(t.getMonth()+e)},function(t){return t.getMonth()}),ys.months=ys.month.range,ys.months.utc=ys.month.utc.range;var el=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],nl=[[ys.second,1],[ys.second,5],[ys.second,15],[ys.second,30],[ys.minute,1],[ys.minute,5],[ys.minute,15],[ys.minute,30],[ys.hour,1],[ys.hour,3],[ys.hour,6],[ys.hour,12],[ys.day,1],[ys.day,2],[ys.week,1],[ys.month,1],[ys.month,3],[ys.year,1]],rl=Qu.multi([[".%L",function(t){return t.getMilliseconds()}],[":%S",function(t){return t.getSeconds()}],["%I:%M",function(t){return t.getMinutes()}],["%I %p",function(t){return t.getHours()}],["%a %d",function(t){return t.getDay()&&1!=t.getDate()}],["%b %d",function(t){return 1!=t.getDate()}],["%B",function(t){return t.getMonth()}],["%Y",je]]),il={range:function(t,e,n){return pa.range(Math.ceil(t/n)*n,+e,n).map(ca)},floor:E,ceil:E};nl.year=ys.year,ys.scale=function(){return la(pa.scale.linear(),nl,rl)};var ol=nl.map(function(t){return[t[0].utc,t[1]]}),al=Ku.multi([[".%L",function(t){return t.getUTCMilliseconds()}],[":%S",function(t){return t.getUTCSeconds()}],["%I:%M",function(t){return t.getUTCMinutes()}],["%I %p",function(t){return t.getUTCHours()}],["%a %d",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],["%b %d",function(t){return 1!=t.getUTCDate()}],["%B",function(t){return t.getUTCMonth()}],["%Y",je]]);ol.year=ys.year.utc,ys.scale.utc=function(){return la(pa.scale.linear(),ol,al)},pa.text=Dt(function(t){return t.responseText}),pa.json=function(t,e){return Rt(t,"application/json",fa,e)},pa.html=function(t,e){return Rt(t,"text/html",ha,e)},pa.xml=Dt(function(t){return t.responseXML}),this.d3=pa,r=pa,void 0!==(i="function"==typeof r?r.call(e,n,e,t):r)&&(t.exports=i)}()},function(t,e,n){"use strict";n.d(e,"a",function(){return r});var r=function(){function t(){}return t.VIEW="malevoView",t.EVENT_RESIZE="eventResize",t.EVENT_TIMELINE_CHANGED="eventTimelineChanged",t.CHART_VIEW="chartView",t.IMAGE_VIEW="imageView",t.SOFTMAX_STAMP_VIEW="softmaxStampView",t.EVENT_DATA_SET_ADDED="eventDataSetAdded",t.EVENT_DATA_SET_REMOVED="eventDataSetRemoved",t.CLEAR_CONF_MEASURES_VIEW="clearConfMeasuresView",t.EVENT_REDRAW="eventRedraw",t.EVENT_CELL_SELECTED="eventCellSelected",t.EVENT_CLEAR_DETAIL_CHART="eventClarDetailChart",t.EVENT_WEIGHT_FACTOR_CHANGED="eventWeightFactorChanged",t.EVENT_CELL_RENDERER_TRANSPOSED="eventCellRendererTransposed",t.EVENT_CELL_RENDERER_CHANGED="eventCellRendererChanged",t.EVENT_SWITCH_SCALE_TO_ABSOLUTE="eventSwitchScaleToAbsolute",t.EVENT_CLASS_INDICES_CHANGED="eventClassIndicesChanged",t.EVENT_MATRIX_CELL_HOVERED="eventMatrixCellHovered",t.EVENT_RENDER_CONF_MEASURE="eventRenderConfMeasure",t.EVENT_LOADING_COMPLETE="eventLoadingComplete",t.CELL_FP="cellFP",t.CELL_FN="cellFN",t.CELL_PRECISION="cellPrecision",t.CELL_RECALL="cellRecall",t.CELL_F1_SCORE="cellF1Score",t.CELL_OVERALL_ACCURACY_SCORE="overallPrecisionScore",t.CELL_CLASS_SIZE="cellClassSize",t.MAX_DATASET_COUNT=4,t.CONF_MATRIX_SIZE=10,t.TML_HEIGHT=35,t.BG_COLOR_SCALE=["white","gray"],t.COLOR_GRAY="#D3D3D3",t}()},function(t,e,n){"use strict";function r(t){if(t.ok)return t;throw new b(t)}function i(t,e){switch(t.trim().toLowerCase()){case"json":case"application/json":return e.json();case"text":case"text/plain":return e.text();case"blob":return e.blob();case"arraybuffer":return e.arrayBuffer();default:throw new b(e,'unknown expected data type: "'+t+'"')}}function o(t,e,o,a,s){return void 0===e&&(e={}),void 0===o&&(o="GET"),void 0===a&&(a="json"),void 0===s&&(s="formdata"),d.a(this,void 0,void 0,function(){var u,c,f,h,p;return d.b(this,function(d){switch(d.label){case 0:if(o=o.toUpperCase(),"GET"!==o&&"HEAD"!==o||(e=l(e))&&(t+=(/\?/.test(t)?"&":"?")+e,e=null),u={credentials:"same-origin",method:o,headers:{Accept:"application/json"}},e){switch(c="",s.trim().toLowerCase()){case"json":case"application/json":c="application/json",u.body="string"==typeof e?e:JSON.stringify(e);break;case"text":case"text/plain":c="text/plain",u.body=String(e);break;case"blob":case"arraybuffer":c="application/octet-stream",u.body=e;break;default:e instanceof FormData?u.body=e:(c="application/x-www-form-urlencoded",u.body=l(e))}c&&(u.headers["Content-Type"]=c)}return n.i(v.a)(y,t,u),h=r,[4,self.fetch(t,u)];case 1:return f=h.apply(void 0,[d.sent()]),p=i(a,f),n.i(v.a)(m,t,u,f,p),[2,p]}})})}function a(t,e){return void 0===e&&(e={}),o(t,e)}function s(t,e,n){return void 0===e&&(e={}),void 0===n&&(n="json"),o(t,e,"GET",n)}function u(t,e){return void 0===e&&(e=null),t=""+g.d+t+g.e,e=l(e),e&&(t+=(/\?/.test(t)?"&":"?")+e),t}function l(t){function e(t,n,i){Array.isArray(i)?i.forEach(function(r,i){"object"==typeof r?e(t,n+"["+i+"]",r):e(t,n+"[]",r)}):null==i||("object"==typeof i?Object.keys(i).forEach(function(r){e(t,n+"["+r+"]",i[r])}):r.push(encodeURIComponent(t+n)+"="+encodeURIComponent(i)))}if(void 0===t&&(t=null),null===t)return null;if("string"==typeof t)return encodeURIComponent(t);var n=Object.keys(t);if(0===n.length)return null;var r=[];return n.forEach(function(n){e("",n,t[n])}),r.join("&").replace(/%20/g,"+")}function c(t,e,n){return Promise.resolve("function"==typeof t?t(n,e):t)}function f(t,e,n,r,i){return void 0===e&&(e={}),void 0===n&&(n="GET"),void 0===r&&(r="json"),void 0===i&&(i=x),g.c?c(i,t,e):o(u(t),e,n,r)}function h(t,e,n){return void 0===e&&(e={}),void 0===n&&(n=x),g.c?c(n,t,e):a(u(t),e)}function p(t,e,n,r){return void 0===e&&(e={}),void 0===n&&(n="json"),void 0===r&&(r=function(){return x}),g.c?c(r,t,e):s(u(t),e,n)}var d=n(0),g=n(1),v=n(3);e.d=u,e.b=f,e.a=h,e.c=p;var y="ajaxPreSend",m="ajaxPostSend",b=function(t){function e(n,r){var i=t.call(this,r||n.statusText)||this;return i.response=n,Object.setPrototypeOf(i,e.prototype),i}return d.c(e,t),e}(Error),x=function(){return Promise.reject("offline")}},function(t,e,n){"use strict";function r(t,e){function n(){this.constructor=t}a(t,e),t.prototype=null===e?Object.create(e):(n.prototype=e.prototype,new n)}function i(t,e,n,r){return new(n||(n=Promise))(function(i,o){function a(t){try{u(r.next(t))}catch(t){o(t)}}function s(t){try{u(r.throw(t))}catch(t){o(t)}}function u(t){t.done?i(t.value):new n(function(e){e(t.value)}).then(a,s)}u((r=r.apply(t,e||[])).next())})}function o(t,e){function n(t){return function(e){return r([t,e])}}function r(n){if(i)throw new TypeError("Generator is already executing.");for(;s;)try{if(i=1,o&&(a=o[2&n[0]?"return":n[0]?"throw":"next"])&&!(a=a.call(o,n[1])).done)return a;switch(o=0,a&&(n=[0,a.value]),n[0]){case 0:case 1:a=n;break;case 4:return s.label++,{value:n[1],done:!1};case 5:s.label++,o=n[1],n=[0];continue;case 7:n=s.ops.pop(),s.trys.pop();continue;default:if(a=s.trys,!(a=a.length>0&&a[a.length-1])&&(6===n[0]||2===n[0])){s=0;continue}if(3===n[0]&&(!a||n[1]>a[0]&&n[1]<a[3])){s.label=n[1];break}if(6===n[0]&&s.label<a[1]){s.label=a[1],a=n;break}if(a&&s.label<a[2]){s.label=a[2],s.ops.push(n);break}a[2]&&s.ops.pop(),s.trys.pop();continue}n=e.call(t,s)}catch(t){n=[6,t],o=0}finally{i=a=0}if(5&n[0])throw n[1];return{value:n[0]?n[1]:void 0,done:!0}}var i,o,a,s={label:0,sent:function(){if(1&a[0])throw a[1];return a[1]},trys:[],ops:[]};return{next:n(0),throw:n(1),return:n(2)}}e.c=r,e.a=i,e.b=o;/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */
var a=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(t,e){t.__proto__=e}||function(t,e){for(var n in e)e.hasOwnProperty(n)&&(t[n]=e[n])};Object.assign},function(t,e,n){"use strict";function r(t){return t instanceof Promise||t&&"function"==typeof t.then?t:new i(t)}e.a=r;var i=function(){function t(t){this.v=t}return t.prototype.then=function(t,e){return r(t(this.v))},t}()},function(t,e,n){"use strict";n.d(e,"a",function(){return r});var r=function(){function t(){}return t.APP_NAME="ConfusionFlow",t.DATASET_SELECTOR_PLACEHOLDER="Select a Performance Log",t.GROUND_TRUTH="Ground Truth",t.PREDICTED="Predicted",t.FN="FN",t.FP="FP",t.PRECISION="Precision",t.RECALL="Recall",t.F1_SCORE="F1 Score",t.CLASS_SIZE="Class Size",t.CHART_VIEW="Charts",t.CLASS_LABELS="Class Labels",t.EPOCH="Epoch",t.GIVEN="given",t.RUNS="Runs",t.NUMBER="#",t.PERCENT="%",t.CONFUSION_Y_LABEL="of Confused Instances",t.PRECISION_Y_LABEL="Precision [%]",t.RECALL_Y_LABEL="Recall [%]",t.F1_SCORE_Y_LABEL="F1 Score [%]",t.OVERALL_ACCURACY="Overall Accuracy",t.FP_NUM="# False Positives",t.FP_RATE="False Positive Rate",t.FP_RATES="False Positive Rates",t.FN_NUM="# False Negatives",t.FN_RATE="False Negative Rate",t.FN_RATES="False Negative Rates",t.FOR_ALLCLASS="for all classes",t.FOR_CLASS="for class",t.PREDICTED_AS="predicted as",t.SELECT_CLASSES="Select classes",t.APPLY="Apply",t}()},function(t,e,n){"use strict";var r=function(){function t(){this.counter=0,this.free=[]}return t.prototype.checkOut=function(){return 0===this.free.length?this.counter++:this.free.shift()},t.prototype.checkIn=function(t){t===this.counter-1?this.counter--:this.free.push(t)},t.prototype.isCheckedOut=function(t){return t<this.counter&&this.free.indexOf(t)<0},Object.defineProperty(t.prototype,"size",{get:function(){return this.counter-this.free.length},enumerable:!0,configurable:!0}),t}();e.a=r},function(t,e,n){"use strict";function r(t){for(var e=[],n=t;n;)e.push(n),n=n.parentNode;return e.reverse()}var i=function(){function t(t){var e=this;this.parent=t,this.observer=new MutationObserver(function(t){return e.onChange(t)}),this.observed=new Map,this.enabled=!1}return t.prototype.enable=function(){this.enabled=!0,this.observer.observe(this.parent,{childList:!0,subtree:!0})},t.prototype.disable=function(){this.enabled=!1,this.observer.disconnect()},t.prototype.onChange=function(t){var e=this,n=t.filter(function(t){return"childList"===t.type&&t.removedNodes.length>0});if(0!==n.length&&0!==this.observed.size){var i=Array.from(this.observed.entries()).map(function(t){var e=t[0];return{node:e,callback:t[1],parents:r(e)}}),o=function(t){return i.length===t.length?(e.observed.clear(),e.disable(),!0):(t.forEach(function(t){var n=i.splice(t,1)[0];e.observed.delete(n.node)}),!1)},a=[];if(i.forEach(function(t,n){var r=t.node,i=t.parents,o=t.callback;i.indexOf(e.parent)<0&&(o(r),a.unshift(n))}),!o(a))for(var s=function(t){var e=t.target,n=new Set(Array.from(t.removedNodes)),r=[];if(i.forEach(function(t,i){var o=t.node,a=t.callback,s=t.parents,u=s.indexOf(e);if(!(u<0)){var l=s[u+1];n.has(l)&&(a(o),r.unshift(i))}}),o(r))return{value:void 0}},u=0,l=n;u<l.length;u++){var c=l[u],f=s(c);if("object"==typeof f)return f.value}}},t.prototype.observe=function(t,e,n){this.observed.set(t,e.bind(n)),this.enabled||this.enable()},t}(),o=function(){function t(){this.documents=new WeakMap}return t.prototype.observe=function(t,e,n){var r=t.ownerDocument.body,o=this.documents.get(r);o||(o=new i(r),this.documents.set(r,o)),o.observe(t,e,n)},t}();e.a=o},function(t,e,n){"use strict";function r(t){return Array.apply(null,{length:t}).map(Number.call,Number)}function i(t,e,n){return r(t.length).sort(function(r,i){return e.call(n,t[r],t[i])})}function o(t,e,n){return r(t.length).filter(function(r,i){return e.call(n,t[r],i)})}e.b=i,e.a=o},function(t,e,n){"use strict";n(7),new Map},function(t,e,n){"use strict";var r=n(8),i=(n.n(r),n(10));n.n(i)},function(t,e,n){"use strict";var r=n(33);n.n(r)},function(t,e,n){"use strict";function r(){return Promise.all([Promise.resolve().then(n.bind(null,10)),Promise.resolve().then(n.bind(null,5))]).then(function(t){return t[1]})}var i=n(8);n.n(i);e.a=r},function(t,e,n){"use strict";function r(){return Promise.all([self.fetch("./buildInfo.json").then(function(t){return t.json()}),o.c?null:n.i(i.a)("/buildInfo.json")]).then(function(t){return new a(t[0],t[1])})}var i=n(17),o=n(1);e.a=r;var a=function(){function t(t,e){this.client=t,this.server=e}return t.prototype.toString=function(){return"BuildInfo"},t.prototype.buildBuildInfo=function(){var t=this.client;return'<table class="table table-bordered table-condensed">\n            <tbody>\n              <tr><th>Application</th><td>'+t.name+"</td></tr>\n              <tr><th>Version</th><td>"+t.version+"</td></tr>\n              "+(this.server?"<tr><th>Server</th><td>"+this.server.version+"</td></tr>":"")+"\n              <tr><th>Url</th><td><code>"+location.pathname+location.hash+"</code></td></tr>\n              <tr><th>UserAgent</th><td>"+navigator.userAgent+'</td></tr>\n              <tr><th>GitHub</th><td><a href="'+t.resolved.replace(/(\.git|\/commit\/).*/,"/issues/new")+'" target="_blank">Submit Issue (include the build details below)</a></td></tr>\n            </tbody>\n            </table>'},t.prototype.buildIssuesContent=function(){return"\nKey | Value\n--- | -----\nApplication | "+this.client.name+"\nVersion | ["+this.client.version+"]("+this.client.resolved+")"+(this.server?"\nServer | ["+this.server.version+"]("+this.server.resolved+")":"")+"\nUrl | `"+location.pathname+location.hash+"`\nUserAgent | "+navigator.userAgent+"\nPlatform | "+navigator.platform+"\nScreen Size | "+screen.width+" x "+screen.height+"\nWindow Size | "+window.innerWidth+" x "+window.innerHeight+"\n      \n~~~json\n"+JSON.stringify(this.client,null," ")+"\n"+(this.server?"\n"+JSON.stringify(this.server,null," ")+"\n":"")+"~~~"},t.prototype.toHTML=function(){return"\n      <h4>Build Info</h4>\n      "+this.buildBuildInfo()+'\n      <h4>Build Details</h4>\n      <textarea readonly="readonly">'+this.buildIssuesContent()+"</textarea>\n    "},t}()},function(t,e,n){"use strict";function r(t,e,n){void 0===n&&(n="#");var r=document.createElement("li");return r.innerHTML='<a href="'+n+'">'+t+"</a>",e&&(r.querySelector("a").onclick=e),r}function i(t,e){return void 0===e&&(e={}),new v(t,e)}function o(t,e){n.i(p.a)().then(function(t){e.innerHTML=t.toHTML()}).catch(function(t){e.innerHTML=t.toString()})}function a(t,e){e=e.querySelector(".metaData"),n.i(d.a)().then(function(n){t.innerHTML=(n.displayName||n.name).replace("_"," ");var r='<p class="description">'+n.description+"</p>";n.homepage&&(r+='<p class="homepage"><strong>Homepage</strong>: <a href="'+n.homepage+'" target="_blank" rel="noopener">'+n.homepage+"</a></p>"),r+='<p class="version"><strong>Version</strong>: '+n.version+"</p>",n.screenshot&&(r+='<img src="'+n.screenshot+'" class="center-block img-responsive img-thumbnail"/>'),e.innerHTML=r})}function s(t,e){e.innerHTML="No options available"}var u=n(18),l=(n(26),n(34)),c=(n.n(l),n(49)),f=(n.n(c),n(1)),h=n(27),p=n(28),d=n(30);n.d(e,"b",function(){return g}),e.a=i;var g=function(){function t(t,e,n,r){void 0===t&&(t="Phovea"),void 0===e&&(e=function(t){return!1}),void 0===n&&(n="#"),void 0===r&&(r=!0),this.name=t,this.action=e,this.href=n,this.addLogo=r}return t}(),v=function(){function t(t,e){void 0===e&&(e={}),this.parent=t,this.options={prepend:!0,inverse:!1,appLink:new g,mainMenu:[],rightMenu:[],showOptionsLink:!1,showReportBugLink:!0,showCookieDisclaimer:!1,showHelpLink:!1},n.i(f.b)(this.options,e),this.addEUCookieDisclaimer(),this.build()}return t.prototype.addEUCookieDisclaimer=function(){if(this.options.showCookieDisclaimer){var t=document.createElement("script");t.type="text/javascript",t.async=!0,t.src="https://cdn.jsdelivr.net/npm/cookie-bar/cookiebar-latest.min.js?theme=flying",t.onload=function(){setupCookieBar()},this.parent.ownerDocument.body.appendChild(t)}},t.prototype.build=function(){return u.a(this,void 0,void 0,function(){var t,e,n=this;return u.b(this,function(r){for(void 0!==this.options.app&&void 0===this.options.appLink&&(this.options.appLink.name=this.options.app),void 0!==this.options.addLogo&&void 0===!this.options.appLink&&(this.options.appLink.addLogo=this.options.addLogo),t=document.createElement("div"),t.innerHTML=String(c);t.lastChild;)this.parent.insertBefore(t.lastChild,this.parent.firstChild);return this.options.inverse&&this.parent.querySelector("nav.navbar").classList.add("navbar-inverse"),e=this.parent.querySelector('*[data-header="appLink"]'),e.innerHTML=this.options.appLink.name,e.onclick=this.options.appLink.action,e.setAttribute("href",this.options.appLink.href),this.options.appLink.addLogo&&e.classList.add("caleydo_app"),this.mainMenu=this.parent.querySelector('*[data-header="mainMenu"]'),this.rightMenu=this.parent.querySelector('*[data-header="rightMenu"]'),this.aboutDialog=this.parent.querySelector('*[data-header="about"]'),this.optionsDialog=this.parent.querySelector('*[data-header="options"]'),this.toggleOptionsLink(!1!==this.options.showOptionsLink,"function"==typeof this.options.showOptionsLink?this.options.showOptionsLink:null),this.toggleAboutLink(!1!==this.options.showAboutLink,"function"==typeof this.options.showAboutLink?this.options.showAboutLink:null),this.toggleReportBugLink(!1!==this.options.showReportBugLink,"function"==typeof this.options.showReportBugLink?this.options.showReportBugLink:null),this.toggleHelpLink(!1!==this.options.showHelpLink,"string"==typeof this.options.showHelpLink?this.options.showHelpLink:null),this.options.mainMenu.forEach(function(t){return n.addMainMenu(t.name,t.action,t.href)}),this.options.rightMenu.forEach(function(t){return n.addRightMenu(t.name,t.action,t.href)}),[2]})})},t.prototype.addMainMenu=function(t,e,n){void 0===n&&(n="#");var i=r(t,e,n);return this.mainMenu.appendChild(i),i},t.prototype.addRightMenu=function(t,e,n){void 0===n&&(n="#");var i=r(t,e,n);return this.rightMenu.insertBefore(i,this.rightMenu.firstChild),i},t.prototype.insertCustomMenu=function(t){this.rightMenu.parentElement.insertBefore(t,this.rightMenu)},t.prototype.insertCustomRightMenu=function(t){this.rightMenu.parentElement.appendChild(t)},t.prototype.wait=function(){t.setVisibility(document.querySelector("#headerWaitingOverlay"),!0)},t.prototype.ready=function(){t.setVisibility(document.querySelector("#headerWaitingOverlay"),!1)},t.setVisibility=function(t,e){t.classList.toggle("hidden",!e)},t.prototype.toggleOptionsLink=function(e,r){var i=this,o=this.parent.querySelector('*[data-header="optionsLink"]');t.setVisibility(o,e),e&&(r=r||s,n.i(h.a)().then(function(t){t("#headerOptionsDialog").one("show.bs.modal",function(){var t=i.parent.querySelector('*[data-header="options"]'),e=i.parent.querySelector("#headerOptionsDialog .modal-title");t.innerHTML="Loading...",r(e,t)})}))},t.prototype.toggleHelpLink=function(e,n){var r=this.parent.querySelector('*[data-header="helpLink"]');t.setVisibility(r,e),e&&n&&(r.querySelector("a").href=n)},t.prototype.toggleReportBugLink=function(e,r){var i=this,a=this.parent.querySelector('*[data-header="bugLink"]');t.setVisibility(a,e),e&&(r=r||o,n.i(h.a)().then(function(t){t("#headerReportBugDialog").one("show.bs.modal",function(){var t=i.parent.querySelector('*[data-header="bug"]'),e=i.parent.querySelector("#headerReportBugDialog .modal-title");t.innerHTML="Loading...",r(e,t)})}))},t.prototype.toggleAboutLink=function(e,n){var r=this,i=this.parent.querySelector('*[data-header="aboutLink"]');if(t.setVisibility(i,e),e){n=n||a;var o=function(){var t=r.aboutDialog,e=r.aboutDialog.parentElement.querySelector(".modal-title");n(e,t),i.removeEventListener("click",o)};i.addEventListener("click",o)}},t.prototype.hideDialog=function(t){n.i(h.a)().then(function(e){e(t).modal("hide")})},t.prototype.showAndFocusOn=function(t,e){n.i(h.a)().then(function(n){n(t).modal("show").on("shown.bs.modal",function(){n(e,t).focus()})})},t}()},function(t,e,n){"use strict";function r(){return null===i&&(i=self.fetch("./phoveaMetaData.json").then(function(t){return t.json()}).catch(function(t){return console.warn("cannot read phoveaMetaData.json file, generate dummy"),{name:"Phovea Application",version:"?",repository:"?",homepage:"",description:"Fallback appication meta data"}})),i}e.a=r;var i=null},function(t,e,n){"use strict";function r(t){return new u(t)}var i=n(2),o=n(15),a=(n.n(o),n(3)),s=n(16);e.a=r;var u=function(){function t(t){this.views=[{view:"DataSetSelector",parent:"selector",options:{}},{view:"ConfusionMatrix",parent:"conf-matrix-wrapper",options:{eventName:""}},{view:"TimelineView",parent:"timeline-wrapper",options:{eventName:""}},{view:"DetailChart",parent:"details-wrapper",options:{eventName:""}},{view:"ToolbarView",parent:"toolbar-wrapper",options:{eventName:""}},{view:"ConfusionMeasuresView",parent:"conf-measure-table-wrapper",options:{eventName:""}}],this.$node=o.select(t);var e=this.$node.append("main").classed("main-wrapper",!0);e.append("div").classed("timeline-wrapper",!0),e.append("div").classed("toolbar-wrapper",!0),e.append("div").classed("conf-matrix-wrapper",!0),e.append("div").classed("conf-measure-table-wrapper",!0),e.append("div").classed("details-wrapper",!0)}return t.prototype.init=function(){return this.attachListener(),this.build()},t.prototype.attachListener=function(){window.addEventListener("resize",function(){a.a(s.a.EVENT_RESIZE)})},t.prototype.build=function(){var t=this,e=this.views.map(function(t){return i.a(s.a.VIEW,t.view)}).filter(function(t){return void 0!==t}).map(function(t){return t.load()});return Promise.all(e).then(function(e){t.$node.select("h3").remove();var n=e.map(function(e,n){return e.factory(t.$node.select("."+t.views[n].parent).node(),t.views[n].options||{}).init()});return Promise.all(n)}).then(function(e){return t})},t}()},function(t,e,n){"use strict";var r=n(37),i=(n.n(r),n(38)),o=(n.n(i),n(39)),a=(n.n(o),n(40)),s=(n.n(a),n(43)),u=(n.n(s),n(41)),l=(n.n(u),n(42)),c=(n.n(l),n(45)),f=(n.n(c),n(47)),h=(n.n(f),n(48));n.n(h)},function(t,e){},function(t,e){},function(t,e){},function(t,e,n){t.exports=n.p+"404.html-loader"},function(t,e,n){t.exports=n.p+"android-chrome-192x192.png"},function(t,e,n){t.exports=n.p+"android-chrome-384x384.png"},function(t,e,n){t.exports=n.p+"apple-touch-icon.png"},function(t,e,n){t.exports=n.p+"browserconfig.xml"},function(t,e,n){t.exports=n.p+"favicon-16x16.png"},function(t,e,n){t.exports=n.p+"favicon-32x32.png"},function(t,e,n){t.exports=n.p+"favicon.ico"},function(t,e,n){t.exports=n.p+"index.html"},function(t,e,n){t.exports=n.p+"mstile-150x150.png"},function(t,e,n){t.exports=n.p+"robots.txt"},function(t,e,n){t.exports=n.p+"safari-pinned-tab.svg"},function(t,e,n){t.exports=n.p+"site.webmanifest"},function(t,e,n){t.exports='<nav class=navbar> <div class=navbar-header> <button type=button class=navbar-toggle data-toggle=collapse data-target=#headerNavBar> <span class=icon-bar></span> <span class=icon-bar></span> <span class=icon-bar></span> </button> <a class=navbar-brand href=# data-header=appLink></a> </div> <div class="collapse navbar-collapse"> <ul class="nav navbar-nav" data-header=mainMenu> </ul> <ul class="nav navbar-nav navbar-right" data-header=rightMenu> <li class=hidden data-header=optionsLink> <a href=# data-toggle=modal data-target=#headerOptionsDialog title=Options> <i class="fa fa-cog fa-fw" aria-hidden=true></i> <span class=sr-only>Open options dialog</span> </a> </li> <li class=hidden data-header=aboutLink> <a href=# data-toggle=modal data-target=#headerAboutDialog title=About> <i class="fa fa-info fa-fw" aria-hidden=true></i> <span class=sr-only>Open about dialog</span> </a> </li> <li class=hidden data-header=bugLink> <a href=# data-toggle=modal data-target=#headerReportBugDialog title="Report a bug"> <i class="fa fa-bug fa-fw" aria-hidden=true></i> <span class=sr-only>Report bug</span> </a> </li> <li class=hidden data-header=helpLink> <a href=//caleydo.org target=_blank title="Open help page"> <i class="fa fa-question fa-fw" aria-hidden=true></i> <span class=sr-only>Open help page</span> </a> </li> </ul> </div> </nav> <div class="modal fade" id=headerAboutDialog tabindex=-1 role=dialog> <div class=modal-dialog role=document> <div class=modal-content> <div class=modal-header> <button type=button class=close data-dismiss=modal aria-label=Close> <span aria-hidden=true>&times;</span> </button> <h4 class=modal-title>About</h4> </div> <div class=modal-body data-header=about> <div class=metaData>Loading ...</div> <div class=caleydoInfo> <a class=logo href=https://phovea.caleydo.org target=_blank><img src='+n(54)+'></a> <p class=info> This application is part of <strong><a href=http://phovea.caleydo.org/ target=_blank>Phovea</a></strong>, a platform for developing web-based visualization applications. For tutorials, API docs, and more information about the build and deployment process, see the <a href=http://phovea.caleydo.org target=_blank>documentation page</a>. </p> </div> </div> </div> </div> </div> <div class="modal fade" id=headerReportBugDialog tabindex=-1 role=dialog> <div class=modal-dialog role=document> <div class=modal-content> <div class=modal-header> <button type=button class=close data-dismiss=modal aria-label=Close> <span aria-hidden=true>&times;</span> </button> <h4 class=modal-title>Report a bug</h4> </div> <div class=modal-body data-header=bug> Loading... </div> </div> </div> </div> <div class="modal fade" id=headerOptionsDialog tabindex=-1 role=dialog> <div class=modal-dialog role=document> <div class=modal-content> <div class=modal-header> <button type=button class=close data-dismiss=modal aria-label=Close> <span aria-hidden=true>&times;</span> </button> <h4 class=modal-title>Options</h4> </div> <div class=modal-body data-header=options> Loading... </div> </div> </div> </div> <div id=headerWaitingOverlay class="phovea-busy hidden"> </div> '},function(t,e,n){t.exports=function(t){t.push("datatype","matrix",function(){return n.e(6).then(n.bind(null,56))},{}),t.push("datatype","table",function(){return n.e(7).then(n.bind(null,57))},{}),t.push("datatype","vector",function(){return n.e(9).then(n.bind(null,62))},{}),t.push("datatype","stratification",function(){return n.e(8).then(n.bind(null,60))},{}),t.push("datatype","graph",function(){return n.e(10).then(n.bind(null,59))},{}),t.push("datatype","atom",function(){return n.e(11).then(n.bind(null,58))},{}),t.push("tabSyncer","selection",function(){return n.e(12).then(n.bind(null,61))},{})}},function(t,e){t.exports=function(t){}},function(t,e,n){"use strict";var r=n(2);n(9);n.i(r.b)("phovea_ui",n(51))},function(t,e,n){t.exports=function(t){t.push("malevoView","ConfusionMatrix",function(){return n.e(1).then(n.bind(null,63))},{name:"Confusion Matrix"}),t.push("malevoView","DataSetSelector",function(){return n.e(0).then(n.bind(null,64))},{name:"Data Set Selector"}),t.push("malevoView","TimelineView",function(){return n.e(3).then(n.bind(null,67))},{name:"TimelineView"}),t.push("malevoView","ToolbarView",function(){return n.e(4).then(n.bind(null,68))},{name:"ToolbarView"}),t.push("malevoView","DetailChart",function(){return n.e(5).then(n.bind(null,66))},{name:"DetailChart",isDetailWindow:!0,order:10}),t.push("malevoView","ConfusionMeasuresView",function(){return n.e(2).then(n.bind(null,65))},{name:"ConfusionMeasuresView"})}},function(t,e){t.exports="data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4KPCFET0NUWVBFIHN2ZyBQVUJMSUMgIi0vL1czQy8vRFREIFNWRyAxLjEvL0VOIiAiaHR0cDovL3d3dy53My5vcmcvR3JhcGhpY3MvU1ZHLzEuMS9EVEQvc3ZnMTEuZHRkIj4KPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeD0iMHB4IiB5PSIwcHgiCgkgd2lkdGg9IjEyMC41MjJweCIgaGVpZ2h0PSIxMzguOTQ0cHgiIHZpZXdCb3g9IjAgMCAxMjAuNTIyIDEzOC45NDQiCgkgeG1sOnNwYWNlPSJwcmVzZXJ2ZSI+Cjxwb2x5Z29uIGZpbGw9IiMxMEFDREYiIHBvaW50cz0iNjMuMTY2LDEzOC45NDYgMTIwLjMzLDEwNS45NDIgNjMuMTY2LDcyLjkzNyAJIi8+Cjxwb2x5Z29uIGZpbGw9IiMxQkE2NEUiIHBvaW50cz0iNTkuMTY0LDcyLjkzNyAyLDEwNS45NDIgNTkuMTY0LDEzOC45NDQgCSIvPgo8cG9seWdvbiBmaWxsPSIjRkFCQzE1IiBwb2ludHM9IjU3LjE2NCw2OS40NzIgMCwzNi40NjggMCwxMDIuNDc4IAkiLz4KPHBvbHlnb24gZmlsbD0iI0Y0N0QyMCIgcG9pbnRzPSI1OS4xNjQsMCAyLDMzLjAwMyA1OS4xNjQsNjYuMDA3IAkiLz4KPHBvbHlnb24gZmlsbD0iI0VFMjMyOSIgcG9pbnRzPSI2My4xNjYsNjYuMDA4IDEyMC4zMywzMy4wMDQgNjMuMTY2LDAgCSIvPgo8L3N2Zz4K"},function(t,e,n){n(14),n(12),n(13),t.exports=n(11)}],[55]);